% File src/library/base/man/Comparison.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{Comparison}
\alias{<}
\alias{<=}
\alias{==}
\alias{!=}
\alias{>=}
\alias{>}
\alias{Comparison}
\alias{collation}
\title{Relational Operators}
\description{
  原子的なベクトル中の値の比較を行う二項演算子．
}
\usage{
x < y
x > y
x <= y
x >= y
x == y
x != y
}
\arguments{
  \item{x, y}{原子的ベクトル，シンボル，呼び出し，もしくは
  メソッドが書かれている他のオブジェクト．}
}
\details{
  二項比較演算子は総称的関数である：メソッドを
  \code{\link[=S3groupGeneric]{Ops}}) グループ総称的関数経由で書くことが出来る．
  (選択適用がどのように計算されるかについては
  \code{\link[=S3groupGeneric]{Ops}} を見よ．)

  文字列ベクトル中の文字列の比較は使用中のロケールの照合用系列を用いて
  辞書式に行われる：\code{\link{locales}} を見よ．
  \samp{en_US} のような照合用系列は通常 \samp{C} と異なる
  (これは ASCII を使う)．そして驚くようなことが起き得る．
  照合順序については \emph{any} 仮定を置くように注意しよう：
  例えばエストニア語の \code{Z} は \code{S} と \code{T} の間に来るし，
  照合は必ずしも文字毎ではない -- デンマーク語では \code{aa} は単一
  文字として \code{Z} の後にソートされる．ウェールズ語では
  \code{ng} は単一のソート単位であったりなかったりする：もしそうなら
  それは \code{g} に続く．ある種のプラットフォームはロケールを
  無視し，常に8ビットロケールや UTF-8 ロケールでのバイトの数値的順序で
  ソートする(そして異なった文字セットでは同一の言語に対し同じ順序で
  ソートしなかったりする)．非文字(空白，句読点，ハイフン，分数記号等)
  はより一層混乱している．

  文字列は異なったマークエンコーディングを使って比較できる
  (\code{\link{Encoding}} を見よ): それらは比較前に UTF-8 に変換される．
  
  バイト(raw)ベクトルは実際には順序を持つとは考えられないが，
  バイト表現の数値的順序が使われる．

  少なくとも \code{x} と \code{y} の一方が原子的ベクトルである必要があるが，
  もし他方がリストであれば \R はそれを原子的ベクトル型に強制変換する：
  これはもしリストが長さが1で正しい型に強制変換可能な要素からなっている際は
  うまく行くだろう．

  もし二つの引数が異なった型の原子的ベクトルならば，一方が他の型に強制変換される．
  (逆方向の)優先順位は文字，複素数，数値，整数，論理値，そしてバイト型である．

  欠損値 (\code{\link{NA}}) と \code{\link{NaN}} は自分自身とさえ
  比較不能と見做されるので，それらを含む比較は \code{NA} を生じる．
  欠損値はまた文字列比較で一方が現在のロケールで不正の時にも生じる．

  シンボルや呼び出しのような言語オブジェクトは比較前に文字列に逆構文解析される．
}
\value{
  要素ごとの比較結果を示す論理値ベクトル．
  短い方のベクトルの要素は必要に応じリサイクルされる．
  
  配列や時系列等のオブジェクトは比較可能である限りこのようにして比較される．
}
\note{
  単一の \code{TRUE} や \code{FALSE} が必要とされる \code{if} 構文に
  於けるように，検査に \code{==} と \code{!=} を使用しない．
  完全に確実でない限り代わりに \code{\link{identical}} 関数を使うべきである．

  数値や複素数値に対しては，\code{==} と \code{!=} は分数の有限表現も
  丸め誤差も許容しないことを忘れない．\code{identical} と共に使われる
  \code{\link{all.equal}} がほとんどすべての場合に好ましい．
  以下の例を見よ．(このことは他の比較演算子にも当てはまる．)
  
  これらの演算子は時折，例えば \sspace{}\code{`<`(x, y)} のような
  関数形で使われる： \code{\link[base]{Ops}} 中で引数の照合が
  どのようになされるかの記述を見よ．
}
\section{S4 メソッド}{
  これらの演算子は S4 \code{\link{Compare}} グループ総称的関数の
  メンバーであり，それらに対するメソッドを，引数 \code{c(e1, e2)} を
  用いて，個別にまたグループ総称的
  (もしくは \code{Ops} グループ総称的)に書くことが出来る．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  文字列の照合は複雑なトピックである．入門には
  \url{https://en.wikipedia.org/wiki/Collating_sequence} を見よ．
  \emph{Unicode 照合アルゴリズム}
  (\url{http://unicode.org/reports/tr10/}) はますます影響度を増して
  行くであろう．もし利用可能なら \R は既定で ICU 照合
  (\url{http://site.icu-project.org/}) を用いる(C ロケール中を除く)．
}
\seealso{
  因子引数の挙動については \code{\link{factor}}．

  演算子の優先順序については \code{\link{Syntax}}．

  ICU の利用可能性については \code{\link{capabilities}} を，
  そしてその時の文字列照合アルゴリズムのチューニングについては 
  \code{\link{icuSetCollate}}．
  }
\examples{
x <- stats::rnorm(20)
x < 1
x[x > 0]

x1 <- 0.5 - 0.3
x2 <- 0.3 - 0.1
x1 == x2                           # 殆どの機械で FALSE
identical(all.equal(x1, x2), TRUE) # いつでも TRUE

\donttest{
# 殆どの8ビット文字セットと Unicode の Latin-1 の範囲
z <- c(32:126, 160:255)
x <- if(l10n_info()$MBCS) {
    intToUtf8(z, multiple = TRUE)
} else rawToChar(as.raw(z), multiple = TRUE)
## 番号による
writeLines(strwrap(paste(x, collapse=" "), width = 60))
## ロケール照合による
writeLines(strwrap(paste(sort(x), collapse=" "), width = 60))
}}
\keyword{logic}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/Comparison.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Comparison}
%\alias{<}
%\alias{<=}
%\alias{==}
%\alias{!=}
%\alias{>=}
%\alias{>}
%\alias{Comparison}
%\alias{collation}
%\title{Relational Operators}
%\description{
%  Binary operators which allow the comparison of values in atomic vectors.
%}
%\usage{
%x < y
%x > y
%x <= y
%x >= y
%x == y
%x != y
%}
%\arguments{
%  \item{x, y}{atomic vectors, symbols, calls, or other objects for which
%    methods have been written.}
%}
%\details{
%  The binary comparison operators are generic functions: methods can be
%  written for them individually or via the
%  \code{\link[=S3groupGeneric]{Ops}}) group generic function.  (See
%  \code{\link[=S3groupGeneric]{Ops}} for how dispatch is computed.)
%
%  Comparison of strings in character vectors is lexicographic within the
%  strings using the collating sequence of the locale in use: see
%  \code{\link{locales}}.  The collating sequence of locales such as
%  \samp{en_US} is normally different from \samp{C} (which should use
%  ASCII) and can be surprising.  Beware of making \emph{any} assumptions
%  about the collation order: e.g.\sspace{}in Estonian \code{Z} comes between
%  \code{S} and \code{T}, and collation is not necessarily
%  character-by-character -- in Danish \code{aa} sorts as a single
%  letter, after \code{z}.  In Welsh \code{ng} may or may not be a single
%  sorting unit: if it is it follows \code{g}.  Some platforms may
%  not respect the locale and always sort in numerical order of the bytes
%  in an 8-bit locale, or in Unicode code-point order for a UTF-8 locale (and
%  may not sort in the same order for the same language in different
%  character sets).  Collation of non-letters (spaces, punctuation signs,
%  hyphens, fractions and so on) is even more problematic.
%
%  Character strings can be compared  with different marked encodings
%  (see \code{\link{Encoding}}): they are translated to UTF-8 before
%  comparison.
%
%  Raw vectors should not really be considered to have an order, but the
%  numeric order of the byte representation is used.
%
%  At least one of \code{x} and \code{y} must be an atomic vector, but if
%  the other is a list \R attempts to coerce it to the type of the atomic
%  vector: this will succeed if the list is made up of elements of length
%  one that can be coerced to the correct type.
%
%  If the two arguments are atomic vectors of different types, one is
%  coerced to the type of the other, the (decreasing) order of precedence
%  being character, complex, numeric, integer, logical and raw.
%
%  Missing values (\code{\link{NA}}) and \code{\link{NaN}} values are
%  regarded as non-comparable even to themselves, so comparisons
%  involving them will always result in \code{NA}.  Missing values can
%  also result when character strings are compared and one is not valid
%  in the current collation locale.
%
%  Language objects such as symbols and calls are deparsed to
%  character strings before comparison.
%}
%\value{
%  A logical vector indicating the result of the element by element
%  comparison.  The elements of shorter vectors are recycled as
%  necessary.
%
%  Objects such as arrays or time-series can be compared this way
%  provided they are conformable.
%}
%\note{
%  Do not use \code{==} and \code{!=} for tests, such as in \code{if}
%  expressions, where you must get a single \code{TRUE} or
%  \code{FALSE}.  Unless you are absolutely sure that nothing unusual
%  can happen, you should use the \code{\link{identical}} function
%  instead.
%
%  For numerical and complex values, remember \code{==} and \code{!=} do
%  not allow for the finite representation of fractions, nor for rounding
%  error.  Using \code{\link{all.equal}} with \code{identical} is almost
%  always preferable.  See the examples.  (This also applies to the other
%  comparison operators.)
%  
%  These operators are sometimes called as functions as
%  e.g.\sspace{}\code{`<`(x, y)}: see the description of how
%  argument-matching is done in \code{\link[base]{Ops}}.
%}
%\section{S4 methods}{
%  These operators are members of the S4 \code{\link{Compare}} group generic,
%  and so methods can be written for them individually as well as for the
%  group generic (or the \code{Ops} group generic), with arguments
%  \code{c(e1, e2)}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Collation of character strings is a complex topic.  For an
%  introduction see
%  \url{https://en.wikipedia.org/wiki/Collating_sequence}.  The
%  \emph{Unicode Collation Algorithm}
%  (\url{http://unicode.org/reports/tr10/}) is likely to be increasingly
%  influential.  Where available \R by default makes use of ICU
%  (\url{http://site.icu-project.org/}) for collation (except in a C
%  locale).
%}
%\seealso{
%  \code{\link{factor}} for the behaviour with factor arguments.
%
%  \code{\link{Syntax}} for operator precedence.
%
%  \code{\link{capabilities}} for whether ICU is available, and
%  \code{\link{icuSetCollate}} to tune the string collation algorithm
%  when it is.
%}
%\examples{
%x <- stats::rnorm(20)
%x < 1
%x[x > 0]
%
%x1 <- 0.5 - 0.3
%x2 <- 0.3 - 0.1
%x1 == x2                           # FALSE on most machines
%identical(all.equal(x1, x2), TRUE) # TRUE everywhere
%
%\donttest{
%# range of most 8-bit charsets, as well as of Latin-1 in Unicode
%z <- c(32:126, 160:255)
%x <- if(l10n_info()$MBCS) {
%    intToUtf8(z, multiple = TRUE)
%} else rawToChar(as.raw(z), multiple = TRUE)
%## by number
%writeLines(strwrap(paste(x, collapse=" "), width = 60))
%## by locale collation
%writeLines(strwrap(paste(sort(x), collapse=" "), width = 60))
%}}
%\keyword{logic}
%
\encoding{UTF8}
