% File src/library/base/man/Hyperbolic.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{Hyperbolic}
\title{Hyperbolic Functions}
\usage{
cosh(x)
sinh(x)
tanh(x)
acosh(x)
asinh(x)
atanh(x)
}
\alias{cosh}
\alias{sinh}
\alias{tanh}
\alias{acosh}
\alias{asinh}
\alias{atanh}
\description{
これらの関数はよく知られた双曲線関数を与える．これらは順に
hyperbolic cosine, sine, tangent そしてそれらの逆関数 
arc-cosine, arc-sine, arc-tangent (または \sQuote{\emph{area cosine}},
等)．
}
\arguments{
   \item{x}{数値もしくは複素数値ベクトル}
}
\details{
これらは内部総称的なプリミティブ関数である：それらに対するメソッドを
個別に，もしくは \code{\link[=S3groupGeneric]{Math}} グループ総称経由で
定義できる．

ブランチのカットは逆三角関数
 \code{asin} 等と両立し，Abramowitz and Stegun, figure 4.7, page 86 で
定義されているものと一致する．このカット上の実際の挙動は 
C99 標準に従い，逆時計回りに端点を連続に廻ることを要求する．
}
\section{S4 メソッド}{
全ては S4 総称的関数である：それらに対するメソッドを
個別に，もしくは \code{\link[=S4groupGeneric]{Math}} グループ総称経由で
定義できる．
}
\seealso{
三角関数 \code{\link{cos}}, \code{\link{sin}},
  \code{\link{tan}}，そしてそれらの逆関数 
  \code{\link{acos}}, \code{\link{asin}}, \code{\link{atan}}．

ロジスティック分布関数 \code{\link{plogis}} は数値 \code{x}
に対する \code{tanh()} のシフト版である．
}
\references{
  Abramowitz, M. and Stegun, I. A. (1972)
  \emph{Handbook of Mathematical Functions.} New York: Dover.\cr
  Chapter 4. Elementary Transcendental Functions: Logarithmic,
  Exponential, Circular and Hyperbolic Functions
}
\keyword{math}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/Hyperbolic.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Hyperbolic}
%\title{Hyperbolic Functions}
%\usage{
%cosh(x)
%sinh(x)
%tanh(x)
%acosh(x)
%asinh(x)
%atanh(x)
%}
%\alias{cosh}
%\alias{sinh}
%\alias{tanh}
%\alias{acosh}
%\alias{asinh}
%\alias{atanh}
%\description{
%  These functions give the obvious hyperbolic functions.  They
%  respectively compute the hyperbolic cosine, sine, tangent, and their
%  inverses, arc-cosine, arc-sine, arc-tangent (or \sQuote{\emph{area cosine}},
%  etc).
%}
%\arguments{
%   \item{x}{a numeric or complex vector}
%}
%\details{
%   These are \link{internal generic} \link{primitive} functions: methods
%   can be defined for them individually or via the
%   \code{\link[=S3groupGeneric]{Math}} group generic.
%
%   Branch cuts are consistent with the inverse trigonometric functions
%   \code{asin} \emph{et seq}, and agree with those defined in Abramowitz
%   and Stegun, figure 4.7, page 86.   The behaviour actually on the cuts
%   follows the C99 standard which requires continuity coming round the
%   endpoint in a counter-clockwise direction.
%}
%\section{S4 methods}{
%  All are S4 generic functions: methods can be defined
%  for them individually or via the
%  \code{\link[=S4groupGeneric]{Math}} group generic.
%}
%\seealso{
%  The trigonometric functions, \code{\link{cos}}, \code{\link{sin}},
%  \code{\link{tan}}, and their inverses
%  \code{\link{acos}}, \code{\link{asin}}, \code{\link{atan}}.
%
%  The logistic distribution function \code{\link{plogis}} is a shifted
%  version of \code{tanh()} for numeric \code{x}.
%}
%\references{
%  Abramowitz, M. and Stegun, I. A. (1972)
%  \emph{Handbook of Mathematical Functions.} New York: Dover.\cr
%  Chapter 4. Elementary Transcendental Functions: Logarithmic,
%  Exponential, Circular and Hyperbolic Functions
%}
%\keyword{math}
%
\encoding{UTF8}
