% File src/library/base/man/all.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2010 R Core Team
% Distributed under GPL 2 or later

\name{all}
\title{Are All Values True?}
\usage{
all(\dots, na.rm = FALSE)
}
\alias{all}
\description{
すべての値が真かどうかを示す論理値ベクトルのセットを返す．
}
\arguments{
  \item{\dots}{ゼロ以上の論理値ベクトル．長さゼロの他のオブジェクトは無視される．
  そして残りはすべてのクラスを無視して論理値に強制変換される．}
  \item{na.rm}{論理値．もし真なら値 \code{NA} は結果が計算される前に取り除かれる．}
}
\details{
  これは総称的関数である：それに対するメソッドを直接または 
 \code{\link[=S3groupGeneric]{Summary}} グループ総称経由で書くことが出来る．
これが適切に動作するためには，引数 \code{\dots} は名前無しで，選択適用は最初の引数
についてである必要がある．

整数以外の型 (バイト，倍精度実数，複素数値，文字列，リスト)への変換は
しばしば想定外であるので警告が出る．

  これはプリミティブな関数である．
}
\value{
  値は長さ1の論理値ベクトルである．

  \code{x} を(強制変換後の) \code{...} 中のすべての論理値ベクトルを結合したものとする．
もし \code{na.rm = TRUE} ならば \code{NA} は除かれる．

  返される値は，もし \code{x} 中のすべての値が 
  \code{TRUE} (値が一切無い場合を含む) ならば \code{TRUE} で，もし
一つでも \code{FLASE} ならば \code{FALSE} となる．さもなければ値は \code{NA} である
(これは \code{na.rm = FALSE} で \code{\dots} が \code{FALSE} 値を全く含まず，そして
少なくともひとつ \code{NA} 値を含む時だけ起こる)．
}
\note{
  \code{all(logical(0))} が真であることは便利な規約である：
  \code{x} が長さゼロであっても
\preformatted{all(all(x), all(y)) == all(x, y)}
が成り立つ．
}
\section{S4 メソッド}{
  これは S4 \code{\link[=S4groupGeneric]{Summary}} グループ総称的関数の
一部分である．それに対するメソッドはシグネチャ \code{x, \dots, na.rm} を使うべきである．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{any}} は \code{all} を補う．そして 
  \code{\link{stopifnot}(*)} は \code{all(*)} が成り立たない時の保険である．
}
\examples{
range(x <- sort(round(stats::rnorm(10) - 1.2, 1)))
if(all(x < 0)) cat("all x values are negative\n")

all(logical(0))  # 真，要素のすべてのゼロが真なので．
}
\keyword{logic}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/all.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2010 R Core Team
%% Distributed under GPL 2 or later
%
%\name{all}
%\title{Are All Values True?}
%\usage{
%all(\dots, na.rm = FALSE)
%}
%\alias{all}
%\description{
%  Given a set of logical vectors, are all of the values true?
%}
%\arguments{
%  \item{\dots}{zero or more logical vectors.  Other objects of zero
%    length are ignored, and the rest are coerced to logical ignoring
%    any class.}
%  \item{na.rm}{logical.  If true \code{NA} values are removed before
%    the result is computed.}
%}
%\details{
%  This is a generic function: methods can be defined for it
%  directly or via the \code{\link[=S3groupGeneric]{Summary}} group generic.
%  For this to work properly, the arguments \code{\dots} should be
%  unnamed, and dispatch is on the first argument.
%
%  Coercion of types other than integer (raw, double, complex, character,
%  list) gives a warning as this is often unintentional.
%
%  This is a \link{primitive} function.
%}
%\value{
%  The value is a logical vector of length one.
%
%  Let \code{x} denote the concatenation of all the logical vectors in
%  \code{...} (after coercion), after removing \code{NA}s if requested by
%  \code{na.rm = TRUE}.
%
%  The value returned is \code{TRUE} if all of the values in \code{x} are
%  \code{TRUE} (including if there are no values), and \code{FALSE} if at
%  least one of the values in \code{x} is \code{FALSE}.  Otherwise the
%  value is \code{NA} (which can only occur if \code{na.rm = FALSE} and
%  \code{\dots} contains no \code{FALSE} values and at least one
%  \code{NA} value).
%}
%\note{
%  That \code{all(logical(0))} is true is a useful convention:
%  it ensures that
%\preformatted{all(all(x), all(y)) == all(x, y)
%}
%  even if \code{x} has length zero.
%}
%\section{S4 methods}{
%  This is part of the S4 \code{\link[=S4groupGeneric]{Summary}}
%  group generic.  Methods for it must use the signature
%  \code{x, \dots, na.rm}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{any}}, the \sQuote{complement} of \code{all}, and
%  \code{\link{stopifnot}(*)} which is an \code{all(*)}
%  \sQuote{insurance}.
%}
%\examples{
%range(x <- sort(round(stats::rnorm(10) - 1.2, 1)))
%if(all(x < 0)) cat("all x values are negative\n")
%
%all(logical(0))  # true, as all zero of the elements are true.
%}
%\keyword{logic}
%
\encoding{UTF8}
