% File src/library/base/man/attach.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{attach}
\alias{attach}
\alias{.conflicts.OK}

\title{Attach Set of R Objects to Search Path}
\usage{
attach(what, pos = 2L, name = deparse(substitute(what)),
       warn.conflicts = TRUE)
}
\arguments{
  \item{what}{\sQuote{データベース}．これは
    \code{data.frame}，\code{list}，\code{\link{save}} で
作られた \R データファイル， \code{NULL}，もしくは環境でよい．
また\sQuote{詳細}を見よ．}
  \item{pos}{ \code{\link{search}()} で付加すべき位置を表す整数．}
  \item{name}{付加されるデータベースに対して使われる名前．
    \code{package:} で始まる名前は \code{\link{library}} 用に予約されている．}
  \item{warn.conflicts}{論理値．データベースがオブジェクト \code{.conflicts.OK} を
含まない限り，もし \code{TRUE} ならデータベースの付加による
衝突 \code{\link{conflicts}} に関して警告がプリントされる．
衝突とはある関数をマスクする関数や，非関数をマスクする非関数である．
  }
}
\description{
データベースは \R の検索パスに付加される．これは変数を評価する際に \R により
データベースが検索されることを意味し，このデータベース中のオブジェクトは
単にその名前を与えるだけでアクセス可能になる．
}
\details{
変数や関数名を評価する際，\R はその名前を \code{\link{search}} で
リストされるデータベース中で探す．適当なタイプの最初のものが使われる．

データフレーム(もしくはリスト)を検索パスに付加することで，
データフレーム中の変数を，データフレームの成分としてではなく，
それらの名前だけで参照することが可能になる
(例えば下の例の中では \code{women$height}) ではなく \code{height} で)．

既定ではデータベースは検索パス中の位置 2 に付加される．
これはユーザの作業空間の直後で以前に付加されたパッケージやデータベーズの
前になる．これは \code{pos} オプションを使って検索パスの後方位置に変更できるが，
 \code{pos = 1} に付加することはできない．

データベースは実際には付加されない．そうではなく，新しい環境が検索パス上に
作られ，リスト(データフレームの列を含む)の要素や，セーブされたファイルや
環境中のオブジェクトが新しい環境中にコピーされる．
もし付加されたデータベースに \code{\link{<<-}} や \code{\link{assign}} を
使って付値すると付加されたコピーが変更されるだけでオリジナルのオブジェクトは
未変更である．
(普通の付値は変更されたバージョンをユーザの作業空間中に置く：例を見よ．)
この理由から \code{attach} は混乱を招くことがある．

一つの有用な\sQuote{トリック}は新しい環境を検索パス上に
 \code{what = NULL} (または同値である長さゼロのリスト) を使って
作ることである．オブジェクトはこの中に 
 \code{\link{assign}}，\code{\link{load}} または \code{\link{sys.source}}
を使って付値することが出来る．

\code{"package:"} で始まる名前は \code{\link{library}} 用に予約されており，
末端ユーザは使うべきではない．付加されたファイルは既定では名前 
 \code{file:\var{what}} を与えられる．付加された環境に対する与えられた 
 \code{name} 引数は \code{\link{search}} によって使うことができ，
 \code{\link{as.environment}} への引数として使うことが出来る．

クラス \code{"UserDefinedDatabase"} のユーザ定義の表オブジェクトを付加する
フックが有り，Omegahat パッケージ \pkg{RObjectTables} でサポートされている．
\url{http://www.omegahat.org/RObjectTables/} を見よ．
}

\value{
  \code{"name"} 属性を持つ \code{\link{environment}} が不可視で返される．
}

\section{良い作法}{
  \code{attach} は検索パスを変更するという副作用を持ち，
特定の名前を持つ間違ったオブジェクトが見つかるということに
つながりやすい．人はしばしばデータベースを \code{\link{detach}} することを
忘れる．

対話的な使用では \code{\link{with}} が通常 \code{attach}/\code{detach} よりも
好ましい．例外は \code{what} が \code{\link{save}()} で作られたファイルの場合で，
その時は \code{attach()} が \code{\link{load}()} に対する(安全な)ラッパである．

プログラミングでは，関数はそれが目的である場合を除いて検索パスを
変更すべきではない．しばしば関数内部で \code{\link{with}} を使うことが出来る．
もしそうでなければ，良い作法は
  \itemize{
    \item 常に異なった \code{name} 引数を使い，そして
    \item \code{attach} のすぐ後に違いがわかりやすい名前を用いた
 \code{detach} への \code{\link{on.exit}} 呼び出しを続けることである．
   }
  これはもし関数が中断されたり，\code{attach} 呼び出しの後の
コードが検索パスを変更しても検索パスが未変更のままになることを保証する．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{library}}, \code{\link{detach}}, \code{\link{search}},
  \code{\link{objects}}, \code{\link{environment}}, \code{\link{with}}.
}
\examples{
require(utils)

summary(women$height)   # データフレーム中の変数 'height' を参照
attach(women)
summary(height)         # 同じ変数が今や名前で利用できる
height <- height*2.54   # これをしない，新しい変数が
                        # ユーザの作業空間に作られる
find("height")
summary(height)         # 作業空間中の新しい変数
rm(height)
summary(height)         # 元の変数
height <<- height*25.4  # 付加された環境中のコピーを変更
find("height")
summary(height)         # 変更されたコピー
detach("women")
summary(women$height)   # 未変更

\dontrun{## 検索パスに環境を生成し中身を登録
sys.source("myfuns.R", envir = attach(NULL, name = "myfuns"))
}}
\keyword{data}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/attach.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{attach}
%\alias{attach}
%\alias{.conflicts.OK}
%
%\title{Attach Set of R Objects to Search Path}
%\usage{
%attach(what, pos = 2L, name = deparse(substitute(what)),
%       warn.conflicts = TRUE)
%}
%\arguments{
%  \item{what}{\sQuote{database}.  This can be a
%    \code{data.frame} or a \code{list} or a \R data file created with
%    \code{\link{save}} or \code{NULL} or an environment.  See also
%    \sQuote{Details}.}
%  \item{pos}{integer specifying position in \code{\link{search}()} where
%    to attach.}
%  \item{name}{name to use for the attached database. Names starting with
%    \code{package:} are reserved for \code{\link{library}}.}
%  \item{warn.conflicts}{logical.  If \code{TRUE}, warnings are
%    printed about \code{\link{conflicts}} from attaching the database,
%    unless that database contains an object \code{.conflicts.OK}.  A
%    conflict is a function masking a function, or a non-function masking
%    a non-function.
%  }
%}
%\description{
%  The database is attached to the \R search path.  This means that the
%  database is searched by \R when evaluating a variable, so objects in
%  the database can be accessed by simply giving their names.
%}
%\details{
%  When evaluating a variable or function name \R searches for
%  that name in the databases listed by \code{\link{search}}.  The first
%  name of the appropriate type is used.
%
%  By attaching a data frame (or list) to the search path it is possible
%  to refer to the variables in the data frame by their names alone,
%  rather than as components of the data frame (e.g., in the example below,
%  \code{height} rather than \code{women$height}).
%
%  By default the database is attached in position 2 in the search path,
%  immediately after the user's workspace and before all previously
%  attached packages and previously attached databases.  This can be
%  altered to attach later in the search path with the \code{pos} option,
%  but you cannot attach at \code{pos = 1}.
%
%  The database is not actually attached.  Rather, a new environment is
%  created on the search path and the elements of a list (including
%  columns of a data frame) or objects in a save file or an environment
%  are \emph{copied} into the new environment.  If you use
%  \code{\link{<<-}} or \code{\link{assign}} to assign to an attached
%  database, you only alter the attached copy, not the original object.
%  (Normal assignment will place a modified version in the user's
%  workspace: see the examples.)  For this reason \code{attach} can lead
%  to confusion.
%
%  One useful \sQuote{trick} is to use \code{what = NULL} (or equivalently a
%  length-zero list) to create a new environment on the search path into
%  which objects can be assigned by \code{\link{assign}} or
%  \code{\link{load}} or \code{\link{sys.source}}.
%
%  Names starting \code{"package:"} are reserved for
%  \code{\link{library}} and should not be used by end users.  Attached
%  files are by default given the name \code{file:\var{what}}.  The
%  \code{name} argument given for the attached environment will be used
%  by \code{\link{search}} and can be used as the argument to
%  \code{\link{as.environment}}.
%
%  There are hooks to attach user-defined table objects of class
%  \code{"UserDefinedDatabase"}, supported by the Omegahat package
%  \pkg{RObjectTables}.  See \url{http://www.omegahat.org/RObjectTables/}.
%}
%
%\value{
%  The \code{\link{environment}} is returned invisibly with a
%  \code{"name"} attribute.
%}
%
%\section{Good practice}{
%  \code{attach} has the side effect of altering the search path and this
%  can easily lead to the wrong object of a particular name being found.
%  People do often forget to \code{\link{detach}} databases.
%
%  In interactive use, \code{\link{with}} is usually preferable to the
%  use of \code{attach}/\code{detach}, unless \code{what} is a
%  \code{\link{save}()}-produced file in which case
%  \code{attach()} is a (safety) wrapper for \code{\link{load}()}.
%
%  In programming, functions should not change the search path unless
%  that is their purpose.  Often \code{\link{with}} can be used within a
%  function. If not, good practice is to
%  \itemize{
%    \item Always use a distinctive \code{name} argument, and
%    \item To immediately follow the \code{attach} call by an
%    \code{\link{on.exit}} call to \code{detach} using the distinctive name.
%  }
%  This ensures that the search path is left unchanged even if the
%  function is interrupted or if code after the \code{attach} call
%  changes the search path.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{library}}, \code{\link{detach}}, \code{\link{search}},
%  \code{\link{objects}}, \code{\link{environment}}, \code{\link{with}}.
%}
%\examples{
%require(utils)
%
%summary(women$height)   # refers to variable 'height' in the data frame
%attach(women)
%summary(height)         # The same variable now available by name
%height <- height*2.54   # Don't do this. It creates a new variable
%                        # in the user's workspace
%find("height")
%summary(height)         # The new variable in the workspace
%rm(height)
%summary(height)         # The original variable.
%height <<- height*25.4  # Change the copy in the attached environment
%find("height")
%summary(height)         # The changed copy
%detach("women")
%summary(women$height)   # unchanged
%
%\dontrun{## create an environment on the search path and populate it
%sys.source("myfuns.R", envir = attach(NULL, name = "myfuns"))
%}}
%\keyword{data}
%
\encoding{UTF8}
