% File src/library/base/man/capabilities.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{capabilities}
\alias{capabilities}
\title{Report Capabilities of this Build of R}
\description{
  この \R の構築のコンパイル時のオプション特性についてのレポート．
}
\usage{
capabilities(what = NULL)
}
\arguments{
  \item{what}{文字列もしくは \code{NULL} で，必要な成分を指定する．
    \code{NULL} は全て必要を意味する．}
}
%#ifdef unix
\section{OS X ユーザへのノート}{
  機能 \code{"jpeg"}, \code{"png"} そして \code{"tiff"} はこれらのデバイスの
  X11 ベースのバージョンを参照する．もし 
  \code{capabilities("aqua")} が真ならば，\code{type = "quartz"} を持つ
  これらのデバイスが利用可能であり，out-of-the-box が既定のタイプになる．
  従って，例えば \code{\link{tiff}} デバイスは既定値が未変更なら 
  \code{capabilities("aqua") || capabilities("tiff")} の時利用可能になる．
}
%#endif
\value{
  名前付きの論理値ベクトル．現在の成分は
  \item{jpeg}{関数 \code{\link{jpeg}} は機能しているか?}
  \item{png}{関数 \code{\link{png}} は機能しているか?}
  \item{tiff}{関数 \code{\link{tiff}} は機能しているか?}
  \item{tcltk}{パッケージ \pkg{tcltk} はは機能しているか?
%#ifdef unix
  Unix の場合，Tk を利用可能にするためにはほとんど常に
    \code{"X11"} が利用可能なことが必要になる．
%#endif
  }
%#ifdef unix
  \item{X11}{(Unix の場合) \code{\link{X11}} グラフィックスデバイスと
    X11ベースのデータエディタが利用可能か?  これはまだ読み込まれていなければ
    X11 モジュールを読み込む．そして \code{X11} デバイスが既に
    使われていない限り既定のディスプレイが接続しているかどうかをチェックする．}

  \item{aqua}{(Unix の場合)関数 \code{\link{quartz}} は機能しているか?
    ある種の OS X の構築上でだけ，\R の \acronym{CRAN} バイナリ
    ディストリビューションを含む．

    これは \code{.Platform$GUI == "AQUA"} とは異なることを注意する．
    後者は Mac \code{R.app} GUI コンソールを使っている時だけ真となる．}
%#endif
%#ifdef windows
  \item{X11}{(Windows の場合) 常に \code{FALSE}．}
  \item{aqua}{(Windows の場合) OS X 上を除き \code{FALSE}．}
%#endif
  \item{http/ftp}{\code{\link{url}} と \code{\link{download.file}} に
  対する内部メソッドは \samp{http://} and \samp{ftp://} URL を
  サポートしているか?}
  \item{sockets}{\code{\link{make.socket}} と関連関数が利用できるか?}
  \item{libxml}{\code{libxml} を \R のイベントループと統合するための
  サポートがあるか?}
  \item{fifo}{FIFO コネクションはサポートされているか?}
  \item{cledit}{現在の \R セッションでコマンドライン編集が利用できるか?
    これは非対話的なセッションでは偽である．
%#ifdef unix
    (Unix の場合) もし \code{readline} のサポートがコンパイルされており
    \R が起動された時オプション \option{--no-readline} が使用されていなければ，
    これはコマンドラインインタフェイスに対して真になる．
    (もし \option{--interactive}
    が使用されれば，コマンドライン編集は実際は利用できないかもしれない．)
%#endif
  }
  \item{iconv}{\code{\link{iconv}} による国際化転換がサポートされているか?
  現在の \R では常に真．}
  \item{NLS}{自然言語サポートがあるか(メッセージの翻訳のため)?}
  \item{profmem}{メモリプロファイルのためのサポートがあるか? 
    \code{\link{tracemem}} を見よ．}
  \item{cairo}{\code{\link{svg}},
    \code{\link{cairo_pdf}} そして \code{\link{cairo_ps}} デバイス，また
    (Unix の場合) \code{\link{X11}} 中の \code{type = "cairo"}，
    \code{\link{bmp}}, \code{\link{jpeg}}, \code{\link{png}},
    そして \code{\link{tiff}} デバイスのサポートがあるか?}

  \item{ICU}{文章照合用の ICU が利用できるか? 
    \link{Comparison} と \code{\link{icuSetCollate}} のヘルプを見よ：これは
    C ロケールに対しては決して使われない．}

  \item{long.double}{この構築は \code{double} より長い \code{C} の
    \code{long double} 型を使っているか?  ある種のプラットフォームは
    そうした型を持たず，他ではその使用はコンフィギュアのオプション
    \option{--disable-long-double} で抑制されている．

    保証はできないが，もしあれば long double は少なくとも
    ISO/IEC 60559 80ビット\sQuote{拡張精度}書式と同等の範囲と精度を
    持つと仮定するのは合理的である．
}

  \item{libcurl}{この構築では \code{libcurl} が利用できるか?
    これは関数 \code{\link{curlGetHeaders}} と，オプションで
    \code{\link{download.file}} と \code{\link{url}} により使われる．}
}
\seealso{\R の外部機能であるが \R 関数が利用する機能の利用可能性については
(そこにあるリンクとともに)\code{\link{.Platform}} と \code{\link{extSoftVersion}} ．
  }
\examples{
capabilities()

if(!capabilities("http/ftp"))
   warning("internal download.file() method is not available")

## 'connections' に対する例も見よ．
}
\keyword{utilities}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/capabilities.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{capabilities}
%\alias{capabilities}
%\title{Report Capabilities of this Build of R}
%\description{
%  Report on the optional features which have been compiled into this
%  build of \R.
%}
%\usage{
%capabilities(what = NULL)
%}
%\arguments{
%  \item{what}{character vector or \code{NULL}, specifying
%    required components.  \code{NULL} implies that all are required.}
%}
%#ifdef unix
%\section{Note to OS X users}{
%  Capabilities \code{"jpeg"}, \code{"png"} and \code{"tiff"} refer to
%  the X11-based versions of these devices.  If
%  \code{capabilities("aqua")} is true, then these devices with
%  \code{type = "quartz"} will be available, and out-of-the-box will be the
%  default type.  Thus for example the \code{\link{tiff}} device will be
%  available if \code{capabilities("aqua") || capabilities("tiff")} if
%  the defaults are unchanged.
%}
%#endif
%\value{
%  A named logical vector.  Current components are
%  \item{jpeg}{is the \code{\link{jpeg}} function operational?}
%  \item{png}{is the \code{\link{png}} function operational?}
%  \item{tiff}{is the \code{\link{tiff}} function operational?}
%  \item{tcltk}{is the \pkg{tcltk} package operational?
%#ifdef unix
%    Note that to make use of Tk you will almost always need to check
%    that \code{"X11"} is also available.
%#endif
%  }
%#ifdef unix
%  \item{X11}{are the \code{\link{X11}} graphics device and the
%    X11-based data editor available?  This loads the X11 module if not
%    already loaded, and checks that the default display can be
%    contacted unless a \code{X11} device has already been used.}
%
%  \item{aqua}{is the \code{\link{quartz}} function operational?
%    Only on some OS X builds, including \acronym{CRAN} binary
%    distributions of \R.
%
%    Note that this is distinct from \code{.Platform$GUI == "AQUA"},
%    which is true only when using the Mac \code{R.app} GUI console.}
%#endif
%#ifdef windows
%  \item{X11}{always \code{FALSE} on Windows.}
%  \item{aqua}{\code{FALSE} except on OS X.}
%#endif
%  \item{http/ftp}{does the internal method for \code{\link{url}} and
%    \code{\link{download.file}} support \samp{http://} and \samp{ftp://}
%    URLs?}
%  \item{sockets}{are \code{\link{make.socket}} and related functions
%    available?}
%  \item{libxml}{is there support for integrating \code{libxml} with
%    the \R event loop?}
%  \item{fifo}{are FIFO \link{connections} supported?}
%  \item{cledit}{is command-line editing available in the current \R
%    session?  This is false in non-interactive sessions.
%#ifdef unix
%    It will be true for the command-line interface if \code{readline}
%    support has been compiled in and \option{--no-readline} was
%    \emph{not} used when \R was invoked.  (If \option{--interactive}
%    was used, command-line editing will not actually be available.)
%#endif
%  }
%  \item{iconv}{is internationalization conversion via
%    \code{\link{iconv}} supported?  Always true in current \R.}
%  \item{NLS}{is there Natural Language Support (for message translations)?}
%  \item{profmem}{is there support for memory profiling?  See
%    \code{\link{tracemem}}.}
%  \item{cairo}{is there support for the \code{\link{svg}},
%    \code{\link{cairo_pdf}} and \code{\link{cairo_ps}} devices, and
%    for \code{type = "cairo"} in the
%#ifdef unix
%    \code{\link{X11}},
%#endif
%    \code{\link{bmp}}, \code{\link{jpeg}}, \code{\link{png}},
%    and \code{\link{tiff}} devices?}
%
%  \item{ICU}{is ICU available for collation?  See the help on
%    \link{Comparison} and \code{\link{icuSetCollate}}: it is never
%    used for a C locale.}
%
%  \item{long.double}{does this build use a \code{C} \code{long double}
%    type which is longer than \code{double}?  Some platforms do not
%    have such a type, and on others its use can be suppressed by the
%    configure option \option{--disable-long-double}.
%
%    Although not guaranteed, it is a reasonable assumption that if
%    present long doubles will have at least as much range and accuracy
%    as the ISO/IEC 60559 80-bit \sQuote{extended precision} format.
%  }
%
%  \item{libcurl}{is \code{libcurl} available in this build?  Used by
%    function \code{\link{curlGetHeaders}} and optionally by
%    \code{\link{download.file}} and \code{\link{url}}.}
%}
%\seealso{\code{\link{.Platform}} and \code{\link{extSoftVersion}} (and
%    links there) for availability capabilities \emph{external} to \R but
%    used from \R functions.
%  }
%\examples{
%capabilities()
%
%if(!capabilities("http/ftp"))
%   warning("internal download.file() method is not available")
%
%## See also the examples for 'connections'.
%}
%\keyword{utilities}
%
\encoding{UTF8}
