% File src/library/base/man/colSums.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2012 R Core Team
% Distributed under GPL 2 or later

\name{colSums}
\alias{colSums}
\alias{rowSums}
\alias{colMeans}
\alias{rowMeans}
\alias{.colSums}
\alias{.rowSums}
\alias{.colMeans}
\alias{.rowMeans}
\title{Form Row and Column Sums and Means}
\description{
  数値配列の行和，列和そして平均を作る．
}
\usage{
colSums (x, na.rm = FALSE, dims = 1)
rowSums (x, na.rm = FALSE, dims = 1)
colMeans(x, na.rm = FALSE, dims = 1)
rowMeans(x, na.rm = FALSE, dims = 1)

.colSums(x, m, n, na.rm = FALSE)
.rowSums(x, m, n, na.rm = FALSE)
.colMeans(x, m, n, na.rm = FALSE)
.rowMeans(x, m, n, na.rm = FALSE)
}
\arguments{
  \item{x}{2もしくはそれ以上の次元の配列で．数値，複素数値，整数，論理値を含む．
    又は数値データフレーム．}
  \item{na.rm}{論理値．欠損値(\code{NaN} を含む)は計算前に除外するか?}
  \item{dims}{整数：どの次元を加えあげる\sQuote{行}又は\sQuote{列}と
    見做すか．\code{row*} に対しては和及び平均は 
    次元 \code{dims+1, \dots} 上； \code{col*} に対しては次元 
    \code{1:dims} 上．}
  \item{X}{数値行列．}
  \item{m, n}{\code{X} の次元．}
}
\details{
  これらの関数は \code{\link{apply}} を適当なマージンに
  \code{FUN = mean} 又は \code{FUN = sum} で適用するのと同値であるが，
  相当速い．速度重視で書かれているため \code{NaN} と \code{NA}
  に関する微妙な点が曖昧にされている．もし \code{na.rm = FALSE} で，
  \code{NaN} か \code{NA} が和に現れれば，結果は \code{NaN} か \code{NA}
  になるが，しかしこれはプラットフォーム依存である．

  欠損値の無視は列毎もしくは行毎になされることを注意しよう．
  従って列(行)和は同じ行集合に関するものではないかもしれない．
  完全な行や列に対してだけ使うためには，最初にそれらを
  \code{\link{na.omit}} や \code{\link{complete.cases}} で選択する
  (もしかすると \code{x} の転置に関して)．

  名前の先頭にドットがあるバージョンはプログラミングで使う
  骨格だけのバージョンである：これらは数値行列にだけ適用され結果に
  名前を付かない．
}
\value{
  適当なサイズの数値か複素数値配列．もし結果が一次元ならばベクトルになる．
  最初の4つの関数に対しては \code{dimnames}
  (ベクトルの結果に対しては \code{names} )がオリジナルの配列から取られる．

  もし加えあげられる範囲内に値がなければ
  (\code{na.rm = TRUE} で欠損値を取り除いた場合)，出力のその成分は
  \code{0} (\code{*Sums}) 又は \code{NaN} とされ，
  \code{\link{sum}} と \code{\link{mean}} とに首尾一貫する．
}
\seealso{
  \code{\link{apply}}, \code{\link{rowsum}}
}
\examples{
## 行列の行和と列和を計算：
x <- cbind(x1 = 3, x2 = c(4:1, 2:5))
rowSums(x); colSums(x)
dimnames(x)[[1]] <- letters[1:8]
rowSums(x); colSums(x); rowMeans(x); colMeans(x)
x[] <- as.integer(x)
rowSums(x); colSums(x)
x[] <- x < 3
rowSums(x); colSums(x)
x <- cbind(x1 = 3, x2 = c(4:1, 2:5))
x[3, ] <- NA; x[4, 2] <- NA
rowSums(x); colSums(x); rowMeans(x); colMeans(x)
rowSums(x, na.rm = TRUE); colSums(x, na.rm = TRUE)
rowMeans(x, na.rm = TRUE); colMeans(x, na.rm = TRUE)

## 配列
dim(UCBAdmissions)
rowSums(UCBAdmissions); rowSums(UCBAdmissions, dims = 2)
colSums(UCBAdmissions); colSums(UCBAdmissions, dims = 2)

## 複素数ケース
x <- cbind(x1 = 3 + 2i, x2 = c(4:1, 2:5) - 5i)
x[3, ] <- NA; x[4, 2] <- NA
rowSums(x); colSums(x); rowMeans(x); colMeans(x)
rowSums(x, na.rm = TRUE); colSums(x, na.rm = TRUE)
rowMeans(x, na.rm = TRUE); colMeans(x, na.rm = TRUE)
}
\keyword{array}
\keyword{algebra}
\keyword{arith}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/colSums.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2012 R Core Team
%% Distributed under GPL 2 or later
%
%\name{colSums}
%\alias{colSums}
%\alias{rowSums}
%\alias{colMeans}
%\alias{rowMeans}
%\alias{.colSums}
%\alias{.rowSums}
%\alias{.colMeans}
%\alias{.rowMeans}
%\title{Form Row and Column Sums and Means}
%\description{
%  Form row and column sums and means for numeric arrays.
%}
%\usage{
%colSums (x, na.rm = FALSE, dims = 1)
%rowSums (x, na.rm = FALSE, dims = 1)
%colMeans(x, na.rm = FALSE, dims = 1)
%rowMeans(x, na.rm = FALSE, dims = 1)
%
%.colSums(X, m, n, na.rm = FALSE)
%.rowSums(X, m, n, na.rm = FALSE)
%.colMeans(X, m, n, na.rm = FALSE)
%.rowMeans(X, m, n, na.rm = FALSE)
%}
%\arguments{
%  \item{x}{an array of two or more dimensions, containing numeric,
%    complex, integer or logical values, or a numeric data frame.}
%  \item{na.rm}{logical.  Should missing values (including \code{NaN})
%    be omitted from the calculations?}
%  \item{dims}{integer: Which dimensions are regarded as \sQuote{rows} or
%    \sQuote{columns} to sum over.  For \code{row*}, the sum or mean is
%    over dimensions \code{dims+1, \dots}; for \code{col*} it is over
%    dimensions \code{1:dims}.}
%  \item{X}{a numeric matrix.}
%  \item{m, n}{the dimensions of X.}
%}
%\details{
%  These functions are equivalent to use of \code{\link{apply}} with
%  \code{FUN = mean} or \code{FUN = sum} with appropriate margins, but
%  are a lot faster.  As they are written for speed, they blur over some
%  of the subtleties of \code{NaN} and \code{NA}.  If \code{na.rm =
%    FALSE} and either \code{NaN} or \code{NA} appears in a sum, the
%  result will be one of \code{NaN} or \code{NA}, but which might be
%  platform-dependent.
%
%  Notice that omission of missing values is done on a per-column or
%  per-row basis, so column means may not be over the same set of rows,
%  and vice versa.  To use only complete rows or columns, first select
%  them with \code{\link{na.omit}} or \code{\link{complete.cases}}
%  (possibly on the transpose of \code{x}).
%
%  The versions with an initial dot in the name are \sQuote{bare-bones}
%  versions for use in programming: they apply only to numeric matrices
%  and do not name the result.
%}
%\value{
%  A numeric or complex array of suitable size, or a vector if the result
%  is one-dimensional.  For the first four functions the \code{dimnames}
%  (or \code{names} for a vector result) are taken from the original
%  array.
%
%  If there are no values in a range to be summed over (after removing
%  missing values with \code{na.rm = TRUE}), that
%  component of the output is set to \code{0} (\code{*Sums}) or \code{NaN}
%  (\code{*Means}), consistent with \code{\link{sum}} and
%  \code{\link{mean}}.
%}
%\seealso{
%  \code{\link{apply}}, \code{\link{rowsum}}
%}
%\examples{
%## Compute row and column sums for a matrix:
%x <- cbind(x1 = 3, x2 = c(4:1, 2:5))
%rowSums(x); colSums(x)
%dimnames(x)[[1]] <- letters[1:8]
%rowSums(x); colSums(x); rowMeans(x); colMeans(x)
%x[] <- as.integer(x)
%rowSums(x); colSums(x)
%x[] <- x < 3
%rowSums(x); colSums(x)
%x <- cbind(x1 = 3, x2 = c(4:1, 2:5))
%x[3, ] <- NA; x[4, 2] <- NA
%rowSums(x); colSums(x); rowMeans(x); colMeans(x)
%rowSums(x, na.rm = TRUE); colSums(x, na.rm = TRUE)
%rowMeans(x, na.rm = TRUE); colMeans(x, na.rm = TRUE)
%
%## an array
%dim(UCBAdmissions)
%rowSums(UCBAdmissions); rowSums(UCBAdmissions, dims = 2)
%colSums(UCBAdmissions); colSums(UCBAdmissions, dims = 2)
%
%## complex case
%x <- cbind(x1 = 3 + 2i, x2 = c(4:1, 2:5) - 5i)
%x[3, ] <- NA; x[4, 2] <- NA
%rowSums(x); colSums(x); rowMeans(x); colMeans(x)
%rowSums(x, na.rm = TRUE); colSums(x, na.rm = TRUE)
%rowMeans(x, na.rm = TRUE); colMeans(x, na.rm = TRUE)
%}
%\keyword{array}
%\keyword{algebra}
%\keyword{arith}
%
\encoding{UTF8}
