% File src/library/base/man/do.call.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{do.call}
\title{Execute a Function Call}
\usage{
do.call(what, args, quote = FALSE, envir = parent.frame())
}
\alias{do.call}
\arguments{
  \item{what}{関数か呼び出されるべき関数の名前である空でない文字列．}
  \item{args}{関数呼び出しに対する引数リスト．
     \code{args} の \code{names} 属性は引数名を与える．}
  \item{quote}{引数を引用化するかどうかを指示する論理値．}
  \item{envir}{呼び出しをその中で評価する環境．これは
    \code{what} が文字列で引数がシンボルか引用化表現式である場合に
    最も有用になる．}
}
\description{
  \code{do.call} は名前や関数とそれに渡される引数リストから
  関数呼び出しを構成し実行する．
}
\details{
  もし \code{quote} が \code{FALSE} ならば(既定)，引数は評価される
  (\code{envir} 中ではなく呼び出し環境中で)．もし
  \code{quote} が \code{TRUE} ならば各引数は引用化される(\code{\link{quote}} を見よ)
  ので引数評価の効果は引用符を取り去ることにあり，
  呼び出しが構成されるときオリジナルの引数は未評価のままにされる．

  \code{\link{substitute}} のようなある種の関数の挙動は，
  あたかもインタプリタから評価されたかのような \code{do.call} を
  用いて評価された関数に対するものとは同じではない．
  正確な構文は現在未定義で変更されるかもしれない．
}
\value{
  結果は(未評価の)関数呼び出し．
}
\section{警告}{
  これは \code{.Internal} や他の非 API 呼び出しの使用に関する
  制限を回避する試みに使われるべきではない．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  未評価の呼び出しを作る \code{\link{call}}．
}
\examples{
do.call("complex", list(imag = 1:3))

## もし既にリスト(例えばデータフレーム)があれば
## 更に引数を加えるために c() が必要になる
tmp <- expand.grid(letters[1:2], 1:3, c("+", "-"))
do.call("paste", c(tmp, sep = ""))

do.call(paste, list(as.name("A"), as.name("B")), quote = TRUE)

## オブジェクトをどこで見つけるかに関する例．
A <- 2
f <- function(x) print(x^2)
env <- new.env()
assign("A", 10, envir = env)
assign("f", f, envir = env)
f <- function(x) print(x)
f(A)                                      # 2
do.call("f", list(A))                     # 2
do.call("f", list(A), envir = env)        # 4
do.call(f, list(A), envir = env)          # 2
do.call("f", list(quote(A)), envir = env) # 100
do.call(f, list(quote(A)), envir = env)   # 10
do.call("f", list(as.name("A")), envir = env) # 100

eval(call("f", A))                      # 2
eval(call("f", quote(A)))               # 2
eval(call("f", A), envir = env)         # 4
eval(call("f", quote(A)), envir = env)  # 100
}
\keyword{programming}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/do.call.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{do.call}
%\title{Execute a Function Call}
%\usage{
%do.call(what, args, quote = FALSE, envir = parent.frame())
%}
%\alias{do.call}
%\arguments{
%  \item{what}{either a function or a non-empty character string naming the
%    function to be called.}
%  \item{args}{a \emph{list} of arguments to the function call.  The
%    \code{names} attribute of \code{args} gives the argument names.}
%  \item{quote}{a logical value indicating whether to quote the
%    arguments.}
%  \item{envir}{an environment within which to evaluate the call.  This
%    will be most useful if \code{what} is a character string and
%    the arguments are symbols or quoted expressions.}
%}
%\description{
%  \code{do.call} constructs and executes a function call from a name or
%  a function and a list of arguments to be passed to it.
%}
%\details{
%  If \code{quote} is \code{FALSE}, the default, then the arguments are
%  evaluated (in the calling environment, not in \code{envir}).  If
%  \code{quote} is \code{TRUE} then each argument is quoted (see
%  \code{\link{quote}}) so that the effect of argument evaluation is to
%  remove the quotes -- leaving the original arguments unevaluated when the
%  call is constructed.
%
%  The behavior of some functions, such as \code{\link{substitute}},
%  will not be the same for functions evaluated using \code{do.call} as
%  if they were evaluated from the interpreter.  The precise semantics
%  are currently undefined and subject to change.
%}
%\value{
%  The result of the (evaluated) function call.
%}
%\section{Warning}{
%  This should not be used to attempt to evade restrictions on the use of
%  \code{.Internal} and other non-API calls.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{call}} which creates an unevaluated call.
%}
%\examples{
%do.call("complex", list(imag = 1:3))
%
%## if we already have a list (e.g., a data frame)
%## we need c() to add further arguments
%tmp <- expand.grid(letters[1:2], 1:3, c("+", "-"))
%do.call("paste", c(tmp, sep = ""))
%
%do.call(paste, list(as.name("A"), as.name("B")), quote = TRUE)
%
%## examples of where objects will be found.
%A <- 2
%f <- function(x) print(x^2)
%env <- new.env()
%assign("A", 10, envir = env)
%assign("f", f, envir = env)
%f <- function(x) print(x)
%f(A)                                      # 2
%do.call("f", list(A))                     # 2
%do.call("f", list(A), envir = env)        # 4
%do.call(f, list(A), envir = env)          # 2
%do.call("f", list(quote(A)), envir = env) # 100
%do.call(f, list(quote(A)), envir = env)   # 10
%do.call("f", list(as.name("A")), envir = env) # 100
%
%eval(call("f", A))                      # 2
%eval(call("f", quote(A)))               # 2
%eval(call("f", A), envir = env)         # 4
%eval(call("f", quote(A)), envir = env)  # 100
%}
%\keyword{programming}
%
\encoding{UTF8}
