% File src/library/base/man/file.show.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{file.show}
\alias{file.show}
\title{Display One or More Text Files}
\description{一つもしくはそれ以上の(平文の)テキストファイルをプラットフォーム固有の
  仕方で表示する．典型的に \sQuote{ページャ} を利用する．
}
\usage{
file.show(\dots, header = rep("", nfiles),
          title = "R Information",
          delete.file = FALSE, pager = getOption("pager"),
          encoding = "")
}
\arguments{
  \item{\dots}{一つ又はそれ以上の表示されるべきファイルの名前を含む文字列ベクトル．
    パスはチルド展開される．}
  \item{header}{表示される各ファイルのヘッダーを与える (\code{\dots} 中で指定された
    ファイルの数と同じ長さの)文字列ベクトル．既定値は空文字列．}
  \item{title}{表示に対する全体的なタイトル．もし単一の別個のウィンドウが表示に使われるのなら，
    \code{title} はウィンドウのタイトルに使われる．
    もし複数のウィンドウが使われるのなら，それらのタイトルはタイトルとファイル固有のヘッダー
    を連結すべきである．}
  \item{delete.file}{表示の後にファイルを抹消すべきか?  一時的ファイルに使われる．}
  \item{pager}{使われるページャ：すべてのプラットフォームで使われるわけではない．}
  \item{encoding}{ファイルに仮定されるエンコーディングを与える文字列．}
}
\details{
  この関数は \R のヘルプシステムの中核であるが，\code{\link{page}} 等の他の目的にも
  同様に使える．

  ページャがどのように実装されているかは高度にシステム依存である．

  基本の Unix バージョンはファイルを(ヘッダーを使い)一時的ファイルに連結し，
  それを \code{pager} 引数で選択されたページャ中に表示する．
  これはファイルのセットに対し実行されるシステム命令を指定する文字列である
  (完全なパス又は \env{PATH} 上で見つかる命令)．
  \sQuote{工場出荷}既定値は \file{R_HOME/bin/pager} の使用で，これは
  環境変数 \code{PAGER} で指定されるコマンドラインを実行するシェルスクリプトで
  その既定値はコンフィギュアの段階で設定される．通常 
  \command{less} である．Unix 風システムではもし \code{pager} が空であれば
  \command{more} が使われる．

  殆どの GUI システムは各ファイルに対し個別のページャウィンドウを使い，
  \R が実行を続ける間ユーザにそのままにしておかせる．
  そうしたページャの選択は特別な低水準コードが横取りするページャ
  (\code{"internal"} と Windows 上では \code{"console"})の名前を使ってなされるか，
  \code{pager} を \R 関数 \code{file.show} の最初の四つの引数に対応する
  引数 \code{(files, header, title, delete.file)} で呼び出し
  GUI とやり取りするように手配する．

  OS X の \command{R.app} GUI は \code{pager} の設定にかかわらず内部的な
  ページャを使う．

  すべての実装が \code{delete.file} に敬意を払うわけではない．特に
  Windows の外部ページャはそうであり，いつファイルに伴う外部アプリケーションが
  終了したかを知る手段がない．
}
\author{Ross Ihaka, Brian Ripley.}
\seealso{
  \code{\link{files}}, \code{\link{list.files}},
  \code{\link{help}};
  \code{\link{RShowDoc}} は \code{type = "text"} に対して
  \code{file.show()} を呼び出す．pdf ファイルの表示には
  \code{\link{getOption}("pdfviewer")} と
  例えば \code{\link{system}} を考慮しよう．

  \code{\link{file.edit}}.
}
\examples{
file.show(file.path(R.home("doc"), "COPYRIGHTS"))
}
\keyword{file}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/file.show.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{file.show}
%\alias{file.show}
%\title{Display One or More Text Files}
%\description{Display one or more (plain) text files, in a platform
%  specific way, typically via a \sQuote{pager}.
%}
%\usage{
%file.show(\dots, header = rep("", nfiles),
%          title = "R Information",
%          delete.file = FALSE, pager = getOption("pager"),
%          encoding = "")
%}
%\arguments{
%  \item{\dots}{one or more character vectors containing the names of the
%    files to be displayed.  Paths with have \link{tilde expansion}.}
%  \item{header}{character vector (of the same length as the number of files
%    specified in \code{\dots}) giving a header for each file being
%    displayed.  Defaults to empty strings.}
%  \item{title}{an overall title for the display.  If a single separate
%    window is used for the display, \code{title} will be used as the window
%    title.  If multiple windows are used, their titles should combine the title
%    and the file-specific header.}
%  \item{delete.file}{should the files be deleted after display?  Used
%    for temporary files.}
%  \item{pager}{the pager to be used: not used on all platforms}
%  \item{encoding}{character string giving the encoding to be assumed for
%    the file(s).}
%}
%\details{
%  This function provides the core of the R help system, but it can be
%  used for other purposes as well, such as \code{\link{page}}.
%
%  How the pager is implemented is highly system-dependent.
%
%  The basic Unix version concatenates the files (using the headers) to a
%  temporary file, and displays it in the pager selected by the
%  \code{pager} argument, which is a character vector specifying a system
%  command (a full path or a command found on the \env{PATH}) to run on
%  the set of files.  The \sQuote{factory-fresh} default is to use
%  \file{R_HOME/bin/pager}, which is a shell script running the command-line
%  specified by the environment variable \env{PAGER} whose default is set
%  at configuration, usually to \command{less}.  On a Unix-alike
%  \command{more} is used if \code{pager} is empty.
%
%  Most GUI systems will use a separate pager window for each file, and
%  let the user leave it up while \R continues running.  The selection of
%  such pagers could either be done using special pager names being
%  intercepted by lower-level code (such as \code{"internal"} and
%  \code{"console"} on Windows), or by letting \code{pager} be an \R
%  function which will be called with arguments \code{(files, header,
%    title, delete.file)} corresponding to the first four arguments of
%  \code{file.show} and take care of interfacing to the GUI.
%
%  The \command{R.app} GUI on OS X uses its internal pager irrespective
%  of the setting of \code{pager}.
%
%  Not all implementations will honour \code{delete.file}.  In
%  particular, using an external pager on Windows does not, as there is
%  no way to know when the external application has finished with the
%  file.
%}
%\author{Ross Ihaka, Brian Ripley.}
%\seealso{
%  \code{\link{files}}, \code{\link{list.files}},
%  \code{\link{help}};
%  \code{\link{RShowDoc}} call \code{file.show()} for \code{type =
%  "text"}.  Consider \code{\link{getOption}("pdfviewer")} and
%  e.g., \code{\link{system}} for displaying pdf files.
%
%  \code{\link{file.edit}}.
%}
%\examples{
%file.show(file.path(R.home("doc"), "COPYRIGHTS"))
%}
%\keyword{file}
%
\encoding{UTF8}
