% File src/library/base/man/getDLLRegisteredRoutines.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{getDLLRegisteredRoutines}
\alias{getDLLRegisteredRoutines}
\alias{getDLLRegisteredRoutines.character}
\alias{getDLLRegisteredRoutines.DLLInfo}
\alias{print.NativeRoutineList}
\alias{print.DLLRegisteredRoutines}
\title{Reflectance Information for C/Fortran routines in a DLL}
\description{
  この関数は \R に登録された DLL 中のルーチンの集合の問い合わせを
  可能にし，動的な検索，ネイティブルーチンを呼び出す際のエラー処理，
  そして可能性として将来はセキュリティ，を拡張する．
  この関数は異なったインタフェイス，つまり
  \code{\link{.C}}, \code{\link{.Call}}, \code{\link{.Fortran}}
  そして \code{\link{.External}}，に対する DLL 中の各登録ルーチン
  の説明を提供する．
}
\usage{
getDLLRegisteredRoutines(dll, addNames = TRUE)
}
\arguments{
  \item{dll}{文字列又は \code{DLLInfo} オブジェクト．
    文字列は興味のある DLL noファイル名を指定し，ファイル拡張子
    (つまり \file{.dll} や \file{.so}) やディレクトリ/パス情報無しで
    与えられる．従ってファイル \file{MyPackage/libs/MyPackage.so} は
    \samp{MyPackage} として指定される．

    \code{DLLInfo} オブジェクトは \code{\link{dyn.load}}
    と \code{\link{library.dynam}} への呼び出し中で
    直接得ることができる．また \code{\link{getLoadedDLLs}}
    を使って DLL がロードされた後で見つけることが出来る．
    これは \code{DLLInfo} オブジェクトのリストである(DLL ファイル名で
    添え字化出来る)．

    \code{DLLInfo} アプローチは同じ名前を持つが異なるディレクトリ中にある
    ファイルに対応する二つの DLL に関係する任意の
    曖昧さを避ける．
  }
  \item{addNames}{論理値．もしこれが \code{TRUE} なら返り値リストの要素は
    ルーチン名(登録によって \R が理解する又は素の名前)を使って名前付けられる．
    もし \code{FALSE} ならばこれらの名前は計算されずリストに付加される．
    結果として呼び出しは早くなる．名前情報はまたリスト中の  \code{NativeSymbolInfo}
    オブジェクト中でも得られる．
  }
}
\details{
  これは登録され \R の内部機構で処理された後の登録情報を取る．
  換言すればそれは拡張情報を使う．

  このクラスに対する \code{print} メソッドがあり，登録されたルーチンの
  型だけをプリントする．
}
\value{
  クラス \code{"DLLRegisteredRoutines"} のリストで \code{.C},
  \code{.Call}, \code{.Fortran} そして \code{.External} インタフェイスに
  対して登録されたルーチンに対応する四つの要素を持つ．
  各々はそのインタフェイスに登録されたルーチンと同じ数の要素を持つ
  リストである．

  各要素はルーチンを特定しクラス \code{"NativeSymbolInfo"} のオブジェクトである．
  このクラスのオブジェクトは以下の欄を持つ：
  \item{name}{ルーチンの登録名(C コード中の名前とは限らない)．}
  \item{address}{ロードされた DLL 中で解決されたようなルーチンのメモリアドレス．
    もしシンボルがまだ解決されていなければ \code{NULL} かもしれない．}
  \item{dll}{DLL を記述するクラス \code{DLLInfo} のオブジェクト．
    これは返されるすべての要素で同一である．}
  \item{numParameters}{ネイティブルーチンが呼び出された際の引数の数．
    将来はパラメータの型に関する情報がまた提供されるであろう．
  }
}
\references{
  シンボルの登録は \sQuote{Writing R Extensions Manual}．

  R News, Volume 1/3, September 2001.   "In search of C/C++ & Fortran Symbols"
}
\author{Duncan Temple Lang \email{duncan@wald.ucdavis.edu}}

\seealso{
  \code{\link{getLoadedDLLs}},
  リストされたエントリポイントに関する情報は \code{\link{getNativeSymbolInfo}}．
}
\examples{
dlls <- getLoadedDLLs()
getDLLRegisteredRoutines(dlls[["base"]])

getDLLRegisteredRoutines("stats")
}
\keyword{interface}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/getDLLRegisteredRoutines.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{getDLLRegisteredRoutines}
%\alias{getDLLRegisteredRoutines}
%\alias{getDLLRegisteredRoutines.character}
%\alias{getDLLRegisteredRoutines.DLLInfo}
%\alias{print.NativeRoutineList}
%\alias{print.DLLRegisteredRoutines}
%\title{Reflectance Information for C/Fortran routines in a DLL}
%\description{
%  This function allows us to query the set of routines
%  in a DLL that are registered with R to enhance
%  dynamic lookup, error handling when calling native routines,
%  and potentially security in the future.
%  This function provides a description of each of the
%  registered routines in the DLL for the different interfaces,
%  i.e.\sspace{}\code{\link{.C}}, \code{\link{.Call}}, \code{\link{.Fortran}}
%  and \code{\link{.External}}.
%}
%\usage{
%getDLLRegisteredRoutines(dll, addNames = TRUE)
%}
%\arguments{
%  \item{dll}{a character string or \code{DLLInfo} object.
%    The character string specifies the file name of the DLL
%    of interest, and is given without the file name extension (e.g., the
%    \file{.dll} or \file{.so}) and with no directory/path information.
%    So a file \file{MyPackage/libs/MyPackage.so} would be specified as
%    \samp{MyPackage}.
%
%    The \code{DLLInfo} objects can be obtained directly
%    in calls to \code{\link{dyn.load}} and  \code{\link{library.dynam}},
%    or can be found after the DLL has been loaded using
%    \code{\link{getLoadedDLLs}}, which returns a list of
%    \code{DLLInfo} objects (index-able by DLL file name).
%
%    The \code{DLLInfo} approach avoids any ambiguities related to two
%    DLLs having the same name but corresponding to files in different
%    directories.
%  }
%  \item{addNames}{a logical value.  If this is \code{TRUE}, the elements
%    of the returned lists are named using the names of the routines (as
%    seen by R via registration or raw name).  If \code{FALSE},
%    these names are not computed and assigned to the lists.  As a
%    result, the call should be quicker.  The name information is also
%    available in the \code{NativeSymbolInfo} objects in the lists.
%  }
%}
%\details{
%  This takes the registration information after it has been registered
%  and processed by the R internals.  In other words, it uses the extended
%  information.
%
%  There is \code{print} methods for the class, which prints only the
%  types which have registered routines.
%}
%\value{
%  A list of class \code{"DLLRegisteredRoutines"} with four elements
%  corresponding to the routines registered for the \code{.C},
%  \code{.Call}, \code{.Fortran} and \code{.External} interfaces. Each is
%  a list with as many elements as there were routines registered for
%  that interface.
%
%  Each element identifies a routine and is an object
%  of class \code{"NativeSymbolInfo"}.
%  An object of this class has the following fields:
%  \item{name}{the registered name of the routine (not necessarily the
%    name in the C code).}
%  \item{address}{the memory address of the routine as resolved in the
%    loaded DLL. This may be \code{NULL} if the symbol has not yet been
%    resolved.}
%  \item{dll}{an object of class \code{DLLInfo} describing the DLL.
%    This is same for all elements returned.}
%  \item{numParameters}{the number of arguments the native routine is to
%    be called with.  In the future, we will provide information about
%    the types of the parameters also.
%  }
%}
%\references{
%  \sQuote{Writing R Extensions Manual} for symbol registration.
%
%  R News, Volume 1/3, September 2001.   "In search of C/C++ & Fortran Symbols"
%}
%\author{Duncan Temple Lang \email{duncan@wald.ucdavis.edu}}
%
%\seealso{
%  \code{\link{getLoadedDLLs}},
%  \code{\link{getNativeSymbolInfo}} for information on the entry points listed.
%}
%\examples{
%dlls <- getLoadedDLLs()
%getDLLRegisteredRoutines(dlls[["base"]])
%
%getDLLRegisteredRoutines("stats")
%}
%\keyword{interface}
%
%
\encoding{UTF8}
