% File src/library/base/man/gzcon.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2010 R Core Team
% Distributed under GPL 2 or later

\name{gzcon}
\alias{gzcon}
\title{
  (De)compress I/O Through Connections
}
\description{
  \code{gzcon} は既存のコネクションをラップする修正コネクションを
  提供する．そしてそのコネクションを経由して解凍読み取りや圧縮書き込みが
  できるようになる．標準的な \code{gzip} ヘッダが仮定される．
}
\usage{
gzcon(con, level = 6, allowNonCompressed = TRUE)
}
\arguments{
  \item{con}{コネクション．}
  \item{level}{0 と 9 の間の整数，書き込み時の圧縮レベル．}
  \item{allowNonCompressed}{論理値．読み込み時非圧縮入力を認めるか?}
}
\details{
  もし \code{con} が開かれていれば修正されたコネクションが開かれる．
  ラッパコネクションを閉じれば基礎にあるコネクションも閉じられる．

  \code{gzip} のマジックヘッダーを提供しないコネクションからの読み取りは，
  もし\cr
  \code{allowNonCompressed} が真なら元のコネクションからの読み取りに
  同値であるが，さもなければエラーになる．

  圧縮出力は埋め込まれた NUL バイトを含み，従って
  \code{con} は \code{open = "w"} で開かれた\cr
  \code{\link{textConnection}} で
  あることは許されない．データを変数に圧縮するには書き込み可能な \code{\link{rawConnection}}
  を使う．

  元のコネクションは使用できなくなる：それを指し示す任意のオブジェクトは
  今や修正コネクションを参照するようになる．この理由から新しいコネクションは
  明示的に閉じられる必要がある．
}
\value{
  クラス \code{"connection"} を継承するオブジェクト．これは提供されたのと
  同じコネクション\emph{番号}であるが，修正された内部構造を持つ．
  これはバイナリーモードを持つ．
}
\seealso{\code{\link{gzfile}}}
\examples{
\donttest{## URL からの非圧縮データファイル
z <- gzcon(url("http://www.stats.ox.ac.uk/pub/datasets/csb/ch12.dat.gz"))
# read.table はテキストモードのコネクションからだけ読み取れる
raw <- textConnection(readLines(z))
close(z)
dat <- read.table(raw)
close(raw)
dat[1:4, ]
}

## gzfile と gzcon は相互連携できる．
## ここでは勿論 gzfile を使うが，file() はすべての他のコネクション生成器で
## 置き換えられる．
zz <- gzfile("ex.gz", "w")
cat("TITLE extra line", "2 3 5 7", "", "11 13 17", file = zz, sep = "\n")
close(zz)
readLines(zz <- gzcon(file("ex.gz", "rb")))
close(zz)
unlink("ex.gz")
% Cygwin seems to require a different name
zz <- gzcon(file("ex2.gz", "wb"))
cat("TITLE extra line", "2 3 5 7", "", "11 13 17", file = zz, sep = "\n")
close(zz)
readLines(zz <- gzfile("ex2.gz"))
close(zz)
unlink("ex2.gz")
}
\keyword{file}
\keyword{connection}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/gzcon.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2010 R Core Team
%% Distributed under GPL 2 or later
%
%\name{gzcon}
%\alias{gzcon}
%\title{
%  (De)compress I/O Through Connections
%}
%\description{
%  \code{gzcon} provides a modified connection that wraps an existing
%  connection, and decompresses reads or compresses writes through that
%  connection.  Standard \code{gzip} headers are assumed.
%}
%\usage{
%gzcon(con, level = 6, allowNonCompressed = TRUE)
%}
%\arguments{
%  \item{con}{a connection.}
%  \item{level}{integer between 0 and 9, the compression level when writing.}
%  \item{allowNonCompressed}{logical.  When reading, should
%    non-compressed input be allowed?}
%}
%\details{
%  If \code{con} is open then the modified connection is opened.  Closing
%  the wrapper connection will also close the underlying connection.
%
%  Reading from a connection which does not supply a \code{gzip} magic
%  header is equivalent to reading from the original connection if
%  \code{allowNonCompressed} is true, otherwise an error.
%
%  Compressed output will contain embedded NUL bytes, and so \code{con}
%  is not permitted to be a \code{\link{textConnection}} opened with
%  \code{open = "w"}.  Use a writable \code{\link{rawConnection}} to
%  compress data into a variable.
%
%  The original connection becomes unusable: any object pointing to it will
%  now refer to the modified connection.  For this reason, the new
%  connection needs to be closed explicitly.
%}
%\value{
%  An object inheriting from class \code{"connection"}.  This is the same
%  connection \emph{number} as supplied, but with a modified internal
%  structure.  It has binary mode.
%}
%\seealso{\code{\link{gzfile}}}
%\examples{
%\donttest{## Uncompress a data file from a URL
%z <- gzcon(url("http://www.stats.ox.ac.uk/pub/datasets/csb/ch12.dat.gz"))
%# read.table can only read from a text-mode connection.
%raw <- textConnection(readLines(z))
%close(z)
%dat <- read.table(raw)
%close(raw)
%dat[1:4, ]
%}
%
%## gzfile and gzcon can inter-work.
%## Of course here one would use gzfile, but file() can be replaced by
%## any other connection generator.
%zz <- gzfile("ex.gz", "w")
%cat("TITLE extra line", "2 3 5 7", "", "11 13 17", file = zz, sep = "\n")
%close(zz)
%readLines(zz <- gzcon(file("ex.gz", "rb")))
%close(zz)
%unlink("ex.gz")
%% Cygwin seems to require a different name
%zz <- gzcon(file("ex2.gz", "wb"))
%cat("TITLE extra line", "2 3 5 7", "", "11 13 17", file = zz, sep = "\n")
%close(zz)
%readLines(zz <- gzfile("ex2.gz"))
%close(zz)
%unlink("ex2.gz")
%}
%\keyword{file}
%\keyword{connection}
%
\encoding{UTF8}
