% File src/library/base/man/libPaths.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{libPaths}
\title{Search Paths for Packages}
\alias{.Library}
\alias{.Library.site}
\alias{.libPaths}
\alias{R_LIBS}
\alias{R_LIBS_SITE}
\alias{R_LIBS_USER}
\alias{.expand_R_libs_env_var}
\description{
  \code{.libPaths} はその中でパッケージを眺めるライブラリツリーを
  得る/設定する．
}
\usage{
.libPaths(new)

.Library
.Library.site
}
\arguments{
  \item{new}{\R のライブラリツリーを持つ文字列ベクトル．
    チルド展開(\code{\link{path.expand}})がなされ，もし
    プラットフォームがサポートすれば，
    ある要素が \code{*?[} のどれかを含めば
    展開される；\code{\link{Sys.glob}} を見よ．}
}
\details{
  \code{.Library} は既定のライブラリである \env{R_HOME} の
  サブディレクトリ \file{library} の位置を与える文字列である．

  \code{.Library.site} はサイトのライブラリの位置を与える(可能性として空の)
  文字列である．これは既定では \env{R_HOME} のサブディレクトリ
  \file{site-library} である(存在しないかもしれない)．

  \code{.libPaths} は \R が知っているライブラリツリーを得たり，
  設定するのに使われる(従ってパッケージを探すときにも)．もし引数
  \code{new} とともに使われると，ライブラリの検索パスは
  \code{unique(c(new, .Library.site, .Library))} 中の既存のディレクトリに設定され
  そしてこれが返される．もし引数がないと現在のアクティブなライブラリツリーが
  返される．

  末尾にスラッシュを持つパス \code{new} がどのように扱われるかは OS に依存する．
  POSIX ファイルシステムでは既存のディレクトリは普通末尾にスラッシュを使って
  指定される：末尾にスラッシュを持つ Windows のファイルパスは不正で，従って
  ライブラリ検索パスに加えられない．

#ifdef unix
  ライブラリ検索パスは起動時に環境変数 \env{R_LIBS} 
  (これは \R のライブラリツリーがルートを持つコロンで分離されたディレクトリの
  リストでなければならない)，ついで環境変数 \env{R_LIBS_USER} 中にあるものに
  よって初期化される．その時に存在するものだけが含められる．

  既定では \env{R_LIBS} は未設定であり，\R のバージョン \var{x.y.z} に対しては
  \env{R_LIBS_USER} はホームディレクトリの
  ディレクトリ \file{R/\var{R.version$platform}-library/\var{x.y}}
  に設定される(CRAN の OS X ビルドでは  \file{Library/R/\var{x.y}/library}．

  \code{.Library.site} は環境変数
  \env{R_LIBS_SITE} (ライブラリツリーのコロンで分離された空でないリスト)
  経由で設定できる．
#endif
#ifdef windows
  ライブラリ検索パスは起動時に環境変数 \env{R_LIBS} 
  (これは \R のライブラリツリーがルートを持つセミコロンで分離されたディレクトリの
  リストでなければならない)，ついで環境変数 \env{R_LIBS_USER} 中にあるものに
  よって初期化される．その時に存在するものだけが含められる．

  既定では \env{R_LIBS} は未設定であり，\R のバージョン \var{x.y.z} に対しては
  \env{R_LIBS_USER} はホームディレクトリの
  サブディレクトリ \file{R/win-library/\var{x.y}}
  に設定される(CRAN の OS X ビルドでは  \file{Library/R/\var{x.y}/library}．

  \code{.Library.site} は環境変数
  \env{R_LIBS_SITE} (ライブラリツリーのセミコロンで分離された空でないリスト)
  経由で設定できる．
#endif

  \env{R_LIBS_USER} と \env{R_LIBS_SITE} は共に起動プロセスの一部分として
  \R のバージョン固有の情報に対する指示事項の可能な拡張を集めることが出来る．
  可能な改造指示事項はすべて \samp{\%} で始まり一つの文字が続く(\samp{\%} を
  得るには \samp{\%\%} を使う)．現在利用できる改造指示事項には次がある：
  \describe{
    \item{\samp{\%V}}{パッチレベルを含む \R のバージョン数(例えば \samp{2.5.0})．}
    \item{\samp{\%v}}{パッチレベルを除いた \R のバージョン数(例えば \samp{2.5})．}
    \item{\samp{\%p}}{それ用に \R が構築されたプラットフォーム，
      \code{\link{R.version}$platform} の値．}
    \item{\samp{\%o}}{基礎にあるオペレーティングシステム，
      \code{\link{R.version}$os} の値．}
    \item{\samp{\%a}}{\R がそれ用に構築されたアーキテクチャ(CPU)，
      \code{\link{R.version}$arch} の値．}
  }
  (\R のバージョン情報の詳細は \code{\link{version}} を見よ．)

  関数 \code{.libPaths} は常に基礎名前空間中の \code{.Library} と
  \code{.Library.site} の値を使う．サイトにより
  \code{.Library.site} は \file{Rprofile.site} 中に設定できる．更新値を利用するにはこれは
  \code{.libPaths(.libPaths())} の呼び出しが続く必要がある．

  一貫性のため，パスは常に \code{\link{normalizePath}(winslash = "/")}
  で正規化される．
}
\value{
  ファイルパスの文字列ベクトル．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{library}}
}
\examples{
.libPaths()                 # R が知っている全てのライブラリツリー
}
\keyword{data}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/libPaths.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{libPaths}
%\title{Search Paths for Packages}
%\alias{.Library}
%\alias{.Library.site}
%\alias{.libPaths}
%\alias{R_LIBS}
%\alias{R_LIBS_SITE}
%\alias{R_LIBS_USER}
%\alias{.expand_R_libs_env_var}
%\description{
%  \code{.libPaths} gets/sets the library trees within which packages are
%  looked for.
%}
%\usage{
%.libPaths(new)
%
%.Library
%.Library.site
%}
%\arguments{
%  \item{new}{a character vector with the locations of \R library
%    trees.  Tilde expansion (\code{\link{path.expand}}) is done, and if
%    any element contains one of \code{*?[}, globbing is done where
%    supported by the platform: see \code{\link{Sys.glob}}.}
%}
%\details{
%  \code{.Library} is a character string giving the location of the
%  default library, the \file{library} subdirectory of \env{R_HOME}.
%
%  \code{.Library.site} is a (possibly empty) character vector giving the
%  locations of the site libraries, by default the \file{site-library}
%  subdirectory of \env{R_HOME} (which may not exist).
%
%  \code{.libPaths} is used for getting or setting the library trees that
%  \R knows about (and hence uses when looking for packages).  If called
%  with argument \code{new}, the library search path is set to
%  the existing directories in \code{unique(c(new, .Library.site, .Library))}
%  and this is returned.  If given no argument, a character vector with
%  the currently active library trees is returned.
%
%  How paths \code{new} with a trailing slash are treated is
%  OS-dependent.  On a POSIX filesystem existing directories can usually
%  be specified with a trailing slash: on Windows filepaths with a
%  trailing slash (or backslash) are invalid and so will never be added
%  to the library search path.
%
%#ifdef unix
%  The library search path is initialized at startup from the environment
%  variable \env{R_LIBS} (which should be a colon-separated list of
%  directories at which \R library trees are rooted) followed by those in
%  environment variable \env{R_LIBS_USER}.  Only directories which exist
%  at the time will be included.
%
%  By default \env{R_LIBS} is unset, and \env{R_LIBS_USER} is set to
%  directory \file{R/\var{R.version$platform}-library/\var{x.y}}
%  of the home directory (or \file{Library/R/\var{x.y}/library} for
%  CRAN OS X builds), for \R \var{x.y.z}.
%
%  \code{.Library.site} can be set via the environment variable
%  \env{R_LIBS_SITE} (as a non-empty colon-separated list of library trees).
%#endif
%#ifdef windows
%  The library search path is initialized at startup from the environment
%  variable \env{R_LIBS} (which should be a semicolon-separated list of
%  directories at which \R library trees are rooted) followed by those in
%  environment variable \env{R_LIBS_USER}.  Only directories which exist
%  at the time will be included.
%
%  By default \env{R_LIBS} is unset, and \env{R_LIBS_USER} is set to
%  subdirectory \file{R/win-library/\var{x.y}} of the home directory,
%  for \R \var{x.y.z}.
%
%  \code{.Library.site} can be set via the environment variable
%  \env{R_LIBS_SITE} (as a non-empty semicolon-separated list of library trees).
%#endif
%
%  Both \env{R_LIBS_USER} and \env{R_LIBS_SITE} feature possible
%  expansion of specifiers for \R version specific information as part of
%  the startup process.  The possible conversion specifiers all start
%  with a \samp{\%} and are followed by a single letter (use \samp{\%\%}
%  to obtain \samp{\%}), with currently available conversion
%  specifications as follows:
%  \describe{
%    \item{\samp{\%V}}{\R version number including the patchlevel (e.g.,
%      \samp{2.5.0}).}
%    \item{\samp{\%v}}{\R version number excluding the patchlevel (e.g.,
%      \samp{2.5}).}
%    \item{\samp{\%p}}{the platform for which \R was built, the value of
%      \code{\link{R.version}$platform}.}
%    \item{\samp{\%o}}{the underlying operating system, the value of
%      \code{\link{R.version}$os}.}
%    \item{\samp{\%a}}{the architecture (CPU) \R was built on/for, the
%      value of \code{\link{R.version}$arch}.}
%  }
%  (See \code{\link{version}} for details on R version information.)
%
%  Function \code{.libPaths} always uses the values of \code{.Library}
%  and \code{.Library.site} in the base namespace.  \code{.Library.site}
%  can be set by the site in \file{Rprofile.site}, which should be
%  followed by a call to \code{.libPaths(.libPaths())} to make use of the
%  updated value.
%
%  For consistency, the paths are always normalized by
%  \code{\link{normalizePath}(winslash = "/")}.
%}
%\value{
%  A character vector of file paths.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{library}}
%}
%\examples{
%.libPaths()                 # all library trees R knows about
%}
%\keyword{data}
%
\encoding{UTF8}
