% File src/library/base/man/match.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{match}
\alias{match}
\alias{\%in\%}
\title{Value Matching}
\description{
  \code{match} はその最初の引数と二番目の引数中の(最初の)マッチの位置の
  ベクトルを返す．

  \code{\%in\%} は二項演算子としてのより直感的なインタフェイスで，
  その左側の被演算項に対するマッチの有無を示す論理値ベクトルを返す．
}
\usage{
match(x, table, nomatch = NA_integer_, incomparables = NULL)

x \%in\% table
}
\arguments{
  \item{x}{ベクトルか \code{NULL}：マッチされるべき値．
    \link{long vector} がサポートされている．}
  \item{table}{ベクトルか \code{NULL}：マッチの対象になる値．
    \link{long vector} がサポートされている．}
  \item{nomatch}{マッチが見つからなかった場合に返される値．
    これは \code{integer} に強制変換されることを注意する．}
  \item{incomparables}{マッチ不能な値のベクトル．
    \code{x} 中のこのベクトル中の値にマッチする任意の値には
    \code{nomatch} 値が付値される．歴史的な理由から \code{FALSE} は
    \code{NULL} に等しい．}
}
\value{
  \code{x} と同じ長さのベクトル．

  \code{match}: もしマッチがあれば \code{table} 中の最初のマッチの位置，
  マッチが無ければ  \code{nomatch} を与える整数ベクトル．

  もし \code{x[i]} が \code{table[j]} に等しいことがわかれば，返される値の
  \code{i} 番目の値は可能な最小の \code{j} に対する \code{j} である．,
  もしマッチが見つからなければ，値は \code{nomatch} である．

  \code{\%in\%}: 論理値ベクトルで，\code{x} の各要素に対してマッチがあったかどうかを
  指示する：従って値は \code{TRUE} か \code{FALSE} で，決して \code{NA}
  にはならない．
}
\details{
  \code{\%in\%} は現在以下のように定義されている\cr
  \code{"\%in\%" <- function(x, table) match(x, table, nomatch = 0) > 0}

  因子，バイトベクトル，そしてリストは文字列に変換され，それからマッチ前に
  \code{x} と \code{table} は同じ型に変換される(\R の順序
  logical < integer < numeric < complex < character 中の二つの型の後者)
  もし \code{incomparables} が正の長さを持てばそれは同じ型に変換される．

  リストへに対するマッチングは非常に遅くなる可能性があり，簡単な場合をのぞいて
  避けることが勧められる．

  正確には何が何にマッチするかはある程度定義次第である．
  全ての型に対し \code{NA} は \code{NA} にマッチするが他の型には
  マッチしない．
  実数と複素数値に対しては，\code{NaN} 値は他の任意の \code{NaN} 値に
  マッチすると見做されるが，\code{NA} とはマッチしない．

  \code{\%in\%} が決して \code{NA} を返さないという点は
  \code{if} 条件で特に有用になる．

  もし入力が \code{"bytes"} とマークされていれば文字列はバイト列として比較される
  (\code{\link{Encoding}} を見よ)．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  文字列の(\emph{部分})マッチングには \code{\link{pmatch}} と \code{\link{charmatch}}，
  関数の引数のマッチングには \code{\link{match.arg}} 等．
  \code{\link{findInterval}} は同じように位置のベクトルを返すが，
  正確なマッチよりは区間中の個数を見つける．

  \code{\%in\%} の S 互換な同値物は \code{\link{is.element}}．
}
\examples{
## 二つの集合の共通部分は match() を使って定義できる：
## 簡単なバージョン：
## intersect <- function(x, y) y[match(x, y, nomatch = 0)]
intersect # 基本パッケージ中の R 関数はもう少し注意深い
intersect(1:10, 7:20)

1:10 \%in\% c(1,3,5,9)
sstr <- c("c","ab","B","bba","c",NA,"@","bla","a","Ba","\%")
sstr[sstr \%in\% c(letters, LETTERS)]

"\%w/o\%" <- function(x, y) x[!x \%in\% y] #--  y を除いた x
(1:10) \%w/o\% c(3,7,12)
## setdiff() は非常に似ており典型的により意味がある：
        c(1:6,7:2) \%w/o\% c(3,7,12)  # -> 重複を保存
setdiff(c(1:6,7:2),        c(3,7,12)) # -> ユニークな値
}
\keyword{manip}
\keyword{logic}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/match.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{match}
%\alias{match}
%\alias{\%in\%}
%\title{Value Matching}
%\description{
%  \code{match} returns a vector of the positions of (first) matches of
%  its first argument in its second.
%
%  \code{\%in\%} is a more intuitive interface as a binary operator,
%  which returns a logical vector indicating if there is a match or not
%  for its left operand.
%}
%\usage{
%match(x, table, nomatch = NA_integer_, incomparables = NULL)
%
%x \%in\% table
%}
%\arguments{
%  \item{x}{vector or \code{NULL}: the values to be matched.
%    \link{Long vectors} are supported.}
%  \item{table}{vector or \code{NULL}: the values to be matched against.
%    \link{Long vectors} are not supported.}
%  \item{nomatch}{the value to be returned in the case when no match is
%    found.  Note that it is coerced to \code{integer}.}
%  \item{incomparables}{a vector of values that cannot be matched.  Any
%    value in \code{x} matching a value in this vector is assigned the
%    \code{nomatch} value.  For historical reasons, \code{FALSE} is
%    equivalent to \code{NULL}.}
%}
%\value{
%  A vector of the same length as \code{x}.
%
%  \code{match}: An integer vector giving the position in \code{table} of
%  the first match if there is a match, otherwise \code{nomatch}.
%
%  If \code{x[i]} is found to equal \code{table[j]} then the value
%  returned in the \code{i}-th position of the return value is \code{j},
%  for the smallest possible \code{j}.  If no match is found, the value
%  is \code{nomatch}.
%
%  \code{\%in\%}: A logical vector, indicating if a match was located for
%  each element of \code{x}: thus the values are \code{TRUE} or
%  \code{FALSE} and never \code{NA}.
%}
%\details{
%  \code{\%in\%} is currently defined as \cr
%  \code{"\%in\%" <- function(x, table) match(x, table, nomatch = 0) > 0}
%
%  Factors, raw vectors and lists are converted to character vectors, and
%  then \code{x} and \code{table} are coerced to a common type (the later
%  of the two types in \R's ordering, logical < integer < numeric <
%  complex < character) before matching.  If \code{incomparables} has
%  positive length it is coerced to the common type.
%
%  Matching for lists is potentially very slow and best avoided except in
%  simple cases.
%
%  Exactly what matches what is to some extent a matter of definition.
%  For all types, \code{NA} matches \code{NA} and no other value.
%  For real and complex values, \code{NaN} values are regarded
%  as matching any other \code{NaN} value, but not matching \code{NA}.
%
%  That \code{\%in\%} never returns \code{NA} makes it particularly
%  useful in \code{if} conditions.
%
%  Character strings will be compared as byte sequences if any input is
%  marked as \code{"bytes"} (see \code{\link{Encoding}}).
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{pmatch}} and \code{\link{charmatch}} for (\emph{partial})
%  string matching, \code{\link{match.arg}}, etc for function argument
%  matching.
%  \code{\link{findInterval}} similarly returns a vector of positions, but
%  finds numbers within intervals, rather than exact matches.
%
%  \code{\link{is.element}} for an S-compatible equivalent of \code{\%in\%}.
%}
%\examples{
%## The intersection of two sets can be defined via match():
%## Simple version:
%## intersect <- function(x, y) y[match(x, y, nomatch = 0)]
%intersect # the R function in base is slightly more careful
%intersect(1:10, 7:20)
%
%1:10 \%in\% c(1,3,5,9)
%sstr <- c("c","ab","B","bba","c",NA,"@","bla","a","Ba","\%")
%sstr[sstr \%in\% c(letters, LETTERS)]
%
%"\%w/o\%" <- function(x, y) x[!x \%in\% y] #--  x without y
%(1:10) \%w/o\% c(3,7,12)
%## Note that setdiff() is very similar and typically makes more sense: 
%        c(1:6,7:2) \%w/o\% c(3,7,12)  # -> keeps duplicates
%setdiff(c(1:6,7:2),        c(3,7,12)) # -> unique values
%}
%\keyword{manip}
%\keyword{logic}
%
\encoding{UTF8}
