% File src/library/base/man/matmult.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{matmult}
\alias{\%*\%}
\alias{matmult}
\title{Matrix Multiplication}
\description{
  もしそれらが共形ならば二つの行列の積を取る．もしひとつの引数がベクトルならば，
  それは二つの引数が共形になるように行又は列だけの行列に昇格される．
  もし双方が同じ長さのベクトルならば(行列としての)内積を返す．
}
\usage{
x \%*\% y
}
\arguments{
  \item{x, y}{数値又は複素数値の行列かベクトル．}
}
\details{
  \code{\link{as.matrix}} とは異なり，ベクトルが行列に昇格されるときは
  その名前は行又は列名として使われない．

  この演算子は S4 総称的であるが S3 総称的ではない．S4 メソッドは
  名前 \code{x} と \code{y} を持つ二つの関数として書かれる必要がある．
}
\value{
  倍精度実数もしくは複素数値の行列積．
  ただ一つのレベルを持つ次元を取り除くには \code{\link{drop}} を使う．
}
\note{ 
  もし二つの選択が \code{x} と \code{y} が共形な次元を持つことを
  許す時には，\R 3.2.0 以来ベクトルを 1 行または 1 列の行列とすることが
  より多くのケースで奨励されている．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  行列の \emph{クロス} 積には典型的には \code{\link{crossprod}()} と
  \code{tcrossprod()} が好ましい．
  \code{\link{matrix}}, \code{\link{Arithmetic}}, \code{\link{diag}}.
}
\examples{
x <- 1:4
(z <- x \%*\% x)    # スカラー("内")積 (1 x 1 行列)
drop(z)             # スカラーとして

y <- diag(x)
z <- matrix(1:12, ncol = 3, nrow = 4)
y \%*\% z
y \%*\% x
x \%*\% z
}
\keyword{array}
\keyword{arith}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/matmult.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{matmult}
%\alias{\%*\%}
%\alias{matmult}
%\title{Matrix Multiplication}
%\description{
%  Multiplies two matrices, if they are conformable.  If one argument is
%  a vector, it will be promoted to either a row or column matrix to make
%  the two arguments conformable.  If both are vectors of the same
%  length, it will return the inner product (as a matrix).
%}
%\usage{
%x \%*\% y
%}
%\arguments{
%  \item{x, y}{numeric or complex matrices or vectors.}
%}
%\details{
%  When a vector is promoted to a matrix, its names are not
%  promoted to row or column names, unlike \code{\link{as.matrix}}.
%
%  This operator is S4 generic but not S3 generic.  S4 methods need to be
%  written for a function of two arguments named \code{x} and \code{y}.
%}
%\value{
%  A double or complex matrix product.  Use \code{\link{drop}} to remove
%  dimensions which have only one level.
%}
%\note{
%  Since \R 3.2.0, promotion of a vector to a 1-row or 1-column matrix
%  happens in even more cases, when one of the two choices allows
%  \code{x} and \code{y} to get conformable dimensions.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  For matrix \emph{cross}products, \code{\link{crossprod}()} and
%  \code{tcrossprod()} are typically preferable.
%  \code{\link{matrix}}, \code{\link{Arithmetic}}, \code{\link{diag}}.
%}
%\examples{
%x <- 1:4
%(z <- x \%*\% x)    # scalar ("inner") product (1 x 1 matrix)
%drop(z)             # as scalar
%
%y <- diag(x)
%z <- matrix(1:12, ncol = 3, nrow = 4)
%y \%*\% z
%y \%*\% x
%x \%*\% z
%}
%\keyword{array}
%\keyword{arith}
%
\encoding{UTF8}
