% File src/library/base/man/seq.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{seq}
\title{Sequence Generation}
\alias{seq}
\alias{seq.default}
\alias{seq.int}
\alias{seq_along}
\alias{seq_len}
\description{
  規則正しい列を作る．\code{seq} は既定のメソッドを持つ標準的な総称的関数である．
  \code{seq.int} はプリミティブ関数で相当速いが少しの制約を持つ．
  \code{seq_along} と \code{seq_len} は二つの普通のケースに対する非常に
  速いプリミティブ関数である．
}
\usage{
seq(\dots)

\method{seq}{default}(from = 1, to = 1, by = ((to - from)/(length.out - 1)),
    length.out = NULL, along.with = NULL, \dots)

seq.int(from, to, by, length.out, along.with, \dots)

seq_along(along.with)
seq_len(length.out)
}
\arguments{
  \item{\dots}{メソッドに・から渡される引数．}
  \item{from, to}{列の開始と(最大)終了値．
    \code{from} が名前無しの引数として提供されない限り長さ \code{1}．}
  \item{by}{数値：列の増分．}
  \item{length.out}{列の希望の長さ．
    非負値で，\code{seq} と \code{seq.int} に対しては整数でなければ
    丸められる．}
  \item{along.with}{この引数の長さから長さを取る．}
}
\details{
  数値の入力は全て有限でなければならない(つまり無限，\code{\link{NaN}}，
  そして \code{NA} でない)．

  \code{seq} と \code{seq.int} の名前のない引数の解釈は標準ではなく，
  プログラムでは常に引数に名前を付けることが勧められる．

  \code{seq} は総称的であり，既定のメソッドだけがここで説明される．
  これは引数の名前にかかわらずその\strong{最初の}引数に関して
  選択適用される．これは \code{along.with} のつもりで唯一つの引数で
  呼び出されると意図しない結果を持ち得る：
  その場合は \code{seg_along} を使うほうが好ましい．

  \code{seq.int} は内部総称的で，(引数のマッチング前に)最初に与えられた引数に基づいて
  \code{"seq"} に対するメソッドを選択適用する．

  典型的な使用法は
\preformatted{seq(from, to)
seq(from, to, by= )
seq(from, to, length.out= )
seq(along.with= )
seq(from)
seq(length.out= )
}
  最初の形式は列 \code{from, from+/-1, \dots, to} を生成する
  (\code{from:to} と同じ)．

  二番目の形式は列の値が \code{to} より小さいか等しくなるまで
  \code{from, from+by}, \ldots, を生成する．
  \code{to - from} と \code{by} が異なった符号ならエラーになる．
  計算された最後の値は丸め誤差を許して \code{to} を超えることができるが，
  \code{to} に丸められる．(\sQuote{少し超える}とは
  \eqn{10^{-10}}{1e-10} 倍の \code{abs(from - to)} の範囲の誤差である．)

  三番目の形式は \code{length.out} 個の
  \code{from} から \code{to} までの等間隔の値の列を生成する．
  (\code{length.out} は普通 \code{length} や \code{len} と省略され，
  \code{seq_len} は相当速い．)

  四番目の形式は整数列 \code{1, 2, \dots, length(along.with)}
  を生成する．(\code{along.with} は普通 \code{along} と省略され，
  \code{seq_along} は相当速い．)

  五番目の形式は列 \code{1, 2, \dots, length(from)} を
  生成する(あたかも引数 \code{along.with} が指定されているかのように)．
  例外は引数が長さ 1 の数値の時で，その時は(S との互換性から \code{seq(0)}
  に対しても) \code{1:from} と解釈される．
  \code{seq_along} か \code{seq_len} のどちらかの使用がよほど好ましい
  (S との厳密な互換性が本質的でない限り)．

  最後の形式は整数列 \code{1, 2, \dots, length.out} を生成する．
  例外は \code{length.out = 0} の時で，その時は
  \code{integer(0)} を生成する．

  非常に小さな列(\code{from - to} がオーダー \eqn{10^{-14}} 倍の
  二つの端点の大きい方の値)は \code{from} を返す．

  \code{seq} に対して(だけ)は，\code{length.out} 又は \code{along.with} が
  指定されている限り \code{from}, \code{to} そして
  \code{by} の内最大二つまでを複素数で与えられる．
  より一般的に，\code{seq} の既定メソッドは
  \code{Math}, \code{Ops} そして \code{Summary} グループ総称的
  関数に対するメソッドを持つクラス付きオブジェクトを処理する．

  \code{seq.int}, \code{seq_along} そして \code{seq_len} は
  プリミティブである．
}
% We used to explain some of the circumstances when integer was
% returned, but people read that carelessly, so no longer.
\value{
  \code{seq.int} と数値引数に対する \code{seq} の既定メソッドは
  型 \code{"integer"} か \code{"double"} のベクトルを返す：
  プログラマーはそれを信用すべきではない．

  \code{seq_along} と \code{seq_len} は整数ベクトルを返す．
  例外はそれが\emph{ロングベクトル}の場合で，その時は倍精度実数になる．
}

\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  メソッド \code{\link{seq.Date}} と \code{\link{seq.POSIXt}}．

  \code{\link{:}},
  \code{\link{rep}},
  \code{\link{sequence}},
  \code{\link{row}},
  \code{\link{col}}.
}
\examples{
seq(0, 1, length.out = 11)
seq(stats::rnorm(20)) # 実効的に 'along'
seq(1, 9, by = 2)     # 'end' にマッチ
seq(1, 9, by = pi)    # 'end' 以下にとどまる
seq(1, 6, by = 3)
seq(1.575, 5.125, by = 0.05)
seq(17) # 1:17 と同じ，又は seq_len(17) がより良い
}
\keyword{manip}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/seq.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{seq}
%\title{Sequence Generation}
%\alias{seq}
%\alias{seq.default}
%\alias{seq.int}
%\alias{seq_along}
%\alias{seq_len}
%\description{
%  Generate regular sequences.  \code{seq} is a standard generic with a
%  default method.  \code{seq.int} is a primitive which can be
%  much faster but has a few restrictions.  \code{seq_along} and
%  \code{seq_len} are very fast primitives for two common cases.
%}
%\usage{
%seq(\dots)
%
%\method{seq}{default}(from = 1, to = 1, by = ((to - from)/(length.out - 1)),
%    length.out = NULL, along.with = NULL, \dots)
%
%seq.int(from, to, by, length.out, along.with, \dots)
%
%seq_along(along.with)
%seq_len(length.out)
%}
%\arguments{
%  \item{\dots}{arguments passed to or from methods.}
%  \item{from, to}{the starting and (maximal) end values of the
%    sequence.  Of length \code{1} unless just \code{from} is supplied as
%    an unnamed argument.}
%  \item{by}{number: increment of the sequence.}
%  \item{length.out}{desired length of the sequence.  A
%    non-negative number, which for \code{seq} and \code{seq.int} will be
%    rounded up if fractional.}
%  \item{along.with}{take the length from the length of this argument.}
%}
%\details{
%  Numerical inputs should all be \link{finite} (that is, not infinite,
%  \code{\link{NaN}} or \code{NA}).
%
%  The interpretation of the unnamed arguments of \code{seq} and
%  \code{seq.int} is \emph{not} standard, and it is recommended always to
%  name the arguments when programming.
%
%  \code{seq} is  generic, and only the default method is described here.
%  Note that it dispatches on the class of the \strong{first} argument
%  irrespective of argument names.  This can have unintended consequences
%  if it is called with just one argument intending this to be taken as
%  \code{along.with}: it is much better to use \code{seg_along} in that
%  case.
%
%  \code{seq.int} is an \link{internal generic} which dispatches on
%  methods for \code{"seq"} based on the class of the first supplied
%  argument (before argument matching).
%
%  Typical usages are
%\preformatted{seq(from, to)
%seq(from, to, by= )
%seq(from, to, length.out= )
%seq(along.with= )
%seq(from)
%seq(length.out= )
%}
%  The first form generates the sequence \code{from, from+/-1, \dots, to}
%  (identical to \code{from:to}).
%
%  The second form generates \code{from, from+by}, \ldots, up to the
%  sequence value less than or equal to \code{to}.  Specifying \code{to -
%  from} and \code{by} of opposite signs is an error.  Note that the
%  computed final value can go just beyond \code{to} to allow for
%  rounding error, but is truncated to \code{to}.  (\sQuote{Just beyond}
%  is by up to \eqn{10^{-10}}{1e-10} times \code{abs(from - to)}.)
%
%  The third generates a sequence of \code{length.out} equally spaced
%  values from \code{from} to \code{to}.  (\code{length.out} is usually
%  abbreviated to \code{length} or \code{len}, and \code{seq_len} is much
%  faster.)
%
%  The fourth form generates the integer sequence \code{1, 2, \dots,
%    length(along.with)}.  (\code{along.with} is usually abbreviated to
%  \code{along}, and \code{seq_along} is much faster.)
%
%  The fifth form generates the sequence \code{1, 2, \dots, length(from)}
%  (as if argument \code{along.with} had been specified), \emph{unless}
%  the argument is numeric of length 1 when it is interpreted as
%  \code{1:from} (even for \code{seq(0)} for compatibility with S).
%  Using either \code{seq_along} or \code{seq_len} is much preferred
%  (unless strict S compatibility is essential).
%
%  The final form generates the integer sequence \code{1, 2, \dots,
%  length.out} unless \code{length.out = 0}, when it generates
%  \code{integer(0)}.
%
%  Very small sequences (with \code{from - to} of the order of \eqn{10^{-14}}
%  times the larger of the ends) will return \code{from}.
%
%  For \code{seq} (only), up to two of \code{from}, \code{to} and
%  \code{by} can be supplied as complex values provided \code{length.out}
%  or \code{along.with} is specified.  More generally, the default method
%  of \code{seq} will handle classed objects with methods for
%  the \code{Math}, \code{Ops} and \code{Summary} group generics.
%
%  \code{seq.int}, \code{seq_along} and \code{seq_len} are
%  \link{primitive}.
%}
%% We used to explain some of the circumstances when integer was
%% returned, but people read that carelessly, so no longer.
%\value{
%  \code{seq.int} and the default method of \code{seq} for numeric
%  arguments return a vector of type \code{"integer"} or \code{"double"}:
%  programmers should not rely on which.
%
%  \code{seq_along} and \code{seq_len} return an integer vector, unless
%  it is a \emph{long vector} when it will be double.
%}
%
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  The methods \code{\link{seq.Date}} and \code{\link{seq.POSIXt}}.
%
%  \code{\link{:}},
%  \code{\link{rep}},
%  \code{\link{sequence}},
%  \code{\link{row}},
%  \code{\link{col}}.
%}
%\examples{
%seq(0, 1, length.out = 11)
%seq(stats::rnorm(20)) # effectively 'along'
%seq(1, 9, by = 2)     # matches 'end'
%seq(1, 9, by = pi)    # stays below 'end'
%seq(1, 6, by = 3)
%seq(1.575, 5.125, by = 0.05)
%seq(17) # same as 1:17, or even better seq_len(17)
%}
%\keyword{manip}
%
\encoding{UTF8}
