% File src/library/base/man/sets.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{sets}
\alias{union}
\alias{intersect}
\alias{setdiff}
\alias{is.element}
\alias{setequal}
\concept{set operations}
\concept{sets} % not that useful for searches, but requested in a bug report
\alias{intersection}
\concept{difference}

\title{Set Operations}
\usage{
union(x, y)
intersect(x, y)
setdiff(x, y)
setequal(x, y)

is.element(el, set)
}
\arguments{
  \item{x, y, el, set}{(同じモードの)ベクトルで重複値を持たない(概念上)
    項目の列を含む．}
}
\description{
  二つのベクトルに関する\bold{集合の}合併，共通部分，(非対称!)差，同等性，
  そして所属関係の検査を実行する．
}
\details{
  \code{union}, \code{intersect}, \code{setdiff} そして
  \code{setequal} の各々は引数中の重複値を捨て去り，
  それらの引数に \code{\link{as.vector}} を適用する(従って
  特に因子は文字列ベクトルに変換される)．

  \code{is.element(x, y)} は \code{x \%in\% y} と等しい．
}
\value{
  \code{setdiff} と \code{intersect} に対してそれぞれ \code{x} や \code{y}
  と同じモードのベクトル．そして \code{union} に対しては共通ｎモード．

  \code{setequal} に対しては論理値スカラーで，
  \code{is.element} に対しては \code{x} と同じ長さの論理値．
}
\seealso{
  \code{\link{\%in\%}}

  プロットの注釈で \code{union} と \code{intersect} を使うには
  \sQuote{\link{plotmath}}．
}

\examples{
(x <- c(sort(sample(1:20, 9)), NA))
(y <- c(sort(sample(3:23, 7)), NA))
union(x, y)
intersect(x, y)
setdiff(x, y)
setdiff(y, x)
setequal(x, y)

## 全ての可能な x & y に対して真：
setequal( union(x, y),
          c(setdiff(x, y), intersect(x, y), setdiff(y, x)))

is.element(x, y) # 長さ 10
is.element(y, x) # 長さ  8
}
\keyword{misc}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/sets.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{sets}
%\alias{union}
%\alias{intersect}
%\alias{setdiff}
%\alias{is.element}
%\alias{setequal}
%\concept{set operations}
%\concept{sets} % not that useful for searches, but requested in a bug report
%\alias{intersection}
%\concept{difference}
%
%\title{Set Operations}
%\usage{
%union(x, y)
%intersect(x, y)
%setdiff(x, y)
%setequal(x, y)
%
%is.element(el, set)
%}
%\arguments{
%  \item{x, y, el, set}{vectors (of the same mode) containing a sequence
%    of items (conceptually) with no duplicated values.}
%}
%\description{
%  Performs \bold{set} union, intersection, (asymmetric!) difference,
%  equality and membership on two vectors.
%}
%\details{
%  Each of \code{union}, \code{intersect}, \code{setdiff} and
%  \code{setequal} will discard any duplicated values in the arguments,
%  and they apply \code{\link{as.vector}} to their arguments (and so
%  in particular coerce factors to character vectors).
%
%  \code{is.element(x, y)} is identical to \code{x \%in\% y}.
%}
%\value{
%  A vector of the same \code{\link{mode}} as \code{x} or \code{y} for
%  \code{setdiff} and \code{intersect}, respectively, and
%  of a common mode for \code{union}.
%
%  A logical scalar for \code{setequal} and a logical of the same
%  length as \code{x} for \code{is.element}.
%}
%\seealso{
%  \code{\link{\%in\%}}
%
%  \sQuote{\link{plotmath}} for the use of \code{union} and
%  \code{intersect} in plot annotation.
%}
%
%\examples{
%(x <- c(sort(sample(1:20, 9)), NA))
%(y <- c(sort(sample(3:23, 7)), NA))
%union(x, y)
%intersect(x, y)
%setdiff(x, y)
%setdiff(y, x)
%setequal(x, y)
%
%## True for all possible x & y :
%setequal( union(x, y),
%          c(setdiff(x, y), intersect(x, y), setdiff(y, x)))
%
%is.element(x, y) # length 10
%is.element(y, x) # length  8
%}
%\keyword{misc}
%
\encoding{UTF8}
