% File src/library/base/man/system.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{system}
%%\alias{system}
#ifdef unix
%%\alias{shell}
#endif
\title{Invoke a System Command}
\description{
  \code{system} は \code{command} で指定される OS 命令を実行する．
}
\usage{
system(command, intern = FALSE,
       ignore.stdout = FALSE, ignore.stderr = FALSE,
       wait = TRUE, input = NULL, show.output.on.console = TRUE,
       minimized = FALSE, invisible = TRUE)
}
\arguments{
  \item{command}{起動されるシステム命令で文字列で与えられる．}
  \item{intern}{論理値(\code{NA} でない)で命令の出力を \R の
    文字列ベクトルとして捕捉するかどうかを指示する．}
  \item{ignore.stdout, ignore.stderr}{論理値(\code{NA} でない)で
    \file{stdout} や \file{stderr} へ書かれるメッセージを無視すべきかどうか
    を指示する．}
  \item{wait}{論理値(\code{NA} でない)で \R インタプリタが
    命令が終了するまで待つかどうか，それとも非同期的に実行するかどうかを
    指示する．もし \code{intern = TRUE} ならばこれは無視される
    (そしてインタプリタは常に待つ)．}
  \item{input}{もし文字列ベクトルが提供されると，
    これは行毎に一つの文字列を一時ファイルに
    コピーし，そして \code{command} の標準入力はファイルへ
    リダイレクトされる．}
#ifdef unix
  \item{show.output.on.console, minimized, invisible}{
    Windows では受け入れられるがこのプラットフォームでは無視される
    引数で，警告が出る．}
#endif
#ifdef windows
  \item{show.output.on.console}{論理値(\code{NA} でない)で，
    命令の出力を捕捉しそれを \R コンソールに表示する
    (\code{Rterm} では使われず，それは \code{wait} が偽で無い限り
    出力を端末に示す)．}
  \item{minimized}{論理値(\code{NA} でない)で，命令ウィンドが
    最初最小化されたウィンドとして表示されるかどうかを指示する．}
  \item{invisible}{論理値(\code{NA} でない)で，
    命令ウィンドがスクリーン上に見えるかどうかを指示する．}
#endif
}
\details{
  このインタフェイスは年と共にかなり複雑になって来ている：
  新しいコードに対して勧められるより可搬性があり柔軟な
  インタフェイスである \code{\link{system2}} を見よ．
  
  \code{command} は空白で分離された命令と引数として構文解析される．
  従って命令へのパス(またはファイルパスのような単一の引数)が
  空白を持てば，それは例えば \code{\link{shQuote}} を使い引用化
  されなければならない．
#ifdef windows
  Windows では二重引用符だけが許される：
  例を見よ．(注意：Windows のパス名は二重引用符を含めないので，
  埋め込み引用符のエスケープ化を心配する必要は無い．)

  \code{command} は実行可能プログラム(拡張子 \file{.exe}, \file{.com})又は
  バッチファイル(拡張子 \file{.cmd} と \file{.bat})でなければならない：
  もし何も提供されないとこれらの拡張子が順に試みられる．
  これはリダイレクション，パイプ，DOS の内部命令等は使うことが出来ない
  ことを意味する：
  もしシェルのコマンドラインを渡したければ \code{\link{shell}} を見よ．

  \code{command} に対する検索はシステム依存である：
  それは \env{PATH} の前に \R の \file{bin} ディレクトリ，作業ディレクトリ，
  そして Windows のシステムディレクトリを含む．
#endif
#ifdef unix
  Unix 風システムはコマンドラインをシェル(普通 \file{/bin/sh} で
  POSIX はこのシェルを要求する)に送るので，\code{command} はシェルが実行可能と
  考える何でも良く，シェルスクリプトを含み，それは \code{;} で
  分離された複数の命令を含むことが出来る．

  Windows では \code{system} はシェルを使わず，コマンドラインをシェルに渡す
  別の関数 \code{shell} がある．

  もし \code{intern} が \code{TRUE} なら \code{popen} が命令を起動し，
  出力は行ごとに \R の文字列ベクトルに集められる．
  もし \code{intern} が \code{FALSE} なら C 関数 \code{system} が
  命令の起動に使われる．

  \code{wait} が命令に \code{&} を加えることで実装されている：これは
  原理的にシェルとは独立であるが，POSIX により必要とされるので広く
  サポートされている．
#endif

  最初の二つの後の引数は時折変更されてきている：最初の後の全ての引数には
  名前を付けることが勧められる．

  命令が実行できるかどうかを確認するのに \code{system} を使うのは
  多くの落とし穴がある --- \code{\link{Sys.which}} がより好ましい．
}

\value{
  もし \code{intern = TRUE} なら命令の出力を与える文字列で，
  文字列毎に一行を与える．(8095 バイトを超える出力行は分割される．)
  もし命令が \R によって実行できなければエラーになる．
#ifdef windows
  \code{Rgui} コンソールの下では \code{intern = TRUE} は
   \code{ignore.stderr = TRUE} で無い限り \code{stderr} も
   捕捉する．
#endif
  もし \code{command} が稼働するがゼロでない終了状態を返すならば
  警告と共にそれが報告され結果の属性 \code{"status"} に記録される：
  属性 \code{"errmsg"} もまた利用できる．

  もし \code{intern = FALSE} ならば，返り値はエラーコード(成功ならば \code{0})で，
  不可視の属性を与える(従って明示的にプリントされる必要がある)．
  もし命令が何らかの理由で実行不可能ならば値は
  \code{127} になる．さもなければ，もし \code{wait = TRUE} ならば，値は
  命令が返す終了状態で，そしてもし \code{wait = FALSE} ならばそれは
  \code{0} (便宜的な成功値)になる．
#ifdef windows
  ある種の Windows の命令は範囲外の状態値(例えば \code{-1})を返すので
  値の最下位 16 ビットだけが使われる．

  もし \code{intern = FALSE, wait = TRUE, show.output.on.console = TRUE} ならば
  \sQuote{コンソールアプリケーション}である命令からの \file{stdout} と
  \file{stderr} 出力(\code{ignore.stdout = TRUE} や
  \code{ignore.stderr = TRUE} で無い限り)は
  \R コンソール(\code{Rgui})か \R を実行しているウィンド(\code{Rterm}) に
  現れるべきである．

  全ての Windows の実行プログラムが出力のリダイレクトを訂正に尊重するわけではなく，
  \code{Rterm} (\code{Rgui} ではなく)のようなコンソールアプリケーションからの
  ものだけに限られるかもしれない：
  例えば \file{fc.exe} はかってはそうしたものの一つであったが，最近では
  かなり改善されてきている．
#endif
}

#ifdef unix
\section{stdout と stderr}{
  \R のコマンドラインに対しては，\code{ignore.stderr = TRUE} で無い限り
  \file{stderr} に書き込まれたエラーメッセージは端末に送られる．
  これらは(殆どのシェルで恐らく)次のようにして捕捉できる
\preformatted{    system("some command 2>&1", intern = TRUE)
}

  GUI に対しては，もし \code{intern = FALSE} ならば
  \file{stdout} や \file{stderr} に送られた出力に何が起きるかは
  インタフェイス依存であり，そうしたメッセージが GUI コンソールに
  現れると仮定するのは安全ではない
  (OS X の GUI コンソールでは現れるが，そうではないものもある)．
}
#endif

#ifdef windows
\section{命令との交互作用}{
  正確にはユーザに何が見えるかはオプションパラメータ，
  \code{Rgui} か \code{Rterm} が使われているか，そして
  コンソール命令又は GUI アプリケーションが命令で実行されているか．
  に依存する，

  既定では命令が終了し出力が表示されるまでそのフロントエンドにも何も
  見えない．

  コンソール命令に対しては \code{Rgui} はあたらしい\sQuote{コンソール}を
  開くので，もし \code{invisible = FALSE} なら命令用のウィンドが
  命令の持続期間の間現れる．\code{Rterm} に対しては
  \code{wait = FALSE} で \code{invisible = FALSE} の時だけ
  コンソールアプリケーションのために別個の命令用ウィンドが
  現れる．

  GUI アプリケーションは \code{invisible} が偽で無い限りどのフロントエンド
  にも表示しない．

  待機している実行中の命令をキーボードから
  (\code{Rgui} では the \samp{Esc} キー，又は \code{Rterm} では
  \samp{Ctrl-C})ｍ又は \code{Rgui} メニューから中断することが可能である：
  これは少なくとも制御を \R コンソールに戻す必要がある．\R はプロセスを
  クリーンにシャットダウンしようと試みるが，
  停止を矯正しなければならないこともあり，保存されていない作業を失う
  可能性もある．

  \code{intern = TRUE} 又は \code{show.output.on.console = TRUE} を設定し
  \code{Rgui} からユーザの入力を要求するコンソールアプリケーションを
  実行しようとしない．それらは動作しない．
}
#endif

\section{Unix と Windows の違い}{
  プロセスがどのように起動されるのかは基本的に Windows と
  Unix 風システムでは異なるし，\R 関数はその上に組み立てられている
  高水準 OS 関数も同様である．従って \code{system} がどのように振る舞うかについて
  OS 間で多くの違いがあるのは驚きではない．
  プログラマの便宜のためより重要なものをこの節で要約しておく．

  \itemize{
    \item 最も重要な違いは，Unix 風システムでは \code{system} は
    シェルを起動し，それからそれが \code{command} を実行することである．
    Windows では命令は直接実行される --
    \code{command} をシェルを使って実行するインタフェイスとしては
    \code{shell} を使う
    (既定では Windows のシェル \command{cmd.exe} で，これは POSIX シェル
    と大きな違いがある)．

    これはリダイレクトやパイプが \code{system} で動作することを
    仮定できないことを意味する(リダイレクトは時折動作するが，
    Windows のセキュリティパッチの後で動作しなくなる例を見たことがある)ので，
    WIndows では \code{\link{system2}} (又は \code{shell}) を使うべきである．

    \item 捕捉されない時 \code{stdout} と \code{stderr} に何が起きるかは
    \R がどのように実行されているかに依存する：Windows のバッチ命令は
    Unix 風に動作するが，Windows の GUI からはそれらは一般に失われる．
    \code{ignore.stderr = TRUE} で無い限り Windows の GUI コンソール
    から実行されれば \code{system(intern = TRUE)} は \file{stderr} を捕捉する．

    \item エラー時の挙動が微妙な仕方で異なる(そして \R のバージョンで
    異なっている)．

    \item \code{command} に対する引用化の慣例が異なるが，
    \code{\link{shQuote}}は可搬性のあるインタフェイスである．

    \item 引数 \code{show.output.on.console}, \code{minimized},
    \code{invisible} は Windows でだけ何かをする(そしてそこでは殆どの場合
    \command{Rgui} に関係する)．
  }
}
\seealso{
#ifdef windows
  より素朴ではないインタフェイスについては \code{\link{shell}} や
  \code{\link{shell.exec}}．
#endif
#ifdef unix
  使用中の OS でこれはどのように実装されているかについては
  \command{man system} と \command{man sh}．
#endif

  プラットフォーム固有の変数については \code{\link{.Platform}}．

  パイプコネクションの設定には \code{\link{pipe}}．
}
#ifdef unix
\examples{
# -F フラグを使い現在のディレクトリ中の全てのファイルをリストする
\dontrun{system("ls -F")}

# t1 は文字列ベクトルで，各要素は who からの出力の一つの行を与える
# (もしプラットフォームが who を持てば)
t1 <- try(system("who", intern = TRUE))

try(system("ls fizzlipuzzli", intern = TRUE, ignore.stderr = TRUE))
#ファイルが存在しないので長さゼロの結果，そして警告を与える．
}
#endif
#ifdef windows
\examples{
# エディタを起動し，それを終了するために待機する
\dontrun{system("notepad myfile.txt")}
# 好みのシェルを起動する：
\dontrun{system(Sys.getenv("COMSPEC"))}
\dontrun{
## ここで二種類の引用化を注意：
system(paste('"c:/Program Files/Mozilla Firefox/firefox.exe"',
             '-url cran.r-project.org'), wait = FALSE)}
}
#endif
\keyword{interface}
\keyword{file}
\keyword{utilities}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/system.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{system}
%\alias{system}
%#ifdef unix
%\alias{shell}
%#endif
%\title{Invoke a System Command}
%\description{
%  \code{system} invokes the OS command specified by \code{command}.
%}
%\usage{
%system(command, intern = FALSE,
%       ignore.stdout = FALSE, ignore.stderr = FALSE,
%       wait = TRUE, input = NULL, show.output.on.console = TRUE,
%       minimized = FALSE, invisible = TRUE)
%}
%\arguments{
%  \item{command}{the system command to be invoked, as a character string.}
%  \item{intern}{a logical (not \code{NA}) which indicates whether to
%    capture the output of the command as an \R character vector.}
%  \item{ignore.stdout, ignore.stderr}{a logical (not \code{NA})
%    indicating whether messages written to \file{stdout} or
%    \file{stderr} should be ignored.}
%  \item{wait}{a logical (not \code{NA}) indicating whether the \R
%    interpreter should wait for the command to finish, or run it
%    asynchronously.  This will be ignored (and the interpreter will
%    always wait) if \code{intern = TRUE}.}
%  \item{input}{if a character vector is supplied, this is copied one
%    string per line to a temporary file, and the standard input of
%    \code{command} is redirected to the file.}
%#ifdef unix
%  \item{show.output.on.console, minimized, invisible}{arguments
%    that are accepted on Windows but ignored on this platform, with a
%    warning.}
%#endif
%#ifdef windows
%  \item{show.output.on.console}{logical (not \code{NA}), indicates
%    whether to capture the output of the command and show it on the \R
%    console (not used by \code{Rterm}, which shows the output in the
%    terminal unless \code{wait} is false).}
%  \item{minimized}{logical (not \code{NA}), indicates whether a
%    command window should be displayed initially as a minimized window.}
%  \item{invisible}{logical (not \code{NA}), indicates whether a
%    command window should be visible on the screen.}
%#endif
%}
%\details{
%  This interface has become rather complicated over the years: see
%  \code{\link{system2}} for a more portable and flexible interface
%  which is recommended for new code.
%  
%  \code{command} is parsed as a command plus arguments separated by
%  spaces.  So if the path to the command (or a single argument such as a
%  file path) contains spaces, it must be quoted e.g.\sspace{}by
%  \code{\link{shQuote}}.
%#ifdef windows
%  Only double quotes are allowed on Windows: see the examples.  (Note: a
%  Windows path name cannot contain a double quote, so we do not need to
%  worry about escaping embedded quotes.)
%
%  \code{command} must be an executable (extensions \file{.exe},
%  \file{.com}) or a batch file (extensions \file{.cmd} and \file{.bat}):
%  these extensions are tried in turn if none is supplied.)  This means
%  that redirection, pipes, DOS internal commands, \dots cannot be used:
%  see \code{\link{shell}} if you want to pass a shell command-line.
%
%  The search path for \code{command} may be system-dependent: it will
%  include the \R \file{bin} directory, the working directory and the
%  Windows system directories before \env{PATH}.
%#endif
%#ifdef unix
%  Unix-alikes pass the command line to a shell (normally \file{/bin/sh},
%  and POSIX requires that shell), so \code{command} can be anything the
%  shell regards as executable, including shell scripts, and it can
%  contain multiple commands separated by \code{;}.
%
%  On Windows, \code{system} does not use a shell and there is a separate
%  function \code{shell} which passes command lines to a shell.
%
%  If \code{intern} is \code{TRUE} then \code{popen} is used to invoke the
%  command and the output collected, line by line, into an \R
%  \code{\link{character}} vector.  If \code{intern} is \code{FALSE} then
%  the C function \code{system} is used to invoke the command.
%
%  \code{wait} is implemented by appending \code{&} to the command: this
%  is in principle shell-dependent, but required by POSIX and so widely
%  supported.
%#endif
%
%  The ordering of arguments after the first two has changed from time to
%  time: it is recommended to name all arguments after the first.
%
%  There are many pitfalls in using \code{system} to ascertain if a
%  command can be run --- \code{\link{Sys.which}} is more suitable.
%}
%
%\value{
%  If \code{intern = TRUE}, a character vector giving the output of the
%  command, one line per character string.  (Output lines of more than
%  8095 bytes will be split.)  If the command could not be run an \R
%  error is generated.
%#ifdef windows
%  Under the \code{Rgui} console \code{intern = TRUE} also captures
%  \code{stderr} unless \code{ignore.stderr = TRUE}.
%#endif
%  If \code{command} runs but gives a non-zero exit status this will be
%  reported with a warning and in the attribute \code{"status"} of the
%  result: an attribute \code{"errmsg"} may also be available
%
%  If \code{intern = FALSE}, the return value is an error code (\code{0}
%  for success), given the invisible attribute (so needs to be printed
%  explicitly).  If the command could not be run for any reason, the
%  value is \code{127}.  Otherwise if \code{wait = TRUE} the value is the
%  exit status returned by the command, and if \code{wait = FALSE} it is
%  \code{0} (the conventional success value).
%#ifdef windows
%  Some Windows commands return out-of-range status values
%  (e.g., \code{-1}) and so only the bottom 16 bits of the value are used.
%
%  If \code{intern = FALSE, wait = TRUE, show.output.on.console = TRUE} the
%  \file{stdout} and \file{stderr} (unless \code{ignore.stdout = TRUE} or
%  \code{ignore.stderr = TRUE}) output from a command that is a
%  \sQuote{console application} should appear in the \R console
%  (\code{Rgui}) or the window running \R (\code{Rterm}).
%
%  Not all Windows executables properly respect redirection of output, or
%  may only do so from a console application such as \code{Rterm} and not
%  from \code{Rgui}: for example, \file{fc.exe} was among these in the past,
%  but we have had more success recently.
%#endif
%}
%
%#ifdef unix
%\section{Stdout and stderr}{
%  For command-line \R, error messages written to \file{stderr} will be
%  sent to the terminal unless \code{ignore.stderr = TRUE}.  They can be
%  captured (in the most likely shells) by
%\preformatted{    system("some command 2>&1", intern = TRUE)
%}
%
%  For GUIs, what happens to output sent to \file{stdout} or
%  \file{stderr} if \code{intern = FALSE} is interface-specific, and it
%  is unsafe to assume that such messages will appear on a GUI console
%  (they do on the OS X GUI's console, but not on some others).
%}
%#endif
%
%#ifdef windows
%\section{Interaction with the command}{
%  Precisely what is seen by the user depends on the optional parameters,
%  whether \code{Rgui} or \code{Rterm} is being used, and whether a
%  console command or GUI application is run by the command.
%
%  By default nothing will be seen in either front-end until the command
%  finishes and the output is displayed.
%
%  For console commands \code{Rgui} will open a new \sQuote{console}, so
%  if \code{invisible = FALSE}, a commands window will appear for the
%  duration of the command.  For \code{Rterm} a separate commands window
%  will appear for console applications only if \code{wait = FALSE} and
%  \code{invisible = FALSE}.
%
%  GUI applications will not display in either front-end unless
%  \code{invisible} is false.
%
%  It is possible to interrupt a running command being waited for from
%  the keyboard (using the \samp{Esc} key in \code{Rgui} or \samp{Ctrl-C}
%  in \code{Rterm}) or from the \code{Rgui} menu: this should at least
%  return control to the \R console.  \R will attempt to shut down the
%  process cleanly, but may need to force it to terminate, with the
%  possibility of losing unsaved work, etc.
%
%  Do not try to run console applications that require user
%  input from \code{Rgui} setting \code{intern = TRUE} or
%  \code{show.output.on.console = TRUE}.  They will not work.
%}
%#endif
%
%\section{Differences between Unix and Windows}{
%  How processes are launched differs fundamentally between Windows and
%  Unix-alike operating systems, as do the higher-level OS functions on
%  which this \R function is built.  So it should not be surprising that
%  there are many differences between OSes in how \code{system} behaves.
%  For the benefit of programmers, the more important ones are summarized
%  in this section.
%
%  \itemize{
%    \item The most important difference is that on a Unix-alike
%    \code{system} launches a shell which then runs \code{command}.  On
%    Windows the command is run directly -- use \code{shell} for an
%    interface which runs \code{command} \emph{via} a shell (by default
%    the Windows shell \command{cmd.exe}, which has many differences from
%    a POSIX shell).
%
%    This means that it cannot be assumed that redirection or piping will
%    work in \code{system} (redirection sometimes does, but we have seen
%    cases where it stopped working after a Windows security patch), and
%    \code{\link{system2}} (or \code{shell}) must be used on Windows.
%
%    \item What happens to \code{stdout} and \code{stderr} when not
%    captured depends on how \R is running: Windows batch commands behave
%    like a Unix-alike, but from the Windows GUI they are
%    generally lost.  \code{system(intern = TRUE)} captures \file{stderr}
%    when run from the Windows GUI console unless \code{ignore.stderr =
%      TRUE}.
%
%    \item The behaviour on error is different in subtle ways (and has
%    differed between \R versions).
%
%    \item The quoting conventions for \code{command} differ, but
%    \code{\link{shQuote}} is a portable interface.
%
%    \item Arguments \code{show.output.on.console}, \code{minimized},
%    \code{invisible} only do something on Windows (and are most relevant
%    to \command{Rgui} there).
%  }
%}
%\seealso{
%#ifdef windows
%  \code{\link{shell}} or \code{\link{shell.exec}} for a less raw
%  interface.
%#endif
%#ifdef unix
%  \command{man system} and \command{man sh} for how this is implemented
%  on the OS in use.
%#endif
%
%  \code{\link{.Platform}} for platform-specific variables.
%
%  \code{\link{pipe}} to set up a pipe connection.
%}
%#ifdef unix
%\examples{
%# list all files in the current directory using the -F flag
%\dontrun{system("ls -F")}
%
%# t1 is a character vector, each element giving a line of output from who
%# (if the platform has who)
%t1 <- try(system("who", intern = TRUE))
%
%try(system("ls fizzlipuzzli", intern = TRUE, ignore.stderr = TRUE))
%# zero-length result since file does not exist, and will give warning.
%}
%#endif
%#ifdef windows
%\examples{
%# launch an editor, wait for it to quit
%\dontrun{system("notepad myfile.txt")}
%# launch your favourite shell:
%\dontrun{system(Sys.getenv("COMSPEC"))}
%\dontrun{
%## note the two sets of quotes here:
%system(paste('"c:/Program Files/Mozilla Firefox/firefox.exe"',
%             '-url cran.r-project.org'), wait = FALSE)}
%}
%#endif
%\keyword{interface}
%\keyword{file}
%\keyword{utilities}
%\encoding{UTF8}

\encoding{UTF8}

