% File src/library/base/man/warning.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{warning}
\alias{warning}
\alias{suppressWarnings}
\title{Warning Messages}
\description{
  その引数そして(オプションで)それが呼び出された表現式や関数に
  対応する警告メッセージを生成する．
}
\usage{
warning(\dots, call. = TRUE, immediate. = FALSE, noBreaks. = FALSE,
        domain = NULL)
suppressWarnings(expr)
}
\arguments{
  \item{\dots}{文字列に強制変換出来るゼロかそれ以上のオブジェクト
    (そしてそれは分離記号無し連結される)又は単一の条件オブジェクト．}
  \item{call.}{論理値，呼び出しが警告メッセージの一部分になるべきかどうかを指示する．}
  \item{immediate.}{論理値，\code{\link{getOption}("warn") <= 0} であっても
    呼び出しは即座に出力されるべきかどうかを指示する．}
  \item{noBreaks.}{論理値，\code{options(warn = 1)} の時は
    可能な限りメッセージを一行として出力すべきかどうか指示する．}
  \item{expr}{評価される表現式．}
  \item{domain}{\code{\link{gettext}} を見よ．もし \code{NA} なら，メッセージは
    翻訳されない．\code{\link{stop}} 中の注意も見よ．}
}
\details{
  結果は \code{\link{options}("warn")} の値と実行コード中で確立されたハンドラー
  に\emph{依存}する．

  もし条件オブジェクトが提供されるとそれは唯一の引数であるべきで，
  それ以上の引数は警告と共に無視される．

  \code{warning} は警告条件シグナルを(実際上) \code{signalCondition}
  を呼び出すことで出す．もしハンドラーが無いか，全てのハンドラーが
  復帰すれば，\code{warn = \link{getOption}("warn")} の値が
  適当な行動を決定するために使われる．もし \code{warn} が負なら警告は
  無視される；もしそれがゼロならば，それらは蓄積されトップレベルが完了
  した後にプリントされる；もしそれが 1 ならばそれが発生した場所でプリントされ，
  もしそれが 2 (もしくはそれ以上)なら警告はエラーに変わる．
  \code{warning(immediate. = TRUE)} の呼び出しはこの呼び出しに限り
  \code{warn <= 0} を \code{warn = 1} に変える．

  もし \code{warn} がゼロ(既定)ならば，読み取り専用の変数
  \code{last.warning} が作りだされる．それは \code{\link{warnings}}
  への呼び出しでプリント出来る警告を含む．

  警告は \code{\link{getOption}("warning.length")} 文字に切り詰められ
  \code{[... truncated]} で指示される．既定値は 1000 文字．
  
  警告が処理されている間に \code{muffleWarning} による再開が利用できる．
  もし \code{invokeRestart} の起動で再開されると
  警告は即座に返される．

  \code{warning} への他のタイプの入力を文字列に変換することが試みられる．

  \code{suppressWarnings} はその表現式を全ての警告無視した文脈中で評価する．
}
\value{
  不可視の文字列としての警告メッセージ．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  致命的なエラーについては \code{\link{stop}}．
  診断メッセージについては \code{\link{message}}，
  \code{\link{warnings}}，
  そして引数 \code{warn=} を持つ \code{\link{options}}．

  メッセージの自動翻訳の機構については \code{\link{gettext}}．
}
\examples{
\dontshow{oldopt <- options(warn = 1)}
testit <- function() warning("testit")
testit() ## 呼び出しを示す
testit <- function() warning("problem in testit", call. = FALSE)
testit() ## 呼び出しなし
suppressWarnings(warning("testit"))
\dontshow{eigenval <- 10 ^ -stats::rnorm(1, mean = 6)
if(eigenval < 1.e-7) warning("system near singular")
options(oldopt)}
}
\keyword{programming}
\keyword{error}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/warning.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{warning}
%\alias{warning}
%\alias{suppressWarnings}
%\title{Warning Messages}
%\description{
%  Generates a warning message that corresponds to its argument(s) and
%  (optionally) the expression or function from which it was called.
%}
%\usage{
%warning(\dots, call. = TRUE, immediate. = FALSE, noBreaks. = FALSE,
%        domain = NULL)
%suppressWarnings(expr)
%}
%\arguments{
%  \item{\dots}{zero or more objects which can be coerced to character
%    (and which are pasted together with no separator) or a single
%    condition object.}
%  \item{call.}{logical, indicating if the call should become part of the
%    warning message.}
%  \item{immediate.}{logical, indicating if the call should be output
%    immediately, even if \code{\link{getOption}("warn") <= 0}.}
%  \item{noBreaks.}{logical, indicating as far as possible the message should
%    be output as a single line when \code{options(warn = 1)}.}
%  \item{expr}{expression to evaluate.}
%  \item{domain}{see \code{\link{gettext}}.  If \code{NA}, messages will
%    not be translated, see also the note in \code{\link{stop}}.}
%}
%\details{
%  The result \emph{depends} on the value of
%  \code{\link{options}("warn")} and on handlers established in the
%  executing code.
%
%  If a condition object is supplied it should be the only argument, and
%  further arguments will be ignored, with a message.
%
%  \code{warning} signals a warning condition by (effectively) calling
%  \code{signalCondition}.  If there are no handlers or if all handlers
%  return, then the value of \code{warn = \link{getOption}("warn")} is
%  used to determine the appropriate action.  If \code{warn} is negative
%  warnings are ignored; if it is zero they are stored and printed after
%  the top--level function has completed; if it is one they are printed
%  as they occur and if it is 2 (or larger) warnings are turned into
%  errors. Calling \code{warning(immediate. = TRUE)} turns \code{warn <=
%    0} into \code{warn = 1} for this call only.
%
%
%  If \code{warn} is zero (the default), a read-only variable
%  \code{last.warning} is created.  It contains the warnings which can be
%  printed via a call to \code{\link{warnings}}.
%
%  Warnings will be truncated to \code{\link{getOption}("warning.length")}
%  characters, default 1000, indicated by \code{[... truncated]}.
%
%  While the warning is being processed, a \code{muffleWarning} restart
%  is available.  If this restart is invoked with \code{invokeRestart},
%  then \code{warning} returns immediately.
%
%  An attempt is made to coerce other types of inputs to \code{warning}
%  to character vectors.
%
%  \code{suppressWarnings} evaluates its expression in a context that
%  ignores all warnings.
%}
%\value{
%  The warning message as \code{\link{character}} string, invisibly.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{stop}} for fatal errors,
%  \code{\link{message}} for diagnostic messages,
%  \code{\link{warnings}},
%  and \code{\link{options}} with argument \code{warn=}.
%
%  \code{\link{gettext}} for the mechanisms for the automated translation
%  of messages.
%}
%\examples{
%\dontshow{oldopt <- options(warn = 1)}
%testit <- function() warning("testit")
%testit() ## shows call
%testit <- function() warning("problem in testit", call. = FALSE)
%testit() ## no call
%suppressWarnings(warning("testit"))
%\dontshow{eigenval <- 10 ^ -stats::rnorm(1, mean = 6)
%if(eigenval < 1.e-7) warning("system near singular")
%options(oldopt)}
%}
%\keyword{programming}
%\keyword{error}
%\encoding{UTF8}

\encoding{UTF8}

