% File src/library/datasets/man/UCBAdmissions.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{UCBAdmissions}
\docType{data}
\title{UCBAdmissions}
\alias{UCBAdmissions}
%%\title{Student Admissions at UC Berkeley}
\description{
  1973年の Berkeley の六つの主要学部の大学院への出願者
  を合否と性別で分類した累計データ．
}
\usage{UCBAdmissions}
\format{
  4526観測値を3変数でクロス集計した結果の3次元配列．
  変数とそれらの水準は次の通り．

  \tabular{rll}{
    No \tab 名前 \tab 水準\cr
    1 \tab Admit \tab Admitted, Rejected\cr
    2 \tab Gender \tab Male, Female\cr
    3 \tab Dept \tab A, B, C, D, E, F
  }
}
\details{
  このデータセットはしばしば
  Simpson のパラドックスの説明に用いられる，
  Bickel \emph{et al} (1975) を見よ．
  問題はデータが合否判定における性別バイアスの証拠を
  示すかどうかである．2691人の男性出願者の内
  1198人(44.5\%)が合格し，1835人の女性出願者の内
  557人(30.4\%)が合格した．これは標本オッズ比
  1.83 をあたえ，男性がほとんど二倍合格しやすいことを示している．
  実際には，グラフィカルな方法(下の例におけるような)や
  対数線形モデルによる解析は
  見かけ上の合否と性別の関連は男女が出願した個々の学部の傾向の
  差に基づく(女性は高い不合格率の学部に
  \emph{より}出願する傾向があった)．

  このデータセットはまた
  一般的な \link{mosaicplot} や 2-by-2-by-\eqn{k} テーブルに対する
  \link{fourfoldplot} の様な
  カテゴリカルなデータのグラフィカルな
  表示に対する説明的な手法に対しても使うことが出来る．
}
\references{
  Bickel, P. J., Hammel, E. A., and O'Connell, J. W. (1975)
  Sex bias in graduate admissions: Data from Berkeley.
  \emph{Science}, \bold{187}, 398--403.
}
\examples{
require(graphics)
## 学部について累計したデータ
apply(UCBAdmissions, c(1, 2), sum)
mosaicplot(apply(UCBAdmissions, c(1, 2), sum),
           main = "Student admissions at UC Berkeley")
## 個々の学部についてのデータ
opar <- par(mfrow = c(2, 3), oma = c(0, 0, 2, 0))
for(i in 1:6)
  mosaicplot(UCBAdmissions[,,i],
    xlab = "Admit", ylab = "Sex",
    main = paste("Department", LETTERS[i]))
mtext(expression(bold("Student admissions at UC Berkeley")),
      outer = TRUE, cex = 1.5)
par(opar)
}
\keyword{datasets}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/datasets/man/UCBAdmissions.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{UCBAdmissions}
%\docType{data}
%\alias{UCBAdmissions}
%\title{Student Admissions at UC Berkeley}
%\description{
%  Aggregate data on applicants to graduate school at Berkeley for the
%  six largest departments in 1973 classified by admission and sex.
%}
%\usage{UCBAdmissions}
%\format{
%  A 3-dimensional array resulting from cross-tabulating 4526
%  observations on 3 variables.  The variables and their levels are as
%  follows:
%
%  \tabular{rll}{
%    No \tab Name \tab Levels\cr
%    1 \tab Admit \tab Admitted, Rejected\cr
%    2 \tab Gender \tab Male, Female\cr
%    3 \tab Dept \tab A, B, C, D, E, F
%  }
%}
%\details{
%  This data set is frequently used for illustrating Simpson's paradox,
%  see Bickel \emph{et al} (1975).  At issue is whether the data show evidence
%  of sex bias in admission practices.  There were 2691 male applicants,
%  of whom 1198 (44.5\%) were admitted, compared with 1835 female
%  applicants of whom 557 (30.4\%) were admitted.  This gives a sample
%  odds ratio of 1.83, indicating that males were almost twice as likely
%  to be admitted.  In fact, graphical methods (as in the example below)
%  or log-linear modelling show that the apparent association between
%  admission and sex stems from differences in the tendency of males and
%  females to apply to the individual departments (females used to apply
%  \emph{more} to departments with higher rejection rates).
%
%  This data set can also be used for illustrating methods for graphical
%  display of categorical data, such as the general-purpose \link{mosaicplot}
%  or the \link{fourfoldplot} for 2-by-2-by-\eqn{k} tables.
%}
%\references{
%  Bickel, P. J., Hammel, E. A., and O'Connell, J. W. (1975)
%  Sex bias in graduate admissions: Data from Berkeley.
%  \emph{Science}, \bold{187}, 398--403.
%}
%\examples{
%require(graphics)
%## Data aggregated over departments
%apply(UCBAdmissions, c(1, 2), sum)
%mosaicplot(apply(UCBAdmissions, c(1, 2), sum),
%           main = "Student admissions at UC Berkeley")
%## Data for individual departments
%opar <- par(mfrow = c(2, 3), oma = c(0, 0, 2, 0))
%for(i in 1:6)
%  mosaicplot(UCBAdmissions[,,i],
%    xlab = "Admit", ylab = "Sex",
%    main = paste("Department", LETTERS[i]))
%mtext(expression(bold("Student admissions at UC Berkeley")),
%      outer = TRUE, cex = 1.5)
%par(opar)
%}
%\keyword{datasets}
%
%\encoding{UTF8}
%