% File src/library/grDevices/man/palette.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2012 R Core Team
% Copyright 2002-2010 The R Foundation
% Distributed under GPL 2 or later

\name{adjustcolor}
\alias{adjustcolor}
\title{色の補正}
%%\title{Adjust Colors in One or More Directions Conveniently.}
\description{
  色の補正や修正を \eqn{(r,g,b,\alpha)} 空間中の一つ又は複数の座標上で
  \dQuote{調整ノブ}により行う．典型的にはそれらのスケールを
  上下することで行う．
}

\usage{
adjustcolor(col, alpha.f = 1, red.f = 1, green.f = 1, blue.f = 1,
            offset = c(0, 0, 0, 0),
            transform = diag(c(red.f, green.f, blue.f, alpha.f)))}
\arguments{
  \item{col}{色のベクトル，
    col2rgb() が受け入れる任意のフォーマットが可能．}
  \item{alpha.f}{不透明度アルファを修正する因子；典型的には [0,1] 中．}
  \item{red.f, green.f, blue.f}{それぞれ色の
    \dQuote{赤}，\dQuote{緑} 又は \dQuote{青}味を修正する因子．}
  \item{offset}{
  }
  \item{transform}{
  }
}
\value{
  \code{col} と同じ長さの色ベクトルで，実効的には
  \code{\link{rgb}() の結果．}
}
%\author{Thomas Lumley, Luke Tierney, Martin Maechler, Duncan Murdoch...}
% \details{

% }
\seealso{
  \code{\link{rgb}}, \code{\link{col2rgb}}.
  より洗練された色の構成には \code{\link{convertColor}．}
}
\examples{
## 説明のための例：
opal <- palette("default")
stopifnot(identical(adjustcolor(1:8,       0.75),
                    adjustcolor(palette(), 0.75)))
cbind(palette(), adjustcolor(1:8, 0.75))

##  alpha = 1/2 * 直線のアルファ --> 不透明色
x <- palette(adjustcolor(palette(), 0.5))

sines <- outer(1:20, 1:4, function(x, y) sin(x / 20 * pi * y))
matplot(sines, type = "b", pch = 21:23, col = 2:5, bg = 2:5,
        main = "Using an 'opaque ('translucent') color palette")

x. <- adjustcolor(x, offset = c(0.5, 0.5, 0.5, 0), # <- "より白っぽい"
                  transform = diag(c(.7, .7, .7, 0.6)))
cbind(x, x.)
op <- par(bg = adjustcolor("goldenrod", offset = -rep(.4, 4)), xpd = NA)
plot(0:9, 0:9, type = "n", axes = FALSE, xlab = "", ylab = "",
     main = "adjustcolor() -> translucent")
text(1:8, labels = paste0(x,"++"), col = x., cex = 8)
par(op)

## そして

(M <- cbind( rbind( matrix(1/3, 3, 3), 0), c(0, 0, 0, 1)))
adjustcolor(x, transform = M)

## 直線のパレットに復帰：アクティブ
palette(opal)
}

\encoding{UTF-8}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/palette.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2012 R Core Team
%% Copyright 2002-2010 The R Foundation
%% Distributed under GPL 2 or later
%
%\name{adjustcolor}
%\alias{adjustcolor}
%\title{Adjust Colors in One or More Directions Conveniently.}
%\description{
%  Adjust or modify a vector of colors by \dQuote{turning knobs} on one or more
%  coordinates in \eqn{(r,g,b,\alpha)} space, typically by up or down
%  scaling them.
%}
%
%\usage{
%adjustcolor(col, alpha.f = 1, red.f = 1, green.f = 1, blue.f = 1,
%            offset = c(0, 0, 0, 0),
%            transform = diag(c(red.f, green.f, blue.f, alpha.f)))}
%\arguments{
%  \item{col}{vector of colors, in any format that col2rgb() accepts}
%  \item{alpha.f}{factor modifying the opacity alpha; typically in [0,1]}
%  \item{red.f, green.f, blue.f}{factors modifying the \dQuote{red-},
%    \dQuote{green-} or \dQuote{blue-}ness of the colors, respectively.}
%  \item{offset}{
%  }
%  \item{transform}{
%  }
%}
%\value{a color vector of the same length as \code{col}, effectively the
%  result of \code{\link{rgb}()}.
%}
%%\author{Thomas Lumley, Luke Tierney, Martin Maechler, Duncan Murdoch...}
%% \details{
%
%% }
%\seealso{
%  \code{\link{rgb}}, \code{\link{col2rgb}}.  For more sophisticated
%  color constructions: \code{\link{convertColor}}
%}
%\examples{
%## Illustrative examples :
%opal <- palette("default")
%stopifnot(identical(adjustcolor(1:8,       0.75),
%                    adjustcolor(palette(), 0.75)))
%cbind(palette(), adjustcolor(1:8, 0.75))
%
%##  alpha = 1/2 * previous alpha --> opaque colors
%x <- palette(adjustcolor(palette(), 0.5))
%
%sines <- outer(1:20, 1:4, function(x, y) sin(x / 20 * pi * y))
%matplot(sines, type = "b", pch = 21:23, col = 2:5, bg = 2:5,
%        main = "Using an 'opaque ('translucent') color palette")
%
%x. <- adjustcolor(x, offset = c(0.5, 0.5, 0.5, 0), # <- "more white"
%                  transform = diag(c(.7, .7, .7, 0.6)))
%cbind(x, x.)
%op <- par(bg = adjustcolor("goldenrod", offset = -rep(.4, 4)), xpd = NA)
%plot(0:9, 0:9, type = "n", axes = FALSE, xlab = "", ylab = "",
%     main = "adjustcolor() -> translucent")
%text(1:8, labels = paste0(x,"++"), col = x., cex = 8)
%par(op)
%
%## and
%
%(M <- cbind( rbind( matrix(1/3, 3, 3), 0), c(0, 0, 0, 1)))
%adjustcolor(x, transform = M)
%
%## revert to previous palette: active
%palette(opal)
%}
%
%\encoding{UTF-8}
%