% File src/library/grDevices/man/contourLines.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2008 R Core Team
% Distributed under GPL 2 or later

\name{contourLines}
\alias{contourLines}
\title{等高線を計算}
%%\title{Calculate Contour Lines}
\description{
  与えられたデータのセットに対し等高線を計算．
}
\usage{
contourLines(x = seq(0, 1, length.out = nrow(z)),
             y = seq(0, 1, length.out = ncol(z)),
             z, nlevels = 10,
             levels = pretty(range(z, na.rm = TRUE), nlevels))
}
\arguments{
  \item{x, y}{
    \code{z} 中の値が測られるグリッド線の位置．
    これらは上昇順でなければならない．
    既定では 0 から 1 までの等間隔の値が使われる．
    もし \code{x} が \code{list} ならば，
    その成分 \code{x$x} と \code{x$y} がそれぞれ \code{x}
    と \code{y} として使われる．もしリストが成分
    \code{z} を持てば，これは \code{z} として使われる．}
  \item{z}{プロットされるべき値をもつ行列
    (\code{NA} が許される)．
    便宜上 \code{x} を \code{z} の代わりに使うことが出来る．}
  \item{nlevels}{\code{levels} が提供されないとき，そしてその時だけ
    希望の等高線水準の数．}
  \item{levels}{等高線を描く水準の数値ベクトル．}
}
\details{
  \code{contourLines} は何も描かず，等高線のセットを返す．

  現在アルゴリズムに関するドキュメントは無い．
  ソースコードは \file{\var{\link{R_HOME}}/src/main/plot3d.c} にある．
}
\value{
  等高線のリスト．各等高線は次の要素を持つリスト：
  \item{level }{等高線の水準．}
  \item{x }{等高線の x 座標．}
  \item{y }{等高線の y 座標．}
}
\seealso{
  単一の等高線の最大複雑度に対しては \code{\link{options}("max.contour.segments")}．

  \code{\link{contour}}.
}
\examples{
x <- 10*1:nrow(volcano)
y <- 10*1:ncol(volcano)
contourLines(x, y, volcano)
}
\keyword{dplot}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/contourLines.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2008 R Core Team
%% Distributed under GPL 2 or later
%
%\name{contourLines}
%\alias{contourLines}
%\title{Calculate Contour Lines}
%\description{
%  Calculate contour lines for a given set of data.
%}
%\usage{
%contourLines(x = seq(0, 1, length.out = nrow(z)),
%             y = seq(0, 1, length.out = ncol(z)),
%             z, nlevels = 10,
%             levels = pretty(range(z, na.rm = TRUE), nlevels))
%}
%\arguments{
%  \item{x, y}{locations of grid lines at which the values in \code{z} are
%    measured.  These must be in ascending order.  By default, equally
%    spaced values from 0 to 1 are used.  If \code{x} is a \code{list},
%    its components \code{x$x} and \code{x$y} are used for \code{x}
%    and \code{y}, respectively. If the list has component \code{z} this
%    is used for \code{z}.}
%  \item{z}{a matrix containing the values to be plotted (\code{NA}s are
%    allowed).  Note that \code{x} can be used instead of \code{z} for
%    convenience.}
%  \item{nlevels}{number of contour levels desired \bold{iff}
%    \code{levels} is not supplied.}
%  \item{levels}{numeric vector of levels at which to draw contour
%    lines.}
%}
%\details{
%  \code{contourLines} draws nothing, but returns a set of contour lines.
%
%  There is currently no documentation about the algorithm.
%  The source code is in \file{\var{\link{R_HOME}}/src/main/plot3d.c}.
%}
%\value{
%  A list of contours.
%  Each contour is a list with elements:
%  \item{level }{The contour level.}
%  \item{x }{The x-coordinates of the contour.}
%  \item{y }{The y-coordinates of the contour.}
%}
%\seealso{
%  \code{\link{options}("max.contour.segments")} for the maximal
%  complexity of a single contour line.
%
%  \code{\link{contour}}.
%}
%\examples{
%x <- 10*1:nrow(volcano)
%y <- 10*1:ncol(volcano)
%contourLines(x, y, volcano)
%}
%\keyword{dplot}
%
%\encoding{UTF-8}
%