% File src/library/grDevices/man/embedFonts.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{embedFonts}
\alias{embedFonts}
\title{ポストスクリプトやPDFにフォントを埋め込む}
\concept{encoding}
%%\title{Embed Fonts in PostScript and PDF}
\description{
  Ghostscript を実行して PDF や PostScript フィルを処理し
  全てのフォントをファイルに埋め込む．
}
\usage{
embedFonts(file, format, outfile = file,
           fontpaths = character(), options = character())
}
\arguments{
  \item{file}{オリジナルのファイルの名前を与える文字列．}
  \item{format}{
    ghostscript の出力デバイスの名前としての
    (埋め込みフォントの)新しいファイルの書式．
    もし指定されないと
    \code{file} の拡張子から推測される．}
  \item{outfile}{(フォント埋め込みの)新しいファイルの名前．}
  \item{fontpaths}{Ghostscript がフォントを探すディレクトリを与える文字列．}
  \item{options}{Ghostscript への追加オプションを含む文字列．}
}
\details{
  この関数は
  PostScript と PDF 出力に対して単に標準の既定のフォントを
  使うのなら不要である．

  もし特殊なフォントを使うのなら，この関数は
  PostScript や PDF ドキュメントにそのフォントを埋め込むために役に立つ
  ので，特別なフォントをインストールすることなしに他と共有することが出来る
  (フォントのライセンスがこれを許す限り)．

  Ghostscript ように特殊なフォントがインストールされていなければ，
  Ghostscript にフォントがどこにあるか
  \code{options="-sFONTPATH=path/to/font"} のようにして
  教える必要がある．

  \code{ghostscript} が必要になる：実行ファイルへのフルパスは
  環境変数 \env{R_GSCMD} で設定できる．もしこれが未設定なら，
  GhostScript の実行ファイルは自分のパス上で名前で探される：
  Unix 風システムでは \code{"gs"} が使われ，そして Windows 上では
  環境変数 \env{GSC} の設定が使われ，さもなければ命令
  \code{"gswi64c.exe"} そしてそれから \code{"gswin32c.exe"} が試みられる．

  \code{format} は
  オリジナルのファイルが \code{.ps} 又は \code{.eps} 拡張子を持てば
  既定では \code{"ps2write"} であり，
  オリジナルファイルが拡張子 \code{.pdf} の時は
  \code{"pdfwrite"} である．
  9.10 以前のバージョンの Ghostscript に対しては，
  \code{format = "pswrite"} 又は \code{format = "epswrite"} を使うことが出来る：
  9.14 以降では \code{format = "eps2write"} も利用できる．
  もし不正なデバイスが与えられると，エラーメッセージは
  利用可能なデバイスをリストする．
  
  Ghostscript はフォントの差し替えをするかもしれず，
  埋め込まれたフォントはオリジナルのファイル中で指定されたものとは
  異なるかもしれないことを注意する．

  有用かもしれない他のオプション
  (Ghostscript のドキュメントを見よ)は \option{-dMaxSubsetPct=100},
  \option{-dSubsetFonts=true} そして \option{-dEmbedAllFonts=true} である．
}
\value{
  Ghostscript を起動したシェル命令が不可視で返される．
  これは問題を見つけるためシェルで命令を手動で実行出来るため
  デバッグ用に有用かもしれない．
}
\seealso{
  \code{\link{postscriptFonts}},
  \code{\link{Devices}}.

  Paul Murrell and Brian Ripley (2006) Non-standard fonts in PostScript
  and PDF graphics. \emph{R News}, 6(2):41--47.
  \url{https://www.r-project.org/doc/Rnews/Rnews_2006-2.pdf}.
}
\keyword{device}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/embedFonts.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{embedFonts}
%\alias{embedFonts}
%\concept{encoding}
%\title{Embed Fonts in PostScript and PDF}
%\description{
%  Runs Ghostscript to process a PDF or PostScript file and
%  embed all fonts in the file.
%}
%\usage{
%embedFonts(file, format, outfile = file,
%           fontpaths = character(), options = character())
%}
%\arguments{
%  \item{file}{a character string giving the name of the original file.}
%  \item{format}{the format for the new file (with fonts embedded) given as
%    the name of a ghostscript output device.
%    If not specified, it is guessed from the suffix of \code{file}.}
%  \item{outfile}{the name of the new file (with fonts embedded).}
%  \item{fontpaths}{a character vector giving directories that
%    Ghostscript will search for fonts.}
%  \item{options}{a character vector containing further options to
%    Ghostscript.}
%}
%\details{
%  This function is not necessary if you just use the standard
%  default fonts for PostScript and PDF output.
%
%  If you use a special font, this function is useful for
%  embedding that font in your PostScript or PDF document
%  so that it can be shared with others without them having
%  to install your special font (provided the font licence allows this).
%
%  If the special font is not installed for Ghostscript,
%  you will need to tell Ghostscript where the font is, using
%  something like \code{options="-sFONTPATH=path/to/font"}.
%
%  You will need \code{ghostscript}: the full path to the executable can
%  be set by the environment variable \env{R_GSCMD}. If this is
%  unset, a GhostScript executable will be looked for by name on your
%  path: on a Unix alike \code{"gs"} is used, and on Windows the setting
%  of the environment variable \env{GSC} is used, otherwise commands
%  \code{"gswi64c.exe"} then \code{"gswin32c.exe"} are tried.
%
%  The \code{format} is by default \code{"ps2write"}, when the original
%  file has a \code{.ps} or \code{.eps} suffix, or \code{"pdfwrite"} when
%  the original file has a \code{.pdf} suffix.  For versions of
%  Ghostscript before 9.10, \code{format = "pswrite"} or \code{format =
%  "epswrite"} can be used: as from 9.14 \code{format = "eps2write"} is
%  also available.  If an invalid device is given, the error message will
%  list the available devices.
%  
%  Note that Ghostscript may do font substitution, so the font embedded
%  may differ from that specified in the original file.
%
%  Some other options which can be useful (see your Ghostscript
%  documentation) are \option{-dMaxSubsetPct=100},
%  \option{-dSubsetFonts=true} and  \option{-dEmbedAllFonts=true}.
%}
%\value{
%  The shell command used to invoke Ghostscript is returned
%  invisibly. This may be useful for debugging purposes as
%  you can run the command by hand in a shell to look for problems.
%}
%\seealso{
%  \code{\link{postscriptFonts}},
%  \code{\link{Devices}}.
%
%  Paul Murrell and Brian Ripley (2006) Non-standard fonts in PostScript
%  and PDF graphics. \emph{R News}, 6(2):41--47.
%  \url{https://www.r-project.org/doc/Rnews/Rnews_2006-2.pdf}.
%}
%\keyword{device}
%
%\encoding{UTF-8}
%