% File src/library/grDevices/man/hcl.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{hcl}
\title{色調，彩度，輝度を与えた色ベクトル}
\alias{hcl}
\encoding{UTF-8}
%%\title{HCL Color Specification}
\description{
  色調，彩度そして輝度を与えて色のベクトルを作る．
}
\usage{
hcl(h = 0, c = 35, l = 85, alpha, fixup = TRUE)
}
\arguments{
  \item{h}{
    範囲 [0,360] 中の角度として指定された色の色調．
    0 は赤，120 は緑，240 は青等．}
  \item{c}{色の彩度．彩度の上限は hue と輝度に依存する．}
  \item{l}{
    色の輝度を与える範囲 [0,100] 内の値．
    与えられた色調と輝度の組み合わせに対して
    この範囲の一部分だけが可能になる．}
  \item{alpha}{
    アルファ透明度チャンネルに対する範囲 \code{[0,1]} 中の
    値の数値ベクトル
    (0 は透明で 1 は不透明を意味する)．}
  \item{fixup}{
    結果の RGB 値は真の色の結果であることを保証する補正を
    行うべきかどうかを指示する論理値，
    もし \code{fixup} が \code{FALSE} ならば
    範囲 [0,1] 外の RGB 成分は \code{NA} 値になる．}
}
\details{
この関数は
CIE-LUV 色空間中の極座標に対応する．
この空間中の同じサイズのステップは近似的に
等しい知覚的な色の変化に対応する．
このように，\code{hcl} は知覚に基づいた
\code{\link{hsv}} のバージョンと考えられる．

この関数は当初面積が数値に対応するプロット
(円グラフ，棒グラフ，モザイクプロット，ヒストグラム等)
中の面を埋める色を計算する方法を意図していた．
等しい彩度と輝度を持つ色の選択は
さもなければ面積がどれくらい大きいかの誤った印象を生み出す
照射を最小化する方法を与える．

彩度と輝度の既定値は色調の全範囲を生成することが出来，相対的に
快適なパステル調の概観を持つ．

この関数が生み出す RGB 値はほとんどの PC のディスプレイ上で使われる
sRGB 色空間に対応する．より一般的な色空間機能を提供する
他のパッケージがある．

半透明色(\code{0 < alpha < 1})はある種のデバイスでだけサポートされる：
\code{\link{rgb}} を見よ．
}
\value{
  \R のグラフィックス関数で色指定に使える文字列のベクトル．
  
  \code{h}, \code{c}, \code{l} のいずれかの欠損値や無現値
  は \code{NA} になる：そうした値の \code{alpha} は
  \code{1} (不透明)とされる．
}
\references{
Ihaka, R. (2003).
Colour for Presentation Graphics, Proceedings of the 3rd International
Workshop on Distributed Statistical Computing (DSC 2003), March 20-22,
2003, Technische Universität Wien, Vienna, Austria.
\url{http://www.ci.tuwien.ac.at/Conferences/DSC-2003}.
}
\author{Ross Ihaka}
\note{
  現在の所 \R のグラフィックスデバイスが作る
  色がそれらの sRGB 記述に対応するという保証はない．
  将来 sRGB を標準の \R 色指定にする計画がある．
}
\seealso{
  \code{\link{hsv}},
  \code{\link{rgb}}.
}
\examples{
require(graphics)

# Foley と Van Dam PhD のデータ．
csd <- matrix(c( 4,2,4,6, 4,3,1,4, 4,7,7,1,
                 0,7,3,2, 4,5,3,2, 5,4,2,2,
                 3,1,3,0, 4,4,6,7, 1,10,8,7,
                 1,5,3,2, 1,5,2,1, 4,1,4,3,
                 0,3,0,6, 2,1,5,5), nrow = 4)

csphd <- function(colors)
  barplot(csd, col = colors, ylim = c(0,30),
          names = 72:85, xlab = "Year", ylab = "Students",
          legend = c("Winter", "Spring", "Summer", "Fall"),
          main = "Computer Science PhD Graduates", las = 1)

# オリジナルの(比喩的)色 (ひどい!)
csphd(c("blue", "green", "yellow", "orange"))

# 色四面体(最大色差)
csphd(hcl(h = c(30, 120, 210, 300)))

# 同じだが，より明るく色どりに欠ける
# 真の色を定義したことを確信するため自動的な補正を停止
csphd(hcl(h = c(30, 120, 210, 300),
          c = 20, l = 90, fixup = FALSE))

# 類似色
# 赤緑色盲者に良い
csphd(hcl(h = seq(60, 240, by = 60)))

# 比喩的な色
csphd(hcl(h = seq(210, 60, length = 4)))

# クールな色
csphd(hcl(h = seq(120, 0, length = 4) + 150))

# 暖色
csphd(hcl(h = seq(120, 0, length = 4) - 30))

# 単一の色
hist(stats::rnorm(1000), col = hcl(240))

## hcl() 色空間を探索{R の sRGB 色にマップして}：
demo(hclColors)

}
\keyword{color}
\keyword{dplot}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/hcl.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{hcl}
%\alias{hcl}
%\encoding{UTF-8}
%\title{HCL Color Specification}
%\description{
%  Create a vector of colors from vectors specifying hue,
%  chroma and luminance.
%}
%\usage{
%hcl(h = 0, c = 35, l = 85, alpha, fixup = TRUE)
%}
%\arguments{
%  \item{h}{The hue of the color specified as an angle in the range
%      [0,360].  0 yields red, 120 yields green 240 yields blue, etc.}
%  \item{c}{The chroma of the color.  The upper bound for chroma depends
%      on hue and luminance.}
%  \item{l}{A value in the range [0,100] giving the luminance of the
%        colour.  For a given combination of hue and chroma, only
%        a subset of this range is possible.}
%  \item{alpha}{numeric vector of values in the range \code{[0,1]} for
%    alpha transparency channel (0 means transparent and 1 means opaque).}
%  \item{fixup}{a logical value which indicates whether the resulting
%    RGB values should be corrected to ensure that a real color results.
%    if \code{fixup} is \code{FALSE} RGB components lying outside the
%    range [0,1] will result in an \code{NA} value.}
%}
%\details{
%This function corresponds to polar coordinates in the CIE-LUV
%color space. Steps of equal size in this space correspond to
%approximately equal perceptual changes in color.  Thus, \code{hcl}
%can be thought of as a perceptually based version of \code{\link{hsv}}.
%
%The function is primarily intended as a way of computing
%colors for filling areas in plots where area corresponds to a
%numerical value (pie charts, bar charts, mosaic plots, histograms,
%etc).  Choosing colors which have equal chroma and luminance
%provides a way of minimising the irradiation illusion which
%would otherwise produce a misleading impression of how large
%the areas are.
%
%The default values of chroma and luminance make it possible
%to generate a full range of hues and have a relatively pleasant
%pastel appearance.
%
%The RGB values produced by this function correspond to the sRGB
%color space used on most PC computer displays.  There are other
%packages which provide more general color space facilities.
%
%  Semi-transparent colors (\code{0 < alpha < 1}) are supported only on
%  some devices: see \code{\link{rgb}}.
%}
%\value{
%  A vector of character strings which can be used as color
%  specifications by \R graphics functions.
%  
%  Missing or infinite values of any of \code{h}, \code{c}, \code{l}
%  result in \code{NA}: such values of \code{alpha} are taken as \code{1}
%  (opaque).  
%}
%\references{
%Ihaka, R. (2003).
%Colour for Presentation Graphics, Proceedings of the 3rd International
%Workshop on Distributed Statistical Computing (DSC 2003), March 20-22,
%2003, Technische Universität Wien, Vienna, Austria.
%\url{http://www.ci.tuwien.ac.at/Conferences/DSC-2003}.
%}
%\author{Ross Ihaka}
%\note{
%  At present there is no guarantee that the colours rendered by R
%  graphics devices will correspond to their sRGB description.
%  It is planned to adopt sRGB as the standard R color description
%  in future.
%}
%\seealso{
%  \code{\link{hsv}},
%  \code{\link{rgb}}.
%}
%\examples{
%require(graphics)
%
%# The Foley and Van Dam PhD Data.
%csd <- matrix(c( 4,2,4,6, 4,3,1,4, 4,7,7,1,
%                 0,7,3,2, 4,5,3,2, 5,4,2,2,
%                 3,1,3,0, 4,4,6,7, 1,10,8,7,
%                 1,5,3,2, 1,5,2,1, 4,1,4,3,
%                 0,3,0,6, 2,1,5,5), nrow = 4)
%
%csphd <- function(colors)
%  barplot(csd, col = colors, ylim = c(0,30),
%          names = 72:85, xlab = "Year", ylab = "Students",
%          legend = c("Winter", "Spring", "Summer", "Fall"),
%          main = "Computer Science PhD Graduates", las = 1)
%
%# The Original (Metaphorical) Colors (Ouch!)
%csphd(c("blue", "green", "yellow", "orange"))
%
%# A Color Tetrad (Maximal Color Differences)
%csphd(hcl(h = c(30, 120, 210, 300)))
%
%# Same, but lighter and less colorful
%# Turn off automatic correction to make sure
%# that we have defined real colors.
%csphd(hcl(h = c(30, 120, 210, 300),
%          c = 20, l = 90, fixup = FALSE))
%
%# Analogous Colors
%# Good for those with red/green color confusion
%csphd(hcl(h = seq(60, 240, by = 60)))
%
%# Metaphorical Colors
%csphd(hcl(h = seq(210, 60, length = 4)))
%
%# Cool Colors
%csphd(hcl(h = seq(120, 0, length = 4) + 150))
%
%# Warm Colors
%csphd(hcl(h = seq(120, 0, length = 4) - 30))
%
%# Single Color
%hist(stats::rnorm(1000), col = hcl(240))
%
%## Exploring the hcl() color space {in its mapping to R's sRGB colors}:
%demo(hclColors)
%
%}
%\keyword{color}
%\keyword{dplot}
%
%