% File src/library/grDevices/man/recordplot.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{recordPlot}
\title{プロットを記録し再生する}
\alias{replayPlot}
\alias{recordPlot}
\alias{print.recordedplot}
%%\title{Record and Replay Plots}
\description{
  現在のプロットを \R 変数に保存し，それを再生する関数．
}
\usage{
recordPlot(load=NULL, attach=NULL)
replayPlot(x, reloadPkgs=FALSE)
}
\arguments{
  \item{load}{もし \code{NULL} で無ければ，記録されたプロットの一部として
    保存されるパッケージ名の文字列ベクトル．}
  \item{attach}{もし \code{NULL} で無ければ，記録されたプロットの一部として
    保存されるパッケージ名の文字列ベクトル．}
    \item{x}{保存されたプロット．}
  \item{reloadPkgs}{
    記録されたプロットの一部として保存された任意のパッケージを
    再ロード and/or 再付加するかどうかを指示する論理値．}
}
\details{
  これらの関数は現在のグラフィックスデバイスの
  displaylist を保存し再生する．
  返されるオブジェクトはクラス \code{"recordedplot"} で，
  \code{replayPlot} はこのクラスへの \code{print} メソッドとして動作する．

  返されるオブジェクトは対リストとして保管されるが，
  \code{\link{deparse}} と \code{\link{str}} のような
  \R オブジェクトを調べるための普通のメソッドは
  誤解に導きやすい．
}
\section{警告}{
  記録されたプロットの書式は
  \R のバージョン間で変わるかもしれず，
  記録されたプロットは \R プロットの永久保存の
  書式としては使われるべきではない．
  
  \R 3.3.0 のように，例えば
  \code{\link{saveRDS}} と \code{\link{readRDS}} を使い
  プロットを別の \R セッションで再生することが(また)可能である．
  別の \R バージョンからのプロットを再生することすら
  可能であるが，しかしこれは警告を生み，エラーになるかもしれず，
  もっと悪いことになりかねない．
}
\section{注意}{
  記録されたプロットの再生は，
  ディスプレイリストが
  \pkg{graphics} や \pkg{grid} 以外の基本的でないパッケージからの
  呼び出しコードを含むかもしれず，
  もし \code{\link{recordGraphics}} の呼び出しを含むと正しい結果を
  作り出さない(又は単に失敗する)かもしれない．
  
  これの最も良く知られた例は
  パッケージ \pkg{ggplot2} で描かれたプロットである．
  一つの解決策は記録されたプロットを再生する前に
  関連パッケージをロードしておくことである．
  \code{recordPlot} への
  \code{load} や \code{attach} 引数はこれを自動化するのに使うことが出来る
  -- \code{load} 中に名前のある任意のパッケージは
  \code{\link{loadNamespace}} を使い再ロードされ，
  \code{attach} 中に名前のある任意のパッケージは
  \code{replayPlot} への呼び出し中で
  \code{reloadPkgs} が \code{TRUE} である限り
  \code{\link{library}} を使い付加される．
  これは異なった \R セッションで記録されたプロットを
  一つの \R セッション中で再生しようと試みる時だけ問題になる．
}
\value{
  \code{recordPlot} は
  クラス \code{"recordedplot"} のオブジェクトを返す．

  \code{replayPlot} は返り値を持たない．
}
\seealso{
  displaylist は
  最初はスクリーンデバイスに対してはオンで，プリントデバイスに対しては
  オフである．
}
\keyword{iplot}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/recordplot.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{recordPlot}
%\alias{replayPlot}
%\alias{recordPlot}
%\alias{print.recordedplot}
%\title{Record and Replay Plots}
%\description{
%  Functions to save the current plot in an \R variable, and to replay it.
%}
%\usage{
%recordPlot(load=NULL, attach=NULL)
%replayPlot(x, reloadPkgs=FALSE)
%}
%\arguments{
%  \item{load}{If not \code{NULL}, a character vector of package names,
%    which are saved as part of the recorded plot.}
%  \item{attach}{If not \code{NULL}, a character vector of package names,
%    which are saved as part of the recorded plot.}
%  \item{x}{A saved plot.}
%  \item{reloadPkgs}{A logical indicating whether to reload and/or
%    reattach any packages that were saved as part of the recorded plot.}
%}
%\details{
%  These functions record and replay the displaylist of the current
%  graphics device.  The returned object is of class
%  \code{"recordedplot"}, and \code{replayPlot} acts as a \code{print}
%  method for that class.
%
%  The returned object is stored as a pairlist, but the usual methods for
%  examining \R objects such as \code{\link{deparse}} and
%  \code{\link{str}} are liable to mislead.
%}
%\section{Warning}{
%  The format of recorded plots may change between \R versions, so
%  recorded plots should \strong{not} be used as a permanent
%  storage format for \R plots.
%  
%  As of \R 3.3.0, it is possible (again)
%  to replay a plot from another \R session using, for example,
%  \code{\link{saveRDS}} and \code{\link{readRDS}}.
%  It is even possible to replay a plot from another \R version,
%  however, this will produce warnings, may produce errors,
%  or something worse.
%}
%\section{Note}{
%  Replay of a recorded plot may not produce the correct result
%  (or may just fail) if the display list contains a call to
%  \code{\link{recordGraphics}} which in turn contains an expression
%  that calls code from a non-base package other than \pkg{graphics}
%  or \pkg{grid}.  The most well-known example of this is a plot
%  drawn with the package \pkg{ggplot2}.  One solution is to load
%  the relevant package(s) before replaying the recorded plot.
%  The \code{load} and \code{attach} arguments to \code{recordPlot}
%  can be used to automate this - any packages named in \code{load}
%  will be reloaded, via \code{\link{loadNamespace}}, and any packages
%  named in \code{attach} will be reattached, via \code{\link{library}},
%  as long as \code{reloadPkgs} is \code{TRUE} in the call to
%  \code{replayPlot}.  This is only relevant when attempting to
%  replay in one R session a plot that was recorded in a different R session.
%}
%\value{
%  \code{recordPlot} returns an object of class \code{"recordedplot"}.
%
%  \code{replayPlot} has no return value.
%}
%\seealso{
%  The displaylist can be turned on and off using \code{\link{dev.control}}.
%  Initially recording is on for screen devices, and off for print devices.
%}
%\keyword{iplot}
%
%\encoding{UTF-8}
%