% File src/library/grDevices/man/windows/png.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{png}
\title{ビットマップグラフィックスデバイス}
\alias{png}
\alias{jpeg}
\alias{tiff}
\alias{bmp}
%%\title{BMP, JPEG, PNG and TIFF graphics devices}
\encoding{UTF-8}
\description{
  書式 BMP, JPEG, PNG そして TIFF のビットマップに対する
  グラフィックスデバイス．
}
\usage{
bmp(filename = "Rplot\%03d.bmp",
    width = 480, height = 480, units = "px", pointsize = 12,
    bg = "white", res = NA, family = "", restoreConsole = TRUE,
    type = c("windows", "cairo"), antialias)

jpeg(filename = "Rplot\%03d.jpg",
     width = 480, height = 480, units = "px", pointsize = 12,
     quality = 75,
     bg = "white", res = NA, family = "", restoreConsole = TRUE,
     type = c("windows", "cairo"), antialias)

png(filename = "Rplot\%03d.png",
    width = 480, height = 480, units = "px", pointsize = 12,
    bg = "white", res = NA, family = "", restoreConsole = TRUE,
    type = c("windows", "cairo", "cairo-png"), antialias)

tiff(filename = "Rplot\%03d.tif",
     width = 480, height = 480, units = "px", pointsize = 12,
     compression = c("none", "rle", "lzw", "jpeg", "zip", "lzw+p", "zip+p"),
     bg = "white", res = NA, family = "", restoreConsole = TRUE,
     type = c("windows", "cairo"), antialias)
}
\arguments{
  \item{filename}{出力ファイルの名前，最大 511 文字．
    既定であるように，もし C の整数書式が含まれるとページ番号が挿入される．
    チルド展開が行われる
    (\code{\link{path.expand}} を見よ)．
    (結果の長さは 600 文字未満でなければならない．
    より詳細は \code{\link{postscript}} を見よ．)
  }
  \item{width}{デバイスの幅．}
  \item{height}{デバイスの高さ．}
  \item{units}{\code{height} と \code{width} が与えられる単位．
    \code{px} (ピクセル，既定値)，\code{in} (インチ)，
    \code{cm} 又は \code{mm} が可能である．}
  \item{pointsize}{プロットされる既定のポイントサイズ，
    \code{res} ppi ではビッグポイント(1/72 インチ)と解釈される．} 
  \item{bg}{初期背景色：
    par("bg") の設定で変更できる．}
  \item{quality}{JPEG イメージの\sQuote{品質}，パーセント．
    より小さな値はより大きな圧縮度を与えるが，又より大きな劣化をもたらす．}
  \item{compression}{使用される圧縮のタイプ．}
  \item{res}{ppi 単位の名目上の解像度で，もし整数ならビットマップファイルに
    記録される．また既定値以外の単位として使われる．
    もし指定されないとテキストと線幅を設定する 72 ppi とされる．}
  \item{family}{長さ 1 の文字列ベクトルで既定のフォントファミリを指定する．
    既定値は Windows GDI バージョンのフォント番号と
    cairographics バージョンでは \code{"sans"} の使用を意味する．}
  \item{restoreConsole}{
    \code{\link{windows}} の\sQuote{詳細}節を見よ．
    \code{type == "windows"} に対してのみ．}
  \item{type}{プロットは
    Windows GDI か cairographics を使ってなされるべきか?}
  \item{antialias}{長さ 1 の文字列ベクトル．

    \code{type = "windows"} の時の許される値と
    フォントへの効果については
    \code{\link{windows}} を見よ：そのタイプに対しては，もし
    引数が欠損していれば既定値は\cr
    \code{windows.options()$bitmap.aa.win} から取られる．

    \code{type = "cairo"} の時の許される値とそれらの効果
    (フォントと線について，しかし塗りつぶしについてではない) \code{\link{svg}} を見よ．
  }
}
\details{
  PNG と JPEG 書式でのプロットは容易に多くの他のビットマップ書式に
  変換でき，どちらも現代のブラウザで表示できる．
  PNG 書式はロスがなく線図と色ブロックに最適である．
  JPEG 書式はロスがあるが，しかし例えばイメージプロットには有用かもしれない．
  BMP 書式は
  Windows では標準であり，その他のビューアーでサポートされている．
  TIFF はメタ書式である：
  \code{tiff} で描かれた既定の書式はロスが無く RGB 値を
  圧縮無しで保管する
  ---そうしたファイルは幅広く受け入れられ，それが
  PNG に比較しての主な長所である．

  Windows の GDI はビットマップのサイズに制限を課す：
  これらは
  SDK にはドキュメント化されておらず
  Windows のバージョンに依存する．
  \code{width} と \code{height} は各々
  \eqn{2^{15}-1}{2^15-1} に制限されているように見える．
  加えてグラフィックスハードウェアに依存するピクセルの総数に制限がある．

  既定では解像度はファイルに記録されない(BMP を除く)．
  ビューアーはしばしば記録がなければ通常の解像度
  72 ppi を仮定する．
  PNG ファイルの解像度はピクセル/メートルで記録されるので，
  報告される ppi 値は少し変更される．

  インチ単位の次元を利用するグラフィックスパラメータに対しては
  \code{res} ppi (既定値 72) が仮定される．

  \code{bmp} と \code{png} は共に
  一ページに 256 色未満であればパレットを使い，
  さもなければ
  24 ビット RGB ファイルを記録する．
  \code{png} デバイスに対しては \code{type = "cairo"} はドライバー中に
  PNG 出力を行うので，
  \code{"windows"} タイプと互換性がある．
  \code{type = "cairo-png"} は cairographics の PNG バックエンドを使い，
  これは決してパレットを使わず普通より大きな
  32 ビットの ARGB ファイルを作る
  ---これは半透明色を使う専門家的使用に対してより良く動作するかもしれない．

  \code{png(type = "windows")} は
  16 ビット(\sQuote{High Color})上の透明な背景やより良いスクリーンを
  サポートする：
  \code{bg = "transparent"} を使おう．
  線，塗りつぶしそしてテキストの半透明色に対するサポートが又ある．
  しかしながら使われるグラフィックスの道具箱中には
  透明性に対する部分的なサポートしか無い：
  もし透明な背景があれば，半透明色は僅かに灰色がかった白の上に
  塗られ，従ってピクセルは不透明である．

  全ての PNG ビューアーが透明性を持つファイルを正確に描画出来るわけではない．

  \code{tiff} の圧縮タイプ \code{"lzw+p"} と \code{"zip+p"} は
  水平な差分(\sQuote{差分予測子}，
  TIFF 仕様の14節)を圧縮法と組み合わせて使うので，
  連続なトーン，特に色付き，の像に対して効果的である．
  
  \R 3.0.3 以前では
  BMP ファイル中の未知の解像度は時おり不正確に記録されていた：
  それらは今では 72 ppi と記録される．
}

\value{
  プロット用のデバイスが開かれる：
  \R インタプリタには何も返されない．
}

\section{警告}{
  既定では \code{width} と \code{height} 値はピクセル単位であり
  インチ単位ではないことを注意する．
  両者が 20 未満であれば警告が出る．

  もし一つのこれらのデバイス上に一ページより多くをプロットし
  系列番号に対する \code{\%d} の様なものを
  \code{file} 中に含めなければ，ファイルはプロットされた
  最後のプロットを含む．
}

\section{OS 間の違い}{
  これらの関数は三つもしくはそれ以上の異なった背景にあるデバイスへの
  インタフェイスである．
  \itemize{
    \item Windows では
    Windows の GDI 呼び出しを用いた隠れスクリーンへのプロットに基づく．

    \item
    X11 に対するサポートを持つプラットフォームでは隠し
    X11 デイスプレイへのプロット．

    \item コンソールで作業時の OS X 上で
    \R が適当なサポート込みでコンパイルされていれば，
    Apple の Quartz プロットシステムを使う．

    \item
    cairographics に対するサポート込でコンパイルされていれば
    cairo 曲面へのプロット．
    これはフォントに対する素朴なプラットフォームのサポートを
    使うかもしれない．又は広範囲のフォント書式をサポートするために
    \code{fontconfig} を使うかもしれない．
    (これは最初 Windows 上では \R 2.14.0 で利用可能になった．)
  }
  従って
  サポートされるオプションと作られる出力に差があるのは避けられない．
  恐らく最も重要なことは
  アンチエイリアシングされたフォントと半透明食に対するサポートである：
  最良の結果は，もし利用できれば，
  cairo 又は Quartz に基づくデバイスを利用した時得られそうである．

  既定の拡張子は Windows では \file{.jpg} と \file{.tif} で，
  そしてその他では \file{.jpeg} と \file{.tiff} である．
}

\note{
  これらのデバイスの \code{type = "windows"} バージョンは実効的には
  隠れスクリーンへのプロットで，それからイメージを要求された書式に変換する．
  これはそれらが実際のスクリーンデバイスと同じ色諸李を持つことを
  意味し，もしそれが
  24 ビットか 32 ビットの色モードに設定された時最も良く動作する．

  高品位のプロットには，もしそれが自分の Windows システム上で
  既定でなければ\cr
  \code{antialias = "cleartype"} としたくなるであろう．
  他方で
  \code{png(antialias = "none")} は最もコンパクトなファイルを与える．
}

\references{
  PNG の仕様は \url{http://www.w3.org/TR/PNG/}.
  
  拡張を含む TIFF の仕様は
  \url{https://partners.adobe.com/public/developer/tiff/}．
}
\seealso{
  \code{\link{Devices}}, \code{\link{dev.print}}

  \code{\link{bitmap}} は GhostScript が利用できる時多くのビットマップ書式での
  プロットを生成する別の方法を提供する．
}

\section{慣例}{
  この節は
  \dQuote{R Internals Manual} 中で設定されているグラフィックスデバイス
  に対する慣例の実装を説明する．

  \itemize{
    \item 既定のデバイスサイズはピクセル単位．
    \item フォントのサイズはビッグポイントで \code{res} ppi で解釈される．
    \item 既定のフォントファミリは Arial．
    \item 線幅は 1/96 インチの倍数(\code{res} ppi で解釈される)で，最小値は1ピクセル
      (\code{type = "windows"}) 又は 0.01 (\code{type = "cairo"})．
    \item 円の最少半径は \code{type = "windows"} に対しては 1 ピクセル．
    \item 色は閲覧アプリケーションにより解釈される．
  }
}

\examples{
## 現在のプロットを(大きな) PNG ファイルにコピー
\dontrun{dev.print(png, file = "myplot.png", width = 1024, height = 768)

png(file = "myplot.png", bg = "transparent")
plot(1:10)
rect(1, 5, 3, 7, col = "white")
dev.off()

jpeg(file = "myplot.jpeg")
example(rect)
dev.off()
}}
\keyword{device}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/grDevices/man/windows/png.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{png}
%\alias{png}
%\alias{jpeg}
%\alias{tiff}
%\alias{bmp}
%\title{BMP, JPEG, PNG and TIFF graphics devices}
%\description{
%  Graphics devices for BMP, JPEG, PNG and TIFF format bitmap files.
%}
%\usage{
%bmp(filename = "Rplot\%03d.bmp",
%    width = 480, height = 480, units = "px", pointsize = 12,
%    bg = "white", res = NA, family = "", restoreConsole = TRUE,
%    type = c("windows", "cairo"), antialias)
%
%jpeg(filename = "Rplot\%03d.jpg",
%     width = 480, height = 480, units = "px", pointsize = 12,
%     quality = 75,
%     bg = "white", res = NA, family = "", restoreConsole = TRUE,
%     type = c("windows", "cairo"), antialias)
%
%png(filename = "Rplot\%03d.png",
%    width = 480, height = 480, units = "px", pointsize = 12,
%    bg = "white", res = NA, family = "", restoreConsole = TRUE,
%    type = c("windows", "cairo", "cairo-png"), antialias)
%
%tiff(filename = "Rplot\%03d.tif",
%     width = 480, height = 480, units = "px", pointsize = 12,
%     compression = c("none", "rle", "lzw", "jpeg", "zip", "lzw+p", "zip+p"),
%     bg = "white", res = NA, family = "", restoreConsole = TRUE,
%     type = c("windows", "cairo"), antialias)
%}
%\arguments{
%  \item{filename}{the name of the output file, up to 511 characters.  The
%    page number is substituted if a C integer format is included in the
%    character string, as in the default, and tilde-expansion is
%    performed (see \code{\link{path.expand}}).   (The result must be less than
%    600 characters long.  See \code{\link{postscript}} for further
%    details.)
%  }
%  \item{width}{the width of the device.}
%  \item{height}{the height of the device.}
%  \item{units}{The units in which \code{height} and \code{width} are
%    given.  Can be \code{px} (pixels, the default), \code{in} (inches),
%    \code{cm} or \code{mm}.}
%  \item{pointsize}{the default pointsize of plotted text, interpreted as
%    big points (1/72 inch) at \code{res} ppi.}
%  \item{bg}{the initial background colour: can be overridden by setting
%    par("bg").}
%  \item{quality}{the \sQuote{quality} of the JPEG image, as a
%    percentage.  Smaller values will give more compression but also more
%    degradation of the image.}
%  \item{compression}{the type of compression to be used.}
%  \item{res}{The nominal resolution in ppi which will be recorded in the
%    bitmap file, if a positive integer.  Also used for units other than
%    the default.  If not specified, taken as 72 ppi to set the size of
%    text and line widths.}
%  \item{family}{A length-one character vector specifying the default
%    font family.  The default means to use the font numbers on the
%    Windows GDI versions and \code{"sans"} on the cairographics
%    versions.}
%  \item{restoreConsole}{See the \sQuote{Details} section of
%    \code{\link{windows}}.  For \code{type == "windows"} only.}
%  \item{type}{Should be plotting be done using Windows GDI or cairographics?}
%  \item{antialias}{Length-one character vector.
%
%    For allowed values and their effect on fonts with \code{type =
%      "windows"} see \code{\link{windows}}: for that type if the
%    argument is missing the default is taken from
%    \code{windows.options()$bitmap.aa.win}.
%
%    For allowed values and their effect (on fonts and lines, but not
%    fills) with \code{type = "cairo"} see \code{\link{svg}}.}
%}
%\details{
%  Plots in PNG and JPEG format can easily be converted to many other
%  bitmap formats, and both can be displayed in modern web browsers.  The
%  PNG format is lossless and is best for line diagrams and blocks of
%  colour.  The JPEG format is lossy, but may be useful for image plots,
%  for example.  The BMP format is standard on Windows, and supported by
%  most viewers elsewhere.  TIFF is a meta-format: the default format
%  written by \code{tiff} is lossless and stores RGB values
%  uncompressed---such files are widely accepted, which is their main
%  virtue over PNG.
%
%  Windows GDI imposes limits on the size of bitmaps: these are not
%  documented in the SDK and may depend on the version of Windows.
%  It seems that \code{width} and \code{height} are each limited to
%  \eqn{2^{15}-1}{2^15-1}.  In addition, there are limits on the total
%  number of pixels which depend on the graphics hardware.
%
%  By default no resolution is recorded in the file (except for BMP).
%  Viewers will often assume a nominal resolution of 72 ppi when none is
%  recorded.  As resolutions in PNG files are recorded in pixels/metre,
%  the reported ppi value will be changed slightly.
%
%  For graphics parameters that make use of dimensions in inches,
%  \code{res} ppi (default 72) is assumed.
%
%  Both \code{bmp} and \code{png} will use a palette if there are fewer
%  than 256 colours on the page, and record a 24-bit RGB file otherwise.
%  For the \code{png} device, \code{type = "cairo"} does the PNG output in
%  the driver and so is compatible with the \code{"windows"} type.
%  \code{type = "cairo-png"} uses cairographics' PNG backend which will
%  never use a palette and normally creates a larger 32-bit ARGB
%  file---this may work better for specialist uses with semi-transparent
%  colours.
%
%  \code{png(type = "windows")} supports transparent backgrounds on 16-bit
%  (\sQuote{High Color}) or better screens: use \code{bg =
%    "transparent"}.  There is also support for semi-transparent colours
%  of lines, fills and text.  However, as there is only partial support
%  for transparency in the graphics toolkit used: if there is a
%  transparent background semi-transparent colours are painted onto a
%  slightly off-white background and hence the pixels are opaque.
%
%  Not all PNG viewers render files with transparency correctly.
%
%  \code{tiff} compression types \code{"lzw+p"} and \code{"zip+p"} use
%  horizontal differencing (\sQuote{differencing predictor}, section 14
%  of the TIFF specification) in combination with the compression method,
%  which is effective for continuous-tone images, especially colour ones.
%  
%  Prior to \R 3.0.3 unknown resolutions in BMP files were sometimes
%  recorded incorrectly: they are now recorded as 72 ppi.
%}
%
%\value{
%  A plot device is opened: nothing is returned to the \R interpreter.
%}
%
%\section{Warnings}{
%  Note that by default the \code{width} and \code{height} values are in
%  pixels not inches.  A warning will be issued if both are less than 20.
%
%  If you plot more than one page on one of these devices and do not
%  include something like \code{\%d} for the sequence number in
%  \code{file}, the file will contain the last page plotted.
%}
%
%\section{Differences between OSes}{
%  These functions are interfaces to three or more different underlying
%  devices.
%  \itemize{
%    \item On Windows, devices based on plotting to a hidden screen using
%    Windows' GDI calls.
%
%    \item On platforms with support for X11, plotting to a hidden X11
%    display.
%
%    \item On OS X when working at the console and when \R is
%    compiled with suitable support, using Apple's Quartz plotting
%    system.
%
%    \item Where support has been compiled in for cairographics, plotting
%    on cairo surfaces.  This may use the native platform support for
%    fonts, or it may use \code{fontconfig} to support a wide range of
%    font formats.  (This was first available on Windows in \R 2.14.0.)
%  }
%  Inevitably there will be differences between the options supported and
%  output produced.  Perhaps the most important are support for
%  antialiased fonts and semi-transparent colours: the best results are
%  likely to be obtained with the cairo- or Quartz-based devices where
%  available.
%
%  The default extensions are \file{.jpg} and \file{.tif} on Windows, and
%  \file{.jpeg} and \file{.tiff} elsewhere.
%}
%
%\note{
%  The \code{type = "windows"} versions of these devices effectively
%  plot on a hidden screen and then copy the image to the required
%  format.  This means that they have the same colour handling as the
%  actual screen device, and work best if that is set to a 24-bit or
%  32-bit colour mode.
%
%  For high-quality plots you will probably want \code{antialias =
%    "cleartype"} if this is not the default on your Windows system.  On
%  the other hand, \code{png(antialias = "none")} will give the most
%  compact files
%}
%
%\references{
%  The PNG specification, \url{http://www.w3.org/TR/PNG/}.
%  
%  The TIFF specification, including extensions, at
%  \url{https://partners.adobe.com/public/developer/tiff/}.
%}
%\seealso{
%  \code{\link{Devices}}, \code{\link{dev.print}}
%
%  \code{\link{bitmap}} provides an alternative way to generate plots in
%  many bitmap formats if GhostScript is available.
%}
%
%\section{Conventions}{
%  This section describes the implementation of the conventions for
%  graphics devices set out in the \dQuote{R Internals Manual}.
%
%  \itemize{
%    \item The default device size is in pixels.
%    \item Font sizes are in big points interpreted at \code{res} ppi.
%    \item The default font family is Arial.
%    \item Line widths are a multiple of 1/96 inch (interpreted at
%    \code{res} ppi), with a minimum of one pixel (\code{type =
%      "windows"}) or 0.01 (\code{type = "cairo"}).
%    \item The minimum radius of a circle is 1 pixel for \code{type =
%      "windows"}.
%    \item Colours are interpreted by the viewing application.
%  }
%}
%
%\examples{
%## copy current plot to a (large) PNG file
%\dontrun{dev.print(png, file = "myplot.png", width = 1024, height = 768)
%
%png(file = "myplot.png", bg = "transparent")
%plot(1:10)
%rect(1, 5, 3, 7, col = "white")
%dev.off()
%
%jpeg(file = "myplot.jpeg")
%example(rect)
%dev.off()
%}}
%\keyword{device}
%
