% File src/library/graphics/man/boxplot.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{boxplot}
\alias{boxplot}
\alias{boxplot.default}
\alias{boxplot.formula}
\title{Box Plots}
\description{
  与えられた(グループ化された)値に対して箱型図を作る．
}
\usage{
boxplot(x, \dots)

\method{boxplot}{formula}(formula, data = NULL, \dots, subset, na.action = NULL)

\method{boxplot}{default}(x, \dots, range = 1.5, width = NULL, varwidth = FALSE,
        notch = FALSE, outline = TRUE, names, plot = TRUE,
        border = par("fg"), col = NULL, log = "",
        pars = list(boxwex = 0.8, staplewex = 0.5, outwex = 0.5),
        horizontal = FALSE, add = FALSE, at = NULL)
}
\arguments{
  \item{formula}{\code{y ~ grp} のような公式で，\code{y} はデータ値の
    数値ベクトルでグルーピング変数(普通因子) \code{grp} に従って
    分割される．}
  \item{data}{\code{formula} 中の変数がそこから取られるデータフレーム
    (又はリスト)．}
  \item{subset}{プロットに対して使われる観測値の部分集合を指定するオプションのベクトル．}
  \item{na.action}{データが \code{NA} 値を含む時何が起こるべきかを指示する関数．
    既定では応答変数とグループ変数共に欠損理を無視する．}
  \item{x}{そこから箱型図を作るデータの指定用．
    数値ベクトルかそうしたベクトルを含む一つのリスト．
    追加の名前無しの引数はベクトルを分離する追加のデータを指定する
    (各々が一つの箱型図成分に対応する)．
    \code{\link{NA}} はデータ中にあっても良い．}
  \item{\dots}{\code{formula} メソッドに対して，既定メソッドに渡される名前付き引数．

    既定のメソッドに対しては，名前のない引数は追加のデータベクトルである
    (\code{x} がリストでない限り，リストならそれらは無視される)．
    そして名前付きの引数は，引数 \code{pars} で与えられるものに加えて，
    \code{\link{bxp}} に渡されるグラフィカルパラメータ
    (そして \code{pars} 中のそれらを上書きする)である．
    \code{bxp} はそれが渡されたグラフィカルパラメータを使うかもしれないし
    使わないかもしれない；そのドキュメントを見よ．
  }
  \item{range}{これはプロットのヒゲが箱からどれくらい外へ伸びるかを
    決定する．もし \code{range} が正なら，ヒゲは箱から
    四分偏差の \code{range} 倍以下で最も離れたデータ点まで伸びる．
    値がゼロならヒゲはデータの極値まで伸びる．}
  \item{width}{プロットを作り上げる箱の相対的な幅を与えるベクトル．}
  \item{varwidth}{もし \code{varwidth} が \code{TRUE} なら，箱は幅が
    グループ中の観測値の平方根に比例する幅で描かれる．}
  \item{notch}{もし \code{notch} が \code{TRUE} なら，箱の両側に刻み目が描かれる．
    もし二つのプロットの刻み目が重ならなければ，これは二つの中央値が
    異なる\sQuote{強力な証拠}である
    (Chambers \emph{et al}, 1983, p.\sspace{}62)．使われる計算法については
    \code{\link{boxplot.stats}} を見よ．}
  \item{outline}{もし \code{outline} が真で無ければ，外れ値は描かれない
    (点として，一方 Splus は線を使う)．}% the argument name is most ugly but S+ compatible
  \item{names}{各箱形図プロットの下にプリントされるグループラベル．
    文字列ベクトルや表現式で良い(\link{plotmath} を見よ)．}
  \item{boxwex}{全ての箱に適用されるスケール因子．数個のグループしか
    なければ，箱を狭くするとプロットの外見が良くなる．}
  \item{staplewex}{主要な線幅の拡大，箱幅に比例する．}
  \item{outwex}{外れ値の線の拡大，箱幅に比例する．}
  \item{plot}{もし \code{TRUE} (既定)なら箱型図が描かれる．さもなければ
    箱型図の基本となる要約を返す．}
  \item{border}{箱型図の外れ値に対するオプションの色のベクトル．
    もし \code{border} の長さがプロットの数より少なければ \code{border} 中の値は
    リサイクルされる．}
  \item{col}{もし \code{col} が null で無ければこれは箱型図の本体を彩色する
    色を含むとされる．既定ではそれらは背景色である．}
  \item{log}{x や y 又は双方の座標が対数スケールでプロットすべきかを指示する．}
  \item{pars}{例えば \code{boxwex} や \code{outpch} のような(もしかすると多くの)
    グラフィカルパラメータのリスト；これらは(もし \code{plot} が真なら)
    \code{\link{bxp}} に渡される；詳細はそれを見よ．}
  \item{horizontal}{箱型図が水平であるべきかどうかを指示する論理値；
    既定の \code{FALSE} は垂直の箱を意味する．}
  \item{add}{論理値．もし真なら現在のプロットに箱型図を\emph{加える}．}
  \item{at}{特に \code{add = TRUE} の時，箱型図を描くべき位置を与える数値ベクトル；
    既定では \code{1:n} で \code{n} は箱の数．}
}
\details{
  総称的関数 \code{boxplot} は現在既定メソッド
  (\code{boxplot.default}) と公式を用いたインタフェイス(\code{boxplot.formula})
  を持つ．

  もし複数のグループが複数引数や公式で与えられると，
  平行な箱型図が引数の順序か因子の水準の順序でプロットされる
  (\code{\link{factor}} を見よ)．

  箱型図を作る時欠損値は無視される．
}
\value{
  次の成分を持つリスト：
  \item{stats}{行列で，各列は下側ヒゲの極値，下側ヒンジ，中央値，上側ヒンジ，
    そして上側ヒゲの極値を一つのグループ/プロット毎に持つ．
    もし全ての入力が同じクラス属性を持てばこの成分もそれを持つ．}
  \item{n}{各グループ中の観測値の数を持つベクトル．}
  \item{conf}{ノッチの下側と上側の極値を各列に含む行列．}
  \item{out}{ヒゲの極値を超える任意のデータ点の値．}
  \item{group}{\code{out} と同じ長さのベクトルで，その要素は
    外れ値がそのグループに属するかを指示する．}
  \item{names}{グループに対する名前のベクトル．}
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Chambers, J. M., Cleveland, W. S., Kleiner, B. and Tukey, P. A. (1983)
  \emph{Graphical Methods for Data Analysis.}  Wadsworth & Brooks/Cole.

  Murrell, P. (2005) \emph{R Graphics}. Chapman & Hall/CRC Press.

  \code{\link{boxplot.stats}} も見よ．
}
\seealso{
  計算を受け持つ \code{\link{boxplot.stats}}，
  プロットとより多くの例は \code{\link{bxp}}；
  そして(少ないデータセットに対する)別法 \code{\link{stripchart}}．
}
\examples{
## 公式を用いた箱型図：
boxplot(count ~ spray, data = InsectSprays, col = "lightgray")
# *add* notches (somewhat funny here):
boxplot(count ~ spray, data = InsectSprays,
        notch = TRUE, add = TRUE, col = "blue")

boxplot(decrease ~ treatment, data = OrchardSprays,
        log = "y", col = "bisque")

rb <- boxplot(decrease ~ treatment, data = OrchardSprays, col = "bisque")
title("Comparing boxplot()s and non-robust mean +/- SD")

mn.t <- tapply(OrchardSprays$decrease, OrchardSprays$treatment, mean)
sd.t <- tapply(OrchardSprays$decrease, OrchardSprays$treatment, sd)
xi <- 0.3 + seq(rb$n)
points(xi, mn.t, col = "orange", pch = 18)
arrows(xi, mn.t - sd.t, xi, mn.t + sd.t,
       code = 3, col = "pink", angle = 75, length = .1)

## 行列を用いた箱型図：
mat <- cbind(Uni05 = (1:100)/21, Norm = rnorm(100),
             `5T` = rt(100, df = 5), Gam2 = rgamma(100, shape = 2))
boxplot(as.data.frame(mat),
        main = "boxplot(as.data.frame(mat), main = ...)")
par(las = 1) # all axis labels horizontal
boxplot(as.data.frame(mat), main = "boxplot(*, horizontal = TRUE)",
        horizontal = TRUE)

## 'at = ' の使用と箱型図の追加 -- Roger Bivand によるアイデア：

boxplot(len ~ dose, data = ToothGrowth,
        boxwex = 0.25, at = 1:3 - 0.2,
        subset = supp == "VC", col = "yellow",
        main = "Guinea Pigs' Tooth Growth",
        xlab = "Vitamin C dose mg",
        ylab = "tooth length",
        xlim = c(0.5, 3.5), ylim = c(0, 35), yaxs = "i")
boxplot(len ~ dose, data = ToothGrowth, add = TRUE,
        boxwex = 0.25, at = 1:3 + 0.2,
        subset = supp == "OJ", col = "orange")
legend(2, 9, c("Ascorbic acid", "Orange juice"),
       fill = c("yellow", "orange"))

## より多くの例が help(bxp) 中にある
}
\keyword{hplot}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/boxplot.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{boxplot}
%\alias{boxplot}
%\alias{boxplot.default}
%\alias{boxplot.formula}
%\title{Box Plots}
%\description{
%  Produce box-and-whisker plot(s) of the given (grouped) values.
%}
%\usage{
%boxplot(x, \dots)
%
%\method{boxplot}{formula}(formula, data = NULL, \dots, subset, na.action = NULL)
%
%\method{boxplot}{default}(x, \dots, range = 1.5, width = NULL, varwidth = FALSE,
%        notch = FALSE, outline = TRUE, names, plot = TRUE,
%        border = par("fg"), col = NULL, log = "",
%        pars = list(boxwex = 0.8, staplewex = 0.5, outwex = 0.5),
%        horizontal = FALSE, add = FALSE, at = NULL)
%}
%\arguments{
%  \item{formula}{a formula, such as \code{y ~ grp}, where \code{y} is a
%    numeric vector of data values to be split into groups according to
%    the grouping variable \code{grp} (usually a factor).}
%  \item{data}{a data.frame (or list) from which the variables in
%    \code{formula} should be taken.}
%  \item{subset}{an optional vector specifying a subset of observations
%    to be used for plotting.}
%  \item{na.action}{a function which indicates what should happen
%    when the data contain \code{NA}s.  The default is to ignore missing
%    values in either the response or the group.}
%  \item{x}{for specifying data from which the boxplots are to be
%    produced. Either a numeric vector, or a single list containing such
%    vectors. Additional unnamed arguments specify further data
%    as separate vectors (each corresponding to a component boxplot).
%    \code{\link{NA}}s are allowed in the data.}
%  \item{\dots}{For the \code{formula} method, named arguments to be passed to
%    the default method.
%
%    For the default method, unnamed arguments are additional data
%    vectors (unless \code{x} is a list when they are ignored), and named
%    arguments are arguments and \link{graphical parameters} to be passed
%    to \code{\link{bxp}} in addition to the ones given by argument
%    \code{pars} (and override those in \code{pars}). Note that
%    \code{bxp} may or may not make use of graphical parameters it is
%    passed: see its documentation.
%  }
%  \item{range}{this determines how far the plot whiskers extend out
%    from the box.  If \code{range} is positive, the whiskers extend
%    to the most extreme data point which is no more than
%    \code{range} times the interquartile range from the box. A value
%    of zero causes the whiskers to extend to the data extremes.}
%  \item{width}{a vector giving the relative widths of the boxes making
%    up the plot.}
%  \item{varwidth}{if \code{varwidth} is \code{TRUE}, the boxes are
%    drawn with widths proportional to the square-roots of the number
%    of observations in the groups.}
%  \item{notch}{if \code{notch} is \code{TRUE}, a notch is drawn in
%    each side of the boxes.  If the notches of two plots do not
%    overlap this is \sQuote{strong evidence} that the two medians differ
%    (Chambers \emph{et al}, 1983, p.\sspace{}62).  See \code{\link{boxplot.stats}}
%    for the calculations used.}
%  \item{outline}{if \code{outline} is not true, the outliers are
%    not drawn (as points whereas S+ uses lines).}% the argument name is most ugly but S+ compatible
%  \item{names}{group labels which will be printed under each boxplot.
%    Can be a character vector or an \link{expression} (see
%    \link{plotmath}).}
%  \item{boxwex}{a scale factor to be applied to all boxes.  When there
%    are only a few groups, the appearance of the plot can be improved
%    by making the boxes narrower.}
%  \item{staplewex}{staple line width expansion, proportional to box
%    width.}
%  \item{outwex}{outlier line width expansion, proportional to box
%    width.}
%  \item{plot}{if \code{TRUE} (the default) then a boxplot is
%    produced.  If not, the summaries which the boxplots are based on
%    are returned.}
%  \item{border}{an optional vector of colors for the outlines of the
%    boxplots.  The values in \code{border} are recycled if the
%    length of \code{border} is less than the number of plots.}
%  \item{col}{if \code{col} is non-null it is assumed to contain colors
%    to be used to colour the bodies of the box plots. By default they
%    are in the background colour.}
%  \item{log}{character indicating if x or y or both coordinates should
%    be plotted in log scale.}
%  \item{pars}{a list of (potentially many) more graphical parameters,
%    e.g., \code{boxwex} or \code{outpch}; these are passed to
%    \code{\link{bxp}} (if \code{plot} is true); for details, see there.}
%  \item{horizontal}{logical indicating if the boxplots should be
%    horizontal; default \code{FALSE} means vertical boxes.}
%  \item{add}{logical, if true \emph{add} boxplot to current plot.}
%  \item{at}{numeric vector giving the locations where the boxplots should
%    be drawn, particularly when \code{add = TRUE};
%    defaults to \code{1:n} where \code{n} is the number of boxes.}
%}
%\details{
%  The generic function \code{boxplot} currently has a default method
%  (\code{boxplot.default}) and a formula interface (\code{boxplot.formula}).
%
%  If multiple groups are supplied either as multiple arguments or via a
%  formula, parallel boxplots will be plotted, in the order of the
%  arguments or the order of the levels of the factor (see
%  \code{\link{factor}}).
%
%  Missing values are ignored when forming boxplots.
%}
%\value{
%  List with the following components:
%  \item{stats}{a matrix, each column contains the extreme of the lower
%    whisker, the lower hinge, the median, the upper hinge and the
%    extreme of the upper whisker for one group/plot.  If all the inputs
%    have the same class attribute, so will this component.}
%  \item{n}{a vector with the number of observations in each group.}
%  \item{conf}{a matrix where each column contains the lower and upper
%    extremes of the notch.}
%  \item{out}{the values of any data points which lie beyond the
%    extremes of the whiskers.}
%  \item{group}{a vector of the same length as \code{out} whose elements
%    indicate to which group the outlier belongs.}
%  \item{names}{a vector of names for the groups.}
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Chambers, J. M., Cleveland, W. S., Kleiner, B. and Tukey, P. A. (1983)
%  \emph{Graphical Methods for Data Analysis.}  Wadsworth & Brooks/Cole.
%
%  Murrell, P. (2005) \emph{R Graphics}. Chapman & Hall/CRC Press.
%
%  See also \code{\link{boxplot.stats}}.
%}
%\seealso{
%  \code{\link{boxplot.stats}} which does the computation,
%  \code{\link{bxp}} for the plotting and more examples;
%  and \code{\link{stripchart}} for an alternative (with small data
%  sets).
%}
%\examples{
%## boxplot on a formula:
%boxplot(count ~ spray, data = InsectSprays, col = "lightgray")
%# *add* notches (somewhat funny here):
%boxplot(count ~ spray, data = InsectSprays,
%        notch = TRUE, add = TRUE, col = "blue")
%
%boxplot(decrease ~ treatment, data = OrchardSprays,
%        log = "y", col = "bisque")
%
%rb <- boxplot(decrease ~ treatment, data = OrchardSprays, col = "bisque")
%title("Comparing boxplot()s and non-robust mean +/- SD")
%
%mn.t <- tapply(OrchardSprays$decrease, OrchardSprays$treatment, mean)
%sd.t <- tapply(OrchardSprays$decrease, OrchardSprays$treatment, sd)
%xi <- 0.3 + seq(rb$n)
%points(xi, mn.t, col = "orange", pch = 18)
%arrows(xi, mn.t - sd.t, xi, mn.t + sd.t,
%       code = 3, col = "pink", angle = 75, length = .1)
%
%## boxplot on a matrix:
%mat <- cbind(Uni05 = (1:100)/21, Norm = rnorm(100),
%             `5T` = rt(100, df = 5), Gam2 = rgamma(100, shape = 2))
%boxplot(as.data.frame(mat),
%        main = "boxplot(as.data.frame(mat), main = ...)")
%par(las = 1) # all axis labels horizontal
%boxplot(as.data.frame(mat), main = "boxplot(*, horizontal = TRUE)",
%        horizontal = TRUE)
%
%## Using 'at = ' and adding boxplots -- example idea by Roger Bivand :
%
%boxplot(len ~ dose, data = ToothGrowth,
%        boxwex = 0.25, at = 1:3 - 0.2,
%        subset = supp == "VC", col = "yellow",
%        main = "Guinea Pigs' Tooth Growth",
%        xlab = "Vitamin C dose mg",
%        ylab = "tooth length",
%        xlim = c(0.5, 3.5), ylim = c(0, 35), yaxs = "i")
%boxplot(len ~ dose, data = ToothGrowth, add = TRUE,
%        boxwex = 0.25, at = 1:3 + 0.2,
%        subset = supp == "OJ", col = "orange")
%legend(2, 9, c("Ascorbic acid", "Orange juice"),
%       fill = c("yellow", "orange"))
%
%## more examples in  help(bxp)
%}
%\keyword{hplot}
%
\encoding{UTF8}
