% File src/library/graphics/man/hist.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{hist}
\title{Histograms}
\usage{
hist(x, \dots)

\method{hist}{default}(x, breaks = "Sturges",
     freq = NULL, probability = !freq,
     include.lowest = TRUE, right = TRUE,
     density = NULL, angle = 45, col = NULL, border = NULL,
     main = paste("Histogram of" , xname),
     xlim = range(breaks), ylim = NULL,
     xlab = xname, ylab,
     axes = TRUE, plot = TRUE, labels = FALSE,
     nclass = NULL, warn.unused = TRUE, \dots)
}
\alias{hist}
\alias{hist.default}
\arguments{
  \item{x}{それに対してヒストグラムが期待される値のベクトル．}
  \item{breaks}{以下の一つ：
    \itemize{
      \item ヒストグラムの間の分点を与えるベクトル，
      \item 分点のベクトルを計算する関数．
      \item ヒストグラムに対するセル数を与える単一の数，
      \item セルの数を計算するアルゴリズムの名前である文字列，
      (\sQuote{詳細}を見よ)，
      \item セル数を計算する関数．
    }
     最後の三つのケースでは数は示唆されるだけである；
     分点は \code{\link{pretty}} な値にせっていされる．
     もし \code{breaks} が関数なら，\code{x} ベクトルは唯一の
     引数としてそれに提供される．
  }
  \item{freq}{論理値；もし \code{TRUE} ならばヒストグラムグラフィックスは
    結果の \code{counts} 成分である頻度の表現である．
    もし \code{FALSE} ならば成分 \code{density} である
    確率密度がプロットされる(のでヒストグラムが総面積 1 を持つ)．
    \code{breaks} が等間隔(で \code{probability} が指定されていない)
    時，そしてその時だけ既定値は \code{TRUE} である．}
  \item{probability}{\code{!freq} に対する\emph{別名}，S との互換性
    のためにある．}
  \item{include.lowest}{論理値；もし \code{TRUE} ならば，
    \code{breaks} 値に等しい \code{x[i]} は最初
    (もしくは \code{right = FALSE} の時は最後)のバーに含められる．
    これは \code{breaks} がベクトルでない限り(警告と共に)
    無視される．}
  \item{right}{論理値；もし \code{TRUE} なら，ヒストグラムのセルは
    右に閉じた(左に開いた)区間である．}
  \item{density}{陰影線の密度でインチあたりの線数．
    既定値の \code{NULL} は陰影線を描かないことを意味する．
    正でない \code{density} の値も又陰影線を禁止する．}
  \item{angle}{陰影線の傾きで，度単位の角度で与えられる
    (逆時計まわり)．}
  \item{col}{バーを塗りつぶすのに使われる色．
    既定の \code{NULL} は塗りつぶされていないバーを作る．}
  \item{border}{バーの輪郭の色．
    既定は標準の前景食．}
  \item{main, xlab, ylab}{これらの \code{title} への引数はここでは有用な
    既定値を持つ．}
  \item{xlim, ylim}{有意な既定値を持つ x と y 値の範囲．
    \code{xlim} はヒストグラムを定義するのに\emph{使われず}，
    プロット(\code{plot = TRUE} の時)に対してだけ使われることを
    周囲する．}
  \item{axes}{論理値．もし \code{TRUE} (既定)ならば，もしプロットが描かれるなら
    軸が描かれる．}
  \item{plot}{論理値．もし \code{TRUE} (既定)ならば，ヒストグラムが
    描かれる，さもなければ分点とカウントのリストが返される．
    後者の場合，\code{plot = TRUE} の場合だけに適用される
    (典型的にはグラフィカルな)引数が指定されると警告が出る．}
  \item{labels}{論理値又は文字列．もし \code{FALSE} で無ければ，
    追加でバーの上にラベルを描く；
    \code{\link{plot.histogram}} を見よ．}
  \item{nclass}{数値(整数)．S(-PLUS) との互換性のためだけに，
    \code{nclass} はスカラもしくは文字列引数に対して \code{breaks}
    と同値になる．}
  \item{warn.unused}{論理値．もし \code{plot = FALSE} で
    \code{warn.unused = TRUE} ならば，グラフィカルパラメータが
    \code{hist.default()} に渡されると警告が出る．}
  \item{\dots}{\code{\link{plot.histogram}}，従って
    \code{\link{title}} と \code{\link{axis}}
    (もし \code{plot = TRUE} ならば)，に引き渡される追加の引数と
    グラフィカルパラメータ．}
}
\description{
  総称的関数 \code{hist} は与えられた値のヒストグラムを計算する．
  もし \code{plot = TRUE} なら，それが復帰する前に，
  結果のクラス \code{"histogram"} の
  オブジェクトが \code{\link{plot.histogram}} により
  プロットされる．
}
\details{
  \emph{ヒストグラム}の定義はソースにより異なる(国固有の
  バイアスを持つ)．等間隔の分点(既定)を持つ \R の既定動作は
  \code{breaks} で定義されるセル中のカウントをプロットする．
  このように矩形の高さはセルに落ちる点の個数に
  比例し，分点が等間隔であれば面積も同様である．

  非等間隔の分点を持つ場合の既定動作は
  面積が 1 であるプロットを与える．この場合矩形の\emph{面積}は
  セルに落ちるデータ点の割合である．

  もし \code{right = TRUE} (既定) ならば，ヒストグラムのセルは
  \code{(a, b]} の形の区間である，つまりそれらは右端を含むが
  左端は含まない．例外は \code{include.lowest} が \code{TRUE} の
  時の最初のセルである．

  \code{right = FALSE} に対して，区間は形式 \code{[a, b)} であり，
  \code{include.lowest} は\sQuote{\emph{最高のものを含む}}を意味する．

  \eqn{10^{-7}}{1e-7} 倍のビンサイズの中央値の数値的許容度
  (4以上のビンに対して，さもなければ中央値が代用される)が
  ビンの端にある項目のカウントに適用される．
  これは報告される \code{breaks} にも \code{density} の計算にも
  含まれない．

  \code{breaks} に対する既定値は \code{"Sturges"} である：
  \code{\link{nclass.Sturges}} を見よ．アルゴリズムが提供されている
  他の名前は \code{"Scott"} と \code{"FD"}/\code{"Freedman-Diaconis"}
  である(対応する関数は \code{\link{nclass.scott}} と
  \code{\link{nclass.FD}} である)．
  大・小文字の区別は無視され部分マッチが使われる．
  別法として，希望する分点数又は実際の分点を計算する \code{x} の
  関数を与えることが出来る．
}
\value{
  クラス \code{"histogram"} のオブジェクトで次の成分を持つリスト：
  \item{breaks}{\eqn{n+1} 個のセル境界(もしそれがベクトルならば
    = \code{breaks})．これらは名目上の分割点で境界でのゴミを含まない．}
  \item{counts}{\eqn{n} 個の整数；各セルに対して，
    内部の \code{x[]} の数．}
  \item{density}{値 \eqn{\hat f(x_i)}{f^(x[i])} で，推定密度の値．
    もし \code{all(diff(breaks) == 1)} なら，それらは相対頻度
    \code{counts/n} で一般に
    \eqn{\sum_i \hat f(x_i) (b_{i+1}-b_i) = 1}{sum[i; f^(x[i])
      (b[i+1]-b[i])] = 1} を満たす，ここで
      \eqn{b_i}{b[i]} = \code{breaks[i]}．}
  \item{mids}{\eqn{n} 個のセルの中間点．}
  \item{xname}{実際の \code{x} 個の引数名の文字列．}
  \item{equidist}{論理値，\code{breaks} 間の距離が皆
    同じかどうかを指示する．}
}

\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Venables, W. N. and Ripley. B. D. (2002)
  \emph{Modern Applied Statistics with S}.  Springer.
}

\seealso{
  \code{\link{nclass.Sturges}}, \code{\link{stem}},
  \code{\link{density}}.
  パッケージ \CRANpkg{MASS} 中の \code{\link[MASS]{truehist}}．

  垂直のバーを持つ典型的なプロットはヒストグラムでは\emph{無い}．
  そうしたバープロットには
  \code{\link{barplot}} や \code{\link{plot}(*, type = "h")}
  を考慮しよう．
}

\examples{
op <- par(mfrow = c(2, 2))
hist(islands)
utils::str(hist(islands, col = "gray", labels = TRUE))

hist(sqrt(islands), breaks = 12, col = "lightblue", border = "pink")
##-- 不等間隔な分割に対しては，カウントはスケール化せずにグラフ化すべきではない：
r <- hist(sqrt(islands), breaks = c(4*0:5, 10*3:5, 70, 100, 140),
          col = "blue1")
text(r$mids, r$density, r$counts, adj = c(.5, -.5), col = "blue3")
sapply(r[2:3], sum)
sum(r$density * diff(r$breaks)) # == 1
lines(r, lty = 3, border = "purple") # -> lines.histogram(*)
par(op)

require(utils) # str に対し
str(hist(islands, breaks = 12, plot =  FALSE)) #-> 10 (~= 12) 分割点
str(hist(islands, breaks = c(12,20,36,80,200,1000,17000), plot = FALSE))

hist(islands, breaks = c(12,20,36,80,200,1000,17000), freq = TRUE,
     main = "WRONG histogram") # そして警告

require(stats)
set.seed(14)
x <- rchisq(100, df = 4)
\dontshow{op <- par(mfrow = 2:1, mgp = c(1.5, 0.6, 0), mar = .1 + c(3,3:1))}
## データとモデル分布の比較は qqplot() を使ってなされる!
qqplot(x, qchisq(ppoints(x), df = 4)); abline(0, 1, col = 2, lty = 2)

## もし hist() の使用に固執するのであれば ... ：
hist(x, freq = FALSE, ylim = c(0, 0.2))
curve(dchisq(x, df = 4), col = 2, lty = 2, lwd = 2, add = TRUE)
\dontshow{par(op)}
}
\keyword{dplot}
\keyword{hplot}
\keyword{distribution}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/hist.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{hist}
%\title{Histograms}
%\usage{
%hist(x, \dots)
%
%\method{hist}{default}(x, breaks = "Sturges",
%     freq = NULL, probability = !freq,
%     include.lowest = TRUE, right = TRUE,
%     density = NULL, angle = 45, col = NULL, border = NULL,
%     main = paste("Histogram of" , xname),
%     xlim = range(breaks), ylim = NULL,
%     xlab = xname, ylab,
%     axes = TRUE, plot = TRUE, labels = FALSE,
%     nclass = NULL, warn.unused = TRUE, \dots)
%}
%\alias{hist}
%\alias{hist.default}
%\arguments{
%  \item{x}{a vector of values for which the histogram is desired.}
%  \item{breaks}{one of:
%    \itemize{
%      \item a vector giving the breakpoints between histogram cells,
%      \item a function to compute the vector of breakpoints,
%      \item a single number giving the number of cells for the histogram,
%      \item a character string naming an algorithm to compute the
%      number of cells (see \sQuote{Details}),
%      \item a function to compute the number of cells.
%    }
%    In the last three cases the number is a suggestion only; the
%     breakpoints will be set to \code{\link{pretty}} values.  If
%     \code{breaks} is a function, the \code{x} vector is supplied to it
%     as the only argument.
%  }
%  \item{freq}{logical; if \code{TRUE}, the histogram graphic is a
%    representation of frequencies, the \code{counts} component of
%    the result; if \code{FALSE}, probability densities, component
%    \code{density}, are plotted (so that the histogram has a total area
%    of one).  Defaults to \code{TRUE} \emph{if and only if} \code{breaks} are
%    equidistant (and \code{probability} is not specified).}
%  \item{probability}{an \emph{alias} for \code{!freq}, for S compatibility.}
%  \item{include.lowest}{logical; if \code{TRUE}, an \code{x[i]} equal to
%    the \code{breaks} value will be included in the first (or last, for
%    \code{right = FALSE}) bar.  This will be ignored (with a warning)
%    unless \code{breaks} is a vector.}
%  \item{right}{logical; if \code{TRUE}, the histogram cells are
%    right-closed (left open) intervals.}
%
%  \item{density}{the density of shading lines, in lines per inch.
%    The default value of \code{NULL} means that no shading lines
%    are drawn. Non-positive values of \code{density} also inhibit the
%    drawing of shading lines.}
%  \item{angle}{the slope of shading lines, given as an angle in
%    degrees (counter-clockwise).}
%  \item{col}{a colour to be used to fill the bars.
%    The default of \code{NULL} yields unfilled bars.}
%  \item{border}{the color of the border around the bars.  The default
%    is to use the standard foreground color.}
%  \item{main, xlab, ylab}{these arguments to \code{title} have useful
%    defaults here.}
%  \item{xlim, ylim}{the range of x and y values with sensible defaults.
%    Note that \code{xlim} is \emph{not} used to define the histogram (breaks),
%    but only for plotting (when \code{plot = TRUE}).}
%  \item{axes}{logical.  If \code{TRUE} (default), axes are draw if the
%    plot is drawn.}
%  \item{plot}{logical.  If \code{TRUE} (default), a histogram is
%    plotted, otherwise a list of breaks and counts is returned.  In the
%    latter case, a warning is used if (typically graphical) arguments
%    are specified that only apply to the \code{plot = TRUE} case.}
%  \item{labels}{logical or character string.  Additionally draw labels on top
%    of bars, if not \code{FALSE}; see \code{\link{plot.histogram}}.}
%  \item{nclass}{numeric (integer).  For S(-PLUS) compatibility only,
%    \code{nclass} is equivalent to \code{breaks} for a scalar or
%    character argument.}
%  \item{warn.unused}{logical.  If \code{plot = FALSE} and
%    \code{warn.unused = TRUE}, a warning will be issued when graphical
%    parameters are passed to \code{hist.default()}.}
%  \item{\dots}{further arguments and \link{graphical parameters} passed to
%    \code{\link{plot.histogram}} and thence to \code{\link{title}} and
%    \code{\link{axis}} (if \code{plot = TRUE}).}
%}
%\description{
%  The generic function \code{hist} computes a histogram of the given
%  data values.  If \code{plot = TRUE}, the resulting object of
%  \link{class} \code{"histogram"} is plotted by
%  \code{\link{plot.histogram}}, before it is returned.
%}
%\details{
%  The definition of \emph{histogram} differs by source (with
%  country-specific biases).  \R's default with equi-spaced breaks (also
%  the default) is to plot the counts in the cells defined by
%  \code{breaks}.  Thus the height of a rectangle is proportional to
%  the number of points falling into the cell, as is the area
%  \emph{provided} the breaks are equally-spaced.
%
%  The default with non-equi-spaced breaks is to give
%  a plot of area one, in which the \emph{area} of the rectangles is the
%  fraction of the data points falling in the cells.
%
%  If \code{right = TRUE} (default), the histogram cells are intervals
%  of the form \code{(a, b]}, i.e., they include their right-hand endpoint,
%  but not their left one, with the exception of the first cell when
%  \code{include.lowest} is \code{TRUE}.
%
%  For \code{right = FALSE}, the intervals are of the form \code{[a, b)},
%  and \code{include.lowest} means \sQuote{\emph{include highest}}.
%
%  A numerical tolerance of \eqn{10^{-7}}{1e-7} times the median bin size
%  (for more than four bins, otherwise the median is substituted) is
%  applied when counting entries on the edges of bins.  This is not
%  included in the reported \code{breaks} nor in the calculation of
%  \code{density}.
%
%  The default for \code{breaks} is \code{"Sturges"}: see
%  \code{\link{nclass.Sturges}}.  Other names for which algorithms
%  are supplied are \code{"Scott"} and \code{"FD"} /
%  \code{"Freedman-Diaconis"} (with corresponding functions
%  \code{\link{nclass.scott}} and \code{\link{nclass.FD}}).
%  Case is ignored and partial matching is used.
%  Alternatively, a function can be supplied which
%  will compute the intended number of breaks or the actual breakpoints
%  as a function of \code{x}.
%}
%\value{
%  an object of class \code{"histogram"} which is a list with components:
%  \item{breaks}{the \eqn{n+1} cell boundaries (= \code{breaks} if that
%    was a vector). These are the nominal breaks, not with the boundary fuzz.}
%  \item{counts}{\eqn{n} integers; for each cell, the number of
%    \code{x[]} inside.}
%  \item{density}{values \eqn{\hat f(x_i)}{f^(x[i])}, as estimated
%    density values. If \code{all(diff(breaks) == 1)}, they are the
%    relative frequencies \code{counts/n} and in general satisfy
%    \eqn{\sum_i \hat f(x_i) (b_{i+1}-b_i) = 1}{sum[i; f^(x[i])
%      (b[i+1]-b[i])] = 1}, where \eqn{b_i}{b[i]} = \code{breaks[i]}.}
%  \item{mids}{the \eqn{n} cell midpoints.}
%  \item{xname}{a character string with the actual \code{x} argument name.}
%  \item{equidist}{logical, indicating if the distances between
%    \code{breaks} are all the same.}
%}
%
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Venables, W. N. and Ripley. B. D. (2002)
%  \emph{Modern Applied Statistics with S}.  Springer.
%}
%
%\seealso{
%  \code{\link{nclass.Sturges}}, \code{\link{stem}},
%  \code{\link{density}},  \code{\link[MASS]{truehist}} in package
%  \CRANpkg{MASS}.
%
%  Typical plots with vertical bars are \emph{not} histograms.  Consider
%  \code{\link{barplot}} or \code{\link{plot}(*, type = "h")}
%  for such bar plots.
%}
%
%\examples{
%op <- par(mfrow = c(2, 2))
%hist(islands)
%utils::str(hist(islands, col = "gray", labels = TRUE))
%
%hist(sqrt(islands), breaks = 12, col = "lightblue", border = "pink")
%##-- For non-equidistant breaks, counts should NOT be graphed unscaled:
%r <- hist(sqrt(islands), breaks = c(4*0:5, 10*3:5, 70, 100, 140),
%          col = "blue1")
%text(r$mids, r$density, r$counts, adj = c(.5, -.5), col = "blue3")
%sapply(r[2:3], sum)
%sum(r$density * diff(r$breaks)) # == 1
%lines(r, lty = 3, border = "purple") # -> lines.histogram(*)
%par(op)
%
%require(utils) # for str
%str(hist(islands, breaks = 12, plot =  FALSE)) #-> 10 (~= 12) breaks
%str(hist(islands, breaks = c(12,20,36,80,200,1000,17000), plot = FALSE))
%
%hist(islands, breaks = c(12,20,36,80,200,1000,17000), freq = TRUE,
%     main = "WRONG histogram") # and warning
%
%require(stats)
%set.seed(14)
%x <- rchisq(100, df = 4)
%\dontshow{op <- par(mfrow = 2:1, mgp = c(1.5, 0.6, 0), mar = .1 + c(3,3:1))}
%## Comparing data with a model distribution should be done with qqplot()!
%qqplot(x, qchisq(ppoints(x), df = 4)); abline(0, 1, col = 2, lty = 2)
%
%## if you really insist on using hist() ... :
%hist(x, freq = FALSE, ylim = c(0, 0.2))
%curve(dchisq(x, df = 4), col = 2, lty = 2, lwd = 2, add = TRUE)
%\dontshow{par(op)}
%}
%\keyword{dplot}
%\keyword{hplot}
%\keyword{distribution}
%
\encoding{UTF8}
