% File src/library/graphics/man/spineplot.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{spineplot}
\alias{spineplot}
\alias{spineplot.default}
\alias{spineplot.formula}
\title{Spine Plots and Spinograms}
\description{
  スピンプロットはモザイクプロットの特殊形であり，
  積み重ね棒グラフの一般化と見做せる．
  同様にスピノグラムはヒストグラムの拡張である．
}
\usage{
spineplot(x, \dots)

\method{spineplot}{default}(x, y = NULL,
          breaks = NULL, tol.ylab = 0.05, off = NULL,
          ylevels = NULL, col = NULL,
          main = "", xlab = NULL, ylab = NULL,
          xaxlabels = NULL, yaxlabels = NULL,
          xlim = NULL, ylim = c(0, 1), axes = TRUE, \dots)

\method{spineplot}{formula}(formula, data = NULL,
          breaks = NULL, tol.ylab = 0.05, off = NULL,
          ylevels = NULL, col = NULL,
          main = "", xlab = NULL, ylab = NULL,
          xaxlabels = NULL, yaxlabels = NULL,
          xlim = NULL, ylim = c(0, 1), axes = TRUE, \dots,
          subset = NULL)
}
\arguments{
  \item{x}{オブジェクト，既定メソッドは単一の変数
    (説明変数と解釈される)または二元テーブルを期待する．
    詳細を見よ．}
  \item{y}{従属変数と解釈される \code{"factor"}．}
  \item{formula}{形式 \code{y ~ x} で単一の従属
    \code{"factor"} と単一の説明変数を持つ \code{"formula"}．}
  \item{data}{オプションのデータフレーム．}
  \item{breaks}{もし説明変数が数値ならば，
    これはそれをどのように離散化するかを制御し，
    \code{breaks} は \code{\link{hist}} へ渡され引数のリストで良い．}
  \item{tol.ylab}{
    y 軸注釈に対する便宜的な許容度．
    もし二つのラベルの間の距離がこの閾値以下なら，
    それらは等距離にプロットされる．}
  \item{off}{棒の間の垂直オフセット(単位パーセント)．
    これはスピノグラムに対しては
    \code{0} に固定され，スピンプロットに対する既定値は \code{2}．}
  \item{ylevels}{従属変数の水準をどの順序で
    プロットするかを指定する文字列又は数値ベクトル．}
  \item{col}{
  \code{levels(y)} と同じ長さの塗り潰し色のベクトル．
    既定は \code{\link{gray.colors}} の呼び出し．}
  \item{main, xlab, ylab}{注釈のための文字列．}
  \item{xaxlabels, yaxlabels}{
    x と y 軸の注釈用の文字列ベクトル．
    既定は \code{levels(y)} と \code{levels(x)} で，
    それぞれスピンプロット用．
    スピンプロット中の \code{xaxlabels} に対しては分割点が使われる．}
  \item{xlim, ylim}{意味のある既定値をもつ x と y 値の範囲．}
  \item{axes}{論理値．もし \code{FALSE} ならば全ての軸
    (水準名を与えるものも含む)が抑制される．}
  \item{\dots}{\code{\link{rect}} に渡される追加引数．}
  \item{subset}{プロットに使われる観測値の部分集合を指定するオプションのベクトル．}
}
\details{
  \code{spineplot} はスピノグラム又はスピンプロットを作る．
  ここで \code{y} は従属変数
  (そしてカテゴリカルである必要) で \code{x} は説明変数とすると，
  これは \code{spineplot(x, y)} 又は \code{spineplot(y ~ x)} で呼び出される．
  \code{x} はカテゴリカル
  (するとスピンプロットが作られる) 又は数値
  (するとスピノグラムが作られる)．加えて
  \code{spineplot} は
  単一の引数でも呼び出すことが出来，その時はそれは
  二元配置テーブルでなければならず，
  \code{table(x, y)} に対応する．

  スピンプロットとスピノグラムは共に本質的に
  特殊な間隔と陰影で整形されたモザイクプロットである．
  概念的には \eqn{P(y | x)} を \eqn{P(x)} に対してプロットする．
  スピンプロット(\eqn{x} と \eqn{y} は共にカテゴリカル)では，
  どちらも対応する経験相対頻度で近似される．
  スピノグラム(\eqn{x} が数値)に対しては，\eqn{x} は最初離散化
  (\code{\link{hist}} を \code{breaks} 引数で呼び出して)され，そしてそれから
  経験的相対頻度が使われる．

  このようにスピンプロットはまた
  棒の高さだけでなく幅が \code{x} の相対頻度に対応する
  積み重ね棒グラフの一般化と見做すことができる．
  棒の高さはすると
  全ての \code{x} グループ毎の \code{y} の相対頻度に対応する．
  同様にスピノグラムは積み重ねヒストグラムを拡張する．
}
\value{
  視覚化されたテーブルが不可視で返される．
}
\seealso{
  \code{\link{mosaicplot}}, \code{\link{hist}}, \code{\link{cdplot}}
}
\references{
  Friendly, M. (1994), Mosaic displays for multi-way contingency tables.
  \emph{Journal of the American Statistical Association}, \bold{89},
  190--200.

  Hartigan, J.A., and Kleiner, B. (1984), A mosaic of television ratings.
  \emph{The American Statistician}, \bold{38}, 32--35.

  Hofmann, H., Theus, M. (2005), \emph{Interactive graphics for visualizing
  conditional distributions}, Unpublished Manuscript.

  Hummel, J. (1996), Linked bar charts: Analysing categorical data graphically.
  \emph{Computational Statistics}, \bold{11}, 23--33.
}
\author{
  Achim Zeileis \email{Achim.Zeileis@R-project.org}
}
\examples{
## 関節リューマチの患者の処置と改善
treatment <- factor(rep(c(1, 2), c(43, 41)), levels = c(1, 2),
                    labels = c("placebo", "treated"))
improved <- factor(rep(c(1, 2, 3, 1, 2, 3), c(29, 7, 7, 13, 7, 21)),
                   levels = c(1, 2, 3),
                   labels = c("none", "some", "marked"))

## (カテゴリカルな変数への依存性)
(spineplot(improved ~ treatment))

## UC Berkley 項への出願と認可
## (二元表)
(spineplot(margin.table(UCBAdmissions, c(3, 2)),
           main = "Applications at UCB"))
(spineplot(margin.table(UCBAdmissions, c(3, 1)),
           main = "Admissions at UCB"))

## NASA スペースシャトルの o リングの欠陥
fail <- factor(c(2, 2, 2, 2, 1, 1, 1, 1, 1, 1, 2, 1, 2, 1,
                 1, 1, 1, 2, 1, 1, 1, 1, 1),
               levels = c(1, 2), labels = c("no", "yes"))
temperature <- c(53, 57, 58, 63, 66, 67, 67, 67, 68, 69, 70, 70,
                 70, 70, 72, 73, 75, 75, 76, 76, 78, 79, 81)

## (数値変数への依存性)
(spineplot(fail ~ temperature))
(spineplot(fail ~ temperature, breaks = 3))
(spineplot(fail ~ temperature, breaks = quantile(temperature)))

## 欠陥に対するハイライト
spineplot(fail ~ temperature, ylevels = 2:1)
}
\keyword{hplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/spineplot.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{spineplot}
%\alias{spineplot}
%\alias{spineplot.default}
%\alias{spineplot.formula}
%\title{Spine Plots and Spinograms}
%\description{
%  Spine plots are a special cases of mosaic plots, and can be seen as
%  a generalization of stacked (or highlighted) bar plots. Analogously,
%  spinograms are an extension of histograms.
%}
%\usage{
%spineplot(x, \dots)
%
%\method{spineplot}{default}(x, y = NULL,
%          breaks = NULL, tol.ylab = 0.05, off = NULL,
%          ylevels = NULL, col = NULL,
%          main = "", xlab = NULL, ylab = NULL,
%          xaxlabels = NULL, yaxlabels = NULL,
%          xlim = NULL, ylim = c(0, 1), axes = TRUE, \dots)
%
%\method{spineplot}{formula}(formula, data = NULL,
%          breaks = NULL, tol.ylab = 0.05, off = NULL,
%          ylevels = NULL, col = NULL,
%          main = "", xlab = NULL, ylab = NULL,
%          xaxlabels = NULL, yaxlabels = NULL,
%          xlim = NULL, ylim = c(0, 1), axes = TRUE, \dots,
%          subset = NULL)
%}
%\arguments{
%  \item{x}{an object, the default method expects either a single variable
%    (interpreted to be the explanatory variable) or a 2-way table.  See
%    details.}
%  \item{y}{a \code{"factor"} interpreted to be the dependent variable}
%  \item{formula}{a \code{"formula"} of type \code{y ~ x} with a single
%    dependent \code{"factor"} and a single explanatory variable.}
%  \item{data}{an optional data frame.}
%  \item{breaks}{if the explanatory variable is numeric, this controls how
%    it is discretized. \code{breaks} is passed to \code{\link{hist}} and can
%    be a list of arguments.}
%  \item{tol.ylab}{convenience tolerance parameter for y-axis annotation.
%    If the distance between two labels drops under this threshold, they are
%    plotted equidistantly.}
%  \item{off}{vertical offset between the bars (in per cent). It is fixed to
%    \code{0} for spinograms and defaults to \code{2} for spine plots.}
%  \item{ylevels}{a character or numeric vector specifying in which order
%    the levels of the dependent variable should be plotted.}
%  \item{col}{a vector of fill colors of the same length as \code{levels(y)}.
%    The default is to call \code{\link{gray.colors}}.}
%  \item{main, xlab, ylab}{character strings for annotation}
%  \item{xaxlabels, yaxlabels}{character vectors for annotation of x and y axis.
%    Default to \code{levels(y)} and \code{levels(x)}, respectively for the
%    spine plot. For \code{xaxlabels} in the spinogram, the breaks are
%    used.}
%  \item{xlim, ylim}{the range of x and y values with sensible defaults.}
%  \item{axes}{logical.  If \code{FALSE} all axes (including those giving
%    level names) are suppressed.}
%  \item{\dots}{additional arguments passed to \code{\link{rect}}.}
%  \item{subset}{an optional vector specifying a subset of observations
%    to be used for plotting.  }
%}
%\details{
%  \code{spineplot} creates either a spinogram or a spine plot.  It can
%  be called via \code{spineplot(x, y)} or \code{spineplot(y ~ x)} where
%  \code{y} is interpreted to be the dependent variable (and has to be
%  categorical) and \code{x} the explanatory variable.  \code{x} can be
%  either categorical (then a spine plot is created) or numerical (then a
%  spinogram is plotted).  Additionally, \code{spineplot} can also be
%  called with only a single argument which then has to be a 2-way table,
%  interpreted to correspond to \code{table(x, y)}.
%
%  Both, spine plots and spinograms, are essentially mosaic plots with
%  special formatting of spacing and shading.  Conceptually, they plot
%  \eqn{P(y | x)} against \eqn{P(x)}.  For the spine plot (where both
%  \eqn{x} and \eqn{y} are categorical), both quantities are approximated
%  by the corresponding empirical relative frequencies.  For the
%  spinogram (where \eqn{x} is numerical), \eqn{x} is first discretized
%  (by calling \code{\link{hist}} with \code{breaks} argument) and then
%  empirical relative frequencies are taken.
%
%  Thus, spine plots can also be seen as a generalization of stacked bar
%  plots where not the heights but the widths of the bars corresponds to
%  the relative frequencies of \code{x}. The heights of the bars then
%  correspond to the conditional relative frequencies of \code{y} in
%  every \code{x} group. Analogously, spinograms extend stacked
%  histograms.
%}
%\value{
%  The table visualized is returned invisibly.
%}
%\seealso{
%  \code{\link{mosaicplot}}, \code{\link{hist}}, \code{\link{cdplot}}
%}
%\references{
%  Friendly, M. (1994), Mosaic displays for multi-way contingency tables.
%  \emph{Journal of the American Statistical Association}, \bold{89},
%  190--200.
%
%  Hartigan, J.A., and Kleiner, B. (1984), A mosaic of television ratings.
%  \emph{The American Statistician}, \bold{38}, 32--35.
%
%  Hofmann, H., Theus, M. (2005), \emph{Interactive graphics for visualizing
%  conditional distributions}, Unpublished Manuscript.
%
%  Hummel, J. (1996), Linked bar charts: Analysing categorical data graphically.
%  \emph{Computational Statistics}, \bold{11}, 23--33.
%}
%\author{
%  Achim Zeileis \email{Achim.Zeileis@R-project.org}
%}
%\examples{
%## treatment and improvement of patients with rheumatoid arthritis
%treatment <- factor(rep(c(1, 2), c(43, 41)), levels = c(1, 2),
%                    labels = c("placebo", "treated"))
%improved <- factor(rep(c(1, 2, 3, 1, 2, 3), c(29, 7, 7, 13, 7, 21)),
%                   levels = c(1, 2, 3),
%                   labels = c("none", "some", "marked"))
%
%## (dependence on a categorical variable)
%(spineplot(improved ~ treatment))
%
%## applications and admissions by department at UC Berkeley
%## (two-way tables)
%(spineplot(margin.table(UCBAdmissions, c(3, 2)),
%           main = "Applications at UCB"))
%(spineplot(margin.table(UCBAdmissions, c(3, 1)),
%           main = "Admissions at UCB"))
%
%## NASA space shuttle o-ring failures
%fail <- factor(c(2, 2, 2, 2, 1, 1, 1, 1, 1, 1, 2, 1, 2, 1,
%                 1, 1, 1, 2, 1, 1, 1, 1, 1),
%               levels = c(1, 2), labels = c("no", "yes"))
%temperature <- c(53, 57, 58, 63, 66, 67, 67, 67, 68, 69, 70, 70,
%                 70, 70, 72, 73, 75, 75, 76, 76, 78, 79, 81)
%
%## (dependence on a numerical variable)
%(spineplot(fail ~ temperature))
%(spineplot(fail ~ temperature, breaks = 3))
%(spineplot(fail ~ temperature, breaks = quantile(temperature)))
%
%## highlighting for failures
%spineplot(fail ~ temperature, ylevels = 2:1)
%}
%\keyword{hplot}
%
%\encoding{UTF8}
%