% File src/library/stats/man/SSmicmen.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2010 R Core Team
% Distributed under GPL 2 or later

\name{SSmicmen}
%@%\alias{漸近回帰モデル}%@%\alias{自己開始モデル}%@%\alias{Michaelis-Menten モデル}
\title{Self-Starting Nls Michaelis-Menten Model}
\usage{
SSmicmen(input, Vm, K)
}
\alias{SSmicmen}
\arguments{
 \item{input}{モデルがそこで評価される数値ベクトル．}
 \item{Vm}{応答の最大値を表す数値パラメータ．}
 \item{K}{応答の最大値の半分値が達成される \code{input} を
   表す数値パラメータ．
   酵素反応速度論の分野ではこれは
   Michaelis パラメータと呼ばれている．}
}
\description{
  この \code{自己開始}モデルは Michaelis-Menten モデルとそのグラディエントを
  評価する．
  それは与えられたデータセットに対してパラメータ \code{Vm} と \code{K} 
  の初期推定値を評価する \code{initial} 属性を持つ．
}
\value{
  \code{input} と同じ長さの数値ベクトル．これは表現式
  \code{Vm*input/(K+input)} の値である．
  もし引数 \code{Vm} と \code{K}\code{Asym} の
  全てが名前付きオブジェクトなら，これらの名前に関した
  グラディエント行列が \code{gradient} という名前の属性として付いている．
}
\author{\enc{José}{Jose} Pinheiro と Douglas Bates}
\seealso{\code{\link{nls}}, \code{\link{selfStart}}
}
\examples{
PurTrt <- Puromycin[ Puromycin$state == "treated", ]
SSmicmen(PurTrt$conc, 200, 0.05)  # 応答のみ
Vm <- 200; K <- 0.05
SSmicmen(PurTrt$conc, Vm, K)      # 応答とグラディエント
print(getInitial(rate ~ SSmicmen(conc, Vm, K), data = PurTrt), digits = 3)
## 初期値は実際は収束値
fm1 <- nls(rate ~ SSmicmen(conc, Vm, K), data = PurTrt)
summary(fm1)
## 引数の一部分を使った別の呼び出し
fm2 <- nls(rate ~ SSmicmen(conc, Vm, K), data = Puromycin,
           subset = state == "treated")
summary(fm2)
\dontshow{
require(graphics)

  xx <- seq(0, 5, len = 101)
  yy <- 5 * xx/(1+xx)
  par(mar = c(0, 0, 3.5, 0))
  plot(xx, yy, type = "l", axes = FALSE, ylim = c(0,6), xlim = c(-1, 5),
       xlab = "", ylab = "", lwd = 2,
       main = "Parameters in the SSmicmen model")
  usr <- par("usr")
  arrows(usr[1], 0, usr[2], 0, length = 0.1, angle = 25)
  arrows(0, usr[3], 0, usr[4], length = 0.1, angle = 25)
  text(usr[2] - 0.2, 0.1, "x", adj = c(1, 0))
  text(-0.1, usr[4], "y", adj = c(1, 1))
  abline(h = 5, lty = 2, lwd = 0)
  arrows(-0.8, 2.1, -0.8, 0, length = 0.1, angle = 25)
  arrows(-0.8, 2.9, -0.8, 5, length = 0.1, angle = 25)
  text(-0.8, 2.5, expression(phi[1]), adj = c(0.5, 0.5))
  segments(1, 0, 1, 2.7, lty = 2, lwd = 0.75)
  text(1, 2.7, expression(phi[2]), adj = c(0.5, 0))
}
}
\keyword{models}

\encoding{UTF-8}
