% File src/library/stats/man/add1.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{add1}
\alias{add1}%@%\alias{モデルに項を付加・除去}
\alias{add1.default}
\alias{add1.lm}
\alias{add1.glm}
\alias{drop1}
\alias{drop1.default}
\alias{drop1.lm}
\alias{drop1.glm}
\title{Add or Drop All Possible Single Terms to a Model}
\usage{
add1(object, scope, \dots)

\method{add1}{default}(object, scope, scale = 0, test = c("none", "Chisq"),
     k = 2, trace = FALSE, \dots)

\method{add1}{lm}(object, scope, scale = 0, test = c("none", "Chisq", "F"),
     x = NULL, k = 2, \dots)

\method{add1}{glm}(object, scope, scale = 0,
     test = c("none", "Rao", "LRT", "Chisq", "F"),
     x = NULL, k = 2, \dots)

drop1(object, scope, \dots)

\method{drop1}{default}(object, scope, scale = 0, test = c("none", "Chisq"),
      k = 2, trace = FALSE, \dots)

\method{drop1}{lm}(object, scope, scale = 0, all.cols = TRUE,
      test = c("none", "Chisq", "F"), k = 2, \dots)

\method{drop1}{glm}(object, scope, scale = 0,
      test = c("none", "Rao", "LRT", "Chisq", "F"),
      k = 2, \dots)
}
\arguments{
  \item{object}{当てはめモデルオブジェクト．}
  \item{scope}{追加又は除去を考慮する項を与える公式．}
  \item{scale}{\eqn{C_p}{Cp} の計算で使われる残差二乗平均の推定値．
    もし \code{0} か \code{NULL} ならば無視される．}
  \item{test}{結果はオリジナルのモデルに関するテスト統計量を含むべきか?
    F 検定は \code{\link{lm}} と \code{\link{aov}} モデル，又は
    恐らく推定散布度をもつ \code{\link{glm}} 当てはめだけに適当である．
    \eqn{\chi^2}{Chisq} 検定は正確な検定になり得る
    (既知のスケールを持つ \code{lm} モデル)又は尤度比検定又は
    メソッドに依存するスケール化デビアンス中の縮小の検定．
    \code{\link{glm}} 当てはめに対してはまた \code{"LRT"}，
    尤度比検定に対する \code{"Rao"} そして
    Rao の有効スコア検定を選択する．
    前者は \code{"Chisq"} の同義語である(両者は漸近的カイ二乗分布を持つものの)．
    値は短縮可能である．
    }
  \item{k}{AIC / \eqn{C_p}{Cp} 中のペナルティー定数．}
  \item{trace}{もし \code{TRUE} なら進行経過の報告をプリントする．}
  \item{x}{モデル行列で当てはめモデルと上部スコープ中の全ての項を含む
    列を持つ．もし \code{add1} が繰り返し呼び出されるときに有用．
    \bold{警告:} その正当性はチェックされない．}
  \item{all.cols}{(S との互換性のために提供されている．)
    デザイン行列の全ての列が使われるべきかどうかを指示する論理値．
    もし \code{FALSE} ならば推定不能な列は捨てられるが，
    結果は普通統計的に意味がない．}
  \item{\dots}{他のメソッドに/から渡される追加引数．}
}
\description{
  モデルに加えたり取り除いたり出来る
  \code{scope} 引数中の全ての単一の項を計算し，
  これらのモデルを当てはめ，
  そして当てはめ中の違いのテーブルを計算する．
}
\details{
  \code{drop1} メソッドに対しては \code{scope} が欠損していればモデル中の
  全ての項とされる．
  項を加えたり除いたりする際は階層が尊重される：
  2次の相互作用中に含まれる全ての主効果は保たれなければならない等．

  \code{scope} 公式中では \code{.} は\sQuote{既にそこにあるもの}を意味する．

  \code{\link{lm}} と \code{\link{glm}} に対するメソッドは
  それらがモデル行列を再計算せず
  \code{fit} メソッドを直接呼び出すという点でより効率的である．

  既定の出力では AIC を与える，これは
  対数尤度の2倍のマイナスに
  \eqn{2p} を加えたものである，ここで \eqn{p} はモデルのランク
  (実効的パラメータ数)である．
  これは付加定数を除いてのみ定義される(対数尤度のように)．
  固定スケールの線形ガウスモデルに対してはこの定数は
  Mallows の \eqn{C_p}{Cp}，\eqn{RSS/scale + 2p - n}，を
  与えるように選ばれる．
  \eqn{C_p}{Cp} が使われる時は，
  列は \code{AIC} ではなく \code{Cp} とラベルが付く．

  \code{"glm"} メソッドに対する F 検定はデビアンス分析検定に基づくので，
  もしデビアンスが推定されると \code{\link{anova.glm}} の F 検定とは
  異なり，それは残差デビアンスに基づく．
}
\value{
  モデル間の当てはめの違いを要約する
  クラス \code{"anova"} のオブジェクト．
}
\author{
  デザインは
  Chambers (1992) で記述されている同名の S 関数に啓発された．
}
\references{
  Chambers, J. M. (1992)
  \emph{Linear models.}
  Chapter 4 of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
}
\note{
  これらは完全には S 中の関数に同値ではない．
  \code{keep} 引数が無く，使われていた手法は計算的にそれほど効率的ではなかった．

  Mallows の \eqn{C_p}{Cp} と赤池の AIC のそれらの著者の定義が使われ，
  S のモデルの章のそれらではない．
}
\section{警告}{
  モデル当てはめはモデルを同じデータセットに適用しなければならない．
  殆どのメソッドは
  もし \code{na.action = na.omit} ならば任意の変数に対して
  欠損値がない部分集合を使おうとするが，
  これは偏った結果を与えるかもしれない．
  これらの関数を欠損値を含むデータに使う際は慎重にすべきである．

  既定メソッドは当てはめプロセス中に含まれる観測値の数が
  変更されていないかどうかをチェックするために
  関数 \code{\link{nobs}} を呼び出す．
}
\seealso{
  \code{\link{step}}, \code{\link{aov}}, \code{\link{lm}},
  \code{\link{extractAIC}}, \code{\link{anova}}
}
\examples{
\testonly{od <- options(digits = 5)}
require(graphics); require(utils)
## example(swiss) による
lm1 <- lm(Fertility ~ ., data = swiss)
add1(lm1, ~ I(Education^2) + .^2)
drop1(lm1, test = "F")  # いわゆる 'type II' anova

## example(glm) による
\dontshow{example(glm, echo = FALSE)}
drop1(glm.D93, test = "Chisq")
drop1(glm.D93, test = "F")
add1(glm.D93, scope = ~outcome*treatment, test = "Rao") ## ペアソンのカイ二乗
\testonly{options(od)}
}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/add1.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{add1}
%\alias{add1}
%\alias{add1.default}
%\alias{add1.lm}
%\alias{add1.glm}
%\alias{drop1}
%\alias{drop1.default}
%\alias{drop1.lm}
%\alias{drop1.glm}
%\title{Add or Drop All Possible Single Terms to a Model}
%\usage{
%add1(object, scope, \dots)
%
%\method{add1}{default}(object, scope, scale = 0, test = c("none", "Chisq"),
%     k = 2, trace = FALSE, \dots)
%
%\method{add1}{lm}(object, scope, scale = 0, test = c("none", "Chisq", "F"),
%     x = NULL, k = 2, \dots)
%
%\method{add1}{glm}(object, scope, scale = 0,
%     test = c("none", "Rao", "LRT", "Chisq", "F"),
%     x = NULL, k = 2, \dots)
%
%drop1(object, scope, \dots)
%
%\method{drop1}{default}(object, scope, scale = 0, test = c("none", "Chisq"),
%      k = 2, trace = FALSE, \dots)
%
%\method{drop1}{lm}(object, scope, scale = 0, all.cols = TRUE,
%      test = c("none", "Chisq", "F"), k = 2, \dots)
%
%\method{drop1}{glm}(object, scope, scale = 0,
%      test = c("none", "Rao", "LRT", "Chisq", "F"),
%      k = 2, \dots)
%}
%\arguments{
%  \item{object}{a fitted model object.}
%  \item{scope}{a formula giving the terms to be considered for adding or
%    dropping.}
%  \item{scale}{an estimate of the residual mean square to be
%    used in computing \eqn{C_p}{Cp}. Ignored if \code{0} or \code{NULL}.}
%  \item{test}{should the results include a test statistic relative to the
%    original model?  The F test is only appropriate for \code{\link{lm}} and
%    \code{\link{aov}} models or perhaps for \code{\link{glm}} fits with
%    estimated dispersion.
%    The \eqn{\chi^2}{Chisq} test can be an exact test
%    (\code{lm} models with known scale) or a likelihood-ratio test or a
%    test of the reduction in scaled deviance depending on the method.
%    For \code{\link{glm}} fits, you can also choose \code{"LRT"} and
%    \code{"Rao"} for likelihood ratio tests and Rao's efficient score test.
%    The former is synonymous with \code{"Chisq"} (although both have
%    an asymptotic chi-square distribution).
%    Values can be abbreviated.
%    }
%  \item{k}{the penalty constant in AIC / \eqn{C_p}{Cp}.}
%  \item{trace}{if \code{TRUE}, print out progress reports.}
%  \item{x}{a model matrix containing columns for the fitted model and all
%    terms in the upper scope.  Useful if \code{add1} is to be called
%    repeatedly.  \bold{Warning:} no checks are done on its validity.}
%  \item{all.cols}{(Provided for compatibility with S.)  Logical to specify
%    whether all columns of the design matrix should be used.  If
%    \code{FALSE} then non-estimable columns are dropped, but the result
%    is not usually statistically meaningful.}
%  \item{\dots}{further arguments passed to or from other methods.}
%}
%\description{
%  Compute all the single terms in the \code{scope} argument that can be
%  added to or dropped from the model, fit those models and compute a
%  table of the changes in fit.
%}
%\details{
%  For \code{drop1} methods, a missing \code{scope} is taken to be all
%  terms in the model. The hierarchy is respected when considering terms
%  to be added or dropped: all main effects contained in a second-order
%  interaction must remain, and so on.
%
%  In a \code{scope} formula \code{.} means \sQuote{what is already there}.
%
%  The methods for \code{\link{lm}} and \code{\link{glm}} are more
%  efficient in that they do not recompute the model matrix and call the
%  \code{fit} methods directly.
%
%  The default output table gives AIC, defined as minus twice log
%  likelihood plus \eqn{2p} where \eqn{p} is the rank of the model (the
%  number of effective parameters).  This is only defined up to an
%  additive constant (like log-likelihoods).  For linear Gaussian models
%  with fixed scale, the constant is chosen to give Mallows' \eqn{C_p}{Cp},
%  \eqn{RSS/scale + 2p - n}.  Where \eqn{C_p}{Cp} is used,
%  the column is labelled as \code{Cp} rather than \code{AIC}.
%
%  The F tests for the \code{"glm"} methods are based on analysis of
%  deviance tests, so if the dispersion is estimated it is based on the
%  residual deviance, unlike the F tests of \code{\link{anova.glm}}.
%}
%\value{
%  An object of class \code{"anova"} summarizing the differences in fit
%  between the models.
%}
%\author{
%  The design was inspired by the S functions of the same names described
%  in Chambers (1992).
%}
%\references{
%  Chambers, J. M. (1992)
%  \emph{Linear models.}
%  Chapter 4 of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%}
%\note{
%  These are not fully equivalent to the functions in S.  There is no
%  \code{keep} argument, and the methods used are not quite so
%  computationally efficient.
%
%  Their authors' definitions of Mallows' \eqn{C_p}{Cp} and Akaike's AIC
%  are used, not those of the authors of the models chapter of S.
%}
%\section{Warning}{
%  The model fitting must apply the models to the same dataset. Most
%  methods will attempt to use a subset of the data with no missing
%  values for any of the variables if \code{na.action = na.omit}, but
%  this may give biased results.  Only use these functions with data
%  containing missing values with great care.
%
%  The default methods make calls to the function \code{\link{nobs}} to
%  check that the number of observations involved in the fitting process
%  remained unchanged.
%}
%\seealso{
%  \code{\link{step}}, \code{\link{aov}}, \code{\link{lm}},
%  \code{\link{extractAIC}}, \code{\link{anova}}
%}
%\examples{
%\testonly{od <- options(digits = 5)}
%require(graphics); require(utils)
%## following example(swiss)
%lm1 <- lm(Fertility ~ ., data = swiss)
%add1(lm1, ~ I(Education^2) + .^2)
%drop1(lm1, test = "F")  # So called 'type II' anova
%
%## following example(glm)
%\dontshow{example(glm, echo = FALSE)}
%drop1(glm.D93, test = "Chisq")
%drop1(glm.D93, test = "F")
%add1(glm.D93, scope = ~outcome*treatment, test = "Rao") ## Pearson Chi-square
%\testonly{options(od)}
%}
%\keyword{models}
%
%\encoding{UTF-8}
