% File src/library/stats/man/alias.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{alias}
\title{Find Aliases (Dependencies) in a Model}
\usage{
alias(object, \dots)

\method{alias}{formula}(object, data, \dots)

\method{alias}{lm}(object, complete = TRUE, partial = FALSE,
      partial.pattern = FALSE, \dots)
}
\alias{alias}
\alias{alias.formula}
\alias{alias.lm}
\arguments{
  \item{object}{当てはめモデルオブジェクト，例えば
  \code{lm} や \code{aov} から得られたもの，
  もしくは \code{alias.formula} に対する公式．}
  \item{data}{オプション，公式中のオブジェクトを探すデータフレーム．}
  \item{complete}{完全なエイリアスに対する情報を含めるべきか?}
  \item{partial}{部分的なエイリアスに対する情報を含めるべきか?}
  \item{partial.pattern}{部分的なエイリアスを図式で表現すべきか?
    もしこれが行われると結果はより簡潔な仕方で
    表される．通常係数の十分位数で与えられる．}
  \item{\dots}{他のメソッドへ/から渡される追加引数．}
}
\description{
  公式で指定された線形モデル中のエイリアス(線形従属な項)を見つける．
}
\details{
  主なメソッドはクラス
  \code{"lm"} 用であるが，\code{alias} は
  実験計画法で最も有用であり，従って
  \code{aov} からの当てはめと共に使われる．
  完全なエイリアスとは
  モデル中で先に登場した項とは独立に推定不可能な線形モデル中の
  効果を指し，従ってそれらの係数は当てはめから除外される．
  部分的エイリアスとはデザインによりもたらされた相関のために
  少ない精度でしか推定できない効果を指す．
  
  \code{"lm"} メソッドのある部分は推奨パッケージ
  \CRANpkg{MASS} がインストールされていることを必要とする．
}
\value{
  クラス \code{"\link{listof}"}) のリストで次の成分を含む
  \item{Model}{モデルの記述；普通公式．}
  \item{Complete}{行に線形従属な効果に対する列を持つ行列．}
  \item{Partial}{推定可能な効果の相関係数で，
    対角成分はゼロ．
    クラス \code{"mtable"} のオブジェクトで自分自身の
    \code{\link{print}} メソッドを持つ．}
}
\note{
  エイリアスのパターンは使用中の対比に依存するかもしれない：
  Helmert 対比が恐らく最も有用である．

  既定は S 中のそれらと異なる．
}
\references{
  Chambers, J. M., Freeny, A and Heiberger, R. M. (1992)
  \emph{Analysis of variance; designed experiments.}
  Chapter 5 of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
}
\author{
  デザインは
  Chambers \emph{et al} (1992) 中の同名の S 関数に啓発された．
}
\examples{\donttest{
op <- options(contrasts = c("contr.helmert", "contr.poly"))
npk.aov <- aov(yield ~ block + N*P*K, npk)
alias(npk.aov)
options(op)  # リセット
}}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/alias.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{alias}
%\title{Find Aliases (Dependencies) in a Model}
%\usage{
%alias(object, \dots)
%
%\method{alias}{formula}(object, data, \dots)
%
%\method{alias}{lm}(object, complete = TRUE, partial = FALSE,
%      partial.pattern = FALSE, \dots)
%}
%\alias{alias}
%\alias{alias.formula}
%\alias{alias.lm}
%\arguments{
%  \item{object}{A fitted model object, for example from \code{lm} or
%    \code{aov}, or a formula for \code{alias.formula}.}
%  \item{data}{Optionally, a data frame to search for the objects
%    in the formula.}
%  \item{complete}{Should information on complete aliasing be included?}
%  \item{partial}{Should information on partial aliasing be included?}
%  \item{partial.pattern}{Should partial aliasing be presented in a
%    schematic way? If this is done, the results are presented in a
%    more compact way, usually giving the deciles of the coefficients.}
%  \item{\dots}{further arguments passed to or from other methods.}
%}
%\description{
%  Find aliases (linearly dependent terms) in a linear model specified by
%  a formula.
%}
%\details{
%  Although the main method is for class \code{"lm"}, \code{alias} is
%  most useful for experimental designs and so is used with fits from
%  \code{aov}.
%  Complete aliasing refers to effects in linear models that cannot be estimated
%  independently of the terms which occur earlier in the model and so
%  have their coefficients omitted from the fit. Partial aliasing refers
%  to effects that can be estimated less precisely because of
%  correlations induced by the design.
%  
%  Some parts of the \code{"lm"} method require recommended package
%  \CRANpkg{MASS} to be installed. 
%}
%\value{
%  A list (of \code{\link{class}} \code{"\link{listof}"}) containing components
%  \item{Model}{Description of the model; usually the formula.}
%  \item{Complete}{A matrix with columns corresponding to effects that
%    are linearly dependent on the rows.}
%  \item{Partial}{The correlations of the estimable effects, with a zero
%    diagonal. An object of class \code{"mtable"} which has its own
%    \code{\link{print}} method.}
%}
%\note{
%  The aliasing pattern may depend on the contrasts in use: Helmert
%  contrasts are probably most useful.
%
%  The defaults are different from those in S.
%}
%\references{
%  Chambers, J. M., Freeny, A and Heiberger, R. M. (1992)
%  \emph{Analysis of variance; designed experiments.}
%  Chapter 5 of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%}
%\author{
%  The design was inspired by the S function of the same name described
%  in Chambers \emph{et al} (1992).
%}
%\examples{\donttest{
%op <- options(contrasts = c("contr.helmert", "contr.poly"))
%npk.aov <- aov(yield ~ block + N*P*K, npk)
%alias(npk.aov)
%options(op)  # reset
%}}
%\keyword{models}
%
%\encoding{UTF-8}
%