% File src/library/stats/man/biplot.princomp.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{biplot.princomp}
\alias{biplot.princomp}
\alias{biplot.prcomp}
%%\title{Biplot for Principal Components}
\title{主成分バイプロット}
\description{
  (狭義の)バイプロットを
  \code{\link{princomp}} 又は \code{\link{prcomp}} の
  出力から作る．
}
\usage{
\method{biplot}{prcomp}(x, choices = 1:2, scale = 1, pc.biplot = FALSE, \dots)

\method{biplot}{princomp}(x, choices = 1:2, scale = 1, pc.biplot = FALSE, \dots)
}
\arguments{
  \item{x}{クラス \code{"princomp"} のオブジェクト．}
  \item{choices}{
    プロットする成分を指定する長さ 2 のベクトル．
    既定のみが狭義のバイプロットである．
  }
  \item{scale}{
    変数は \code{lambda ^ scale} でスケール化され
    観測値は \code{lambda ^ (1-scale)} でスケール化される，ここで
    \code{lambda} は \code{\link{princomp}} で計算されるような単一の数．
    普通 \code{0 <= scale <= 1} で，
    指定された \code{scale} がこの範囲を超えると警告が出る．
  }
  \item{pc.biplot}{
    もし真なら，
    Gabriel (1971) が "主成分バイプロット" と読んでいるものを参照し，
    \code{lambda = 1} で観測値は
    sqrt(n) で小さくスケール化され
    変数は sqrt(n) で大きくスケール化される．
    変数の間の内積は共分散を近似し，
    観測値間の距離はマハラノビス距離を近似する．
  }
  \item{\dots}{
    \code{\link{biplot.default}} に渡される追加引数．}
}
\section{副作用}{
  現在のグラフィックスデバイス上にプロットが作られる．
}
\details{
    これは総称的関数
    \code{biplot} に対するメソッドである．
    正確な定義については相当の混乱がある：
    ここではオリジナルの論文 Gabriel (1971) に従う．
    Gabriel and Odoroff (1990) は同じ定義を使っているが，
    彼らのプロットは実際は
    \code{pc.biplot = TRUE} に対応する．
}
\references{
    Gabriel, K. R. (1971).
    The biplot graphical display of matrices with applications to
    principal component analysis.
    \emph{Biometrika}, \bold{58}, 453--467.

    Gabriel, K. R. and Odoroff, C. L. (1990).
    Biplots in biomedical research.
    \emph{Statistics in Medicine}, \bold{9}, 469--485.
}
\seealso{
    \code{\link{biplot}},
    \code{\link{princomp}}.
}
\examples{
require(graphics)
biplot(princomp(USArrests))
}
\keyword{multivariate}
\keyword{hplot}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/biplot.princomp.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{biplot.princomp}
%\alias{biplot.princomp}
%\alias{biplot.prcomp}
%\title{
%Biplot for Principal Components
%}
%\description{
%  Produces a biplot (in the strict sense) from the output of
%  \code{\link{princomp}} or \code{\link{prcomp}}
%}
%\usage{
%\method{biplot}{prcomp}(x, choices = 1:2, scale = 1, pc.biplot = FALSE, \dots)
%
%\method{biplot}{princomp}(x, choices = 1:2, scale = 1, pc.biplot = FALSE, \dots)
%}
%\arguments{
%  \item{x}{an object of class \code{"princomp"}.}
%  \item{choices}{
%    length 2 vector specifying the components to plot. Only the default
%    is a biplot in the strict sense.
%  }
%  \item{scale}{
%    The variables are scaled by \code{lambda ^ scale} and the
%    observations are scaled by \code{lambda ^ (1-scale)} where
%    \code{lambda} are the singular values as computed by
%    \code{\link{princomp}}. Normally \code{0 <= scale <= 1}, and a warning
%    will be issued if the specified \code{scale} is outside this range.
%  }
%  \item{pc.biplot}{
%    If true, use what Gabriel (1971) refers to as a "principal component
%    biplot", with \code{lambda = 1} and observations scaled up by sqrt(n) and
%    variables scaled down by sqrt(n).  Then inner products between
%    variables approximate covariances and distances between observations
%    approximate Mahalanobis distance.
%  }
%  \item{\dots}{optional arguments to be passed to
%    \code{\link{biplot.default}}.}
%}
%\section{Side Effects}{
%    a plot is produced on the current graphics device.
%}
%\details{
%    This is a method for the generic function \code{biplot}.  There is
%    considerable confusion over the precise definitions: those of the
%    original paper, Gabriel (1971), are followed here.  Gabriel and
%    Odoroff (1990) use the same definitions, but their plots actually
%    correspond to \code{pc.biplot = TRUE}.
%}
%\references{
%    Gabriel, K. R. (1971).
%    The biplot graphical display of matrices with applications to
%    principal component analysis.
%    \emph{Biometrika}, \bold{58}, 453--467.
%
%    Gabriel, K. R. and Odoroff, C. L. (1990).
%    Biplots in biomedical research.
%    \emph{Statistics in Medicine}, \bold{9}, 469--485.
%}
%\seealso{
%    \code{\link{biplot}},
%    \code{\link{princomp}}.
%}
%\examples{
%require(graphics)
%biplot(princomp(USArrests))
%}
%\keyword{multivariate}
%\keyword{hplot}
%
%\encoding{UTF-8}
%
