% File src/library/stats/man/checkMFClasses.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{.checkMFClasses}
\alias{.checkMFClasses}%@%\alias{変数のタイプのチェック}
\alias{.MFclass}
\alias{.getXlevels}
\title{Functions to Check the Type of Variables passed to Model Frames}
\description{
  \code{.checkMFClasses} は予測メソッドで使われる変数が
  当てはめで使われたそれらとタイプが一致するかどうかをチェックする．

  \code{.MFclass} はこの目的のために変数をカテゴリー化する．
}
\usage{
.checkMFClasses(cl, m, ordNotOK = FALSE)
.MFclass(x)
.getXlevels(Terms, m)
}
\arguments{
  \item{cl}{マッチするクラス記述の文字列．}
  \item{m}{モデルフレーム．}
  \item{x}{任意の \R オブジェクト．}
  \item{ordNotOK}{論理値：順序因子は異なるか?}
  \item{Terms}{\code{terms} オブジェクト．}
}
\details{
  線形モデル用のような \code{model.matrix} を含む応用では
  順序因子と因子はコーディングには影響するものの区別する必要はなく，
  当てはめで使われるコーディングは既に再順序化されており
  予測の間順守される．
  しかしながら他の応用は順序付き因子を異なって扱うかもしれない：
  例えば \code{\link[rpart]{rpart}} がそうするように．
}
\value{
  \code{.MFclass} は文字列 \code{"logical"},
  \code{"ordered"}, \code{"factor"}, \code{"numeric"}, \code{"nmatrix.*"}
  (列数を付加された数値ベクトル) 又は
  \code{"other"} のどれか一つを返す．

  \code{.getXlevels} は名前付き文字列か \code{NULL} を返す．
}
\keyword{utilities}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/checkMFClasses.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{.checkMFClasses}
%\alias{.checkMFClasses}
%\alias{.MFclass}
%\alias{.getXlevels}
%\title{Functions to Check the Type of Variables passed to Model Frames}
%\description{
%  \code{.checkMFClasses} checks if the variables used in a predict
%  method agree in type with those used for fitting.
%
%  \code{.MFclass} categorizes variables for this purpose.
%}
%\usage{
%.checkMFClasses(cl, m, ordNotOK = FALSE)
%.MFclass(x)
%.getXlevels(Terms, m)
%}
%\arguments{
%  \item{cl}{a character vector of class descriptions to match.}
%  \item{m}{a model frame.}
%  \item{x}{any \R object.}
%  \item{ordNotOK}{logical: are ordered factors different?}
%  \item{Terms}{a \code{terms} object.}
%}
%\details{
%  For applications involving \code{model.matrix} such as linear models
%  we do not need to differentiate between ordered factors and factors as
%  although these affect the coding, the coding used in the fit is
%  already recorded and imposed during prediction.  However, other
%  applications may treat ordered factors differently:
%  \code{\link[rpart]{rpart}} does, for example.
%}
%\value{
%  \code{.MFclass} returns a character string, one of \code{"logical"},
%  \code{"ordered"}, \code{"factor"}, \code{"numeric"}, \code{"nmatrix.*"}
%  (a numeric matrix with a number of columns appended) or \code{"other"}.
%
%  \code{.getXlevels} returns a named character vector, or \code{NULL}.
%}
%\keyword{utilities}
%
%\encoding{UTF-8}
%
