% File src/library/stats/man/cor.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{cor}
\title{Correlation, Variance and Covariance (Matrices)}
\usage{
var(x, y = NULL, na.rm = FALSE, use)

cov(x, y = NULL, use = "everything",
    method = c("pearson", "kendall", "spearman"))

cor(x, y = NULL, use = "everything",
    method = c("pearson", "kendall", "spearman"))

cov2cor(V)
}
\alias{var} 
\alias{cov}
\alias{cor}
\alias{cov2cor}
%@%\alias{分散}%@%\alias{共分散}%@%\alias{相関係数}
\description{
  \code{x} と \code{y} がベクトルとして，
  \code{var}, \code{cov} そして \code{cor} は \code{x} の分散と
  \code{x} と \code{y} の共分散又は相関係数を計算する．
  もし \code{x} と \code{y} が行列ならば
  \code{x} の列と \code{y} の列の間の
  共分散(又は相関係数)が計算される．

  \code{cov2cor} は共分散を対応する相関行列に
  \emph{効率的}に変換する．
}
\arguments{
  \item{x}{数値ベクトル，行列，又はデータフレーム．}
  \item{y}{\code{NULL} (既定)又は \code{x} と整合性のある
    ベクトル，行列，又はデータフレーム．
    既定値は \code{y = x} に等しい(がより効率的)．}
  \item{na.rm}{論理値．欠損値は取り除くか?}
  \item{use}{欠損値がある場合に共分散を計算する方法を与えるオプションの
    文字列．
    これは文字列 \code{"everything"}, \code{"all.obs"}, \code{"complete.obs"},
    \code{"na.or.complete"} または \code{"pairwise.complete.obs"}
    のどれか(の短縮形)でなければならない．}
  \item{method}{どの相関係数(又は共分散)を計算すべきかを指示する文字列．
    \code{"pearson"} (既定), \code{"kendall"} 又は \code{"spearman"}
    のどれか：短縮できる．}
  \item{V}{対称数値行列，普通共分散行列のように正定値符号．}
}
\value{\code{r <- cor(*, use = "all.obs")} に対しては今や
  \code{all(abs(r) <= 1)} が保証される．
}
\details{
  \code{cov} と \code{cor} に対しては，
  \code{x} に行列かデータフレームを与えるか，
  \emph{又は} \code{x} と \code{y} の双方を与えなければならない．

  入力は数値でなければならない(\code{\link{is.numeric} で決定されるような}：
  歴史的な互換性から論理値もまた許される)：
  \code{"kendall"} と \code{"spearman"} 法は順序付けられた
  入力に対して意味を持つが，
  \code{\link{xtfrm}} を使って数への適切な変換を見出すことが出来る．

  \code{var} は
  \code{cov} への別のインタフェイスで，
  \code{na.rm} がもし与えられなければ
  \code{use} に対する既定動作を決めるために使われる．
  もし \code{na.rm} が \code{TRUE} ならば，
  完全な観測値
  (行)が分散を計算するために(\code{use = "na.or.complete"})
  使われる．さもなければ，既定で
  \code{use = "everything"}．

  もし \code{use} が \code{"everything"} ならば，\code{\link{NA}}
  が概念的に伝播する，つまり
  結果の値はそれに寄与する観測値の一つが \code{NA} ならば
  \code{NA} になる．\cr
  もし \code{use} が \code{"all.obs"} ならば，欠損値の存在は
  エラーになる．もし \code{use} が
  \code{"complete.obs"} ならば欠損値はケースごと削除される
  (そしてもし完全なケースがなければエラーになる)．
  \cr
  \code{"na.or.complete"} は完全なケースが無い場合 ，
  \code{NA} になる，を除いて同じである．
  最後に，もし \code{use} が値
  \code{"pairwise.complete.obs"} を持てば，変数の各対間の
  相関係数や共分散はそれぞれの変数について完全な観測値の
  対を用いて計算される．
  これは半正定値符号でない共分散や相関係数になったり，
  その変数対の間に完全な対がなければ
  \code{NA} の項目を生み出す可能性もある．
  \code{cov} と \code{var} に対しては，
  \code{"pairwise.complete.obs"} は
  \code{"pearson"} メソッドとだけ動作する．
  \code{var(double(0), use = *)} (の同値性)は
  \code{use = "everything"} と \code{"na.or.complete"},
  に対して \code{NA} を与え，そして他のケースではエラーを与える．

  独立同分布観測値に対する共分散の
  不偏推定量を与える分母 \eqn{n - 1} が使われる．
  これらの関数は唯一つの観測値しかなければ
  \code{\link{NA}} を返し
  (一方 S-PLUS は \code{NaN} を返してきた)，そして
  もし \code{x} が長さゼロなら失敗する．

  \code{cor()} に対しては，もし \code{method} が \code{"kendall"}
  であるか又は \code{"spearman"} ならば，
  Kendall の \eqn{\tau}{tau} か Spearman の
  \eqn{\rho}{rho} 統計量がランクに基づく関連度の測度の推定に
  用いられる．
  これらはより頑健でありデータがニ変量正規分布からの
  もので無ければ推奨されてきた\cr
  \code{cov()} に対しては Pearson でない方法は普通ではないが，
  完全性のために利用可能である．
  \code{"spearman"} は基本的には
  \code{cor(R(x), R(y))} (又は \code{cov(., .)}) を計算することを注意しよう，
  ここで \code{R(u) := rank(u, na.last = "keep")} である．
  欠損値がある場合ランクは
  \code{use} の値に基づいて計算され，
  完全な観測値に基づくか，又は対毎に完全なものに対してランクを
  取り直したものに基づく．

  共分散行列を相関行列にスケール化することは
  多くの方法で行うことが出来，
  数学的に最も好ましいものは
  対角成分を左と右から掛けることであるが，
  より効率的には
  \code{\link{sweep}(.., FUN = "/")} を二度使う．
  \code{cov2cor} 関数は更に少し効率的で主として教育的な目的で
  低供されている．
}
\note{
  Kendall のτに対するコードが(1000 ケースを遥かに超える)大きなデータセット
  に対して遅いことが
  注意されてきた．そうした計算をすることはほとんど意味がないが，
  例えばパッケージ \CRANpkg{pcaPP} 中の \code{\link[pcaPP:cor.fk]{cor.fk}}
  を見よ．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  信頼区間(と検定)に対しては と\code{\link{cor.test}}．

  \emph{重み付き}共分散の計算に対しては \code{\link{cov.wt}}． 

  標準偏差(ベクトル)に対しては \code{\link{sd}}．
}
\examples{
var(1:10)  # 9.166667

var(1:5, 1:5) # 2.5

## 二つの単純なベクトル
cor(1:10, 2:11) # == 1

## 多変量標本の相関行列：
(Cl <- cor(longley))
## グラフィカルな相関行列：
symnum(Cl) # 高い相関

## Spearman の ρ と  Kendall のτ
symnum(clS <- cor(longley, method = "spearman"))
symnum(clK <- cor(longley, method = "kendall"))
## それらはどれくらい異なるか?
i <- lower.tri(Cl)
cor(cbind(P = Cl[i], S = clS[i], K = clK[i]))


## cov2cor() は共分散行列をその対角成分でスケール化し
## 相関行列にする
cov2cor # 関数定義を見る{そして学習 ..}
stopifnot(all.equal(Cl, cov2cor(cov(longley))),
          all.equal(cor(longley, method = "kendall"),
            cov2cor(cov(longley, method = "kendall"))))

##--- 欠損値の扱い：
% "everything", "all.obs", "complete.obs", "na.or.complete", "pairwise.complete.obs"
C1 <- cov(swiss)
range(eigen(C1, only.values = TRUE)$values) # 6.19        1921

## swM := 三つの欠損値を持つ "swiss"：
swM <- swiss
colnames(swM) <- abbreviate(colnames(swiss), min=6)
swM[1,2] <- swM[7,3] <- swM[25,5] <- NA # 三つの"欠損値"を作る

## 五つ全ての "use" ケースを考える：
(C. <- cov(swM)) # use="everything" 共分散行列には非常に少数の NA
try(cov(swM, use = "all")) # エラー：obs が無い...
C2 <- cov(swM, use = "complete")
stopifnot(identical(C2, cov(swM, use = "na.or.complete")))
range(eigen(C2, only.values = TRUE)$values) # 6.46   1930
C3 <- cov(swM, use = "pairwise")
range(eigen(C3, only.values = TRUE)$values) # 6.19   1938

## Kendall のτはそれほど違わない：
symnum(Rc <- cor(swM, method = "kendall", use = "complete"))
symnum(Rp <- cor(swM, method = "kendall", use = "pairwise"))
symnum(R. <- cor(swiss, method = "kendall"))

## "pairwise" は成分毎により近い，
summary(abs(c(1 - Rp/R.)))
summary(abs(c(1 - Rc/R.)))

## しかし "complete" は固有値空間ではより近い：
EV <- function(m) eigen(m, only.values=TRUE)$values
summary(abs(1 - EV(Rp)/EV(R.)) / abs(1 - EV(Rc)/EV(R.)))
}
\keyword{univar}
\keyword{multivariate}
\keyword{array}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/cor.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{cor}
%\title{Correlation, Variance and Covariance (Matrices)}
%\usage{
%var(x, y = NULL, na.rm = FALSE, use)
%
%cov(x, y = NULL, use = "everything",
%    method = c("pearson", "kendall", "spearman"))
%
%cor(x, y = NULL, use = "everything",
%    method = c("pearson", "kendall", "spearman"))
%
%cov2cor(V)
%}
%\alias{var}
%\alias{cov}
%\alias{cor}
%\alias{cov2cor}
%\description{
%  \code{var}, \code{cov} and \code{cor} compute the variance of \code{x}
%  and the covariance or correlation of \code{x} and \code{y} if these
%  are vectors.   If \code{x} and \code{y} are matrices then the
%  covariances (or correlations) between the columns of \code{x} and the
%  columns of \code{y} are computed.
%
%  \code{cov2cor} scales a covariance matrix into the corresponding
%  correlation matrix \emph{efficiently}.
%}
%\arguments{
%  \item{x}{a numeric vector, matrix or data frame.}
%  \item{y}{\code{NULL} (default) or a vector, matrix or data frame with
%    compatible dimensions to \code{x}.   The default is equivalent to
%    \code{y = x} (but more efficient).}
%  \item{na.rm}{logical. Should missing values be removed?}
%  \item{use}{an optional character string giving a
%    method for computing covariances in the presence
%    of missing values.  This must be (an abbreviation of) one of the strings
%    \code{"everything"}, \code{"all.obs"}, \code{"complete.obs"},
%    \code{"na.or.complete"}, or \code{"pairwise.complete.obs"}.}
%  \item{method}{a character string indicating which correlation
%    coefficient (or covariance) is to be computed.  One of
%    \code{"pearson"} (default), \code{"kendall"}, or \code{"spearman"}:
%    can be abbreviated.}
%  \item{V}{symmetric numeric matrix, usually positive definite such as a
%    covariance matrix.}
%}
%\value{For \code{r <- cor(*, use = "all.obs")}, it is now guaranteed that
%  \code{all(abs(r) <= 1)}.
%}
%\details{
%  For \code{cov} and \code{cor} one must \emph{either} give a matrix or
%  data frame for \code{x} \emph{or} give both \code{x} and \code{y}.
%
%  The inputs must be numeric (as determined by \code{\link{is.numeric}}:
%  logical values are also allowed for historical compatibility): the
%  \code{"kendall"} and \code{"spearman"} methods make sense for ordered
%  inputs but \code{\link{xtfrm}} can be used to find a suitable prior
%  transformation to numbers.
%
%  \code{var} is just another interface to \code{cov}, where
%  \code{na.rm} is used to determine the default for \code{use} when that
%  is unspecified.  If \code{na.rm} is \code{TRUE} then the complete
%  observations (rows) are used (\code{use = "na.or.complete"}) to
%  compute the variance.  Otherwise, by default \code{use = "everything"}.
%
%  If \code{use} is \code{"everything"}, \code{\link{NA}}s will
%  propagate conceptually, i.e., a resulting value will be \code{NA}
%  whenever one of its contributing observations is \code{NA}.\cr
%  If \code{use} is \code{"all.obs"}, then the presence of missing
%  observations will produce an error.  If \code{use} is
%  \code{"complete.obs"} then missing values are handled by casewise
%  deletion (and if there are no complete cases, that gives an error).
%  \cr
%  \code{"na.or.complete"} is the same unless there are no complete
%  cases, that gives \code{NA}.
%  Finally, if \code{use} has the value \code{"pairwise.complete.obs"}
%  then the correlation or covariance between each pair of variables is
%  computed using all complete pairs of observations on those variables.
%  This can result in covariance or correlation matrices which are not positive
%  semi-definite, as well as \code{NA} entries if there are no complete
%  pairs for that pair of variables.   For \code{cov} and \code{var},
%  \code{"pairwise.complete.obs"} only works with the \code{"pearson"}
%  method.
%  Note that (the equivalent of) \code{var(double(0), use = *)} gives
%  \code{NA} for \code{use = "everything"} and \code{"na.or.complete"},
%  and gives an error in the other cases.
%
%  The denominator \eqn{n - 1} is used which gives an unbiased estimator
%  of the (co)variance for i.i.d. observations.
%  These functions return \code{\link{NA}} when there is only one
%  observation (whereas S-PLUS has been returning \code{NaN}), and
%  fail if \code{x} has length zero.
%
%  For \code{cor()}, if \code{method} is \code{"kendall"} or
%  \code{"spearman"}, Kendall's \eqn{\tau}{tau} or Spearman's
%  \eqn{\rho}{rho} statistic is used to estimate a rank-based measure of
%  association.  These are more robust and have been recommended if the
%  data do not necessarily come from a bivariate normal distribution.\cr
%  For \code{cov()}, a non-Pearson method is unusual but available for
%  the sake of completeness.  Note that \code{"spearman"} basically
%  computes \code{cor(R(x), R(y))} (or \code{cov(., .)}) where \code{R(u)
%  := rank(u, na.last = "keep")}. In the case of missing values, the
%  ranks are calculated depending on the value of \code{use}, either
%  based on complete observations, or based on pairwise completeness with
%  reranking for each pair.
%
%  Scaling a covariance matrix into a correlation one can be achieved in
%  many ways, mathematically most appealing by multiplication with a
%  diagonal matrix from left and right, or more efficiently by using
%  \code{\link{sweep}(.., FUN = "/")} twice.  The \code{cov2cor} function
%  is even a bit more efficient, and provided mostly for didactical
%  reasons.
%}
%\note{
%  Some people have noted that the code for Kendall's tau is slow for
%  very large datasets (many more than 1000 cases).  It rarely makes
%  sense to do such a computation, but see function
%  \code{\link[pcaPP:cor.fk]{cor.fk}} in package \CRANpkg{pcaPP}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{cor.test}} for confidence intervals (and tests).
%
%  \code{\link{cov.wt}} for \emph{weighted} covariance computation.
%
%  \code{\link{sd}} for standard deviation (vectors).
%}
%\examples{
%var(1:10)  # 9.166667
%
%var(1:5, 1:5) # 2.5
%
%## Two simple vectors
%cor(1:10, 2:11) # == 1
%
%## Correlation Matrix of Multivariate sample:
%(Cl <- cor(longley))
%## Graphical Correlation Matrix:
%symnum(Cl) # highly correlated
%
%## Spearman's rho  and  Kendall's tau
%symnum(clS <- cor(longley, method = "spearman"))
%symnum(clK <- cor(longley, method = "kendall"))
%## How much do they differ?
%i <- lower.tri(Cl)
%cor(cbind(P = Cl[i], S = clS[i], K = clK[i]))
%
%
%## cov2cor() scales a covariance matrix by its diagonal
%##           to become the correlation matrix.
%cov2cor # see the function definition {and learn ..}
%stopifnot(all.equal(Cl, cov2cor(cov(longley))),
%          all.equal(cor(longley, method = "kendall"),
%            cov2cor(cov(longley, method = "kendall"))))
%
%##--- Missing value treatment:
%% "everything", "all.obs", "complete.obs", "na.or.complete", "pairwise.complete.obs"
%C1 <- cov(swiss)
%range(eigen(C1, only.values = TRUE)$values) # 6.19        1921
%
%## swM := "swiss" with  3 "missing"s :
%swM <- swiss
%colnames(swM) <- abbreviate(colnames(swiss), min=6)
%swM[1,2] <- swM[7,3] <- swM[25,5] <- NA # create 3 "missing"
%
%## Consider all 5 "use" cases :
%(C. <- cov(swM)) # use="everything"  quite a few NA's in cov.matrix
%try(cov(swM, use = "all")) # Error: missing obs...
%C2 <- cov(swM, use = "complete")
%stopifnot(identical(C2, cov(swM, use = "na.or.complete")))
%range(eigen(C2, only.values = TRUE)$values) # 6.46   1930
%C3 <- cov(swM, use = "pairwise")
%range(eigen(C3, only.values = TRUE)$values) # 6.19   1938
%
%## Kendall's tau doesn't change much:
%symnum(Rc <- cor(swM, method = "kendall", use = "complete"))
%symnum(Rp <- cor(swM, method = "kendall", use = "pairwise"))
%symnum(R. <- cor(swiss, method = "kendall"))
%
%## "pairwise" is closer componentwise,
%summary(abs(c(1 - Rp/R.)))
%summary(abs(c(1 - Rc/R.)))
%
%## but "complete" is closer in Eigen space:
%EV <- function(m) eigen(m, only.values=TRUE)$values
%summary(abs(1 - EV(Rp)/EV(R.)) / abs(1 - EV(Rc)/EV(R.)))
%}
%\keyword{univar}
%\keyword{multivariate}
%\keyword{array}
%
%\encoding{UTF-8}
%
