% File src/library/stats/man/cutree.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{cutree}
\alias{cutree}
\title{Cut a Tree into Groups of Data}
\description{
  例えば \code{\link{hclust}} 由来のツリーを
  希望のグループ数かカット高さを指定して
  幾つかのグループにカットする．
}
\usage{
cutree(tree, k = NULL, h = NULL)
}
\arguments{
 \item{tree}{
   \code{\link{hclust}} で作られたようなツリー．
   \code{cutree()} は成分
   \code{merge}, \code{height} そして \code{labels} を
   持ちそれぞれ適当な内容を持つリストだけを期待する．}
 \item{k}{希望するグループ数の整数スカラかベクトル．}
 \item{h}{ツリーがカットされる高さの数値スカラ化ベクトル．
   少なくとも \code{k} か \code{h} のどちらかを指定しなければならず，
   もし双方が与えられると \code{k} は
   \code{h} を上書きする．}
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\value{
  \code{cutree} はもし
  \code{k} か \code{h} がスカラなら
  グループ所属関係のベクトルを返す．
  さもなければ各列がそれぞれ \code{k} 又 \code{h} の要素に
  対応する(それがまた列名に使われる)グループ所属関係の行列を返す．  
}
\details{
  ツリーを与えられた高さでカットすることは
  (単調なクラスタリング高さを持つ) ultrametric なツリー
  に対してだけ可能である．}
\seealso{
  ツリー自体のカットには \code{\link{hclust}}, \code{\link{dendrogram}}．
}
\examples{
hc <- hclust(dist(USArrests))

cutree(hc, k = 1:5) #k = 1 は自明
cutree(hc, h = 250)

## 2 と 4 のグループ化を比較：
g24 <- cutree(hc, k = c(2,4))
table(grp2 = g24[,"2"], grp4 = g24[,"4"])
}
\keyword{multivariate}
\keyword{cluster}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/cutree.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{cutree}
%\alias{cutree}
%\title{Cut a Tree into Groups of Data}
%\description{
%  Cuts a tree, e.g., as resulting from \code{\link{hclust}}, into several
%  groups either by specifying the desired number(s) of groups or the cut
%  height(s).
%}
%\usage{
%cutree(tree, k = NULL, h = NULL)
%}
%\arguments{
% \item{tree}{a tree as produced by \code{\link{hclust}}. \code{cutree()}
%   only expects a list with components \code{merge}, \code{height}, and
%   \code{labels}, of appropriate content each.}
% \item{k}{an integer scalar or vector with the desired number of groups}
% \item{h}{numeric scalar or vector with heights where the tree should
%   be cut.}
% At least one of \code{k} or \code{h} must be specified, \code{k}
% overrides \code{h} if both are given.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\value{
%  \code{cutree} returns a vector with group memberships if \code{k} or
%  \code{h} are scalar, otherwise a matrix with group memberships is returned
%  where each column corresponds to the elements of \code{k} or \code{h},
%  respectively (which are also used as column names).
%}
%\details{
%  Cutting trees at a given height is only possible for ultrametric trees
%  (with monotone clustering heights).
%}
%\seealso{
%  \code{\link{hclust}}, \code{\link{dendrogram}} for cutting trees themselves.
%}
%\examples{
%hc <- hclust(dist(USArrests))
%
%cutree(hc, k = 1:5) #k = 1 is trivial
%cutree(hc, h = 250)
%
%## Compare the 2 and 4 grouping:
%g24 <- cutree(hc, k = c(2,4))
%table(grp2 = g24[,"2"], grp4 = g24[,"4"])
%}
%\keyword{multivariate}
%\keyword{cluster}
%
%\encoding{UTF-8}
%