% File src/library/stats/man/fisher.test.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{fisher.test}
\alias{fisher.test}%@%\alias{計数データに対するフィッシャーの正確検定}
\title{Fisher's Exact Test for Count Data}
\description{
  固定された周辺値の分割表の行と列の独立帰無仮説に対する
  Fisher の正確検定を実行する．
}
\usage{
fisher.test(x, y = NULL, workspace = 200000, hybrid = FALSE,
            control = list(), or = 1, alternative = "two.sided",
            conf.int = TRUE, conf.level = 0.95,
            simulate.p.value = FALSE, B = 2000)
}
\arguments{
  \item{x}{行列形の二次元分割表，又は因子オブジェクト．}
  \item{y}{因子オブジェクト；もし \code{x} が行列なら無視される．}
  \item{workspace}{ネットワークアルゴリズム中で使われる作業スペース
    のサイズを指定する整数．
    4 バイト単位．
    \eqn{2 \times 2}{2 by 2} より大きな表のシミュレーションによらない
    p 値に対してだけ使われる．}
    \item{hybrid}{論理値．
    \eqn{2 \times 2}{2 by 2} より大きな表に対してだけ使われる．
    その場合これは正確な確率を計算するか(既定)，又は
    それについてのハイブリッド近似を計算すべきかを指示する．
    \sQuote{詳細}を見よ．}
  \item{control}{低水準のアルゴリズムの制御のための名前付き成分を持つ
    リスト．
    現在 \code{"mult"} だけが使われる．これは既定値が 30 の
    整数 \eqn{\ge 2} で
    \eqn{2 \times 2}{2 by 2} より大きな表でだけ使われる．
    これはキーとしてのパスにどれだけ倍多くのスペースを
    確保するかを述べる：
    このパッケージのソース中のファイル \file{fexact.c} を見よ．}
  \item{or}{仮説のオッズ比．
    \eqn{2 \times 2}{2 by 2} のケースでだけ使われる．}
  \item{alternative}{対立仮説を指示し，
    \code{"two.sided"}, \code{"greater"} 又は \code{"less"}
    の一つでなければならない．頭文字だけを指定すれば良い．
    \eqn{2 \times 2}{2 by 2} ケースでだけ使われる．}
  \item{conf.int}{
    \eqn{2 \times 2}{2 by 2} 表のオッズ比の信頼区間を計算(そして返す)
    すべきかを指示する論理値．}
  \item{conf.level}{返される信頼区間の信頼水準．
    \eqn{2 \times 2}{2 by 2} ケースで \code{conf.int = TRUE} の時だけ
    だけ使われる．}
  \item{simulate.p.value}{
    \eqn{2 \times 2}{2 by 2} より大きな表で，
    p 値をモンテカルロシミュレーションによって計算すべきかどうかを
    指示する論理値．}
  \item{B}{モンテカルロ検定で使われる複製の数を指示する整数．}
}
\value{
  クラス \code{"htest"} のりストで次の成分を持つ：
  \item{p.value}{検定の p 値．}
  \item{conf.int}{オッズ比の信頼区間．
    \eqn{2 \times 2}{2 by 2} の場合でもし引数 \code{conf.int = TRUE}
    の時だけ存在する．}
  \item{estimate}{オッズ比の推定値．
      無条件 MLE (標本オッズ比)ではなく
     \emph{条件付き}最尤推定値(MLE)が使われていることを注意．
     \eqn{2 \times 2}{2 by 2} の場合だけ存在．}
  \item{null.value}{帰無仮説の下でのオッズ比 \code{or}．
    \eqn{2 \times 2}{2 by 2} の場合だけ存在．}
  \item{alternative}{対立仮説を記述する文字列．}
  \item{method}{文字列 
    \code{"Fisher's Exact Test for Count Data"}．}
  \item{data.name}{データの名前を与える文字列．}
}
\details{
  もし \code{x} が行列ならば，それは二次元の分割表とされ，
  従ってその項目は非負の整数でなければならない．
  さもなければ，\code{x} と \code{y} は共に同じ長さのベクトルでなければならない．
  不完全なケースは除かれ，ベクトルは因子に変換され，
  そしてこれらから分割表が計算される．
  \eqn{2 \times 2}{2 by 2} のケースでは，p 値は
  (中心化か非中心化)超幾何分布を用いて直接計算される．
  さもなければ，計算は
  Mehta and Patel (1986) により開発され，
  Clarkson, Fan and Joe (1993) で改良されたネットワークを
  実装した FORTRAN サブルーチン FEXACT の C バージョンに基づく．
  FORTRAN コードは
  \url{http://www.netlib.org/toms/643}
  から得られる．
  これは表の項目があまりに大きいと(エラーメッセージと共に)失敗する
  ことを注意する．
  (これは必要ならば表を転置するため列よりも多い行は持たない．
  一つの制約は行の周辺和の積が
  \eqn{2^{31} - 1}{2^31 - 1} 以下であることである．)

  \eqn{2 \times 2}{2 by 2} 表に対しては，条件付き独立の
  帰無仮説はオッズ比が 1 であるという仮説に等しい．
  \sQuote{正確}な推測は，一般に，
  全ての周辺和が固定されると，分割表の最初の要素は
  非中心化パラメータがオッズ比で与えられる非中心化超幾何分布に
  従う(Fisher, 1935)ことに基づいている．
  片側検定に対する対立仮説はオッズ比に基づいており，従って
  \code{alternative = "greater"} はオッズ比が \code{or} より大きい
  という検定である．

  両側検定は表の確率に基づいており，
  \sQuote{より極端なもの}として確率が観測された表よりも
  小さいか等しい全ての表を取り，p 値はそうした確率の和である．

  \eqn{2 \times 2}{2 by 2} よりも大きな表で
  \code{hybrid = TRUE} ならば，漸近的カイ二乗分布は
  \sQuote{コクラン条件}が満たされる時だけ使われる，
  つまりカウントがゼロのセルは無く
  80\% 以上のセルが少なくともカウント 5 を持つ：
  さもなければ正確な検定が使われる．

  シミュレーションは行和と列和に関して条件付きで行われ，
  周辺和が狭義に正の時だけ動作する．
  (Patefield (1981) のアルゴリズムの C 翻訳が使われる．)
}
\references{
  Agresti, A. (1990)
  \emph{Categorical data analysis}.
  New York: Wiley.
  Pages 59--66.

  Agresti, A. (2002)
  \emph{Categorical data analysis}. Second edition.
  New York: Wiley.
  Pages 91--101.

  Fisher, R. A. (1935)
  The logic of inductive inference.
  \emph{Journal of the Royal Statistical Society Series A} \bold{98},
  39--54.

  Fisher, R. A. (1962)
  Confidence limits for a cross-product ratio.
  \emph{Australian Journal of Statistics} \bold{4}, 41.

  Fisher, R. A. (1970)
  \emph{Statistical Methods for Research Workers.}  Oliver & Boyd.

  Mehta, C. R. and Patel, N. R. (1986)
  Algorithm 643. FEXACT: A Fortran subroutine for Fisher's exact test
  on unordered \eqn{r*c} contingency tables.
  \emph{ACM Transactions on Mathematical Software}, \bold{12},
  154--161.

  Clarkson, D. B., Fan, Y. and Joe, H. (1993)
  A Remark on Algorithm 643: FEXACT: An Algorithm for Performing
  Fisher's Exact Test in \eqn{r \times c}{r x c} Contingency Tables.
  \emph{ACM Transactions on Mathematical Software}, \bold{19},
  484--488.

  Patefield, W. M. (1981)
  Algorithm AS159.  An efficient method of generating r x c tables
  with given row and column totals.
  \emph{Applied Statistics} \bold{30}, 91--97.
}
\seealso{
  \code{\link{chisq.test}}

  両側検定の別の解釈と
  \eqn{2 \times 2}{2 by 2} 表に対する信頼区間は
  パッケージ \CRANpkg{exact2x2} 中の
  \code{fisher.exact}．
}
\examples{
## Agresti (1990, p. 61f; 2002, p. 91) の Fisher の紅茶データ
## イギリスの女性がミルクと紅茶のどちらが先にカップに注がれたかを
## 識別できると主張した．テストのため四つが最初にミルクが注がれた
## 8カップが与えられた．帰無仮説は実際の順序と女性の推測は独立と
## いうもので，対立仮説は正の関連がある (オッズ比が 1 より大)である．
TeaTasting <-
matrix(c(3, 1, 1, 3),
       nrow = 2,
       dimnames = list(Guess = c("Milk", "Tea"),
                       Truth = c("Milk", "Tea")))
fisher.test(TeaTasting, alternative = "greater")
## => p = 0.2429，関連は確認できなかった

## Fisher (1962, 1970)，同性双子の犯罪有罪数
Convictions <-
matrix(c(2, 10, 15, 3),
       nrow = 2,
       dimnames =
       list(c("Dizygotic", "Monozygotic"),
            c("Convicted", "Not convicted")))
Convictions
fisher.test(Convictions, alternative = "less")
fisher.test(Convictions, conf.int = FALSE)
fisher.test(Convictions, conf.level = 0.95)$conf.int
fisher.test(Convictions, conf.level = 0.99)$conf.int

## r x c 表  Agresti (2002, p. 57) 仕事の満足度
Job <- matrix(c(1,2,1,0, 3,3,6,1, 10,10,14,9, 6,7,12,11), 4, 4,
dimnames = list(income = c("< 15k", "15-25k", "25-40k", "> 40k"),
                satisfaction = c("VeryD", "LittleD", "ModerateS", "VeryS")))
fisher.test(Job)
fisher.test(Job, simulate.p.value = TRUE, B = 1e5)
}
\keyword{htest}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/fisher.test.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{fisher.test}
%\alias{fisher.test}
%\title{Fisher's Exact Test for Count Data}
%\description{
%  Performs Fisher's exact test for testing the null of independence of
%  rows and columns in a contingency table with fixed marginals.
%}
%\usage{
%fisher.test(x, y = NULL, workspace = 200000, hybrid = FALSE,
%            control = list(), or = 1, alternative = "two.sided",
%            conf.int = TRUE, conf.level = 0.95,
%            simulate.p.value = FALSE, B = 2000)
%}
%\arguments{
%  \item{x}{either a two-dimensional contingency table in matrix form,
%    or a factor object.}
%  \item{y}{a factor object; ignored if \code{x} is a matrix.}
%  \item{workspace}{an integer specifying the size of the workspace
%    used in the network algorithm.  In units of 4 bytes.  Only used for
%    non-simulated p-values larger than \eqn{2 \times 2}{2 by 2} tables.}
%  \item{hybrid}{a logical. Only used for larger than \eqn{2 \times 2}{2 by 2}
%    tables, in which cases it indicates whether the exact probabilities
%    (default) or a hybrid approximation thereof should be computed.
%    See \sQuote{Details}.}
%  \item{control}{a list with named components for low level algorithm
%    control.  At present the only one used is \code{"mult"}, a positive
%    integer \eqn{\ge 2} with default 30 used only for larger than
%    \eqn{2 \times 2}{2 by 2} tables.  This says how many times as much
%    space should be allocated to paths as to keys: see file
%    \file{fexact.c} in the sources of this package.}
%  \item{or}{the hypothesized odds ratio.  Only used in the
%    \eqn{2 \times 2}{2 by 2} case.}
%  \item{alternative}{indicates the alternative hypothesis and must be
%    one of \code{"two.sided"}, \code{"greater"} or \code{"less"}.
%    You can specify just the initial letter.  Only used in the
%    \eqn{2 \times 2}{2 by 2} case.}
%  \item{conf.int}{logical indicating if a confidence interval for the
%    odds ratio in a \eqn{2 \times 2}{2 by 2} table should be
%    computed (and returned).}
%  \item{conf.level}{confidence level for the returned confidence
%    interval.  Only used in the \eqn{2 \times 2}{2 by 2} case and if
%    \code{conf.int = TRUE}.}
%  \item{simulate.p.value}{a logical indicating whether to compute
%    p-values by Monte Carlo simulation, in larger than \eqn{2 \times
%      2}{2 by 2} tables.}
%  \item{B}{an integer specifying the number of replicates used in the
%    Monte Carlo test.}
%}
%\value{
%  A list with class \code{"htest"} containing the following components:
%  \item{p.value}{the p-value of the test.}
%  \item{conf.int}{a confidence interval for the odds ratio.
%    Only present in the \eqn{2 \times 2}{2 by 2} case and if argument
%    \code{conf.int = TRUE}.}
%  \item{estimate}{an estimate of the odds ratio.  Note that the
%    \emph{conditional} Maximum Likelihood Estimate (MLE) rather than the
%    unconditional MLE (the sample odds ratio) is used.
%    Only present in the \eqn{2 \times 2}{2 by 2} case.}
%  \item{null.value}{the odds ratio under the null, \code{or}.
%    Only present in the \eqn{2 \times 2}{2 by 2} case.}
%  \item{alternative}{a character string describing the alternative
%    hypothesis.}
%  \item{method}{the character string
%    \code{"Fisher's Exact Test for Count Data"}.}
%  \item{data.name}{a character string giving the names of the data.}
%}
%\details{
%  If \code{x} is a matrix, it is taken as a two-dimensional contingency
%  table, and hence its entries should be nonnegative integers.
%  Otherwise, both \code{x} and \code{y} must be vectors of the same
%  length.  Incomplete cases are removed, the vectors are coerced into
%  factor objects, and the contingency table is computed from these.
%
%  For \eqn{2 \times 2}{2 by 2} cases, p-values are obtained directly
%  using the (central or non-central) hypergeometric
%  distribution. Otherwise, computations are based on a C version of the
%  FORTRAN subroutine FEXACT which implements the network developed by
%  Mehta and Patel (1986) and improved by Clarkson, Fan and Joe (1993).
%  The FORTRAN code can be obtained from
%  \url{http://www.netlib.org/toms/643}.  Note this fails (with an error
%  message) when the entries of the table are too large.  (It transposes
%  the table if necessary so it has no more rows than columns.  One
%  constraint is that the product of the row marginals be less than
%  \eqn{2^{31} - 1}{2^31 - 1}.)
%
%  For \eqn{2 \times 2}{2 by 2} tables, the null of conditional
%  independence is equivalent to the hypothesis that the odds ratio
%  equals one.  \sQuote{Exact} inference can be based on observing that in
%  general, given all marginal totals fixed, the first element of the
%  contingency table has a non-central hypergeometric distribution with
%  non-centrality parameter given by the odds ratio (Fisher, 1935).  The
%  alternative for a one-sided test is based on the odds ratio, so
%  \code{alternative = "greater"} is a test of the odds ratio being bigger
%  than \code{or}.
%
%  Two-sided tests are based on the probabilities of the tables, and take
%  as \sQuote{more extreme} all tables with probabilities less than or
%  equal to that of the observed table, the p-value being the sum of such
%  probabilities.
%
%  For larger than  \eqn{2 \times 2}{2 by 2} tables and \code{hybrid =
%    TRUE}, asymptotic chi-squared probabilities are only used if the
%  \sQuote{Cochran conditions} are satisfied, that is if no cell has
%  count zero, and more than 80\% of the cells have counts at least 5:
%  otherwise the exact calculation is used.
%
%  Simulation is done conditional on the row and column marginals, and
%  works only if the marginals are strictly positive.  (A C translation
%  of the algorithm of Patefield (1981) is used.)
%}
%\references{
%  Agresti, A. (1990)
%  \emph{Categorical data analysis}.
%  New York: Wiley.
%  Pages 59--66.
%
%  Agresti, A. (2002)
%  \emph{Categorical data analysis}. Second edition.
%  New York: Wiley.
%  Pages 91--101.
%
%  Fisher, R. A. (1935)
%  The logic of inductive inference.
%  \emph{Journal of the Royal Statistical Society Series A} \bold{98},
%  39--54.
%
%  Fisher, R. A. (1962)
%  Confidence limits for a cross-product ratio.
%  \emph{Australian Journal of Statistics} \bold{4}, 41.
%
%  Fisher, R. A. (1970)
%  \emph{Statistical Methods for Research Workers.}  Oliver & Boyd.
%
%  Mehta, C. R. and Patel, N. R. (1986)
%  Algorithm 643. FEXACT: A Fortran subroutine for Fisher's exact test
%  on unordered \eqn{r*c} contingency tables.
%  \emph{ACM Transactions on Mathematical Software}, \bold{12},
%  154--161.
%
%  Clarkson, D. B., Fan, Y. and Joe, H. (1993)
%  A Remark on Algorithm 643: FEXACT: An Algorithm for Performing
%  Fisher's Exact Test in \eqn{r \times c}{r x c} Contingency Tables.
%  \emph{ACM Transactions on Mathematical Software}, \bold{19},
%  484--488.
%
%  Patefield, W. M. (1981)
%  Algorithm AS159.  An efficient method of generating r x c tables
%  with given row and column totals.
%  \emph{Applied Statistics} \bold{30}, 91--97.
%}
%\seealso{
%  \code{\link{chisq.test}}
%
%  \code{fisher.exact} in package \CRANpkg{exact2x2} for alternative
%  interpretations of two-sided tests and confidence intervals for
%  \eqn{2 \times 2}{2 by 2} tables.
%}
%\examples{
%## Agresti (1990, p. 61f; 2002, p. 91) Fisher's Tea Drinker
%## A British woman claimed to be able to distinguish whether milk or
%##  tea was added to the cup first.  To test, she was given 8 cups of
%##  tea, in four of which milk was added first.  The null hypothesis
%##  is that there is no association between the true order of pouring
%##  and the woman's guess, the alternative that there is a positive
%##  association (that the odds ratio is greater than 1).
%TeaTasting <-
%matrix(c(3, 1, 1, 3),
%       nrow = 2,
%       dimnames = list(Guess = c("Milk", "Tea"),
%                       Truth = c("Milk", "Tea")))
%fisher.test(TeaTasting, alternative = "greater")
%## => p = 0.2429, association could not be established
%
%## Fisher (1962, 1970), Criminal convictions of like-sex twins
%Convictions <-
%matrix(c(2, 10, 15, 3),
%       nrow = 2,
%       dimnames =
%       list(c("Dizygotic", "Monozygotic"),
%            c("Convicted", "Not convicted")))
%Convictions
%fisher.test(Convictions, alternative = "less")
%fisher.test(Convictions, conf.int = FALSE)
%fisher.test(Convictions, conf.level = 0.95)$conf.int
%fisher.test(Convictions, conf.level = 0.99)$conf.int
%
%## A r x c table  Agresti (2002, p. 57) Job Satisfaction
%Job <- matrix(c(1,2,1,0, 3,3,6,1, 10,10,14,9, 6,7,12,11), 4, 4,
%dimnames = list(income = c("< 15k", "15-25k", "25-40k", "> 40k"),
%                satisfaction = c("VeryD", "LittleD", "ModerateS", "VeryS")))
%fisher.test(Job)
%fisher.test(Job, simulate.p.value = TRUE, B = 1e5)
%}
%\keyword{htest}
%
%\encoding{UTF-8}
%
