% File src/library/stats/man/isoreg.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2008 R Core Team
% Distributed under GPL 2 or later

\name{isoreg}
\title{Isotonic / Monotone Regression}
\alias{isoreg}%@%\alias{単調回帰の計算}
\concept{monotonic regression}
\description{
  局所的に定数なアイソトニック
  (単調増加ノンパラメトリック)最少二乗回帰を計算する．
}
\usage{
isoreg(x, y = NULL)
}
\arguments{
  \item{x, y}{%in \code{isoreg},
    回帰点の座標ベクトル．別の方法として一つの
    プロット構造を与えることが出来る：
    \code{\link{xy.coords}} を見よ．
  }
}
\details{
  アルゴリズムは
  \emph{累積}データ(つまり \code{cumsum(y)}) の
  劣凸関数 \eqn{m(x)} を計算する．これは局所的に線形で結果は
  \eqn{m'(x)} であり，
  凸の \eqn{m(x)} が累積データ多角形に接し傾きを変える
  箇所で高さが変わるステップ関数になる．\cr
  \code{\link{as.stepfun}()} はより簡素化された
  \code{\link{stepfun}} オブジェクトを返す．
}
\value{
  \code{isoreg()} は
  クラス \code{isoreg} のオブジェクトを返す．
  これは基本的に以下の成分を持つリストである：
  \item{x}{オリジナル(構成された)の横座標値 \code{x}．}
  \item{y}{対応する y 値．}
  \item{yf}{\emph{順序付けられた} x 値に対応する当てはめ値．}
  \item{yc}{\emph{順序付けられた} x 値に対応する y の累積値．}
  \item{iKnots}{当てはめ曲線がジャンプする添字を与える整数ベクトル，
    つまり，凸劣関数がねじれる場所．}
  \item{isOrd}{オリジナルの x 値が既に増加順に並べられていたかを指示する論理値．}
  \item{ord}{\code{if(!isOrd)}：
    \emph{オリジナルの} \code{x} の整数置換 \code{\link{order}(x)}．}
  \item{call}{使用された \code{isoreg()} への呼び出し．}
}
\note{
  コードは
  追加で\emph{重み}を受け入れ対応する重み付き最少二乗法を解くべきである．\cr
  \sQuote{パッチを歓迎する!}
}
\references{
  Barlow, R. E., Bartholomew, D. J., Bremner, J. M., and Brunk, H. D. (1972)
  \emph{Statistical inference under order restrictions}; Wiley, London.

  Robertson, T., Wright, F. T. and Dykstra, R. L. (1988)
  \emph{Order Restricted Statistical Inference}; Wiley, New York.
}
%%\author{Original C code by Brian Ripley; all else: Martin Maechler}
\seealso{より多くの例を持つプロットメソッドは \code{\link{plot.isoreg}}；
  パッケージ \CRANpkg{MASS} の \code{\link[MASS]{isoMDS}()} は内部的に
  単調回帰を使っている．
}
\examples{
require(graphics)

(ir <- isoreg(c(1,0,4,3,3,5,4,2,0)))
plot(ir, plot.type = "row")

(ir3 <- isoreg(y3 <- c(1,0,4,3,3,5,4,2, 3))) # last "3", not "0"
(fi3 <- as.stepfun(ir3))
(ir4 <- isoreg(1:10, y4 <- c(5, 9, 1:2, 5:8, 3, 8)))
cat(sprintf("R^2 = \%.2f\n",
            1 - sum(residuals(ir4)^2) / ((10-1)*var(y4))))

## もしノットだけに興味があるのなら：
with(ir4, cbind(iKnots, yf[iKnots]))

## タイを持つ順序付けられていない x[]：
x <- sample((0:30)/8)
y <- exp(x)
x. <- round(x) # タイ!
plot(m <- isoreg(x., y))
stopifnot(all.equal(with(m, yf[iKnots]),
                    as.vector(tapply(y, x., mean))))
}
\keyword{regression}
\keyword{smooth}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/isoreg.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2008 R Core Team
%% Distributed under GPL 2 or later
%
%\name{isoreg}
%\title{Isotonic / Monotone Regression}
%\alias{isoreg}
%\concept{monotonic regression}
%\description{
%  Compute the isotonic (monotonely increasing nonparametric) least
%  squares regression which is piecewise constant.
%}
%\usage{
%isoreg(x, y = NULL)
%}
%\arguments{
%  \item{x, y}{%in \code{isoreg},
%    coordinate vectors of the regression points.  Alternatively a single
%    plotting structure can be specified: see \code{\link{xy.coords}}.
%  }
%}
%\details{
%  The algorithm determines the convex minorant \eqn{m(x)} of the
%  \emph{cumulative} data (i.e., \code{cumsum(y)}) which is piecewise
%  linear and the result is \eqn{m'(x)}, a step function with level
%  changes at locations where the convex \eqn{m(x)} touches the
%  cumulative data polygon and changes slope.\cr
%  \code{\link{as.stepfun}()} returns a \code{\link{stepfun}}
%  object which can be more parsimonious.
%}
%\value{
%  \code{isoreg()} returns an object of class \code{isoreg} which is
%  basically a list with components
%  \item{x}{original (constructed) abscissa values \code{x}.}
%  \item{y}{corresponding y values.}
%  \item{yf}{fitted values corresponding to \emph{ordered} x values.}
%  \item{yc}{cumulative y values corresponding to \emph{ordered} x values.}
%  \item{iKnots}{integer vector giving indices where the fitted curve jumps,
%    i.e., where the convex minorant has kinks.}
%  \item{isOrd}{logical indicating if original x values were ordered
%    increasingly already.}
%  \item{ord}{\code{if(!isOrd)}: integer permutation \code{\link{order}(x)} of
%    \emph{original} \code{x}.}
%  \item{call}{the \code{\link{call}} to \code{isoreg()} used.}
%}
%\note{
%  The code should be improved to accept \emph{weights} additionally and
%  solve the corresponding weighted least squares problem.\cr
%  \sQuote{Patches are welcome!}
%}
%\references{
%  Barlow, R. E., Bartholomew, D. J., Bremner, J. M., and Brunk, H. D. (1972)
%  \emph{Statistical inference under order restrictions}; Wiley, London.
%
%  Robertson, T., Wright, F. T. and Dykstra, R. L. (1988)
%  \emph{Order Restricted Statistical Inference}; Wiley, New York.
%}
%%%\author{Original C code by Brian Ripley; all else: Martin Maechler}
%\seealso{the plotting method \code{\link{plot.isoreg}} with more examples;
%  \code{\link[MASS]{isoMDS}()} from the \CRANpkg{MASS} package internally
%  uses isotonic regression.
%}
%\examples{
%require(graphics)
%
%(ir <- isoreg(c(1,0,4,3,3,5,4,2,0)))
%plot(ir, plot.type = "row")
%
%(ir3 <- isoreg(y3 <- c(1,0,4,3,3,5,4,2, 3))) # last "3", not "0"
%(fi3 <- as.stepfun(ir3))
%(ir4 <- isoreg(1:10, y4 <- c(5, 9, 1:2, 5:8, 3, 8)))
%cat(sprintf("R^2 = \%.2f\n",
%            1 - sum(residuals(ir4)^2) / ((10-1)*var(y4))))
%
%## If you are interested in the knots alone :
%with(ir4, cbind(iKnots, yf[iKnots]))
%
%## Example of unordered x[] with ties:
%x <- sample((0:30)/8)
%y <- exp(x)
%x. <- round(x) # ties!
%plot(m <- isoreg(x., y))
%stopifnot(all.equal(with(m, yf[iKnots]),
%                    as.vector(tapply(y, x., mean))))
%}
%\keyword{regression}
%\keyword{smooth}
%
%\encoding{UTF-8}
%
