% File src/library/stats/man/lm.summaries.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{lm.summaries}
\alias{family.lm}%@%\alias{線形モデル当てはめにアクセスする}
\alias{formula.lm}
\alias{residuals.lm}
\alias{labels.lm}
\title{Accessing Linear Model Fits}
\usage{
\method{family}{lm}(object, \dots)

\method{formula}{lm}(x, \dots)

\method{residuals}{lm}(object,
          type = c("working", "response", "deviance", "pearson",
                   "partial"),
          \dots)

\method{labels}{lm}(object, \dots)
}
\arguments{
  \item{object, x}{
    クラス \code{lm} を継承するオブジェクトで，普通
    \code{\link{lm}} や \code{\link{aov}} への呼び出しの結果．}
  \item{\dots}{他のメソッドへ・から渡される追加の引数．}
  \item{type}{返されるべき残差のタイプ．短縮できる．}
}
\description{
  これら全ての関数は
  クラス \code{"lm"}  のオブジェクトに対するメソッドである．
}
\details{
  一般的なアクセス関数
  \code{coef}, \code{effects},
  \code{fitted} そして \code{residuals} は
  \code{lm} が返す値の様々な有用な特性を取り出すのに使える．

  作業と応答残差は\sQuote{観測値 - 当てはめ値}である．
  逸脱度とペアソン残差は重み付き残差であり，
  当てはめに使われた重みの平方根でスケール化されている．
  部分残差は各列がモデルから一つの項を除いて作られた行列である．
  (スチューデント化 \code{\link{rstudent}} 残差と
  \code{\link{weighted.residuals}} とは異なり)
  これら全てでゼロの重みは決して除かれない．

  \code{residuals} がオリジナルの当てはめで欠損値のあるケースをどのように
  扱うかは当てはめに対する \code{na.action} 引数で決められる．
  もし \code{na.action = na.omit} なら除かれたケースは残差には現れないが，
  もし \code{na.action = na.exclude} ならば
  残差値 \code{NA} で現れる．\code{\link{naresid}} も見よ．

  総称的な \code{\link{labels}} に対する
  \code{"lm"} メソッドは
  推定される項に対する項ラベルを返す，つまり
  少なくとも一つの推定可能な係数を持つ項の名前である．
}
\seealso{
  モデル当てはめ関数 \code{\link{lm}}, \code{\link{anova.lm}}．

  \bold{一般化}線形モデルには
  \code{\link{coef}}, \code{\link{deviance}},
  \code{\link{df.residual}},
  \code{\link{effects}}, \code{\link{fitted}},
  \code{\link{glm}}， 
  回帰診断には \code{\link{influence}} (そのページのその他)，
  \code{\link{weighted.residuals}},
  \code{\link{residuals}}, \code{\link{residuals.glm}},
  \code{\link{summary.lm}}, \code{\link{weights}}．

  標準化(\code{\link{rstandard}})とスチューデント化
  (\code{\link{rstudent}})残差を含む
  削除診断には \link{influence.measures}． 
}
\references{
  Chambers, J. M. (1992)
  \emph{Linear models.}
  Chapter 4 of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
}
\examples{
\dontshow{utils::example("lm", echo = FALSE)}
##-- lm(.) の例に続く：
coef(lm.D90) # 係数そのもの

## 二つの基本的な回帰診断プロット [plot.lm(.) が好ましい]
plot(resid(lm.D90), fitted(lm.D90)) # Tukey-Anscombe の
abline(h = 0, lty = 2, col = "gray")

qqnorm(residuals(lm.D90))
}
\keyword{regression}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/lm.summaries.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{lm.summaries}
%\alias{family.lm}
%\alias{formula.lm}
%\alias{residuals.lm}
%\alias{labels.lm}
%\title{Accessing Linear Model Fits}
%\usage{
%\method{family}{lm}(object, \dots)
%
%\method{formula}{lm}(x, \dots)
%
%\method{residuals}{lm}(object,
%          type = c("working", "response", "deviance", "pearson",
%                   "partial"),
%          \dots)
%
%\method{labels}{lm}(object, \dots)
%}
%\arguments{
%  \item{object, x}{an object inheriting from class \code{lm}, usually
%    the result of a call to \code{\link{lm}} or \code{\link{aov}}.}
%  \item{\dots}{further arguments passed to or from other methods.}
%  \item{type}{the type of residuals which should be returned.  Can be abbreviated.}
%}
%\description{
%  All these functions are \code{\link{methods}} for class \code{"lm"}  objects.
%}
%\details{
%  The generic accessor functions \code{coef}, \code{effects},
%  \code{fitted} and \code{residuals} can be used to extract
%  various useful features of the value returned by \code{lm}.
%
%  The working and response residuals are \sQuote{observed - fitted}.  The
%  deviance and pearson residuals are weighted residuals, scaled by the
%  square root of the weights used in fitting.  The partial residuals
%  are a matrix with each column formed by omitting a term from the
%  model.  In all these, zero weight cases are never omitted (as opposed
%  to the standardized \code{\link{rstudent}} residuals, and the
%  \code{\link{weighted.residuals}}).
%
%  How \code{residuals} treats cases with missing values in the original
%  fit is determined by the \code{na.action} argument of that fit.
%  If \code{na.action = na.omit} omitted cases will not appear in the
%  residuals, whereas if \code{na.action = na.exclude} they will appear,
%  with residual value \code{NA}.  See also \code{\link{naresid}}.
%
%  The \code{"lm"} method for generic \code{\link{labels}} returns the
%  term labels for estimable terms, that is the names of the terms with
%  an least one estimable coefficient.
%}
%\seealso{
%  The model fitting function \code{\link{lm}}, \code{\link{anova.lm}}.
%
%  \code{\link{coef}}, \code{\link{deviance}},
%  \code{\link{df.residual}},
%  \code{\link{effects}}, \code{\link{fitted}},
%  \code{\link{glm}} for \bold{generalized} linear models,
%  \code{\link{influence}} (etc on that page) for regression diagnostics,
%  \code{\link{weighted.residuals}},
%  \code{\link{residuals}}, \code{\link{residuals.glm}},
%  \code{\link{summary.lm}}, \code{\link{weights}}.
%
%  \link{influence.measures} for deletion diagnostics, including
%  standardized (\code{\link{rstandard}})
%  and studentized (\code{\link{rstudent}}) residuals.
%}
%\references{
%  Chambers, J. M. (1992)
%  \emph{Linear models.}
%  Chapter 4 of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%}
%\examples{
%\dontshow{utils::example("lm", echo = FALSE)}
%##-- Continuing the  lm(.) example:
%coef(lm.D90) # the bare coefficients
%
%## The 2 basic regression diagnostic plots [plot.lm(.) is preferred]
%plot(resid(lm.D90), fitted(lm.D90)) # Tukey-Anscombe's
%abline(h = 0, lty = 2, col = "gray")
%
%qqnorm(residuals(lm.D90))
%}
%\keyword{regression}
%\keyword{models}
%
%\encoding{UTF-8}
%
