% File src/library/stats/man/loess.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{loess}
\alias{loess}%@%\alias{局所多項式回帰当てはめ}
\title{Local Polynomial Regression Fitting}
\usage{
loess(formula, data, weights, subset, na.action, model = FALSE,
      span = 0.75, enp.target, degree = 2,
      parametric = FALSE, drop.square = FALSE, normalize = TRUE,
      family = c("gaussian", "symmetric"),
      method = c("loess", "model.frame"),
      control = loess.control(\dots), \dots)
}
\arguments{
  \item{formula}{
    数値応答と一つから四つの数値予測子を
    指定する公式
    (相互作用から指定するのが最良であるが，
    追加で指定することも出来る)．
    必要なら公式に強制変換される．}
  \item{data}{モデル中の変数を含むオプションのデータフレーム，リスト又は環境
    (もしくは
    \code{\link{as.data.frame}} でデータフレームに変換できるオブジェクト)．
    もし \code{data} 中に見つからなければ，変数は
    \code{environment(formula)} から取られる，典型的には
    これは \code{loess} がそこから呼び出された環境．}
  \item{weights}{各ケースに対するオプションの重み．}
  \item{subset}{使用されるデータの部分集合を指定するオプションの指定．}
  \item{na.action}{応答や予測子中の欠損値に対して取られるアクション．
    既定は\cr
    \code{getOption("na.action")} で与えられる．}
  \item{model}{モデルフレームを返すべきか?}
  \item{span}{平滑度を制御するパラメータ \eqn{\alpha}．}
  \item{enp.target}{
    \code{span} を指定する別の方法で，
    使用されるパラメータ数の近似的に同値な数．}
  \item{degree}{使用される多項式の次数で，
    普通 1 か 2．
    (次数 0 もまた許されるが \sQuote{注意}節を見よ．)}
  \item{parametric}{任意の項を局所的ではなく大局的に当てはめるべきか?
    項は名前，番号，又は予測子の数と同じ長さの論理値ベクトルで指定出来る．}
  \item{drop.square}{二つ以上の予測子と
    \code{degree = 2} に対して，特定の予測子から二次の項を取り去るべきか?
    項は \code{parametric} に対してと同様に指定される．}
  \item{normalize}{予測子が二つ以上あれば共通のスケールに正規化すべきか?
    使われる正規化は 10\% を刈り込んだ標準偏差を 1 に設定する．
    空間座標予測子と共通のスケールであることが知られている他の場合は
    偽に設定する．}
  \item{family}{もし \code{"gaussian"} ならば当てはめは最少に乗法による．
    そしてもし
    \code{"symmetric"} ならば Tukey の biweight 関数と共に再下降 
    M 推定量が使われる．短縮化出来る．}
  \item{method}{モデルを当てはめるか単にモデルフレーム取り出すか．}
  \item{control}{制御パラメータ：\code{\link{loess.control}} を見よ．}
  \item{\dots}{制御パラメータはまた直接に提供できる
    (\emph{もし} \code{control} が指定されていなければ)．}
}
\description{
  一つもしくは複数の数値予測子で決まる多項式曲面を当てはめる，
  局所的当てはめを用いる．
}
\details{
  当てはめは局所的に行われる．つまり，
  点 \eqn{x} に於ける当てはめに対して，当てはめは
  \eqn{x} の近傍中の点を用い \eqn{x} からの距離で重みを付け
  て行われる(\sQuote{パラメトリック}な変数は距離の計算では無視される)．
  近傍のサイズは
  \eqn{\alpha} で制御される(\code{span} 又は \code{enp.target} で設定される)．
  \eqn{\alpha < 1} に対しては，近傍は点の割合 \eqn{\alpha} 分を含み
  そしてこれらは3乗の3乗重みを持つ
  (\eqn{(1 -  \mathrm{(dist/maxdist)}^3)^3}{(1 - (dist/maxdist)^3)^3} に比例する)．
  \eqn{\alpha > 1} に対しては全ての点が使われ，
  \sQuote{最大距離}は \eqn{p} 個の説明変数に対して
  実際の距離の \eqn{\alpha^{1/p}}{\alpha^(1/p)} 倍と仮定される．

  既定のファミリに対しては，当てはめは(重み付き)最少二乗法で行われる．
  \code{family="symmetric"} に対しては
  Tukey の biweight を用いた M 推定の数回の繰り返しが用いられる．
  初期値は最少二乗当てはめであるため，これは非常に抵抗力のある当てはめである
  必要はないことを注意する．

  許容できる速度を達成するためには制御リストを調整することが重要になり得る．
  詳細は \code{\link{loess.control}} を見よ．
}
\value{
  クラス \code{"loess"} のオブジェクト．% otherwise entirely unspecified (!)
}
\references{
  W. S. Cleveland, E. Grosse and W. M. Shyu (1992) Local regression
  models. Chapter 8 of \emph{Statistical Models in S} eds J.M. Chambers
  and T.J. Hastie, Wadsworth & Brooks/Cole.
}
\author{
  B. D. Ripley，
  Cleveland, Grosse and Shyu による \code{cloess} パッケージに依る．
}

\source{
  Cleveland, Grosse and Shyu による \code{cloess} パッケージの
  1998 バージョン．その後のバージョンである
  \code{dloess} は \url{http://www.netlib.org/a} で入手できる．
}
\note{
  これは \code{cloess} に基づいているので，
  S の \code{loess} 関数に似ているが同値ではない．
  特に，条件付けは移植されていない．

  この \code{loess} の移植のメモリ使用量は大まかに
  点の数の二乗で，100 個の点で約 10Mb である．

  局所的に定数である \code{degree = 0} はこの移植では許されるが
  参考文献にはドキュメント化されていない．
  これは非常に僅かにしかテストされていないので注意深く使うこと．
}
\seealso{
  \code{\link{loess.control}},
  \code{\link{predict.loess}}.

  \code{loess} の(異なった既定値を持つ)先祖である
  \code{\link{lowess}}．
}
\examples{
cars.lo <- loess(dist ~ speed, cars)
predict(cars.lo, data.frame(speed = seq(5, 30, 1)), se = TRUE)
# 外挿を許すため
cars.lo2 <- loess(dist ~ speed, cars,
  control = loess.control(surface = "direct"))
predict(cars.lo2, data.frame(speed = seq(5, 30, 1)), se = TRUE)
}
\keyword{smooth}
\keyword{loess}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/loess.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{loess}
%\alias{loess}
%\title{Local Polynomial Regression Fitting}
%\usage{
%loess(formula, data, weights, subset, na.action, model = FALSE,
%      span = 0.75, enp.target, degree = 2,
%      parametric = FALSE, drop.square = FALSE, normalize = TRUE,
%      family = c("gaussian", "symmetric"),
%      method = c("loess", "model.frame"),
%      control = loess.control(\dots), \dots)
%}
%\arguments{
%  \item{formula}{a \link{formula} specifying the numeric response and
%    one to four numeric predictors (best specified via an interaction,
%    but can also be specified additively).  Will be coerced to a formula
%    if necessary.}
%  \item{data}{an optional data frame, list or environment (or object
%    coercible by \code{\link{as.data.frame}} to a data frame) containing
%    the variables in the model.  If not found in \code{data}, the
%    variables are taken from \code{environment(formula)},
%    typically the environment from which \code{loess} is called.}
%  \item{weights}{optional weights for each case.}
%  \item{subset}{an optional specification of a subset of the data to be
%    used.}
%  \item{na.action}{the action to be taken with missing values in the
%    response or predictors.  The default is given by
%    \code{getOption("na.action")}.}
%  \item{model}{should the model frame be returned?}
%  \item{span}{the parameter \eqn{\alpha} which controls the degree of
%    smoothing.}
%  \item{enp.target}{an alternative way to specify \code{span}, as the
%    approximate equivalent number of parameters to be used.}
%  \item{degree}{the degree of the polynomials to be used, normally 1 or
%    2. (Degree 0 is also allowed, but see the \sQuote{Note}.)}
%  \item{parametric}{should any terms be fitted globally rather than
%    locally?  Terms can be specified by name, number or as a logical
%    vector of the same length as the number of predictors.}
%  \item{drop.square}{for fits with more than one predictor and
%    \code{degree = 2}, should the quadratic term be dropped for particular
%    predictors?  Terms are specified in the same way as for
%    \code{parametric}.}
%  \item{normalize}{should the predictors be normalized to a common scale
%    if there is more than one?  The normalization used is to set the
%    10\% trimmed standard deviation to one.  Set to false for spatial
%    coordinate predictors and others known to be on a common scale.}
%  \item{family}{if \code{"gaussian"} fitting is by least-squares, and if
%    \code{"symmetric"} a re-descending M estimator is used with Tukey's
%    biweight function.  Can be abbreviated.}
%  \item{method}{fit the model or just extract the model frame.  Can be abbreviated.}
%  \item{control}{control parameters: see \code{\link{loess.control}}.}
%  \item{\dots}{control parameters can also be supplied directly
%    (\emph{if} \code{control} is not specified).}
%}
%\description{
%  Fit a polynomial surface determined by one or more numerical
%  predictors, using local fitting.
%}
%\details{
%  Fitting is done locally.  That is, for the fit at point \eqn{x}, the
%  fit is made using points in a neighbourhood of \eqn{x}, weighted by
%  their distance from \eqn{x} (with differences in \sQuote{parametric}
%  variables being ignored when computing the distance).  The size of the
%  neighbourhood is controlled by \eqn{\alpha} (set by \code{span} or
%  \code{enp.target}).  For \eqn{\alpha < 1}, the
%  neighbourhood includes proportion \eqn{\alpha} of the points,
%  and these have tricubic weighting (proportional to \eqn{(1 -
%    \mathrm{(dist/maxdist)}^3)^3}{(1 - (dist/maxdist)^3)^3}).  For
%  \eqn{\alpha > 1}, all points are used, with the
%  \sQuote{maximum distance} assumed to be \eqn{\alpha^{1/p}}{\alpha^(1/p)}
%  times the actual maximum distance for \eqn{p} explanatory variables.
%
%  For the default family, fitting is by (weighted) least squares.  For
%  \code{family="symmetric"} a few iterations of an M-estimation
%  procedure with Tukey's biweight are used.  Be aware that as the initial
%  value is the least-squares fit, this need not be a very resistant fit.
%
%  It can be important to tune the control list to achieve acceptable
%  speed.  See \code{\link{loess.control}} for details.
%}
%\value{
%  An object of class \code{"loess"}.% otherwise entirely unspecified (!)
%}
%\references{
%  W. S. Cleveland, E. Grosse and W. M. Shyu (1992) Local regression
%  models. Chapter 8 of \emph{Statistical Models in S} eds J.M. Chambers
%  and T.J. Hastie, Wadsworth & Brooks/Cole.
%}
%\author{
%  B. D. Ripley, based on the \code{cloess} package of Cleveland,
%  Grosse and Shyu.
%}
%
%\source{
%  The 1998 version of \code{cloess} package of Cleveland,
%  Grosse and Shyu.  A later version is available as \code{dloess} at
%  \url{http://www.netlib.org/a}.
%}
%\note{
%  As this is based on \code{cloess}, it is similar to but not identical to
%  the \code{loess} function of S.  In particular, conditioning is not
%  implemented.
%
%  The memory usage of this implementation of \code{loess} is roughly
%  quadratic in the number of points, with 1000 points taking about 10Mb.
%
%  \code{degree = 0}, local constant fitting, is allowed in this
%  implementation but not documented in the reference.  It seems very little
%  tested, so use with caution.
%}
%\seealso{
%  \code{\link{loess.control}},
%  \code{\link{predict.loess}}.
%
%  \code{\link{lowess}}, the ancestor of \code{loess} (with
%  different defaults!).
%}
%\examples{
%cars.lo <- loess(dist ~ speed, cars)
%predict(cars.lo, data.frame(speed = seq(5, 30, 1)), se = TRUE)
%# to allow extrapolation
%cars.lo2 <- loess(dist ~ speed, cars,
%  control = loess.control(surface = "direct"))
%predict(cars.lo2, data.frame(speed = seq(5, 30, 1)), se = TRUE)
%}
%\keyword{smooth}
%\keyword{loess}
%
%\encoding{UTF-8}
%
