% File src/library/stats/man/manova.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2016 R Core Team
% Distributed under GPL 2 or later

\name{manova}
\alias{manova}%@%\alias{多変量分散分析}
\title{Multivariate Analysis of Variance}
\description{
  多変量分散分析のためのクラス．
}
\usage{
manova(\dots)
}
\arguments{
  \item{\dots}{\code{\link{aov}} に渡される引数．}
}
\details{
  クラス \code{"manova"} は
  クラス \code{"aov"} とは異なった
  \code{summary} メソッドを選ぶ点で異なる．
  関数 \code{manova} は \code{\link{aov}} を呼び出し，
  それから各層に対する結果のオブジェクトにクラス \code{"manova"}
  を加える．
}
\value{
  \code{\link{aov}} とそこの
  \sQuote{詳細}節中のコメントを見よ．
}
% \note{
%   \code{manova} does not support multistratum analysis of variance, so
%   the formula should not include an \code{Error} term.
% }
\references{
  Krzanowski, W. J. (1988) \emph{Principles of Multivariate Analysis. A
    User's Perspective.} Oxford.

  Hand, D. J. and Taylor, C. C.  (1987)
  \emph{Multivariate Analysis of Variance and Repeated Measures.}
  Chapman and Hall.
}
\seealso{
  \code{\link{aov}}, \code{\link{summary.manova}}，後者は
  より多くの例を持つ．
}
\examples{
## 直交対比を設定．
op <- options(contrasts = c("contr.helmert", "contr.poly"))

## 二つ目の応答変数を偽造
npk2 <- within(npk, foo <- rnorm(24))
( npk2.aov <- manova(cbind(yield, foo) ~ block + N*P*K, npk2) )
summary(npk2.aov)

( npk2.aovE <- manova(cbind(yield, foo) ~  N*P*K + Error(block), npk2) )
summary(npk2.aovE)
}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/manova.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2016 R Core Team
%% Distributed under GPL 2 or later
%
%\name{manova}
%\alias{manova}
%\title{Multivariate Analysis of Variance}
%\description{
%  A class for the multivariate analysis of variance.
%}
%\usage{
%manova(\dots)
%}
%\arguments{
%  \item{\dots}{Arguments to be passed to \code{\link{aov}}.}
%}
%\details{
%  Class \code{"manova"} differs from class \code{"aov"} in selecting a
%  different \code{summary} method.  Function \code{manova} calls
%  \code{\link{aov}} and then add class \code{"manova"} to the result
%  object for each stratum.
%}
%\value{
%  See \code{\link{aov}} and the comments in \sQuote{Details} here.
%}
%% \note{
%%   \code{manova} does not support multistratum analysis of variance, so
%%   the formula should not include an \code{Error} term.
%% }
%\references{
%  Krzanowski, W. J. (1988) \emph{Principles of Multivariate Analysis. A
%    User's Perspective.} Oxford.
%
%  Hand, D. J. and Taylor, C. C.  (1987)
%  \emph{Multivariate Analysis of Variance and Repeated Measures.}
%  Chapman and Hall.
%}
%\seealso{
%  \code{\link{aov}}, \code{\link{summary.manova}}, the latter containing
%  more examples.
%}
%\examples{
%## Set orthogonal contrasts.
%op <- options(contrasts = c("contr.helmert", "contr.poly"))
%
%## Fake a 2nd response variable
%npk2 <- within(npk, foo <- rnorm(24))
%( npk2.aov <- manova(cbind(yield, foo) ~ block + N*P*K, npk2) )
%summary(npk2.aov)
%
%( npk2.aovE <- manova(cbind(yield, foo) ~  N*P*K + Error(block), npk2) )
%summary(npk2.aovE)
%}
%\keyword{models}
%
%\encoding{UTF-8}
%
