% File src/library/stats/man/medpolish.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{medpolish}
\alias{medpolish}
\title{Median Polish of a Matrix}
\description{
  Tukey のメディアンポリッシュ法で加法モデルを当てはめる．
}
\usage{
medpolish(x, eps = 0.01, maxiter = 10, trace.iter = TRUE,
          na.rm = FALSE)
}
\arguments{
  \item{x}{数値行列．}
  \item{eps}{0 より大きな実数．収束に対する許容度：
    \sQuote{詳細}節を見よ．}
  \item{maxiter}{最大繰り返し数．}
  \item{trace.iter}{論理値．収束過程を報告すべきか?}
  \item{na.rm}{論理値．欠損値を除くか?}
}
\details{
  当てはめられるモデルは加法的(定数 + 行 + 列)である．
  アルゴリズムは交互に列と行のメディアンを取り去ることで
  進行し，絶対残差の和の減少割合が
  \code{eps} 以下になるまでか，又は．
  繰り返しが \code{maxiter} 回になるまで続く．
  もし \code{trace.iter} が \code{TRUE} ならば，.
  絶対残差の和は当てはめ過程の各繰り返しごとに報告される．
  もし \code{na.rm} が \code{FALSE} ならば任意の
  \code{x} 中の任意の \code{NA} 値はエラーを惹き起こす，
  さもなければ
  \code{NA} 値は無視される．
  
  \code{medpolish} は
  クラス \code{medpolish} (下を見よ)のオブジェクトを返す．
  このクラスに対してはプリントとプロットメソッドがあり，
  総称的関数 \code{\link{print}} と \code{\link{plot}} によって
  起動される．
}
\value{
  クラス
  \code{medpolish} のオブジェクトで次の名前付き成分を持つ：
  \item{overall}{当てはめられた定数項．}
  \item{row}{当てはめられた行効果．}
  \item{col}{当てはめられた列効果．}
  \item{residuals}{残差．}
  \item{name}{データセットの名前．}
}
\seealso{\code{\link{median}};
  \emph{メディアン}分解の代わりに
  \emph{平均}に対する \code{\link{aov}}．}
  
\references{
  Tukey, J. W. (1977).
  \emph{Exploratory Data Analysis},
  Reading Massachusetts: Addison-Wesley.
}
\examples{
require(graphics)

## スポーツパラシュートによる死亡事故；ABC of EDA, p.224 より：
deaths <-
    rbind(c(14,15,14),
          c( 7, 4, 7),
          c( 8, 2,10),
          c(15, 9,10),
          c( 0, 2, 0))
dimnames(deaths) <- list(c("1-24", "25-74", "75-199", "200++", "NA"),
                         paste(1973:1975))
deaths
(med.d <- medpolish(deaths))
plot(med.d)
## 分解をチェック：
all(deaths ==
    med.d$overall + outer(med.d$row,med.d$col, "+") + med.d$residuals)
}
\keyword{robust}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/medpolish.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{medpolish}
%\alias{medpolish}
%\title{Median Polish of a Matrix}
%\description{
%  Fits an additive model using Tukey's \emph{median polish} procedure.
%}
%\usage{
%medpolish(x, eps = 0.01, maxiter = 10, trace.iter = TRUE,
%          na.rm = FALSE)
%}
%\arguments{
%  \item{x}{a numeric matrix.}
%  \item{eps}{real number greater than 0. A tolerance for convergence:
%    see \sQuote{Details}.}
%  \item{maxiter}{the maximum number of iterations}
%  \item{trace.iter}{logical. Should progress in convergence be reported?}
%  \item{na.rm}{logical. Should missing values be removed?}
%}
%\details{
%  The model fitted is additive (constant + rows + columns). The
%  algorithm works by alternately removing the row and column medians,
%  and continues until the proportional reduction in the sum
%  of absolute residuals is less than \code{eps}
%  or until there have been \code{maxiter} iterations.
%  The sum of absolute residuals is printed at
%  each iteration of the fitting process, if \code{trace.iter} is \code{TRUE}.
%  If \code{na.rm} is \code{FALSE} the presence of any \code{NA} value in
%  \code{x} will cause an error, otherwise \code{NA} values are ignored.
%
%  \code{medpolish} returns an object of class \code{medpolish} (see below).
%  There are printing and plotting methods for this
%  class, which are invoked via by the generics
%  \code{\link{print}} and \code{\link{plot}}.
%}
%\value{
%  An object of class \code{medpolish} with the following named components:
%  \item{overall}{the fitted constant term.}
%  \item{row}{the fitted row effects.}
%  \item{col}{the fitted column effects.}
%  \item{residuals}{the residuals.}
%  \item{name}{the name of the dataset.}
%}
%\seealso{\code{\link{median}}; \code{\link{aov}} for a \emph{mean}
%  instead of \emph{median} decomposition.}
%\references{
%  Tukey, J. W. (1977).
%  \emph{Exploratory Data Analysis},
%  Reading Massachusetts: Addison-Wesley.
%}
%\examples{
%require(graphics)
%
%## Deaths from sport parachuting;  from ABC of EDA, p.224:
%deaths <-
%    rbind(c(14,15,14),
%          c( 7, 4, 7),
%          c( 8, 2,10),
%          c(15, 9,10),
%          c( 0, 2, 0))
%dimnames(deaths) <- list(c("1-24", "25-74", "75-199", "200++", "NA"),
%                         paste(1973:1975))
%deaths
%(med.d <- medpolish(deaths))
%plot(med.d)
%## Check decomposition:
%all(deaths ==
%    med.d$overall + outer(med.d$row,med.d$col, "+") + med.d$residuals)
%}
%\keyword{robust}
%
%\encoding{UTF-8}
%