% File src/library/stats/man/nlminb.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{nlminb}
\alias{nlminb}%@%\alias{PORT ルーチンを用いた最適化}
\title{Optimization using PORT routines }
\description{
  PORT ルーチンを用いた無制約と矩形制約最適化．

  歴史的な互換性のためにある．
}
\usage{
nlminb(start, objective, gradient = NULL, hessian = NULL, \dots,
       scale = 1, control = list(), lower = -Inf, upper = Inf)
}
\arguments{
  \item{start}{
    数値ベクトル．最適化されるパラメータに対する初期値．
  }
  \item{objective}{
    最小化される関数．
    スカラ値を返さなければならない．
    \code{objective} への最初の引数は
    最適化されるパラメータのベクトルで，
    その初期値は
    \code{start} 経由で提供される．
    \code{objective} への追加引数(最適化の過程中固定される)
    も同様に指定可能である(\code{\dots} を見よ)．
  }
  \item{gradient}{
    \code{objective} と同じ引数をとるオプションの関数で，
    \code{objective} の最初の引数でのグラディエントを評価する．
    \code{start} と同じ長さのベクトルを返さなければならない．
  }
  \item{hessian}{
    \code{objective} と同じ引数をとるオプションの関数で，
    \code{objective} の最初の引数でのへッシアンを評価する．
    サイズ \code{length(start)} の正方行列を返さなければならない．
    下側三角部分だけが使われる．
  }
  \item{\dots}{
    \code{objective} に提供される追加引数．}
  \item{scale}{PORT のドキュメントを見よ(もしくはそのままにしておく)．}
  \item{control}{制御パラメータのリスト．詳細は下を見よ．}
  \item{lower, upper}{
    下限と上限のベクトルで
    \code{start} の長さまで複製される．もし指定されないと，
    全てのパラメータは無制約と見做される．
  }
}
\details{
  Any names of
  \code{start} の任意の名前は
  \code{objective} に，そして適用可能ならば
  \code{gradient} と \code{hessian} に渡される．
  パラメータ値は倍精度実数に変換される．

  PORT のドキュメントは以下にある
  \url{http://netlib.bell-labs.com/cm/cs/cstr/153.pdf}．

  \code{objective}, \code{gradient} そして
  \code{hessian} に渡されたパラメータベクトルは
  \R 3.1.0 以前では特殊なセマンティックスを持ち
  呼び出し間で共有された．関数はそれをコピーすべきではない．

  もしどれかの関数が \code{NA} や \code{NaN} を返すと，
  内部コードは
  2.15.2 以前の \R では無限ループを起こす可能性があった：
  これは今ではグラディエントとへッシアンに対してはエラーで，
  関数評価に対するそうした値は
  警告と共に \code{+Inf} で置き換えられる．
}
% see PR#15052.
\value{
  次の成分を持つリスト：
  \item{par}{見つかったパラメータの最良セット．}
  \item{objective}{
    \code{par} に対応する \code{objective} の値．}
  \item{convergence}{整数コード．\code{0} は成功裡の収束を意味する．}
  \item{メッセージ}{
    最適化関数から返された追加の情報を与える文字列，または
    \code{NULL}．詳細は PORT のドキュメントを見よ．
  }
  \item{iterations}{実行された繰り返し回数．}
  \item{evaluations}{
  目的関数とグラディエント関数の評価回数．}
}
\section{制御パラメータ}{
  \code{control} リスト中の可能なな雨とそれらの既定値は：
  \describe{
    \item{\code{eval.max}}{許される目的関数の最大評価数．
      既定値は 200．}
    \item{\code{iter.max}}{許される最大繰り返し数．
      既定値は 150．}
    \item{\code{trace}}{目的関数とパラメータが
      全てのトレース繰り返しでプリントされる値．
      既定値は 0 でトレース情報はプリントされない．}
    \item{\code{abs.tol}}{絶対許容度．
      既定値は 0 で絶対収束テストは使われない．
      もし目的関数が非負であることが知られていれば，
      以前の既定値
      \code{1e-20} がもっと適当かもしれない．}
    \item{\code{rel.tol}}{相対許容度．
      既定値は \code{1e-10}．}
    \item{\code{x.tol}}{X 教養度．既定値は \code{1.5e-8}．}
    \item{\code{xf.tol}}{偽りの収束許容度．
      既定値は \code{2.2e-14}．}
    \item{\code{step.min, step.max}}{最少と最大ステップサイズ．
      両者とも既定値は \code{1.}．}
    \item{sing.tol}{特異収束許容度；既定値は
      \code{rel.tol}．}
    \item{scale.init}{...}% DINIT  38
    \item{diff.g}{目的関数の値中の相対誤差の推定限界．}
  }
}
\source{ \url{http://netlib.bell-labs.com/netlib/port/} }
\author{
  \R への移植：Douglas Bates と Deepayan Sarkar．

  基礎にある Fortran コードは David M. Gay に依る．
}
\seealso{
  (より好ましい) \code{\link{optim}} と \code{\link{nlm}}．

  一次元最小化は \code{\link{optimize}} そして
  制約付き最適化は \code{\link{constrOptim}}．
}
% Lots of near-zeros, platform-specific results.
\examples{\donttest{
x <- rnbinom(100, mu = 10, size = 10)
hdev <- function(par)
    -sum(dnbinom(x, mu = par[1], size = par[2], log = TRUE))
nlminb(c(9, 12), hdev)
nlminb(c(20, 20), hdev, lower = 0, upper = Inf)
nlminb(c(20, 20), hdev, lower = 0.001, upper = Inf)

## S-PLUS の nlminb に対するヘルプページから少し修正
# この例は既知の解 y を持つ二乗和を最小化する
sumsq <- function( x, y) {sum((x-y)^2)}
y <- rep(1,5)
x0 <- rnorm(length(y))
nlminb(start = x0, sumsq, y = y)
# 一部の成分が境界外の y の境界を使う
y <- c( 0, 2, 0, -2, 0)
nlminb(start = x0, sumsq, lower = -1, upper = 1, y = y)
# グラディエントの使用を試みる
sumsq.g <- function(x, y) 2*(x-y)
nlminb(start = x0, sumsq, sumsq.g,
       lower = -1, upper = 1, y = y)
# へッシアンも使ってみる
sumsq.h <- function(x, y) diag(2, nrow = length(x))
nlminb(start = x0, sumsq, sumsq.g, sumsq.h,
       lower = -1, upper = 1, y = y)

## 残りは optim のヘルプページから

fr <- function(x) {   ## Rosenbrock のバナナ関数
    x1 <- x[1]
    x2 <- x[2]
    100 * (x2 - x1 * x1)^2 + (1 - x1)^2
}
grr <- function(x) { ## 'fr' のグラディエント
    x1 <- x[1]
    x2 <- x[2]
    c(-400 * x1 * (x2 - x1 * x1) - 2 * (1 - x1),
       200 *      (x2 - x1 * x1))
}
nlminb(c(-1.2,1), fr)
nlminb(c(-1.2,1), fr, grr)


flb <- function(x)
    { p <- length(x); sum(c(1, rep(4, p-1)) * (x - c(1, x[-p])^2)^2) }
## 25 次元の矩形制約
## par[24] は境界にない
nlminb(rep(3, 25), flb, lower = rep(2, 25), upper = rep(4, 25))
## 小さすぎる許容度を使う：
r <- nlminb(rep(3, 25), flb, control = list(rel.tol = 1e-16))
stopifnot(grepl("rel.tol", r$message))
}}
\keyword{optimize}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/nlminb.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{nlminb}
%\alias{nlminb}
%\title{Optimization using PORT routines }
%\description{
%  Unconstrained and box-constrained optimization using PORT routines.
%
%  For historical compatibility.
%}
%\usage{
%nlminb(start, objective, gradient = NULL, hessian = NULL, \dots,
%       scale = 1, control = list(), lower = -Inf, upper = Inf)
%}
%\arguments{
%  \item{start}{
%    numeric vector, initial values for the parameters to be optimized.
%  }
%  \item{objective}{
%    Function to be minimized.  Must return a scalar value.  The first
%    argument to \code{objective} is the vector of parameters to be
%    optimized, whose initial values are supplied through \code{start}.
%    Further arguments (fixed during the course of the optimization) to
%    \code{objective} may be specified as well (see \code{\dots}).
%  }
%  \item{gradient}{
%    Optional function that takes the same arguments as \code{objective} and
%    evaluates the gradient of \code{objective} at its first argument.  Must
%    return a vector as long as \code{start}.
%  }
%  \item{hessian}{
%    Optional function that takes the same arguments as \code{objective} and
%    evaluates the hessian of \code{objective} at its first argument.  Must
%    return a square matrix of order \code{length(start)}.  Only the
%    lower triangle is used.
%  }
%  \item{\dots}{Further arguments to be supplied to \code{objective}.}
%  \item{scale}{See PORT documentation (or leave alone).}
%  \item{control}{A list of control parameters. See below for details.}
%  \item{lower, upper}{
%    vectors of lower and upper bounds, replicated to be as long as
%    \code{start}.  If unspecified, all parameters are assumed to be
%    unconstrained.
%  }
%}
%\details{
%  Any names of \code{start} are passed on to \code{objective} and where
%  applicable, \code{gradient} and \code{hessian}.  The parameter vector
%  will be coerced to double.
%
%  The PORT documentation is at
%  \url{http://netlib.bell-labs.com/cm/cs/cstr/153.pdf}.
%
%  The parameter vector passed to \code{objective}, \code{gradient} and
%  \code{hessian} had special semantics prior to \R 3.1.0 and was shared
%  between calls.  The functions should not copy it.
%
%  If any of the functions returns \code{NA} or \code{NaN} the internal code
%  could infinite-loop in \R prior to 2.15.2: this is now an error for
%  the gradient and Hessian, and such values for function evaluation are
%  replaced by \code{+Inf} with a warning.
%}
%% see PR#15052.
%\value{
%  A list with components:
%  \item{par}{The best set of parameters found.}
%  \item{objective}{The value of \code{objective} corresponding to \code{par}.}
%  \item{convergence}{An integer code. \code{0} indicates successful
%    convergence.
%  }
%  \item{message}{
%    A character string giving any additional information returned by the
%    optimizer, or \code{NULL}. For details, see PORT documentation.
%  }
%  \item{iterations}{Number of iterations performed.}
%  \item{evaluations}{Number of objective function and gradient function evaluations}
%}
%\section{Control parameters}{
%  Possible names in the \code{control} list and their default values
%  are:
%  \describe{
%    \item{\code{eval.max}}{Maximum number of evaluations of the objective
%      function allowed.  Defaults to 200.}% MXFCAL
%    \item{\code{iter.max}}{Maximum number of iterations allowed.
%      Defaults to 150.}% MXITER
%    \item{\code{trace}}{The value of the objective function and the parameters
%      is printed every trace'th iteration.  Defaults to 0 which
%      indicates no trace information is to be printed.}
%    \item{\code{abs.tol}}{Absolute tolerance.  Defaults
%      to 0 so the absolute convergence test is not used.  If the objective
%      function is known to be non-negative, the previous default of
%      \code{1e-20} would be more appropriate.}% AFCTOL  31
%    \item{\code{rel.tol}}{Relative tolerance.  Defaults to
%      \code{1e-10}.}% RFCTOL  32
%    \item{\code{x.tol}}{X tolerance.  Defaults to \code{1.5e-8}.}% XCTOL  33
%    \item{\code{xf.tol}}{false convergence tolerance.  Defaults to
%      \code{2.2e-14}.}% XFTOL  34
%    \item{\code{step.min, step.max}}{Minimum and maximum step size.  Both
%      default to \code{1.}.}% LMAX0 35  /  LMAXS 36
%    \item{sing.tol}{singular convergence tolerance; defaults to
%      \code{rel.tol}.}% SCTOL  37
%    \item{scale.init}{...}% DINIT  38
%    \item{diff.g}{an estimated bound on the relative error in the
%      objective function value.}% ETA0  42
%  }
%}
%\source{ \url{http://netlib.bell-labs.com/netlib/port/} }
%\author{
%  \R port: Douglas Bates and Deepayan Sarkar.
%
%  Underlying Fortran code by David M. Gay
%}
%\seealso{
%  \code{\link{optim}} (which is preferred) and \code{\link{nlm}}.
%
%  \code{\link{optimize}} for one-dimensional minimization and
%  \code{\link{constrOptim}} for constrained optimization.
%}
%% Lots of near-zeros, platform-specific results.
%\examples{\donttest{
%x <- rnbinom(100, mu = 10, size = 10)
%hdev <- function(par)
%    -sum(dnbinom(x, mu = par[1], size = par[2], log = TRUE))
%nlminb(c(9, 12), hdev)
%nlminb(c(20, 20), hdev, lower = 0, upper = Inf)
%nlminb(c(20, 20), hdev, lower = 0.001, upper = Inf)
%
%## slightly modified from the S-PLUS help page for nlminb
%# this example minimizes a sum of squares with known solution y
%sumsq <- function( x, y) {sum((x-y)^2)}
%y <- rep(1,5)
%x0 <- rnorm(length(y))
%nlminb(start = x0, sumsq, y = y)
%# now use bounds with a y that has some components outside the bounds
%y <- c( 0, 2, 0, -2, 0)
%nlminb(start = x0, sumsq, lower = -1, upper = 1, y = y)
%# try using the gradient
%sumsq.g <- function(x, y) 2*(x-y)
%nlminb(start = x0, sumsq, sumsq.g,
%       lower = -1, upper = 1, y = y)
%# now use the hessian, too
%sumsq.h <- function(x, y) diag(2, nrow = length(x))
%nlminb(start = x0, sumsq, sumsq.g, sumsq.h,
%       lower = -1, upper = 1, y = y)
%
%## Rest lifted from optim help page
%
%fr <- function(x) {   ## Rosenbrock Banana function
%    x1 <- x[1]
%    x2 <- x[2]
%    100 * (x2 - x1 * x1)^2 + (1 - x1)^2
%}
%grr <- function(x) { ## Gradient of 'fr'
%    x1 <- x[1]
%    x2 <- x[2]
%    c(-400 * x1 * (x2 - x1 * x1) - 2 * (1 - x1),
%       200 *      (x2 - x1 * x1))
%}
%nlminb(c(-1.2,1), fr)
%nlminb(c(-1.2,1), fr, grr)
%
%
%flb <- function(x)
%    { p <- length(x); sum(c(1, rep(4, p-1)) * (x - c(1, x[-p])^2)^2) }
%## 25-dimensional box constrained
%## par[24] is *not* at boundary
%nlminb(rep(3, 25), flb, lower = rep(2, 25), upper = rep(4, 25))
%## trying to use a too small tolerance:
%r <- nlminb(rep(3, 25), flb, control = list(rel.tol = 1e-16))
%stopifnot(grepl("rel.tol", r$message))
%}}
%\keyword{optimize}
%
%\encoding{UTF-8}
%
