% File src/library/stats/man/nls.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{nls}
\alias{nls}%@%\alias{非線形最少二乗法}
\title{Nonlinear Least Squares}
\description{
  非線形モデルのパラメータの非線形(重み付き)最少二乗推定値を決定する．
}
\usage{
nls(formula, data, start, control, algorithm,
    trace, subset, weights, na.action, model,
    lower, upper, \dots)
}
\arguments{
  \item{formula}{変数とパラメータを含む非線形モデル公式．
   必要なら公式に強制変換される．}
  \item{data}{
    \code{formula} と \code{weights} 中の変数をその中で評価する
    オプションのデータフレーム．
    リストや環境でも良いが行列は不可．}
  \item{start}{初期推定値の名前付きリスト化名前付き数値ベクトル．
    \code{start} が無いときは，非常に安易な
    \code{start} の推定が試みられる
    (\code{algorithm != "plinear"} の時)．}
  \item{control}{制御設定のオプションのりスト．
    設定可能な制御値の名前とそれらの効果については
    \code{\link{nls.control}} を見よ．}
  \item{algorithm}{
    使用するアルゴリズムを指定する文字列．
    既定のアルゴリズムは Gauss-Newton アルゴリズムである．
    他の可能な値は
    部分的線形最少二乗モデルに対する Golub-Pereyra アルゴリズム
    \code{"plinear"} と，
    Port ライブラリからの \sQuote{nl2sol} アルゴリズム
    \code{"port"} である
    -- 参考文献を見よ．短縮化出来る．}
  \item{trace}{
    繰り返し過程のトレースをプリントするかどうかを指示する論理値．
    既定値は \code{FALSE}．
    もし \code{TRUE} ならば，各繰り返しの終わりに
    残差(重み付き)二乗和と
    パラメータ値がプリントされる．
    \code{"plinear"} アルゴリズムが使われた際は，
    非線形パラメータの後に線形パラメータの条件付き推定値が
    プリントされる．
    \code{"port"} アルゴリズムが使われた際は，
    プリントされる目的関数は
    残差(重み付き)二乗和の半分である．}
  \item{subset}{当てはめ過程で使われる観測値の部分集合を指定するオプションの
    ベクトル．}
  \item{weights}{オプションの(固定)重みの数値ベクトル．
    存在すれば目的関数は重み付き最少二乗である．}
  \item{na.action}{
    データが \code{NA} を含む時何が起こるかを指示する関数．
    既定値は \code{\link{options}} の
    \code{na.action} 設定であり，もしそれが未設定ならば
    \code{\link{na.fail}}．
    \sQuote{工場出荷時}既定値は
    \code{\link{na.omit}}．値 \code{\link{na.exclude}}
    は役に立つ可能性がある．}
  \item{model}{論理値．もし真なら，モデルフレームが
    lオブジェクトの一部として返される．
    既定値は \code{FALSE}．}
  \item{lower, upper}{下限と上限のベクトルで，
    \code{start} と同じ長さまで複製される．
    もし未指定なら全てのパラメータは無制約とされる．
    限界は \code{"port"} アルゴリズムでだけ使うことが出来る．
    他のアルゴリズムを使うと警告と共に無視される．}
  \item{\dots}{追加のオプション引数．現在どれも使われない．}
}
\details{
  当てはめモデルオブジェクトのタイプの \code{nls}オブジェクト．
  これは総称的関数 \code{\link{anova}}, \code{\link{coef}},
  \code{\link{confint}}, \code{\link{deviance}},
  \code{\link{df.residual}}, \code{\link{fitted}},
  \code{\link{formula}}, \code{\link{logLik}}, \code{\link{predict}},
  \code{\link{print}}, \code{\link{profile}}, \code{\link{residuals}},
  \code{\link{summary}}, \code{\link{vcov}} そして \code{\link{weights}}
  に対するメソッドを持つ．

  \code{formula} (そしてもし欠損していなければ \code{weights})中の
  変数は先ず
  \code{data} 中，次に
  \code{formula} の環境中，最後に検索パスに沿って探される．
  \code{formula} 中の関数は先ず
  \code{formula} の環境中，それから検索パスに沿って探される．

  引数 \code{subset} と \code{na.action} は
  公式中の \code{data} から取られた全ての変数が
  同じ長さの時だけサポートされる：
  他のケースは警告を与える．

  \code{\link{anova}} メソッドはモデルが入れ子になっていることを
  チェックしないことを注意する：
  これは簡単には自動化出来ないので，注意して使う．
}
\section{警告}{
  \bold{\code{nls} を"残差ゼロ"の人工的なデータに使ってはならない．}

  \code{nls} 関数は現在のパラメータでの数値的不正確度を
  残差二乗和と比較する相対オフセット収束基準を使う．
  これは
  \deqn{y=f(x, \theta) + \epsilon}{y = f(x, \theta) + eps}
  (\code{var(eps) > 0} の)形のデータに対しては上手く動作する．
  \deqn{y = f(x, \theta)} の形式のデータに関しては
  基準は丸め誤差の二つの成分を比較することになるので
  収束を指示するのに失敗する．
  もし人工的なデータでテストしたければ，
  下の例のようにノイズ成分を加えて欲しい．

  \code{algorithm = "port"} コードは未完成と思われ，
  初期値が境界内にあるかどうかのチェックすらしない．
  特に境界が提供されている場合は注意して使うこと．
}
\value{
  次の成分持つリスト
  \item{m}{モデルを含む \code{nlsModel} オブジェクト．}
  \item{data}{データ引数として \code{nls} に渡される表現式．
    実際のデータ値は \code{m} 成分の環境中にある．}
  \item{call}{幾つかの成分を含むマッチした呼び出し，特に
    \code{algorithm}．}
  \item{na.action}{モデルフレームの(もしあれば) \code{"na.action"} 属性．}
  \item{dataClasses}{
    モデルフレームの \code{"terms"} 属性の(もしあれば)
    \code{"dataClasses"} 属性．}
  \item{model}{もし \code{model = TRUE} ならばモデルフレーム．}
  \item{weights}{もし \code{weights} が提供されると，重み．}
  \item{convInfo}{収束情報を持つリスト．}
  \item{control}{使われた制御リスト，\code{control} 引数を見よ．}
  \item{convergence, message}{
    \code{algorithm = "port"} に依る当てはめのみ，
    収束コード(\code{0} は収束)とメッセージ．

    今では \code{convInfo} から得られるため，
    これらの使用は\emph{廃止されている}．
    
  }
}
\note{
  \code{control} 引数中
  (\code{\link{nls.control}} を見よ)で \code{warnOnly = TRUE} と設定すると
  収束しないオブジェクトを返す
  (\R バージョン 2.5.0 以来)．これは更なる収束解析に役立つかもしれないが，
  \emph{推測には役立たない}．
}
\references{
  Bates, D. M. and Watts, D. G. (1988)
  \emph{Nonlinear Regression Analysis and Its Applications},
  Wiley

  Bates, D. M. and Chambers, J. M. (1992)
  \emph{Nonlinear models.}
  Chapter 10 of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.

  Port ライブラリのドキュメントについては
  \url{http://www.netlib.org/port/}．
}
\author{
  Douglas M. Bates と Saikat DebRoy：
  \code{algorithm = "port"} で使われる Fortran コードは
  David M. Gay．
}
\seealso{
  \code{\link{summary.nls}}, \code{\link{predict.nls}},
  \code{\link{profile.nls}}.

  自己開始モデル(\sQuote{初期値を自動的に与える})：
  \code{\link{selfStart}}.
}
\examples{
\testonly{od <- options(digits=5)}
require(graphics)

DNase1 <- subset(DNase, Run == 1)

## 自己開始モデルを使う
fm1DNase1 <- nls(density ~ SSlogis(log(conc), Asym, xmid, scal), DNase1)
summary(fm1DNase1)
## 係数だけ：
coef(fm1DNase1)
## それらの SE 等を含む：
coef(summary(fm1DNase1))

## 条件付き線形性を使う
fm2DNase1 <- nls(density ~ 1/(1 + exp((xmid - log(conc))/scal)),
                 data = DNase1,
                 start = list(xmid = 0, scal = 1),
                 algorithm = "plinear")
summary(fm2DNase1)

## 条件付き線形性無し
fm3DNase1 <- nls(density ~ Asym/(1 + exp((xmid - log(conc))/scal)),
                 data = DNase1,
                 start = list(Asym = 3, xmid = 0, scal = 1))
summary(fm3DNase1)

## Port の nl2sol アルゴリズムを使う
fm4DNase1 <- nls(density ~ Asym/(1 + exp((xmid - log(conc))/scal)),
                 data = DNase1,
                 start = list(Asym = 3, xmid = 0, scal = 1),
                 algorithm = "port")
summary(fm4DNase1)

## 重み付き非線形回帰
Treated <- Puromycin[Puromycin$state == "treated", ]
weighted.MM <- function(resp, conc, Vm, K)
{
    ## 目標: 白本 p. 451 -- と正確に同じ，nls() の RHS に対して
    ## Michaelis-Menten モデルの重み付きバージョン
    ## ----------------------------------------------------------
    ## 引数： 'y', 'x' そして二つのパラメータ(本を見よ)
    ## ----------------------------------------------------------
    ## 著者：Martin Maechler, Date: 23 Mar 2001

    pred <- (Vm * conc)/(K + conc)
    (resp - pred) / sqrt(pred)
}

Pur.wt <- nls( ~ weighted.MM(rate, conc, Vm, K), data = Treated,
              start = list(Vm = 200, K = 0.1))
summary(Pur.wt)

## 引数をデータフレームに変換できないリストとして渡す
lisTreat <- with(Treated,
                 list(conc1 = conc[1], conc.1 = conc[-1], rate = rate))

weighted.MM1 <- function(resp, conc1, conc.1, Vm, K)
{
     conc <- c(conc1, conc.1)
     pred <- (Vm * conc)/(K + conc)
    (resp - pred) / sqrt(pred)
}
Pur.wt1 <- nls( ~ weighted.MM1(rate, conc1, conc.1, Vm, K),
               data = lisTreat, start = list(Vm = 200, K = 0.1))
stopifnot(all.equal(coef(Pur.wt), coef(Pur.wt1)))

## Chambers and Hastie (1992) Statistical Models in S  (p. 537):
## もし[公式の]右辺がグラディエントと呼ばれる属性を持てば
## これは行列で行数が応答の長さで各パラメータ毎に一つの列を持つべきである．

weighted.MM.grad <- function(resp, conc1, conc.1, Vm, K)
{
  conc <- c(conc1, conc.1)

  K.conc <- K+conc
  dy.dV <- conc/K.conc
  dy.dK <- -Vm*dy.dV/K.conc
  pred <- Vm*dy.dV
  pred.5 <- sqrt(pred)
  dev <- (resp - pred) / pred.5
  Ddev <- -0.5*(resp+pred)/(pred.5*pred)
  attr(dev, "gradient") <- Ddev * cbind(Vm = dy.dV, K = dy.dK)
  dev
}

Pur.wt.grad <- nls( ~ weighted.MM.grad(rate, conc1, conc.1, Vm, K),
                   data = lisTreat, start = list(Vm = 200, K = 0.1))

rbind(coef(Pur.wt), coef(Pur.wt1), coef(Pur.wt.grad))

## この例ではグラディエントを提供する利点は無いように見える．
## 他のケースではあるかもしれない．

## 下の二つの例は雑音を持つ人工的な例にモデルを当てはめることはできるが，
## 雑音を持たない人工的な例には出来ないことを示す．
x <- 1:10
y <- 2*x + 3                            # 完全な当てはめ
yeps <- y + rnorm(length(y), sd = 0.01) # 雑音を加える
nls(yeps ~ a + b*x, start = list(a = 0.12345, b = 0.54321))
## エラーで終了，収束が確証出来ないから：
try(nls(y ~ a + b*x, start = list(a = 0.12345, b = 0.54321)))

## nls() の初期値に対する内部的な簡易な推測が十分であることがある：

x <- -(1:100)/10
y <- 100 + 10 * exp(x / 2) + rnorm(x)/10
nlmod <- nls(y ~  Const + A * exp(B * x))

plot(x,y, main = "nls(*), data, true function and fit, n=100")
curve(100 + 10 * exp(x / 2), col = 4, add = TRUE)
lines(x, predict(nlmod), col = 2)

\donttest{
## MASS 中の筋肉データセットは21頭の動物の筋肉収縮に関するデータセット
## である．観測変数は筋(筋肉を同定する)，Conc (カルシウム濃度)そして
## 長さ(筋肉断面の結果の長さ)．
utils::data(muscle, package = "MASS")

## 用いられる非線形モデルは
##       Length = alpha + beta*exp(-Conc/theta) + error
## で，ここで theta は定数であるが alpha と beta は筋毎に変化するかもしれない．

with(muscle, table(Strip)) # 筋毎に 2, 3 又は 4 観測値

## 最初に plinear アルゴリズムを使い全体的なモデルを当てはめる，
## alpha と beta が筋毎に変わるかもしれないことは無視する．

musc.1 <- nls(Length ~ cbind(1, exp(-Conc/th)), muscle,
              start = list(th = 1), algorithm = "plinear")
summary(musc.1)

## それから，alpha と beta が筋毎に変化するというモデルの
## 当てはめに伝統的なアルゴリズムを使うために
## 非線形モデル中のパラメータに対する nls の添字付け特性を用いる．
## 初期値は先に当てはめたモデルから提供される．
## インデックス化されたパラメータに対しては初期値は
## リスト中(名前付き)で与えなければならないことを注意する：
b <- coef(musc.1)
musc.2 <- nls(Length ~ a[Strip] + b[Strip]*exp(-Conc/th), muscle,
              start = list(a = rep(b[2], 21), b = rep(b[3], 21), th = b[1]))
summary(musc.2)}
\testonly{options(od)}
}
\keyword{nonlinear}
\keyword{regression}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/nls.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{nls}
%\alias{nls}
%\title{Nonlinear Least Squares}
%\description{
%  Determine the nonlinear (weighted) least-squares estimates of the
%  parameters of a nonlinear model.
%}
%\usage{
%nls(formula, data, start, control, algorithm,
%    trace, subset, weights, na.action, model,
%    lower, upper, \dots)
%}
%\arguments{
%  \item{formula}{a nonlinear model \link{formula} including variables and
%    parameters.  Will be coerced to a formula if necessary.}
%  \item{data}{an optional data frame in which to evaluate the variables in
%    \code{formula} and \code{weights}.  Can also be a list or an
%    environment, but not a matrix.}
%  \item{start}{a named list or named numeric vector of starting
%    estimates.  When \code{start} is missing, a very cheap guess for
%    \code{start} is tried (if \code{algorithm != "plinear"}).
%  }
%  \item{control}{an optional list of control settings.  See
%    \code{\link{nls.control}} for the names of the settable control
%    values and their effect.}
%  \item{algorithm}{character string specifying the algorithm to use.
%    The default algorithm is a Gauss-Newton algorithm.  Other possible
%    values are \code{"plinear"} for the Golub-Pereyra algorithm for
%    partially linear least-squares models and \code{"port"} for the
%    \sQuote{nl2sol} algorithm from the Port library -- see the references.
%    Can be abbreviated.}
%  \item{trace}{logical value indicating if a trace of the iteration
%    progress should be printed.  Default is \code{FALSE}.  If
%    \code{TRUE} the residual (weighted) sum-of-squares and the
%    parameter values are printed at the conclusion of each iteration.
%    When the \code{"plinear"} algorithm is used, the conditional
%    estimates of the linear parameters are printed after the nonlinear
%    parameters.  When the \code{"port"} algorithm is used the
%    objective function value printed is half the residual (weighted)
%    sum-of-squares.}
%  \item{subset}{an optional vector specifying a subset of observations
%    to be used in the fitting process.}
%  \item{weights}{an optional numeric vector of (fixed) weights.  When
%    present, the objective function is weighted least squares.}
%  \item{na.action}{a function which indicates what should happen
%    when the data contain \code{NA}s.  The default is set by
%    the \code{na.action} setting of \code{\link{options}}, and is
%    \code{\link{na.fail}} if that is unset.  The \sQuote{factory-fresh}
%    default is \code{\link{na.omit}}.  Value \code{\link{na.exclude}}
%    can be useful.}
%  \item{model}{logical.  If true, the model frame is returned as part of
%    the object. Default is \code{FALSE}.}
%  \item{lower, upper}{vectors of lower and upper bounds, replicated to
%    be as long as \code{start}.  If unspecified, all parameters are
%    assumed to be unconstrained.  Bounds can only be used with the
%    \code{"port"} algorithm.  They are ignored, with a warning, if given
%    for other algorithms.}
%  \item{\dots}{Additional optional arguments.  None are used at present.}
%}
%\details{
%  An \code{nls} object is a type of fitted model object.  It has methods
%  for the generic functions \code{\link{anova}}, \code{\link{coef}},
%  \code{\link{confint}}, \code{\link{deviance}},
%  \code{\link{df.residual}}, \code{\link{fitted}},
%  \code{\link{formula}}, \code{\link{logLik}}, \code{\link{predict}},
%  \code{\link{print}}, \code{\link{profile}}, \code{\link{residuals}},
%  \code{\link{summary}}, \code{\link{vcov}} and \code{\link{weights}}.
%
%  Variables in \code{formula} (and \code{weights} if not missing) are
%  looked for first in \code{data}, then the environment of
%  \code{formula} and finally along the search path.  Functions in
%  \code{formula} are searched for first in the environment of
%  \code{formula} and then along the search path.
%
%  Arguments \code{subset} and \code{na.action} are supported only when
%  all the variables in the formula taken from \code{data} are of the
%  same length: other cases give a warning.
%
%  Note that the \code{\link{anova}} method does not check that the
%  models are nested: this cannot easily be done automatically, so use
%  with care.
%}
%\section{Warning}{
%  \bold{Do not use \code{nls} on artificial "zero-residual" data.}
%
%  The \code{nls} function uses a relative-offset convergence criterion
%  that compares the numerical imprecision at the current parameter
%  estimates to the residual sum-of-squares.  This performs well on data of
%  the form \deqn{y=f(x, \theta) + \epsilon}{y = f(x, \theta) + eps} (with
%  \code{var(eps) > 0}).  It fails to indicate convergence on data of the form
%  \deqn{y = f(x, \theta)} because the criterion amounts to
%  comparing two components of the round-off error.  If you wish to test
%  \code{nls} on artificial data please add a noise component, as shown
%  in the example below.
%
%  The \code{algorithm = "port"} code appears unfinished, and does
%  not even check that the starting value is within the bounds.
%  Use with caution, especially where bounds are supplied.
%}
%\value{
%  A list of
%  \item{m}{an \code{nlsModel} object incorporating the model.}
%  \item{data}{the expression that was passed to \code{nls} as the data
%    argument.  The actual data values are present in the environment of
%    the \code{m} component.}
%  \item{call}{the matched call with several components, notably
%    \code{algorithm}.}
%  \item{na.action}{the \code{"na.action"} attribute (if any) of the
%    model frame.}
%  \item{dataClasses}{the \code{"dataClasses"} attribute (if any) of the
%    \code{"terms"} attribute of the model frame.}
%  \item{model}{if \code{model = TRUE}, the model frame.}
%  \item{weights}{if \code{weights} is supplied, the weights.}
%  \item{convInfo}{a list with convergence information.}
%  \item{control}{the control \code{list} used, see the \code{control}
%    argument.}
%  \item{convergence, message}{for an \code{algorithm = "port"} fit only,
%    a convergence code (\code{0} for convergence) and message.
%
%    To use these is \emph{deprecated}, as they are available from
%    \code{convInfo} now.
%  }
%}
%\note{Setting \code{warnOnly = TRUE} in the \code{control}
%  argument (see \code{\link{nls.control}}) returns a non-converged
%  object (since \R version 2.5.0) which might be useful for further
%  convergence analysis, \emph{but \bold{not} for inference}.
%}
%\references{
%  Bates, D. M. and Watts, D. G. (1988)
%  \emph{Nonlinear Regression Analysis and Its Applications},
%  Wiley
%
%  Bates, D. M. and Chambers, J. M. (1992)
%  \emph{Nonlinear models.}
%  Chapter 10 of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%
%  \url{http://www.netlib.org/port/} for the Port library
%  documentation.
%}
%\author{
%  Douglas M. Bates and Saikat DebRoy: David M. Gay for the Fortran code
%  used by \code{algorithm = "port"}.
%}
%\seealso{
%  \code{\link{summary.nls}}, \code{\link{predict.nls}},
%  \code{\link{profile.nls}}.
%
%  Self starting models (with \sQuote{automatic initial values}):
%  \code{\link{selfStart}}.
%}
%\examples{
%\testonly{od <- options(digits=5)}
%require(graphics)
%
%DNase1 <- subset(DNase, Run == 1)
%
%## using a selfStart model
%fm1DNase1 <- nls(density ~ SSlogis(log(conc), Asym, xmid, scal), DNase1)
%summary(fm1DNase1)
%## the coefficients only:
%coef(fm1DNase1)
%## including their SE, etc:
%coef(summary(fm1DNase1))
%
%## using conditional linearity
%fm2DNase1 <- nls(density ~ 1/(1 + exp((xmid - log(conc))/scal)),
%                 data = DNase1,
%                 start = list(xmid = 0, scal = 1),
%                 algorithm = "plinear")
%summary(fm2DNase1)
%
%## without conditional linearity
%fm3DNase1 <- nls(density ~ Asym/(1 + exp((xmid - log(conc))/scal)),
%                 data = DNase1,
%                 start = list(Asym = 3, xmid = 0, scal = 1))
%summary(fm3DNase1)
%
%## using Port's nl2sol algorithm
%fm4DNase1 <- nls(density ~ Asym/(1 + exp((xmid - log(conc))/scal)),
%                 data = DNase1,
%                 start = list(Asym = 3, xmid = 0, scal = 1),
%                 algorithm = "port")
%summary(fm4DNase1)
%
%## weighted nonlinear regression
%Treated <- Puromycin[Puromycin$state == "treated", ]
%weighted.MM <- function(resp, conc, Vm, K)
%{
%    ## Purpose: exactly as white book p. 451 -- RHS for nls()
%    ##  Weighted version of Michaelis-Menten model
%    ## ----------------------------------------------------------
%    ## Arguments: 'y', 'x' and the two parameters (see book)
%    ## ----------------------------------------------------------
%    ## Author: Martin Maechler, Date: 23 Mar 2001
%
%    pred <- (Vm * conc)/(K + conc)
%    (resp - pred) / sqrt(pred)
%}
%
%Pur.wt <- nls( ~ weighted.MM(rate, conc, Vm, K), data = Treated,
%              start = list(Vm = 200, K = 0.1))
%summary(Pur.wt)
%
%## Passing arguments using a list that can not be coerced to a data.frame
%lisTreat <- with(Treated,
%                 list(conc1 = conc[1], conc.1 = conc[-1], rate = rate))
%
%weighted.MM1 <- function(resp, conc1, conc.1, Vm, K)
%{
%     conc <- c(conc1, conc.1)
%     pred <- (Vm * conc)/(K + conc)
%    (resp - pred) / sqrt(pred)
%}
%Pur.wt1 <- nls( ~ weighted.MM1(rate, conc1, conc.1, Vm, K),
%               data = lisTreat, start = list(Vm = 200, K = 0.1))
%stopifnot(all.equal(coef(Pur.wt), coef(Pur.wt1)))
%
%## Chambers and Hastie (1992) Statistical Models in S  (p. 537):
%## If the value of the right side [of formula] has an attribute called
%## 'gradient' this should be a matrix with the number of rows equal
%## to the length of the response and one column for each parameter.
%
%weighted.MM.grad <- function(resp, conc1, conc.1, Vm, K)
%{
%  conc <- c(conc1, conc.1)
%
%  K.conc <- K+conc
%  dy.dV <- conc/K.conc
%  dy.dK <- -Vm*dy.dV/K.conc
%  pred <- Vm*dy.dV
%  pred.5 <- sqrt(pred)
%  dev <- (resp - pred) / pred.5
%  Ddev <- -0.5*(resp+pred)/(pred.5*pred)
%  attr(dev, "gradient") <- Ddev * cbind(Vm = dy.dV, K = dy.dK)
%  dev
%}
%
%Pur.wt.grad <- nls( ~ weighted.MM.grad(rate, conc1, conc.1, Vm, K),
%                   data = lisTreat, start = list(Vm = 200, K = 0.1))
%
%rbind(coef(Pur.wt), coef(Pur.wt1), coef(Pur.wt.grad))
%
%## In this example, there seems no advantage to providing the gradient.
%## In other cases, there might be.
%
%
%## The two examples below show that you can fit a model to
%## artificial data with noise but not to artificial data
%## without noise.
%x <- 1:10
%y <- 2*x + 3                            # perfect fit
%yeps <- y + rnorm(length(y), sd = 0.01) # added noise
%nls(yeps ~ a + b*x, start = list(a = 0.12345, b = 0.54321))
%## terminates in an error, because convergence cannot be confirmed:
%try(nls(y ~ a + b*x, start = list(a = 0.12345, b = 0.54321)))
%
%## the nls() internal cheap guess for starting values can be sufficient:
%
%x <- -(1:100)/10
%y <- 100 + 10 * exp(x / 2) + rnorm(x)/10
%nlmod <- nls(y ~  Const + A * exp(B * x))
%
%plot(x,y, main = "nls(*), data, true function and fit, n=100")
%curve(100 + 10 * exp(x / 2), col = 4, add = TRUE)
%lines(x, predict(nlmod), col = 2)
%
%
%\donttest{
%## The muscle dataset in MASS is from an experiment on muscle
%## contraction on 21 animals.  The observed variables are Strip
%## (identifier of muscle), Conc (Cacl concentration) and Length
%## (resulting length of muscle section).
%utils::data(muscle, package = "MASS")
%
%## The non linear model considered is
%##       Length = alpha + beta*exp(-Conc/theta) + error
%## where theta is constant but alpha and beta may vary with Strip.
%
%with(muscle, table(Strip)) # 2, 3 or 4 obs per strip
%
%## We first use the plinear algorithm to fit an overall model,
%## ignoring that alpha and beta might vary with Strip.
%
%musc.1 <- nls(Length ~ cbind(1, exp(-Conc/th)), muscle,
%              start = list(th = 1), algorithm = "plinear")
%summary(musc.1)
%
%## Then we use nls' indexing feature for parameters in non-linear
%## models to use the conventional algorithm to fit a model in which
%## alpha and beta vary with Strip.  The starting values are provided
%## by the previously fitted model.
%## Note that with indexed parameters, the starting values must be
%## given in a list (with names):
%b <- coef(musc.1)
%musc.2 <- nls(Length ~ a[Strip] + b[Strip]*exp(-Conc/th), muscle,
%              start = list(a = rep(b[2], 21), b = rep(b[3], 21), th = b[1]))
%summary(musc.2)}
%\testonly{options(od)}
%}
%\keyword{nonlinear}
%\keyword{regression}
%\keyword{models}
%
%\encoding{UTF-8}
%
