% File src/library/stats/man/nobs.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2012 R Core Team
% Distributed under GPL 2 or later

\name{nobs}
\alias{nobs}%@%\alias{当てはめから観測値数を取り出す}
\alias{nobs.default}
\title{
  Extract the Number of Observations from a Fit.
}
\description{
  モデル当てはめから\sQuote{観測値}数を取り出す．
  これは主に
  BIC (\code{\link{AIC}} を見よ)の計算中で使うことを意図している．
}
\usage{
nobs(object, ...)

\method{nobs}{default}(object, use.fallback = FALSE, ...)
}
\arguments{
  \item{object}{当てはめモデルオブジェクト．}
  \item{use.fallback}{論理値：値を推測するのに後退メソッドを使うか?}
  \item{\dots}{メソッドに渡される追加引数．}
}
\details{
  これは総称的関数であり，
  パッケージ \pkg{stats4} 中に S4 総称的関数がある．
  このパッケージ中にはクラス
  \code{"\link{lm}"}, \code{"\link{glm}"}, \code{"\link{nls}"} そして
  \code{"\link{logLik}"} に対するメソッド，そして既定メソッド
  (これは \code{use.fallback = TRUE} でない限り
  \code{weights} と \code{residuals} 成分を探す際にエラーになるので，
  注意深く使う!)がある．

  主な使いみちは BIC に対する適当なペナルティの決定であるが，
  \code{nobs} はまたステップワイズの当てはめメソッド
  \code{\link{step}}, \code{\link{add1}} そして \code{\link{drop1}} で
  異なった当てはめが同じデータのセットに当てはめられているか
  (そして，たとえば，新しい予測量中の NA 値のために追加の行が除かれていないか)
  どうかの迅速なチェックとしても使われる．
  
  \code{lm}, \code{glm} そして \code{nls} 当てはめに対しては，
  重みがゼロの観測値は含められていない．
}
\value{
  単一の数値，普通整数．\code{NA} かもしれない．
}
\seealso{
  \code{\link{AIC}}.
}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/nobs.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2012 R Core Team
%% Distributed under GPL 2 or later
%
%\name{nobs}
%\alias{nobs}
%\alias{nobs.default}
%\title{
%  Extract the Number of Observations from a Fit.
%}
%\description{
%  Extract the number of \sQuote{observations} from a model fit.  This is
%  principally intended to be used in computing BIC (see \code{\link{AIC}}).
%}
%\usage{
%nobs(object, ...)
%
%\method{nobs}{default}(object, use.fallback = FALSE, ...)
%}
%\arguments{
%  \item{object}{A fitted model object.}
%  \item{use.fallback}{logical: should fallback methods be used to try to
%    guess the value?}
%  \item{\dots}{Further arguments to be passed to methods.}
%}
%\details{
%  This is a generic function, with an S4 generic in package \pkg{stats4}.
%  There are methods in this package for objects of classes
%  \code{"\link{lm}"}, \code{"\link{glm}"}, \code{"\link{nls}"} and
%  \code{"\link{logLik}"}, as well as a default method (which throws an
%  error, unless \code{use.fallback = TRUE} when it looks for
%  \code{weights} and \code{residuals} components -- use with care!).
%
%  The main usage is in determining the appropriate penalty for BIC, but
%  \code{nobs} is also used by the stepwise fitting methods
%  \code{\link{step}}, \code{\link{add1}} and \code{\link{drop1}} as a
%  quick check that different fits have been fitted to the same set of
%  data (and not, say, that further rows have been dropped because of NAs
%  in the new predictors).
%
%  For \code{lm}, \code{glm} and \code{nls} fits, observations with zero
%  weight are not included.
%}
%\value{
%  A single number, normally an integer.  Could be \code{NA}.
%}
%\seealso{
%  \code{\link{AIC}}.
%}
%\keyword{models}
%
%\encoding{UTF-8}
%
