% File src/library/stats/man/ppr.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

% file stats/man/ppr.Rd
% copyright (C) 1995-8 B. D. Ripley
% copyright (C) 2000-3   The R Core Team

\name{ppr}
\alias{ppr}
\alias{ppr.default}%@%\alias{射影追跡回帰}
\alias{ppr.formula}
\title{Projection Pursuit Regression}
\description{
  射影追跡回帰モデルを当てはめる．
}
\usage{
ppr(x, \dots)

\method{ppr}{formula}(formula, data, weights, subset, na.action,
    contrasts = NULL, \dots, model = FALSE)

\method{ppr}{default}(x, y, weights = rep(1, n),
    ww = rep(1, q), nterms, max.terms = nterms, optlevel = 2,
    sm.method = c("supsmu", "spline", "gcvspline"),
    bass = 0, span = 0, df = 5, gcvpen = 1, \dots)
}
\arguments{
  \item{formula}{
    一つ又はそれ以上の数値応答変数と説明変数を指定する公式．}
  \item{x}{
    説明変数の数値行列．行は観測値を表し，
    列は変数を表す．欠損値は受け入れられない．}
  \item{y}{
    応答変数の数値行列．
    行は観測値を表し列は変数を表す．欠損値は受け入れられない．}
  \item{nterms}{最後の公式に含められる項の数．}
  \item{data}{
    \code{formula} 中で指定された変数がそこから取られる
    データフレーム(又は類似物：\code{\link{model.frame}} を見よ)．}
  \item{weights}{
    各\emph{ケース}に対する重み \code{w_i} のベクトル．}
  \item{ww}{
    各 \emph{応答}に対する重みのベクトルで，
    当てはめ基準は
    ケース \code{i} と応答 \code{j} に対する和
    \code{w_i ww_j (y_ij - fit_ij)^2} を \code{w_i} の和で割ったもの．}
  \item{subset}{
    訓練標本で使われるケースを指定する添字ベクトル．
    (注意：もし与えられると，この引数は名前付きでなければならない．)
  }
  \item{na.action}{
    \code{\link{NA}} 値が見つかった時に取られる行動を指定する関数．
    既定の行動は\cr
    \code{getOption("na.action")}．
    (注意：もし与えられると，この引数は名前付きでなければならない．)
  }
  \item{contrasts}{
    因子せて説明変数がコードされている時使われる対比．}
  \item{max.terms}{
    モデルを構成する時選ばれる項の最大数．}
  \item{optlevel}{
    SMART プログラム中の最適化ルーチンの徹底度を決定する 0 から 3 までの
    整数．\sQuote{詳細}節を見よ．
  }
  \item{sm.method}{
    リッジ関数の平滑化に使われる手法．
    既定は Friedman のスーパー平滑化 \code{supsmu} である．
    今一つは \code{smooth.spline} の基礎にある平滑化スプラインコードを，
    指定したリッジ関数の(同値)自由度で使うか，
    平滑度を GCV で選択することを許すことである．

    短縮化出来る．
  }
  \item{bass}{
    自動的なスパン選択と共に使われるスーパー平滑化のバストーンの制御
    (\code{supsmu} を見よ)；値の範囲は 0 から 10 で，
    大きな値は平滑度を増す．
  }
  \item{span}{
    スーパー平滑化のスパンの制御(\code{supsmu} を見よ)．
    既定の \code{0} は局所的なクロスバリデーションによる
    自動的なスパン選択である．
    \code{span} もまた \code{(0, 1]} 中の値を取ることができる．
  }
  \item{df}{
    もし \code{sm.method} が \code{"spline"} ならば
    要求される同値自由度を使い各リッジ項の平滑度を指定する．
  }
  \item{gcvpen}{
    もし \code{sm.method} が \code{"gcvspline"} なら，これは
    使われる各自由度に対する GCV 選択で使われるペナルティである．
  }
  \item{\dots}{他のメソッドから・へ渡される引数．}
  \item{model}{論理値．もし真ならばモデルフレームを返す．}
}
\value{
次の成分を持つリストで，
それらの多くはメソッド関数で使われる．

\item{call}{マッチした呼び出し．}
\item{p}{説明変数の数(何らかのコーディングの後で)．}
\item{q}{応答変数の数．}
\item{mu}{引数 \code{nterms}．}
\item{ml}{引数 \code{max.terms}．}
\item{gof}{選択モデルに対する全体的な残差(重み付き)二乗和．}
\item{gofn}{項数に対する全体的な残差(重み付き)二乗和で，
  \code{max.terms} まで．\code{nterms} 未満(そしてゼロ)に対しては不適切．}
\item{df}{引数 \code{df}．}
\item{edf}{もし \code{sm.method} が \code{"spline"} か \code{"gcvspline"} ならば，
  使われる各リッジ項に対する同値自由度．}
\item{xnames}{説明変数の名前．}
\item{ynames}{応答変数の名前．}
\item{alpha}{射影方向の行列で，各リッジ項に対する列を持つ．}
\item{beta}{リッジ項への各応答に対して適用される係数の行列：
  行は応答とリッジ項の列である．}
\item{yb}{各応答の重み付き平均．}
\item{ys}{使われる全体的なスケール：
  内部的には応答は単位重み付き二乗和を持つように \code{ys} で割られる．}
\item{fitted.values}{当てはめ値，
  もし \code{q > 1} ならば行列として．}
\item{residuals}{残差，もし \code{q > 1} ならば行列として．}
\item{smod}{内部的な作業配列で，訓練セット点で評価されたリッジ関数を含む．}
\item{model}{(\code{model = TRUE} の時だけ)モデルフレーム．}
}
\details{
  基本的なメソッドは Friedman (1984) で与えられ，
  本質的に S-PLUS の \code{ppreg} で使われているのと同じコードである．

  アルゴリズムは最初に
  \code{max.terms} 個までのリッジ項を一時に一つ加える；
  もし十分な差を生み出す付加項を見つけられなければより少ない項を使う．
  それはそれから
  \code{nterms} 個の項が残されるまで各ステップで重要さが最少の項を除く．

  最適化のレベル(引数 \code{optlevel})
  はモデルがこの過程で如何に完全に再当てはめがされるかという点で異なる．
  レベル 0 では存在するリッジ項は再当てはめされない．
  レベル 1 では射影方向は再当てはめされないが，
  リッジ関数と回帰係数はされる．
%
  レベル 2 と 3 は全ての項を再当てはめし一つの応答に対しては同値である；
  レベル 3 は各ステップで各回帰式からの貢献をより注意深く再バランスするので，
  二乗和基準の鞍点に少々収束しにくい．
}
\source{
  Friedman (1984): 
  元々 B. D. Ripley により \CRANpkg{MASS} パッケージ用に
  倍精度に変換され平滑化スプラインへのインタフェイスが加えられた．
}

\references{
  Friedman, J. H. and Stuetzle, W. (1981)
  Projection pursuit regression.
  \emph{Journal of the American Statistical Association},
  \bold{76}, 817--823.

  Friedman, J. H. (1984)
  SMART User's Guide.
  Laboratory for Computational Statistics, Stanford University Technical
  Report No.\sspace{}1.

  Venables, W. N. and Ripley, B. D. (2002)
  \emph{Modern Applied Statistics with S.}  Springer.
}
\seealso{
  \code{\link{plot.ppr}}, \code{\link{supsmu}}, \code{\link{smooth.spline}}
}
\examples{
require(graphics)

# 注意：あなたの数値は異なるかもしれない
attach(rock)
area1 <- area/10000; peri1 <- peri/10000
rock.ppr <- ppr(log(perm) ~ area1 + peri1 + shape,
                data = rock, nterms = 2, max.terms = 5)
rock.ppr
# 呼び出し：
# ppr.formula(formula = log(perm) ~ area1 + peri1 + shape, data = rock,
#     nterms = 2, max.terms = 5)
#
# 適合度：
#  2 terms  3 terms  4 terms  5 terms
# 8.737806 5.289517 4.745799 4.490378

summary(rock.ppr)
# .....  (上と同じ)
# .....
#
# 射影の方向ベクトル：
#       term 1      term 2
# area1  0.34357179  0.37071027
# peri1 -0.93781471 -0.61923542
# shape  0.04961846  0.69218595
#
# リッジ項の係数：
#    term 1    term 2
# 1.6079271 0.5460971

par(mfrow = c(3,2))   # 恐らく： pty = "s"
plot(rock.ppr, main = "ppr(log(perm)~ ., nterms=2, max.terms=5)")
plot(update(rock.ppr, bass = 5), main = "update(..., bass = 5)")
plot(update(rock.ppr, sm.method = "gcv", gcvpen = 2),
     main = "update(..., sm.method=\"gcv\", gcvpen=2)")
cbind(perm = rock$perm, prediction = round(exp(predict(rock.ppr)), 1))
detach()
}
\keyword{regression}


\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/ppr.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%% file stats/man/ppr.Rd
%% copyright (C) 1995-8 B. D. Ripley
%% copyright (C) 2000-3   The R Core Team
%
%\name{ppr}
%\alias{ppr}
%\alias{ppr.default}
%\alias{ppr.formula}
%\title{Projection Pursuit Regression}
%\description{
%  Fit a projection pursuit regression model.
%}
%\usage{
%ppr(x, \dots)
%
%\method{ppr}{formula}(formula, data, weights, subset, na.action,
%    contrasts = NULL, \dots, model = FALSE)
%
%\method{ppr}{default}(x, y, weights = rep(1, n),
%    ww = rep(1, q), nterms, max.terms = nterms, optlevel = 2,
%    sm.method = c("supsmu", "spline", "gcvspline"),
%    bass = 0, span = 0, df = 5, gcvpen = 1, \dots)
%}
%\arguments{
%  \item{formula}{
%    a formula specifying one or more numeric response variables and the
%    explanatory variables.
%  }
%  \item{x}{
%    numeric matrix of explanatory variables.  Rows represent observations, and
%    columns represent variables.  Missing values are not accepted.
%  }
%  \item{y}{
%    numeric matrix of response variables.  Rows represent observations, and
%    columns represent variables.  Missing values are not accepted.
%  }
%  \item{nterms}{number of terms to include in the final model.}
%  \item{data}{
%    a data frame (or similar: see \code{\link{model.frame}}) from which
%    variables specified in \code{formula} are preferentially to be taken.
%  }
%  \item{weights}{a vector of weights \code{w_i} for each \emph{case}.}
%  \item{ww}{
%    a vector of weights for each \emph{response}, so the fit criterion is
%    the sum over case \code{i} and responses \code{j} of
%    \code{w_i ww_j (y_ij - fit_ij)^2} divided by the sum of \code{w_i}.
%  }
%  \item{subset}{
%    an index vector specifying the cases to be used in the training
%    sample.  (NOTE: If given, this argument must be named.)
%  }
%  \item{na.action}{
%    a function to specify the action to be taken if \code{\link{NA}}s are
%    found. The default action is given by \code{getOption("na.action")}.
%    (NOTE: If given, this argument must be named.)
%  }
%  \item{contrasts}{
%    the contrasts to be used when any factor explanatory variables are coded.
%  }
%  \item{max.terms}{
%    maximum number of terms to choose from when building the model.
%  }
%  \item{optlevel}{
%    integer from 0 to 3 which determines the thoroughness of an
%    optimization routine in the SMART program. See the \sQuote{Details}
%    section.
%  }
%  \item{sm.method}{
%    the method used for smoothing the ridge functions.  The default is to
%    use Friedman's super smoother \code{supsmu}.  The alternatives are to use
%    the smoothing spline code underlying \code{smooth.spline}, either with a
%    specified (equivalent) degrees of freedom for each ridge functions, or
%    to allow the smoothness to be chosen by GCV.
%
%    Can be abbreviated.
%  }
%  \item{bass}{
%    super smoother bass tone control used with automatic span selection
%    (see \code{supsmu}); the range of values is 0 to 10, with larger values
%    resulting in increased smoothing.
%  }
%  \item{span}{
%    super smoother span control (see \code{supsmu}).  The default, \code{0},
%    results in automatic span selection by local cross validation. \code{span}
%    can also take a value in \code{(0, 1]}.
%  }
%  \item{df}{
%    if \code{sm.method} is \code{"spline"} specifies the smoothness of
%    each ridge term via the requested equivalent degrees of freedom.
%  }
%  \item{gcvpen}{
%    if \code{sm.method} is \code{"gcvspline"} this is the penalty used
%    in the GCV selection for each degree of freedom used.
%  }
%  \item{\dots}{arguments to be passed to or from other methods.}
%  \item{model}{logical.  If true, the model frame is returned.}
%}
%\value{
%A list with the following components, many of which are for use by the
%method functions.
%
%\item{call}{the matched call}
%\item{p}{the number of explanatory variables (after any coding)}
%\item{q}{the number of response variables}
%\item{mu}{the argument \code{nterms}}
%\item{ml}{the argument \code{max.terms}}
%\item{gof}{the overall residual (weighted) sum of squares for the
%  selected model}
%\item{gofn}{the overall residual (weighted) sum of squares against the
%  number of terms, up to \code{max.terms}.  Will be invalid (and zero)
%  for less than \code{nterms}.}
%\item{df}{the argument \code{df}}
%\item{edf}{if \code{sm.method} is \code{"spline"} or \code{"gcvspline"}
%  the equivalent number of degrees of freedom for each ridge term used.}
%\item{xnames}{the names of the explanatory variables}
%\item{ynames}{the names of the response variables}
%\item{alpha}{a matrix of the projection directions, with a column for
%  each ridge term}
%\item{beta}{a matrix of the coefficients applied for each response to
%  the ridge terms: the rows are the responses and the columns the ridge terms}
%\item{yb}{the weighted means of each response}
%\item{ys}{the overall scale factor used: internally the responses are
%  divided by \code{ys} to have unit total weighted sum of squares.}
%\item{fitted.values}{the fitted values, as a matrix if \code{q > 1}.}
%\item{residuals}{the residuals, as a matrix if \code{q > 1}.}
%\item{smod}{internal work array, which includes the ridge functions
%  evaluated at the training set points.}
%\item{model}{(only if \code{model = TRUE}) the model frame.}
%}
%\details{
%  The basic method is given by Friedman (1984), and is essentially the
%  same code used by S-PLUS's \code{ppreg}.  This code is extremely
%  sensitive to the compiler used.
%
%  The algorithm first adds up to \code{max.terms} ridge terms one at a
%  time; it will use less if it is unable to find a term to add that makes
%  sufficient difference.  It then removes the least
%  important term at each step until \code{nterms} terms
%  are left.
%
%  The levels of optimization (argument \code{optlevel})
%  differ in how thoroughly the models are refitted during this process.
%  At level 0 the existing ridge terms are not refitted.  At level 1
%  the projection directions are not refitted, but the ridge
%  functions and the regression coefficients are.
%%
%  Levels 2 and 3 refit all the terms and are equivalent for one
%  response; level 3 is more careful to re-balance the contributions
%  from each regressor at each step and so is a little less likely to
%  converge to a saddle point of the sum of squares criterion.
%}
%\source{
%  Friedman (1984): converted to double precision and added interface to
%  smoothing splines by B. D. Ripley, originally for the \CRANpkg{MASS}
%  package.
%}
%
%\references{
%  Friedman, J. H. and Stuetzle, W. (1981)
%  Projection pursuit regression.
%  \emph{Journal of the American Statistical Association},
%  \bold{76}, 817--823.
%
%  Friedman, J. H. (1984)
%  SMART User's Guide.
%  Laboratory for Computational Statistics, Stanford University Technical
%  Report No.\sspace{}1.
%
%  Venables, W. N. and Ripley, B. D. (2002)
%  \emph{Modern Applied Statistics with S.}  Springer.
%}
%\seealso{
%  \code{\link{plot.ppr}}, \code{\link{supsmu}}, \code{\link{smooth.spline}}
%}
%\examples{
%require(graphics)
%
%# Note: your numerical values may differ
%attach(rock)
%area1 <- area/10000; peri1 <- peri/10000
%rock.ppr <- ppr(log(perm) ~ area1 + peri1 + shape,
%                data = rock, nterms = 2, max.terms = 5)
%rock.ppr
%# Call:
%# ppr.formula(formula = log(perm) ~ area1 + peri1 + shape, data = rock,
%#     nterms = 2, max.terms = 5)
%#
%# Goodness of fit:
%#  2 terms  3 terms  4 terms  5 terms
%# 8.737806 5.289517 4.745799 4.490378
%
%summary(rock.ppr)
%# .....  (same as above)
%# .....
%#
%# Projection direction vectors:
%#       term 1      term 2
%# area1  0.34357179  0.37071027
%# peri1 -0.93781471 -0.61923542
%# shape  0.04961846  0.69218595
%#
%# Coefficients of ridge terms:
%#    term 1    term 2
%# 1.6079271 0.5460971
%
%par(mfrow = c(3,2))   # maybe: , pty = "s")
%plot(rock.ppr, main = "ppr(log(perm)~ ., nterms=2, max.terms=5)")
%plot(update(rock.ppr, bass = 5), main = "update(..., bass = 5)")
%plot(update(rock.ppr, sm.method = "gcv", gcvpen = 2),
%     main = "update(..., sm.method=\"gcv\", gcvpen=2)")
%cbind(perm = rock$perm, prediction = round(exp(predict(rock.ppr)), 1))
%detach()
%}
%\keyword{regression}
%
%
%\encoding{UTF-8}
%
