% File src/library/stats/man/spec.pgram.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{spec.pgram}
\alias{spec.pgram}%@%\alias{ペリオドグラムによるスペクトル密度推定}
\title{Estimate Spectral Density of a Time Series by a Smoothed
    Periodogram}
\usage{
spec.pgram(x, spans = NULL, kernel, taper = 0.1,
           pad = 0, fast = TRUE, demean = FALSE, detrend = TRUE,
           plot = TRUE, na.action = na.fail, \dots)
}
\arguments{
  \item{x}{一変量又は多変量時系列．}
  \item{spans}{ペリオドグラムの平滑化に使われる
    修正 Daniell 平滑法の幅を与える奇数整数のベクトル．}
  \item{kernel}{別法として，クラス
    \code{"tskernel"} のカーネル平滑法．}
  \item{taper}{テーパーにかけるデータの割合を指定する．
    系列の最初と最後のデータのこの割合に
    split cosine bell テーパーが適用される．}
  \item{pad}{データを埋める割合．
    割合 \code{pad} 分だけ系列の長さを増すため最後にゼロが加えられる．}
  \item{fast}{論理値；もし \code{TRUE} なら，
    高度に合成的な長さになるまで埋められる．}
  \item{demean}{論理値．もし \code{TRUE} なら，
    系列の平均を引き去る．}
  \item{detrend}{論理値．もし \code{TRUE} なら，系列から線形トレンドを
    取り去る．これは平均も取り去る．}
  \item{plot}{ペリオドグラムをプロットするか?}
  \item{na.action}{\code{NA} 値を扱う関数．}
  \item{\dots}{
    \code{plot.spec} に渡されるグラフィカルパラメータ．}
}
\description{
  \code{spec.pgram} はペリオドグラムを高速フーリエ変換を使い計算し，
  オプションで結果を修正 Daniell 平滑化の系列でで平滑化する
  (端点に重みの半分を与える移動平均)．
}
\details{
  生のペリオドグラムはスペクトル密度の一致推定量であるが，
  隣り合った値は漸近的に独立になる．
  従って，密度関数が滑らかなことを仮定して，生のペリオドグラムを平滑化することで
  一致推定量が導ける．

  高速フーリエ変換を補助するため，系列は長さが高度に合成的な数になるように
  自動的にゼロで埋められる．
  これは \code{pad} 引数ではなく \code{fast} 引数でで制御される．

  ゼロにおけるペリオドグラムは系列の平均が引かれているため理論上ゼロになる
  (しかしこれはテーパリングで影響を受けるかもしれない)：
  これは平滑化の過程で隣の値で補間値で置き換えられ，
  その周波数に対しては値は返されない．
}
\value{
  クラス \code{"spec"} (\code{\link{spectrum}} を見よ)の
  オブジェクトで次の成分を持つ：
  \item{kernel}{\code{kernel} 引数，又は
    \code{spans} から作られたカーネル．}
  \item{df}{スペクトル密度推定の分布は
    自由度 \code{df} のカイ二乗分布で近似出来る．}
  \item{bandwidth}{
    Bloomfield (1976, page 201) で定義されているようなカーネル
    平滑化の同値バンド幅．}
  \item{taper}{\code{taper} 引数の値．}
  \item{pad}{\code{pad} 引数の値．}
  \item{detrend}{\code{detrend} 引数の値．}
  \item{demean}{\code{demean} 引数の値．}

  もし \code{plot} が真なら，結果は不可視で返される．
}

\references{
  Bloomfield, P. (1976) \emph{Fourier Analysis of Time Series: An
    Introduction.} Wiley.

  Brockwell, P.J. and Davis, R.A. (1991) \emph{Time Series: Theory and
    Methods.} Second edition. Springer.

  Venables, W.N. and Ripley, B.D. (2002) \emph{Modern Applied
    Statistics with S.} Fourth edition. Springer.
  (特に pp.\sspace{}392--7.)
}
\author{
  オリジナルは Martyn Plummer; カーネル平滑化は Adrian Trapletti，
  B.D. Ripley により統合化．
}
\seealso{\code{\link{spectrum}}, \code{\link{spec.taper}},
  \code{\link{plot.spec}}, \code{\link{fft}}}

\examples{
require(graphics)

## Venables & Ripley からの例
spectrum(ldeaths)
spectrum(ldeaths, spans = c(3,5))
spectrum(ldeaths, spans = c(5,7))
spectrum(mdeaths, spans = c(3,3))
spectrum(fdeaths, spans = c(3,3))

## 二変量の例
mfdeaths.spc <- spec.pgram(ts.union(mdeaths, fdeaths), spans = c(3,3))
# plots marginal spectra: now plot coherency and phase
plot(mfdeaths.spc, plot.type = "coherency")
plot(mfdeaths.spc, plot.type = "phase")

## 不揃いの例
mfdeaths.spc <- spec.pgram(ts.intersect(mdeaths, lag(fdeaths, 4)),
   spans = c(3,3), plot = FALSE)
plot(mfdeaths.spc, plot.type = "coherency")
plot(mfdeaths.spc, plot.type = "phase")

stocks.spc <- spectrum(EuStockMarkets, kernel("daniell", c(30,50)),
                       plot = FALSE)
plot(stocks.spc, plot.type = "marginal") # 既定のタイプ
plot(stocks.spc, plot.type = "coherency")
plot(stocks.spc, plot.type = "phase")

sales.spc <- spectrum(ts.union(BJsales, BJsales.lead),
                      kernel("modified.daniell", c(5,7)))
plot(sales.spc, plot.type = "coherency")
plot(sales.spc, plot.type = "phase")
}
\keyword{ts}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/spec.pgram.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{spec.pgram}
%\alias{spec.pgram}
%\title{Estimate Spectral Density of a Time Series by a Smoothed
%    Periodogram}
%\usage{
%spec.pgram(x, spans = NULL, kernel, taper = 0.1,
%           pad = 0, fast = TRUE, demean = FALSE, detrend = TRUE,
%           plot = TRUE, na.action = na.fail, \dots)
%}
%\arguments{
%  \item{x}{univariate or multivariate time series.}
%  \item{spans}{vector of odd integers giving the widths of modified
%    Daniell smoothers to be used to smooth the periodogram.}
%  \item{kernel}{alternatively, a kernel smoother of class
%    \code{"tskernel"}.}
%  \item{taper}{specifies the proportion of data to taper.  A split
%    cosine bell taper is applied to this proportion of the data at the
%    beginning and end of the series.}
%  \item{pad}{proportion of data to pad. Zeros are added to the end of
%    the series to increase its length by the proportion \code{pad}.}
%  \item{fast}{logical; if \code{TRUE}, pad the series to a highly composite
%    length.}
%  \item{demean}{logical. If \code{TRUE}, subtract the mean of the
%    series.}
%  \item{detrend}{logical. If \code{TRUE}, remove a linear trend from
%    the series. This will also remove the mean.}
%  \item{plot}{plot the periodogram?}
%  \item{na.action}{\code{NA} action function.}
%  \item{\dots}{graphical arguments passed to \code{plot.spec}.}
%}
%\description{
%  \code{spec.pgram} calculates the periodogram using a fast Fourier
%  transform, and optionally smooths the result with a series of
%  modified Daniell smoothers (moving averages giving half weight to
%  the end values).
%}
%\details{
%  The raw periodogram is not a consistent estimator of the spectral density,
%  but adjacent values are asymptotically independent. Hence a consistent
%  estimator can be derived by smoothing the raw periodogram, assuming that
%  the spectral density is smooth.
%
%  The series will be automatically padded with zeros until the series
%  length is a highly composite number in order to help the Fast Fourier
%  Transform. This is controlled by the \code{fast} and not the \code{pad}
%  argument.
%
%  The periodogram at zero is in theory zero as the mean of the series
%  is removed (but this may be affected by tapering): it is replaced by
%  an interpolation of adjacent values during smoothing, and no value
%  is returned for that frequency.
%}
%\value{
%  A list object of class \code{"spec"} (see \code{\link{spectrum}})
%  with the following additional components:
%  \item{kernel}{The \code{kernel} argument, or the kernel constructed
%    from \code{spans}.}
%  \item{df}{The distribution of the spectral density estimate can be
%    approximated by a (scaled) chi square distribution with \code{df} degrees
%    of freedom.}
%  \item{bandwidth}{The equivalent bandwidth of the kernel smoother as
%    defined by Bloomfield (1976, page 201).}
%  \item{taper}{The value of the \code{taper} argument.}
%  \item{pad}{The value of the \code{pad} argument.}
%  \item{detrend}{The value of the \code{detrend} argument.}
%  \item{demean}{The value of the \code{demean} argument.}
%
%  The result is returned invisibly if \code{plot} is true.
%}
%
%\references{
%  Bloomfield, P. (1976) \emph{Fourier Analysis of Time Series: An
%    Introduction.} Wiley.
%
%  Brockwell, P.J. and Davis, R.A. (1991) \emph{Time Series: Theory and
%    Methods.} Second edition. Springer.
%
%  Venables, W.N. and Ripley, B.D. (2002) \emph{Modern Applied
%    Statistics with S.} Fourth edition. Springer.
%  (Especially pp.\sspace{}392--7.)
%}
%\author{
%  Originally Martyn Plummer; kernel smoothing by Adrian Trapletti,
%  synthesis by B.D. Ripley
%}
%\seealso{\code{\link{spectrum}}, \code{\link{spec.taper}},
%  \code{\link{plot.spec}}, \code{\link{fft}}}
%
%\examples{
%require(graphics)
%
%## Examples from Venables & Ripley
%spectrum(ldeaths)
%spectrum(ldeaths, spans = c(3,5))
%spectrum(ldeaths, spans = c(5,7))
%spectrum(mdeaths, spans = c(3,3))
%spectrum(fdeaths, spans = c(3,3))
%
%## bivariate example
%mfdeaths.spc <- spec.pgram(ts.union(mdeaths, fdeaths), spans = c(3,3))
%# plots marginal spectra: now plot coherency and phase
%plot(mfdeaths.spc, plot.type = "coherency")
%plot(mfdeaths.spc, plot.type = "phase")
%
%## now impose a lack of alignment
%mfdeaths.spc <- spec.pgram(ts.intersect(mdeaths, lag(fdeaths, 4)),
%   spans = c(3,3), plot = FALSE)
%plot(mfdeaths.spc, plot.type = "coherency")
%plot(mfdeaths.spc, plot.type = "phase")
%
%stocks.spc <- spectrum(EuStockMarkets, kernel("daniell", c(30,50)),
%                       plot = FALSE)
%plot(stocks.spc, plot.type = "marginal") # the default type
%plot(stocks.spc, plot.type = "coherency")
%plot(stocks.spc, plot.type = "phase")
%
%sales.spc <- spectrum(ts.union(BJsales, BJsales.lead),
%                      kernel("modified.daniell", c(5,7)))
%plot(sales.spc, plot.type = "coherency")
%plot(sales.spc, plot.type = "phase")
%}
%\keyword{ts}
%
%\encoding{UTF-8}
%
