% File src/library/stats/man/step.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{step}
\alias{step}%@%\alias{ステップ毎の AIC モデル選択}
\title{
Choose a model by AIC in a Stepwise Algorithm
}
\description{
  AIC で公式ベースのモデルを選択．
}
\usage{
step(object, scope, scale = 0,
     direction = c("both", "backward", "forward"),
     trace = 1, keep = NULL, steps = 1000, k = 2, \dots)
}
\arguments{
  \item{object}{
    適当なクラスのモデルを表すオブジェクト
    (主に \code{"lm"} と \code{"glm"})．
    これはステップワイズの探索の初期モデルとして使われる．
  }
  \item{scope}{
    ステップワイズの探索で調べられるモデルの範囲を定義する．
    の初期モデルとして使われる．
    これは単一の公式であるか，又は共に公式である
    \code{upper} と \code{lower} である．
    公式をどのように指定するかとそれらがどのように使われるかについては
    詳細節を見よ．
  }
  \item{scale}{
    モデル選択に対する AIC 統計量の定義で使われ，
    現在 \code{\link{lm}}, \code{\link{aov}} そして
    \code{\link{glm}} モデルに対してだけである．
    既定値 \code{0} はスケールは推定されることを指示する：
    \code{\link{extractAIC}} を見よ．
  }
  \item{direction}{
    ステップワイズ探索のモードで，
    \code{"both"}, \code{"backward"} 又は \code{"forward"} のどれかで，
    既定では \code{"both"}．もし \code{scope} 引数がなければ
    \code{direction} に対する既定は \code{"backward"}．
    値は短縮化出来る．
  }
  \item{trace}{
    もし正ならば
    \code{step} の実行中に情報がプリントされる．
    値が大きいほどより詳細な情報が与えられる．
  }
  \item{keep}{
    入力が当てはめモデルオブジェクトと関連する
    \code{AIC} 統計量であるフィルター関数で，その出力は任意である．
    典型的には \code{keep} はオブジェクトの成分の一部分を選びそれらを返す．
    既定は何も保存しない．
  }
  \item{steps}{
    考慮される最大ステップ数．
    既定値は 1000 (本質的に必要なだけ大きくて良い)．これは典型的に過程を
    早めに停止するのに使われる．
  }
  \item{k}{
    ペナルティーとして使われる自由度数の倍数．
    \code{k = 2} だけが真正の AIC を与える：
    \code{k = log(n)} はある場合には BIC や SBC と参照される．
  }
  \item{\dots}{
    \code{\link{extractAIC}} に対する任意の追加引数．
  }
}
\value{
  最大二つの追加成分を持つステップワイズ選択モデルが返される．
  \code{"anova"} 成分は探索中に取られたステップに対応し，
  \code{keep=} 引数が呼び出し中に提供されると
  同じく \code{"keep"} 成分もある．
  \code{"Resid. Dev"} 逸脱度分析表の列は
  定数から最大対数尤度の2倍を引いたものを参照する：
  これは飽和モデルが上手く定義できる時だけ逸脱度になる
  (これは例えば \code{lm}, \code{aov} そして \code{survreg} 当てはめを除外する)．
}
\details{
  \code{step} は \code{\link{add1}} と \code{\link{drop1}} を繰り返し使う：
  これはこれらが動作する任意のメソッドに対して使え，
  \code{\link{extractAIC}} に対する適正なメソッドを持つことで
  決定される．
  加法定数が
  AIC が Mallows の \eqn{C_p}{Cp} になるように選ぶことが出来る時には，
  そうされ表は適当にラベルが付く．

  探されるモデルのセットは
  \code{scope} 引数で決定される．
  その \code{lower} 成分の右側は常にモデルに含まれ，
  モデルの右側は \code{upper} 成分に含まれる．
  もし \code{scope} が単一の公式なら，
  それは \code{upper} 成分を指定し，
  \code{lower} モデルは空である．
  もし \code{scope} がなければ，初期モデルが
  \code{upper} モデルとして使われる．

  \code{scope} で指定されるモデルは
  \code{\link{update.formula}} で使われるような
  \code{object} の更新のテンプレートになり得る．
  従って \code{scope} 公式中での \code{.} の使用は
  \sQuote{既にそこにある物}を意味し，\code{.^2} は既存の項の
  全ての交互作用を意味する．

  逸脱度が単純に最大対数尤度に関係しないような場合，
  \code{scale} をもつ \code{\link{glm}} 当てはめの使用には潜在的な問題がある．
  関数 \code{\link{extractAIC}} に対する \code{"glm"} メソッドは
  \code{gaussian} ファミリに対して適当な補正をするが，他のケースでは
  修正されるとは限らない．
  (\code{binomial} と \code{poisson} ファミリは既定で
  固定された \code{scale} を持ち，変数 \code{scale} に対する
  特定の最大尤度問題に対応しない．)
}
\note{
  この関数は S 中の関数とは相当異なる．後者は
  幾つもの近似を用い，一般には正しい AIC を計算しない．

  これは最小限の実装である．より広いオブジェクトのクラスに対しては
  パッケージ \CRANpkg{MASS} 中の \code{\link[MASS]{stepAIC}} を使おう．
}
\section{警告}{
  モデル当てはめは同じデータセットに適用されなければならない．
  これはもし欠損値があり
  \R の既定の \code{na.action = na.omit} が使われた時は問題になり得る．
  最初に欠損値を取り除いておくことを勧める．

  関数 \code{\link{nobs}} の呼び出しは当てはめ過程で含まれる観測値数が
  変更されていないかどうかをチェックするのに使われる．
}
\seealso{
  パッケージ \CRANpkg{MASS} 中の \code{\link[MASS]{stepAIC}}，\code{\link{add1}},
  \code{\link{drop1}}
}
\references{
  Hastie, T. J. and Pregibon, D. (1992)
  \emph{Generalized linear models.}
  Chapter 6 of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.

  Venables, W. N. and Ripley, B. D. (2002)
  \emph{Modern Applied Statistics with S.}
  New York: Springer (4th ed).
}
\author{
  B. D. Ripley: \code{step} は
  パッケージ \CRANpkg{MASS} 中の \code{\link[MASS]{stepAIC}} の
  少し簡略化されたバージョンである
  (Venables & Ripley, 2002 そして前の版)．

  \code{step} 関数のアイデアは
  Hastie & Pregibon (1992) に説明されたものに従っている：
  しかし \R の移植はより一般的である．
}
\examples{\donttest{
## example(lm) の例に従う
\dontshow{utils::example("lm", echo = FALSE)}
step(lm.D9)

summary(lm1 <- lm(Fertility ~ ., data = swiss))
slm1 <- step(lm1)
summary(slm1)
slm1$anova
}}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/step.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{step}
%\alias{step}
%\title{
%Choose a model by AIC in a Stepwise Algorithm
%}
%\description{
%  Select a formula-based model by AIC.
%}
%\usage{
%step(object, scope, scale = 0,
%     direction = c("both", "backward", "forward"),
%     trace = 1, keep = NULL, steps = 1000, k = 2, \dots)
%}
%\arguments{
%  \item{object}{
%    an object representing a model of an appropriate class (mainly
%    \code{"lm"} and \code{"glm"}).
%    This is used as the initial model in the stepwise search.
%  }
%  \item{scope}{
%    defines the range of models examined in the stepwise search.
%    This should be either a single formula, or a list containing
%    components \code{upper} and \code{lower}, both formulae.  See the
%    details for how to specify the formulae and how they are used.
%  }
%  \item{scale}{
%    used in the definition of the AIC statistic for selecting the models,
%    currently only for \code{\link{lm}}, \code{\link{aov}} and
%    \code{\link{glm}} models.  The default value, \code{0}, indicates
%    the scale should be estimated: see \code{\link{extractAIC}}.
%  }
%  \item{direction}{
%    the mode of stepwise search, can be one of \code{"both"},
%    \code{"backward"}, or \code{"forward"}, with a default of \code{"both"}.
%    If the \code{scope} argument is missing the default for
%    \code{direction} is \code{"backward"}.  Values can be abbreviated.
%  }
%  \item{trace}{
%    if positive, information is printed during the running of \code{step}.
%    Larger values may give more detailed information.
%  }
%  \item{keep}{
%    a filter function whose input is a fitted model object and the
%    associated \code{AIC} statistic, and whose output is arbitrary.
%    Typically \code{keep} will select a subset of the components of
%    the object and return them. The default is not to keep anything.
%  }
%  \item{steps}{
%    the maximum number of steps to be considered.  The default is 1000
%    (essentially as many as required).  It is typically used to stop the
%    process early.
%  }
%  \item{k}{
%    the multiple of the number of degrees of freedom used for the penalty.
%    Only \code{k = 2} gives the genuine AIC: \code{k = log(n)} is sometimes
%    referred to as BIC or SBC.
%  }
%  \item{\dots}{
%    any additional arguments to \code{\link{extractAIC}}.
%  }
%}
%\value{
%  the stepwise-selected model is returned, with up to two additional
%  components.  There is an \code{"anova"} component corresponding to the
%  steps taken in the search, as well as a \code{"keep"} component if the
%  \code{keep=} argument was supplied in the call. The
%  \code{"Resid. Dev"} column of the analysis of deviance table refers
%  to a constant minus twice the maximized log likelihood: it will be a
%  deviance only in cases where a saturated model is well-defined
%  (thus excluding \code{lm}, \code{aov} and \code{survreg} fits,
%  for example).
%}
%\details{
%  \code{step} uses \code{\link{add1}} and \code{\link{drop1}}
%  repeatedly; it will work for any method for which they work, and that
%  is determined by having a valid method for \code{\link{extractAIC}}.
%  When the additive constant can be chosen so that AIC is equal to
%  Mallows' \eqn{C_p}{Cp}, this is done and the tables are labelled
%  appropriately.
%
%  The set of models searched is determined by the \code{scope} argument.
%  The right-hand-side of its \code{lower} component is always included
%  in the model, and right-hand-side of the model is included in the
%  \code{upper} component.  If \code{scope} is a single formula, it
%  specifies the \code{upper} component, and the \code{lower} model is
%  empty.  If \code{scope} is missing, the initial model is used as the
%  \code{upper} model.
%
%  Models specified by \code{scope} can be templates to update
%  \code{object} as used by \code{\link{update.formula}}.  So using
%  \code{.} in a \code{scope} formula means \sQuote{what is
%  already there}, with \code{.^2} indicating all interactions of
%  existing terms.
%
%  There is a potential problem in using \code{\link{glm}} fits with a
%  variable \code{scale}, as in that case the deviance is not simply
%  related to the maximized log-likelihood.  The \code{"glm"} method for
%  function \code{\link{extractAIC}} makes the
%  appropriate adjustment for a \code{gaussian} family, but may need to be
%  amended for other cases.  (The \code{binomial} and \code{poisson}
%  families have fixed \code{scale} by default and do not correspond
%  to a particular maximum-likelihood problem for variable \code{scale}.)
%}
%\note{
%  This function differs considerably from the function in S, which uses a
%  number of approximations and does not in general compute the correct AIC.
%
%  This is a minimal implementation.  Use \code{\link[MASS]{stepAIC}}
%  in package \CRANpkg{MASS} for a wider range of object classes.
%}
%\section{Warning}{
%  The model fitting must apply the models to the same dataset. This
%  may be a problem if there are missing values and \R's default of
%  \code{na.action = na.omit} is used.  We suggest you remove the
%  missing values first.
%
%  Calls to the function \code{\link{nobs}} are used to check that the
%  number of observations involved in the fitting process remains unchanged.
%}
%\seealso{
%  \code{\link[MASS]{stepAIC}} in \CRANpkg{MASS}, \code{\link{add1}},
%  \code{\link{drop1}}
%}
%\references{
%  Hastie, T. J. and Pregibon, D. (1992)
%  \emph{Generalized linear models.}
%  Chapter 6 of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%
%  Venables, W. N. and Ripley, B. D. (2002)
%  \emph{Modern Applied Statistics with S.}
%  New York: Springer (4th ed).
%}
%\author{
%  B. D. Ripley: \code{step} is a slightly simplified version of
%  \code{\link[MASS]{stepAIC}} in package \CRANpkg{MASS} (Venables &
%  Ripley, 2002 and earlier editions).
%
%  The idea of a \code{step} function follows that described in Hastie &
%  Pregibon (1992); but the implementation in \R is more general.
%}
%\examples{\donttest{
%## following on from example(lm)
%\dontshow{utils::example("lm", echo = FALSE)}
%step(lm.D9)
%
%summary(lm1 <- lm(Fertility ~ ., data = swiss))
%slm1 <- step(lm1)
%summary(slm1)
%slm1$anova
%}}
%\keyword{models}
%
%\encoding{UTF-8}
%
