% File src/library/stats/man/stl.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{stl}
\alias{stl}%@%\alias{時系列の季節分解}
% all methods -> ./stlmethods.Rd
\title{Seasonal Decomposition of Time Series by Loess}
\description{
  時系列を季節，トレンド，そして非規則成分に
  \code{loess} を使って分解する．別称 STL．
}
\usage{
stl(x, s.window, s.degree = 0,
    t.window = NULL, t.degree = 1,
    l.window = nextodd(period), l.degree = t.degree,
    s.jump = ceiling(s.window/10),
    t.jump = ceiling(t.window/10),
    l.jump = ceiling(l.window/10),
    robust = FALSE,
    inner = if(robust)  1 else 2,
    outer = if(robust) 15 else 0,
    na.action = na.fail)
}
\arguments{
  \item{x}{分解されるべき一変量時系列．
    これはクラス \code{"ts"} のオブジェクトで1より大きな
    周波数を持たなければならない．}
  \item{s.window}{
    文字列 \code{"periodic"} か
    季節成分取り出しのための loess ウィンドのスパン(ラグ単位)で
    Cleveland et al. に従い奇数で最低でも7でなければならない．
    これは既定値を持たない．}
  \item{s.degree}{
    季節成分取り出しのために局所的に当てはめられる多項式の
    次数．0か1でなければならない．}
  \item{t.window}{
    トレンド取り出しのための loess ウィンドのスパン(ラグ単位)で
    奇数でなければならない．もし既定の \code{NULL} ならば\cr
    \code{nextodd(ceiling((1.5*period) / (1-(1.5/s.window))))}
    とされる．}
  \item{t.degree}{
    トレンド取り出しのための局所当てはめ多項式の次数．
    0か1でなければならない．}
  \item{l.window}{
    各副系列に対して使われるローパスフィルターの
    loess ウィンドのスパン(ラグ単位)．
    既定値は \code{frequency(x)} に等しいか大きい最少の奇数整数．
    これはトレンドと季節成分の間の競合を避けるので推薦されている．
    もし奇数でなければその与えられた値は次の奇数に増やされる．}
  \item{l.degree}{
    副系列のローパスフィルターに対する局所当てはめ多項式の次数．
    0 か 1 でなければならない．}
  \item{s.jump, t.jump, l.jump}{
    それぞれの平滑化の速度を増加させる少なくとも 1 の整数．
    全ての \code{*.jump} 番目の値の間で線形補間が起きる．}
  \item{robust}{
    \code{loess} 過程で頑健な当てはめを使うかどうかを指示する論理値．}
  \item{inner}{整数；
    \sQuote{内部}(後ろ向き当てはめ)繰り返しの数；
    普通非常に少数(2)の繰り返しで十分．}
  \item{outer}{整数；\sQuote{外部}頑健性繰り返しの数．}
  \item{na.action}{欠損値に対する挙動．}
}
\details{
  季節成分は季節副系列(全ての1月の値，等の系列)の
  \emph{loess} 平滑化で見つけられる；
  もし \code{s.window = "periodic"} なら平滑化は実効的に
  平均を取ることで置き換えられる．
  季節値が取り除かれ，残りがトレンドを見つけるために平滑化される．
  全体のレベルが季節成分から取り去られトレンドに加えられる．
  この過程が数回繰り返される．
  \code{remainder} 成分は季節とトレンドの和の残りである．

  結果のクラス \code{"stl"} のオブジェクトに対する幾つかのメソッドについては
  \code{\link{plot.stl}} を見よ．
}
\value{
  \code{stl} は次の成分を持つ
  クラス \code{"stl"} のオブジェクトを返す
  \item{time.series}{成分
    \code{seasonal}, \code{trend} と \code{remainder}
    を持つ多重時系列．}
  \item{weights}{最終的な頑健重み(もし当てはめが頑健に行われなければ
    全てが一つ)．}
  \item{call}{マッチした呼び出し．}
  \item{win}{
    \code{"s"}, \code{"t"} そして \code{"l"} 平滑化に対して
    使われるスパンを持つ整数(長さ3のベクトル)．}
  \item{deg}{
    これらの平滑化に対する多項式の次数を持つ整数(長さ3のベクトル)．}
  \item{jump}{
    これらの平滑化に対する
    \sQuote{ジャンプ} (スキップ)を持つ
    整数(長さ3のベクトル)．}
  \item{ni}{内部繰り返し数．}
  \item{no}{外部頑健繰り返しの数．}
}
\references{
  R. B. Cleveland, W. S. Cleveland, J.E.  McRae, and I. Terpenning (1990)
  STL:  A  Seasonal-Trend  Decomposition  Procedure Based on Loess.
  \emph{Journal of Official Statistics}, \bold{6}, 3--73.
}
\author{B.D. Ripley; 
  \file{netlib} からの Cleveland \emph{et al} (1990) の
  Fortran コード．
}
\note{
  これは S-PLUS の
  \code{stl} 関数に似ているが同一ではない．
  S-PLUS の与える \code{remainder} 成分はこの関数が与える
  \code{trend} と \code{remainder} 系列の和である．
}
\seealso{
  \code{stl} メソッドに対する \code{\link{plot.stl}}． 
  パッケージ \pkg{stats} 中の \code{\link{loess}}
  (これは実際には \code{stl} 中で使われない)．

  別の種類の分解には \code{\link{StructTS}}．
}
\examples{
require(graphics)

plot(stl(nottem, "per"))
plot(stl(nottem, s.window = 7, t.window = 50, t.jump = 1))

plot(stllc <- stl(log(co2), s.window = 21))
summary(stllc)
## 線形トレンド，狭義の周期．
plot(stl(log(co2), s.window = "per", t.window = 1000))

## 二つの STL プロットを横に並べる：
        stmd <- stl(mdeaths, s.window = "per") # 頑健でない
summary(stmR <- stl(mdeaths, s.window = "per", robust = TRUE))
op <- par(mar = c(0, 4, 0, 3), oma = c(5, 0, 4, 0), mfcol = c(4, 2))
plot(stmd, set.pars = NULL, labels  =  NULL,
     main = "stl(mdeaths, s.w = \"per\",  robust = FALSE / TRUE )")
plot(stmR, set.pars = NULL)
# '外れ値'をマークする：
(iO <- which(stmR $ weights  < 1e-8)) # 10 個が外れ値と考えられる
sts <- stmR$time.series
points(time(sts)[iO], 0.8* sts[,"remainder"][iO], pch = 4, col = "red")
par(op)   # リセット
}
\keyword{ts}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/stl.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{stl}
%\alias{stl}
%% all methods -> ./stlmethods.Rd
%\title{Seasonal Decomposition of Time Series by Loess}
%\description{
%  Decompose a time series into seasonal, trend and irregular components
%  using \code{loess}, acronym STL.
%}
%\usage{
%stl(x, s.window, s.degree = 0,
%    t.window = NULL, t.degree = 1,
%    l.window = nextodd(period), l.degree = t.degree,
%    s.jump = ceiling(s.window/10),
%    t.jump = ceiling(t.window/10),
%    l.jump = ceiling(l.window/10),
%    robust = FALSE,
%    inner = if(robust)  1 else 2,
%    outer = if(robust) 15 else 0,
%    na.action = na.fail)
%}
%\arguments{
%  \item{x}{univariate time series to be decomposed.
%    This should be an object of class \code{"ts"} with a frequency
%    greater than one.}
%  \item{s.window}{either the character string \code{"periodic"} or the span (in
%    lags) of the loess window for seasonal extraction, which should
%    be odd and at least 7, according to Cleveland et al.  This has no default.}
%  \item{s.degree}{degree of locally-fitted polynomial in seasonal
%    extraction.  Should be zero or one.}
%  \item{t.window}{the span (in lags) of the loess window for trend
%    extraction, which should be odd.  If \code{NULL}, the default,
%    \code{nextodd(ceiling((1.5*period) / (1-(1.5/s.window))))}, is taken.}
%  \item{t.degree}{degree of locally-fitted polynomial in trend
%    extraction.  Should be zero or one.}
%  \item{l.window}{the span (in lags) of the loess window of the low-pass
%    filter used for each subseries.  Defaults to the smallest odd
%    integer greater than or equal to \code{frequency(x)} which is
%    recommended since it prevents competition between the trend and
%    seasonal components.  If not an odd integer its given value is
%    increased to the next odd one.}
%  \item{l.degree}{degree of locally-fitted polynomial for the subseries
%    low-pass filter.  Must be 0 or 1.}
%  \item{s.jump, t.jump, l.jump}{integers at least one to increase speed of
%    the respective smoother.  Linear interpolation happens between every
%    \code{*.jump}th value.}
%  \item{robust}{logical indicating if robust fitting be used in the
%    \code{loess} procedure.}
%  \item{inner}{integer; the number of \sQuote{inner} (backfitting)
%    iterations; usually very few (2) iterations suffice.}
%  \item{outer}{integer; the number of \sQuote{outer} robustness
%    iterations.}
%  \item{na.action}{action on missing values.}
%}
%\details{
%  The seasonal component is found by \emph{loess} smoothing the
%  seasonal sub-series (the series of all January values, \ldots); if
%  \code{s.window = "periodic"} smoothing is effectively replaced by
%  taking the mean. The seasonal values are removed, and the remainder
%  smoothed to find the trend. The overall level is removed from the
%  seasonal component and added to the trend component. This process is
%  iterated a few times.  The \code{remainder} component is the
%  residuals from the seasonal plus trend fit.
%
%  Several methods for the resulting class \code{"stl"} objects, see,
%  \code{\link{plot.stl}}.
%}
%\value{
%  \code{stl} returns an object of class \code{"stl"} with components
%  \item{time.series}{a multiple time series with columns
%    \code{seasonal}, \code{trend} and \code{remainder}.}
%  \item{weights}{the final robust weights (all one if fitting is not
%    done robustly).}
%  \item{call}{the matched call.}
%  \item{win}{integer (length 3 vector) with the spans used for the \code{"s"},
%    \code{"t"}, and \code{"l"} smoothers.}
%  \item{deg}{integer (length 3) vector with the polynomial degrees for
%    these smoothers.}
%  \item{jump}{integer (length 3) vector with the \sQuote{jumps} (skips)
%    used for these smoothers.}
%  \item{ni}{number of \bold{i}nner iterations}
%  \item{no}{number of \bold{o}uter robustness iterations}
%}
%\references{
%  R. B. Cleveland, W. S. Cleveland, J.E.  McRae, and I. Terpenning (1990)
%  STL:  A  Seasonal-Trend  Decomposition  Procedure Based on Loess.
%  \emph{Journal of Official Statistics}, \bold{6}, 3--73.
%}
%\author{B.D. Ripley; Fortran code by Cleveland \emph{et al} (1990) from
%  \file{netlib}.}
%
%\note{This is similar to but not identical to the \code{stl} function in
%  S-PLUS. The \code{remainder} component given by S-PLUS is the sum of
%  the \code{trend} and \code{remainder} series from this function.}
%
%\seealso{
%  \code{\link{plot.stl}} for \code{stl} methods;
%  \code{\link{loess}} in package \pkg{stats} (which is not actually
%  used in \code{stl}).
%
%  \code{\link{StructTS}} for different kind of decomposition.
%}
%\examples{
%require(graphics)
%
%plot(stl(nottem, "per"))
%plot(stl(nottem, s.window = 7, t.window = 50, t.jump = 1))
%
%plot(stllc <- stl(log(co2), s.window = 21))
%summary(stllc)
%## linear trend, strict period.
%plot(stl(log(co2), s.window = "per", t.window = 1000))
%
%## Two STL plotted side by side :
%        stmd <- stl(mdeaths, s.window = "per") # non-robust
%summary(stmR <- stl(mdeaths, s.window = "per", robust = TRUE))
%op <- par(mar = c(0, 4, 0, 3), oma = c(5, 0, 4, 0), mfcol = c(4, 2))
%plot(stmd, set.pars = NULL, labels  =  NULL,
%     main = "stl(mdeaths, s.w = \"per\",  robust = FALSE / TRUE )")
%plot(stmR, set.pars = NULL)
%# mark the 'outliers' :
%(iO <- which(stmR $ weights  < 1e-8)) # 10 were considered outliers
%sts <- stmR$time.series
%points(time(sts)[iO], 0.8* sts[,"remainder"][iO], pch = 4, col = "red")
%par(op)   # reset
%}
%\keyword{ts}
%
%\encoding{UTF-8}
%
