% File src/library/stats/man/weighted.residuals.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{weighted.residuals}
\alias{weighted.residuals}%@%\alias{重み付き残差}
\title{Compute Weighted Residuals}
\usage{
weighted.residuals(obj, drop0 = TRUE)
}
\arguments{
  \item{obj}{\R オブジェクト，典型的にクラス
  \code{\link{lm}} か \code{\link{glm}}．}
  \item{drop0}{論理値．もし \code{TRUE} なら，
    \code{\link{weights} == 0} である全てのケースを捨てる．}
}
\description{
  線形モデル当てはめから重み付き残差を計算する．
}
\details{
  重み付き残差は逸脱度残差に基づいており，
  \code{\link{lm}} 当てはめに対しては生の残差 \eqn{R_i}{Ri}
  に \eqn{\sqrt{w_i}}{wi^0.5} を掛けたもので，ここで
  \eqn{w_i}{wi} は \code{\link{lm}} の呼び出しで指定された
  \code{weights} である．

  重みがゼロのケースを捨て去ることは
  \code{\link{influence}} や関連関数と一貫性がある．
}
\value{
  長さ \eqn{n'} の数値ベクトルで，\eqn{n'} は
  ゼロでない重みの数(\code{drop0 = TRUE})，さもなければ
  観測値の数．
}
\seealso{\code{\link{residuals}}, \code{\link{lm.influence}}, etc.}
\examples{
## 次は example(lm) から
\dontshow{utils::example("lm", echo = FALSE)}
all.equal(weighted.residuals(lm.D9),
          residuals(lm.D9))
x <- 1:10
w <- 0:9
y <- rnorm(x)
weighted.residuals(lmxy <- lm(y ~ x, weights = w))
weighted.residuals(lmxy, drop0 = FALSE)
}
\keyword{regression}


\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/weighted.residuals.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{weighted.residuals}
%\alias{weighted.residuals}
%\title{Compute Weighted Residuals}
%\usage{
%weighted.residuals(obj, drop0 = TRUE)
%}
%\arguments{
%  \item{obj}{\R object, typically of class \code{\link{lm}} or
%    \code{\link{glm}}.}
%  \item{drop0}{logical.  If \code{TRUE}, drop all cases with
%    \code{\link{weights} == 0}.}
%}
%\description{
%  Computed weighted residuals from a linear model fit.
%}
%\details{
%  Weighted residuals are based on the deviance residuals, which for
%  a \code{\link{lm}} fit are the raw residuals \eqn{R_i}{Ri}
%  multiplied by \eqn{\sqrt{w_i}}{wi^0.5}, where \eqn{w_i}{wi} are the
%  \code{weights} as specified in \code{\link{lm}}'s call.
%
%  Dropping cases with weights zero is compatible with
%  \code{\link{influence}} and related functions.
%}
%\value{
%  Numeric vector of length \eqn{n'}, where \eqn{n'} is the number of
%  of non-0 weights (\code{drop0 = TRUE}) or the number of
%  observations, otherwise.
%}
%\seealso{\code{\link{residuals}}, \code{\link{lm.influence}}, etc.}
%\examples{
%## following on from example(lm)
%\dontshow{utils::example("lm", echo = FALSE)}
%all.equal(weighted.residuals(lm.D9),
%          residuals(lm.D9))
%x <- 1:10
%w <- 0:9
%y <- rnorm(x)
%weighted.residuals(lmxy <- lm(y ~ x, weights = w))
%weighted.residuals(lmxy, drop0 = FALSE)
%}
%\keyword{regression}
%
%
%\encoding{UTF-8}
%
