% File src/library/tools/man/Rd2txt_options.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2010 R Core Team
% Distributed under GPL 2 or later

\name{Rd2txt_options}
%@%\alias{テキストのヘルプの整形オプション}
\alias{Rd2txt_options}
\title{テキストのヘルプの整形オプションの設定}
%\title{Set formatting options for text help}
\description{
この関数はテキストのヘルプの表示に対する様々なオプションを設定する．
}
\usage{
Rd2txt_options(...)
}
\arguments{
  \item{\dots}{名前付きのオプションを含むリスト，又は
  個別の名前付き引数として渡されるオプション．
  現在定義されているものは以下を見よ．}
}
\details{
  この関数はテキスト書式のヘルプを表示するために使われる
  関数 \code{\link{Rd2txt}} に対する様々な整形オプションを永続的に設定する．
  現在定義されているオプションは：
  \describe{
    \item{width}{(既定値 80)：出力ページの幅．}
    \item{minIndent}{(既定値 10)：リスト中で使われる最少インデント量．}
    \item{extraIndent}{(既定値 4)：入れ子のリストの各々のレベル中で使われる余分のインデント量．}
    \item{sectionIndent}{(既定値 5)：節に対するインデントレベル．}
    \item{sectionExtra}{(既定値 2)：入れ子の節の各々に対する余分のインデント量．}
    \item{itemBullet}{(既定値 \code{"* "}，アステリスクは
      UTF-8 と殆どの Windows ロケールでは Unicode のブレットに置き換えられる)：
      項目化されたリスト中でブレットとして使われるシンボル．}
    \item{enumFormat}{：数え上げリスト中で項目番号を整形する関数．}
    \item{showURLs}{(既定値 \code{FALSE}):
      \verb{\href} タグを展開する際 URL を示すかどうか．}
    \item{code_quote}{(既定値 \code{TRUE})：
      \verb{\code} や一重引用符を持つ類似物を表現するかどうか．}
    \item{underline_titles}{既定値 \code{TRUE})：
      節タイトルを下線で(バックスペースを用い)表示するかどうか．}
  }
}
\value{
  引数無しで呼び出されると，全てのオプション設定のリストを返す．
  さもなければ，それは名前付きのオプション設定を変更し不可視で前の値を返す．
}
\author{
Duncan Murdoch
}
\seealso{
\code{\link{Rd2txt}}
}
\examples{
\donttest{
# itemBullet はロケール固有である
saveOpts <- Rd2txt_options()
saveOpts
Rd2txt_options(minIndent = 4)
Rd2txt_options()
Rd2txt_options(saveOpts)
Rd2txt_options()
}
}
\keyword{  documentation  }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/Rd2txt_options.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2010 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Rd2txt_options}
%\alias{Rd2txt_options}
%\title{
%Set formatting options for text help
%}
%\description{
%This function sets various options for displaying text help.
%}
%\usage{
%Rd2txt_options(...)
%}
%\arguments{
%  \item{\dots}{A list containing named options, or
%  options passed as individual named arguments.
%  See below for currently defined ones.}
%}
%\details{
%  This function persistently sets various formatting options for the
%  \code{\link{Rd2txt}} function which is used in displaying text format
%  help.  Currently defined options are:
%  \describe{
%    \item{width}{(default 80):  The width of the output page.}
%    \item{minIndent}{(default 10):  The minimum indent to use in a list.}
%    \item{extraIndent}{(default 4):  The extra indent to use in each
%      level of nested lists.}
%    \item{sectionIndent}{(default 5):  The indent level for a section.}
%    \item{sectionExtra}{(default 2):  The extra indentation for each
%      nested section level.}
%    \item{itemBullet}{(default \code{"* "}, with the asterisk replaced by a
%      Unicode bullet in UTF-8 and most Windows locales):
%      The symbol to use as a bullet in itemized lists.}
%    \item{enumFormat}{:  A function to format item numbers in enumerated lists.}
%    \item{showURLs}{(default \code{FALSE}):  Whether to show URLs when
%      expanding \verb{\href} tags.}
%    \item{code_quote}{(default \code{TRUE}):  Whether to render
%      \verb{\code} and similar with single quotes.}
%    \item{underline_titles}{default \code{TRUE}):  Whether to render
%      section titles with underlines (via backspacing).}
%  }
%}
%\value{
%  If called with no arguments, returns all option settings in a list.
%  Otherwise, it changes the named settings and invisibly returns their
%  previous values.
%}
%\author{
%Duncan Murdoch
%}
%\seealso{
%\code{\link{Rd2txt}}
%}
%\examples{
%\donttest{
%# The itemBullet is locale-specific
%saveOpts <- Rd2txt_options()
%saveOpts
%Rd2txt_options(minIndent = 4)
%Rd2txt_options()
%Rd2txt_options(saveOpts)
%Rd2txt_options()
%}
%}
%\keyword{  documentation  }
%
%\encoding{UTF8}
%