% File src/library/tools/man/Rdiff.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2010-2014 R Core Team
% Distributed under GPL 2 or later

\name{Rdiff}
%@%\alias{出力ファイルの差分}
\alias{Rdiff}
\title{R の出力ファイルの差分}
%\title{Difference R Output Files}
\description{
  二つの \R 出力ファイルを与え，
  ヘッダー，フッタ―そしてその他の違いを除いた
  差分を計算する．
}
\usage{
Rdiff(from, to, useDiff = FALSE, forEx = FALSE,
      nullPointers = TRUE, Log = FALSE)
}
\arguments{
  \item{from, to}{比較されるべきファイルパス．}
  \item{useDiff}{結果の比較に常に \command{diff} を
    使うべきか?}
  \item{forEx}{論理値：ヘッダーを取り除くための
    \file{-Ex.Rout} ファイルに対する追加の除去．}
  \item{nullPointers}{論理値：表示されるポインタのアドレスを比較前に
    \code{0x00000000} に設定するか?}
  \item{Log}{論理値：返り値は見つかった差異のログを含むべきか?}
}
\details{
  
  \command{R CMD BATCH} からの \R の開始バナーと任意のタイミング情報
  は共にパッケージのロードに関する行と共に取り除かれる．
  UTF-8 の装飾的引用符(\code{\link{sQuote}} を見よ)と，
  Windows では，Windows のいわゆる\sQuote{スマート引用符} は単純な
  引用符にマップされる．
  環境のアドレス，コンパイルされたバイトコード，そして
  16進アドレスで表される他の風変わりなタイプ
  (例えば \code{<environment: 0x12345678>}) は
  \code{0x00000000} にマップされる．
  ファイルはそれから行毎に比較される．
  もし同じ行数で \code{useDiff} が偽なら，
  単純な \command{diff -b} 風の食い違いがプリントされる
  (これは後に続く空白や引き続く空白の数の差を無視する．
  さもなければ \command{diff -bw} が編集されたファイルに対して呼び出される．
  (これは全ての空白の違いを無視しようと試みる：
  フラグ \option{-w} は POSIX で要求されないが
  GNU, Solaris そして FreeBSD バージョンではサポートされる．)

  これは圧縮されていない PDF ファイルを比較可能で，生成と修正日付を無視する．
}
\value{
  もし \code{Log} が真なら，成分
  \code{status} (下を見よ)と，差異を説明するもしかすると長さがゼロの文字列 \code{out}
  を持つリスト．

  さも無ければ状態の指示で，
  差異がない時そしてその時だけ \code{0L}．
}

\seealso{
  \command{R CMD Rdiff} として実行されるシェルスクリプト．
}

\keyword{utilities}


\encoding{UTF8}

%% File src/library/tools/man/Rdiff.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2010-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Rdiff}
%\alias{Rdiff}
%\title{Difference R Output Files}
%\description{
%  Given two \R output files, compute differences ignoring headers,
%  footers and some other differences.
%}
%\usage{
%Rdiff(from, to, useDiff = FALSE, forEx = FALSE,
%      nullPointers = TRUE, Log = FALSE)
%}
%\arguments{
%  \item{from, to}{filepaths to be compared}
%  \item{useDiff}{should \command{diff} always be used to compare
%    results?}
%  \item{forEx}{logical: extra pruning for \file{-Ex.Rout} files to
%    exclude the header.}
%  \item{nullPointers}{logical: should the displayed addresses of
%    pointers be set to \code{0x00000000} before comparison?}
%  \item{Log}{logical: should the returned value include a log of
%    differences found?}
%}
%\details{
%  
%  The \R startup banner and any timing information from \command{R CMD
%    BATCH} are removed from both files, together with lines about
%  loading packages.  UTF-8 fancy quotes (see \code{\link{sQuote}}) and
%  on Windows, Windows' so-called \sQuote{smart quotes}, are mapped to
%  a simple quote.  Addresses of environments, compiled bytecode and
%  other exotic types expressed as hex addresses
%  (e.g., \code{<environment: 0x12345678>}) are mapped to
%  \code{0x00000000}.  The files are then compared line-by-line.  If
%  there are the same number of lines and \code{useDiff} is false, a
%  simple \command{diff -b} -like display of differences is printed
%  (which ignores trailing spaces and differences in numbers of
%  consecutive spaces), otherwise \command{diff -bw} is called on the
%  edited files.  (This tries to ignore all differences in whitespace:
%  note that flag \option{-w} is not required by POSIX but is supported
%  by GNU, Solaris and FreeBSD versions.)
%
%  This can compare uncompressed PDF files, ignoring differences in
%  creation and modification dates.
%}
%\value{
%  If \code{Log} is true, a list with components \code{status} (see
%  below) and \code{out}, a character vector of descriptions of
%  differences, possibly of zero length.
%
%  Otherwise, a status indicator, \code{0L} if and only if no differences
%  were found.
%}
%
%\seealso{
%  The shell script run as \command{R CMD Rdiff}.
%}
%
%\keyword{utilities}
%
%\encoding{UTF8}