% File src/library/tools/man/psnice.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2011 R Core Team
% Distributed under GPL 2 or later


\name{psnice}
%@%\alias{プロセス優先度}
\alias{psnice}
%\title{Get or Set the Priority (Niceness) of a Process}
\title{プロセスの優先度(niceness)を得る，設定する．}
\description{
  現在のプロセスまたは一つもしくは複数の他のプロセスの
  プロセスの\sQuote{優先度(niceness)}を得る，設定する．
}
\usage{
psnice(pid = Sys.getpid(), value = NA_integer_)
}
\arguments{
  \item{pid}{正整数：一つまたはそれ以上のプロセスのID：
    既定では \R のセッションプロセスのそれ．}
  \item{value}{設定される優先度，または問い合わせには \code{NA}．}
}
\details{
  POSIX オペレーティングシステムはプロセス優先度の概念を持ち，
  普通 0 から 39 (または 40)で 20 が正常の優先度であり
  (些か混乱させるが)より大きな数値はより低い優先度を意味する．
  更に混乱させることに，
  \sQuote{niceness} 値があり，これは
  優先度が数値的に
  20 を超える量である(これは負になり得る)．
  高い niceness を持つプロセスは正常な優先度よりもより少ない CPU 時間を
  割り当てられる．
  ある種の OS では
  niceness が \code{+19} のプロセスはシステムがさもなければ
  アイドル状態の時だけ実行される．

  \command{top} のような多くの OS ユーティリティは
  niceness ではなく優先度を報告する．
  niceness はユーティリティ
  \file{/usr/bin/renice} により使われる：
  \file{/usr/bin/nice} (そして
  \command{/usr/bin/renice -n})は niceness の\emph{増分}を指定する．

  特権を持ったユーザ(usually普通スーパーユーザ)だけが優先度を低下出来る．

  Windows は少し異なった \sQuote{優先度クラス}の概念を持つ．
  アイドリングの優先度は \code{19}，
  \sQuote{正常未満}は \code{15}, 正常は \code{0}, \sQuote{正常以上}は
  \code{-5} そして\sQuote{実時間}は \code{-10} にマップされる．
  Unix 風システムとは異なり，Windows では非特権的ユーザが優先度クラスを増加できる
  (しかし\sQuote{実時間}の使用は推奨できない)．
}
\value{
  \emph{直前}の優先度値の整数ベクトル．
  何らかの理由で未知なら \code{NA}．
}

\seealso{
  パッケージ \pkg{parallel} 中の様々な関数は
  その優先度の変更が必要かもしれない子プロセスを作る．

  \code{\link{pskill}}.
}

\keyword{ utility }

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/psnice.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2011 R Core Team
%% Distributed under GPL 2 or later
%
%
%\name{psnice}
%\alias{psnice}
%\title{Get or Set the Priority (Niceness) of a Process}
%\description{
%  Get or set the \sQuote{niceness} of the current process, or one or
%  more other processes.
%}
%\usage{
%psnice(pid = Sys.getpid(), value = NA_integer_)
%}
%\arguments{
%  \item{pid}{positive integers: the process IDs of one of more
%    processes: defaults to the \R session process.}
%  \item{value}{The niceness to be set, or \code{NA} for an enquiry.}
%}
%\details{
%  POSIX operating systems have a concept of process priorities, usually
%  from 0 to 39 (or 40) with 20 being a normal priority and (somewhat
%  confusingly) larger numeric values denoting lower priority.  To add to
%  the confusion, there is a \sQuote{niceness} value, the amount by which
%  the priority numerically exceeds 20 (which can be negative).
%  Processes with high niceness will receive less CPU time than those
%  with normal priority.  On some OSes, processes with niceness
%  \code{+19} are only run when the system would otherwise be idle.
%
%  On many OSes utilities such as \command{top} report the priority and
%  not the niceness.  Niceness is used by the utility
%  \file{/usr/bin/renice}: \file{/usr/bin/nice} (and
%  \command{/usr/bin/renice -n}) specifies an \emph{increment} in niceness.
%
%  Only privileged users (usually super-users) can lower the niceness.
%
%  Windows has a slightly different concept of \sQuote{priority
%    classes}.  We have mapped the idle priority to niceness \code{19},
%  \sQuote{below normal} to \code{15}, normal to \code{0}, \sQuote{above
%    normal} to \code{-5} and \sQuote{realtime} to \code{-10}.  Unlike
%  Unix-alikes, a non-privileged user can increase the priority class on
%  Windows (but using \sQuote{realtime} is inadvisable).
%}
%\value{
%  An integer vector of \emph{previous} niceness values,
%  \code{NA} if unknown for any reason.
%}
%
%\seealso{
%  Various functions in package \pkg{parallel} create child processes
%  whose priority may need to be changed.
%
%  \code{\link{pskill}}.
%}
%
%\keyword{ utility }
%
%\encoding{UTF8}
%