% File src/library/tools/man/testInstalledPackage.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2009-2014 R Core Team
% Distributed under GPL 2 or later

\name{testInstalledPackage}
%@%\alias{インストールされたパッケージのテスト}
\alias{testInstalledPackage}
\alias{testInstalledPackages}
\alias{testInstalledBasic}
\alias{TEST_MC_CORES}

%\title{Test Installed Packages}
\title{インストールされたパッケージをテストする}
\description{
  これらの関数はインストールされたパッケージ，または
  全ての基本と推奨パッケージのテストを行う．
}
\usage{
testInstalledPackage(pkg, lib.loc = NULL, outDir = ".",
                     types = c("examples", "tests", "vignettes"),
                     srcdir = NULL, Ropts = "", ...)

testInstalledPackages(outDir = ".", errorsAreFatal = TRUE,
                      scope = c("both", "base", "recommended"),
                      types = c("examples", "tests", "vignettes"),
                      srcdir = NULL, Ropts = "", ...)

testInstalledBasic(scope = c("basic", "devel", "both", "internet"))
}
\arguments{
  \item{pkg}{インストール済みパッケージの名前．}
  \item{lib.loc}{パッケージをその中で探すライブラリのパス．
    \code{\link{library}} を見よ．}
  \item{outDir}{その中に出力ファイルを書き出すディレクトリ：
    これは既に存在しなければならない．}
  \item{types}{実行されるてすとのタイプ．}
  \item{errorsAreFatal}{論理値：テストは最初のエラーで停止すべきか?}
  \item{srcdir}{
    \code{.save} ファイルを探すオプションのディレクトリ．}
  \item{Ropts}{
    例やテストを実行する際 \command{R CMD BATCH} に渡される
    \option{-d valgrind} の様な追加のオプション．}
  \item{\dots}{
    実行されるファイルを準備する際に使われる追加の引数，
    例えば\cr
    \code{commentDontrun} と \code{commentDonttest}．}
  \item{scope}{どのセットがテストされるべきか?  短縮できる．}
}
\details{
  これらのテストはパッケージの例のファイルがインストール済みであることに
  依存している
  (これは既定である)．もしパッケージ固有のテストが
  \file{tests} ディレクトリに見つかるとそれらはテストできる：
  これらは既定ではインストールされていないが，
  もし\cr
  \command{R CMD INSTALL --install-tests} が使われれば
  インストールされる．最後に任意のビニエット中の
  \R コードを取り出すことができ検査できる．

  パッケージのテストは
  \file{outDir} の \file{\var{pkg}-tests} 副ディレクトリ中で
  実行されそこに出力を残す．

  \code{testInstalledBasic} はもしインストール済みならば基本的なテストを実行する．
  これは \code{LC_COLLATE=C} を設定して実行されるべきである：
  関数はこれを設定しようと試みるが
  全ての OS で出来るわけではない．
  英語ではないロケールに対しては
  参考結果からの食い違い減らすために
  環境変数 \env{LANGUAGE} を \samp{en} に
  \env{LC_TIME} を \samp{C} に設定することが望ましい．

  Windows を除いては，もし環境変数 \env{TEST_MC_CORES} を
  1より大きな整数に設定すると
  \code{testInstalledPackages} はその値を並列プロセスの最大数として
  並列でパッケージのテストを実行する．

%#ifdef unix
  (もし Unix ならば) 基本と推奨パッケージに対するパッケージ固有の
  テストは普通インストールされていないが，
  それを行う \command{make install-tests} が提供されている
  (基本テストと並んで)．
%#endif
%#ifdef windows
  (もし Windows ならば) 基本と推奨パッケージに対するパッケージ固有の
  インストールのオプションである．
  されていないが，
  現在テストは完全なレポートのため
  もし簡単な食い違い以上のものが見つかると
  Unix 風の \code{diff} を必要とする．
%#endif
}
\value{
  成功なら \code{0L}，失敗なら \code{1L} を不可視で返す．
}
\keyword{utilities}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/testInstalledPackage.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2009-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{testInstalledPackage}
%\alias{testInstalledPackage}
%\alias{testInstalledPackages}
%\alias{testInstalledBasic}
%\alias{TEST_MC_CORES}
%
%\title{Test Installed Packages}
%\description{
%  These functions allow an installed package to be tested, or all base
%  and recommended packages.
%}
%\usage{
%testInstalledPackage(pkg, lib.loc = NULL, outDir = ".",
%                     types = c("examples", "tests", "vignettes"),
%                     srcdir = NULL, Ropts = "", ...)
%
%testInstalledPackages(outDir = ".", errorsAreFatal = TRUE,
%                      scope = c("both", "base", "recommended"),
%                      types = c("examples", "tests", "vignettes"),
%                      srcdir = NULL, Ropts = "", ...)
%
%testInstalledBasic(scope = c("basic", "devel", "both", "internet"))
%}
%\arguments{
%  \item{pkg}{name of an installed package.}
%  \item{lib.loc}{library path(s) in which to look for the package.  See
%    \code{\link{library}}.}
%  \item{outDir}{the directory into which to write the output files: this
%    should already exist.}
%  \item{types}{type(s) of tests to be done.}
%  \item{errorsAreFatal}{logical: should testing terminate at the first
%    error?}
%  \item{srcdir}{Optional directory to look for \code{.save} files.}
%  \item{Ropts}{Additional options such as \option{-d valgrind} to be
%    passed to \command{R CMD BATCH} when running examples or tests.}
%  \item{\dots}{additional arguments use when preparing the files to be
%    run, e.g.\sspace{}\code{commentDontrun} and \code{commentDonttest}.}
%  \item{scope}{Which set(s) should be tested?  Can be abbreviated.}
%}
%\details{
%  These tests depend on having the package example files installed (which
%  is the default).  If package-specific tests are found in a
%  \file{tests} directory they can be tested: these are not
%  installed by default, but will be if
%  \command{R CMD INSTALL --install-tests} was used.  Finally, the \R
%  code in any vignettes can be extracted and tested.
%
%  Package tests are run in a \file{\var{pkg}-tests} subdirectory of
%  \file{outDir}, and leave their output there.
%
%  \code{testInstalledBasic} runs the basic tests, if installed.  This
%  should be run with \code{LC_COLLATE=C} set: the function tries to set
%  this by it may not work on all OSes.  For non-English locales it may
%  be desirable to set environment variables \env{LANGUAGE} to \samp{en}
%  and \env{LC_TIME} to \samp{C} to reduce the number of differences from
%  reference results.
%
%  Except on Windows, if the environment variable \env{TEST_MC_CORES} is
%  set to an integer greater than one, \code{testInstalledPackages} will
%  run the package tests in parallel using its value as the maximum
%  number of parallel processes.
%
%#ifdef unix
%  The package-specific tests for the base and recommended packages are
%  not normally installed, but \command{make install-tests} is provided
%  to do so (as well as the basic tests).
%#endif
%#ifdef windows
%  The package-specific tests for the base and recommended packages are
%  an optional part of the install.
%  Currently testing requires a Unix-like \code{diff} for a full report
%  if more than simple differences are found.
%#endif
%}
%\value{
%  Invisibly \code{0L} for success, \code{1L} for failure.
%}
%\keyword{utilities}
%
%\encoding{UTF8}
%