% File src/library/tools/man/texi2dvi.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2016 R Core Team
% Distributed under GPL 2 or later

\name{texi2dvi}
\alias{texi2dvi}
%@%\alias{LaTeX ファイルのコンパイル}
\alias{texi2pdf}
\title{LaTeX ファイルをコンパイルする}
%\title{Compile LaTeX Files}
\description{
  dvi または PDF ファイルを作るため全ての相互参照が解決されるまで
  \code{latex}/\code{pdflatex}, \code{makeindex} そして \code{bibtex}
  を実行する．
}
\usage{
texi2dvi(file, pdf = FALSE, clean = FALSE, quiet = TRUE,
         texi2dvi = getOption("texi2dvi"),
         texinputs = NULL, index = TRUE)

texi2pdf(file, clean = FALSE, quiet = TRUE,
         texi2dvi = getOption("texi2dvi"),
         texinputs = NULL, index = TRUE)
}
\arguments{
  \item{file}{文字列．LaTeX ソースファイルの名前．}
  \item{pdf}{論理値．もし \code{TRUE} なら既定の
    dvi ファイルの代わりに PDF ファイルを作る 
    (\code{texi2dvi} のコマンドラインオプション \option{--pdf})．}
  \item{clean}{論理値．もし \code{TRUE} なら変換中に作られた全ての
    補助ファイルは取り除かれる．}
  \item{quiet}{論理値．エラーが起きない限り出力はない．}
  \item{texi2dvi}{文字列(または \code{NULL})．
    TeX ファイルを dvi や PDF にコンパイルするのに使われるスクリプトや
    プログラム．既定
    (\code{""} や \code{"texi2dvi"} や \code{NULL} で選択される)では
    パス上の \file{texi2dvi} という名前のプログラムかスクリプトを探し，
    さもなければスクリプトを
    \code{system2} 呼び出しを使いエミュレートする
    (これは値 \code{"emulation"} で選択できる)．
    \sQuote{詳細}節も見よ．} 
  \item{texinputs}{
    \code{NULL} または LaTeX と bibtex 入力の検索パスに付け加えるパスの
    文字列ベクトル．}
  \item{index}{論理値：索引を用意すべきか?}
}
\details{
  \code{texi2pdf} は通常のケース
  \code{texi2dvi(pdf = TRUE)} に対するラッパである．

  名前にもかかわらず，これは
  \R では LaTeX ファイルをコンパイルするために使われる，
  特にビニエットから作られたものや
  \code{\link{Rd2pdf}} スクリプト(パッケージの参照マニュアルに対して
  使われる)．
  これは \file{\var{\link{R_HOME}}/share/texmf} ディレクトリが
  \env{TEXINPUTS} パスにあることを保証するので，
  \file{Sweave} と \file{Rd} といった
  \R のスタイルファイルが見つかる．
  使用される TeX の検索パスは最初に
  既存の \env{TEXINPUTS} 設定(もし未設定なら現在のディレクトリ)，
  それから引数 \code{texinputs} の要素，そして
  \file{\var{R_HOME}/share/texmf} そして最後に既定のパスである．
  同様に \env{BIBINPUTS} と \env{BSTINPUTS} 設定に変更が加えられる．

%#ifdef unix
  (Unix の場合)
  \code{texi2dvi} に対する既定オプションは環境変数
  \env{R_TEXI2DVICMD} から設定され，それに対する既定は
  環境変数 \env{TEXI2DVI} から設定され，もしそれが未設定なら
  \R がコンフィギュレーションされた時の値から選ばれる．
  
  %% issues included not re-running latex in texinfo 6.1 and bashisms in
  %% the /bin/sh script in <= 6.0.
  シェルスクリプト \command{texi2dvi} は GNU の \pkg{texinfo} の一部分である．
  リリースされたバージョンには幾つかの問題が見られるので，
  もし自分のものが正しく動作しなければ\cr
  \env{R_TEXI2DVICMD=emulation} を試みよ．
%#endif

%#ifdef windows
  (Windows の場合) Windows ではオプション \code{"texi2dvi"} は
  普通設定されない．MiKTeX の命令 \command{texify.exe} は
  \code{texi2dvi} に対して適当な選択であり，,
   引数が空か \code{NULL} で
  \code{texi2dvi} というプログラムやスクリプトが見つからなければ
  \R 3.2.3 以来試みられる．

  MiKTeX は Sept 2015 までは \code{texi2dvi} 実行ファイルを持っていたが，
  我々の知る他の Windows の TeX のインストールは持っていないので，
  エミュレーションが例えば Windows の
  TeXLive インストールで使われる．
%#endif

  時おり索引は適正な入力であっても索引作成を失敗させる
  特殊文字を含んでいる
  (特に \samp{hyperref} LaTeX パッケージを使う時)．
  引数 \code{index = FALSE} はこれが起きた時パッケージマニュアル
  を作ることを許すために提供されている．
}

\note{
  %% configure just looks for a texi2dvi command and does not check its
  %% version.  Howvever, it is normally distributed with texinfo, and
  %% that is checked to be >= 5.1.
  %% The OS X distribution by default installs /usr/local/bin/texi2dvi,
  %% but that is optional and OS X has /usr/bin/texi2dvi stuck at 4.8.
  Unix 風システムには
  \command{texi2dvi} スクリプトの様々なバージョンがあるが，
  極めて多くのバグが見つかっており，この \R ラッパはそのうちの幾つかの
  応急処置を与える．

  \command{texi2dvi} のバージョン \code{4.8}
  (OS X で提供される)で存在したものの一つは空白を含む
  パスに対しては正しく動作せず，ファイルへの絶対パスが空白を
  含んでも正しく動作しないことであった．

  三つの可能なアプローチは皆それぞれの癖を持っている．
  例えば Unix 風システムでは \code{texi2dvi} スクリプトは既存の補助ファイルを
  全て取り除くが，他の二つのアプローチはそうしない
  (そしてそうしたファイルで混乱させられるかもしれない)．
  
  もしサポートされているならば(\command{texi2dvi} 5.0 とそれ以降；
  MiKTeX からの \command{texify.exe})，オプション \option{--max-iterations=20}
  が無限の再実行を避けるために使われる．
  
  エミュレーションモードは \R 3.2.3 からのみ \code{quiet = TRUE}
  をサポートしている．現在 \code{clean = TRUE} はこのモード中で
  変換が成功した時だけ掃除を行う---これはユーザにエラー時にログファイルを
  吟味する機会を与える．
  
  全てのアプローチは対応する命令への完全なパスに対する環境変数
  \env{LATEX}, \env{PDFLATEX}, \env{MAKEINDEX} そして \env{BIBTEX} を
  尊重すべきである．
}
\value{
  不可視の \code{NULL}．現在の作業ディレクトリ中に
  dvi または PDF ファイルを作る副作用のために使われる
  (そして恐らくもし特に \code{clean = FALSE} ならば他のファイルも)．
}
\author{
  オリジナルは Achim Zeileis であるが
  R-core により大幅に書き換えられた．
}
\keyword{utilities}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/tools/man/texi2dvi.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2016 R Core Team
%% Distributed under GPL 2 or later
%
%\name{texi2dvi}
%\alias{texi2dvi}
%\alias{texi2pdf}
%\title{Compile LaTeX Files}
%\description{
%  Run \code{latex}/\code{pdflatex}, \code{makeindex} and \code{bibtex}
%  until all cross-references are resolved to create a dvi or a PDF file.
%}
%\usage{
%texi2dvi(file, pdf = FALSE, clean = FALSE, quiet = TRUE,
%         texi2dvi = getOption("texi2dvi"),
%         texinputs = NULL, index = TRUE)
%
%texi2pdf(file, clean = FALSE, quiet = TRUE,
%         texi2dvi = getOption("texi2dvi"),
%         texinputs = NULL, index = TRUE)
%}
%\arguments{
%  \item{file}{character string.  Name of the LaTeX source file.}
%  \item{pdf}{logical.  If \code{TRUE}, a PDF file is produced instead of
%    the default dvi file (\code{texi2dvi} command line option \option{--pdf}).}
%  \item{clean}{logical.  If \code{TRUE}, all auxiliary files created
%    during the conversion are removed.}
%  \item{quiet}{logical.  No output unless an error occurs.}
%  \item{texi2dvi}{character string (or \code{NULL}).  Script or program
%    used to compile a TeX file to dvi or PDF. The default (selected
%    by \code{""} or \code{"texi2dvi"} or \code{NULL}) is to look
%    for a program or script named \file{texi2dvi} on the path and
%    otherwise emulate the script with \code{system2} calls (which
%    can be selected by the value \code{"emulation"}).  See also
%    \sQuote{Details}.} 
%  \item{texinputs}{\code{NULL} or a character vector of paths to add to
%    the LaTeX and bibtex input search paths.}
%  \item{index}{logical: should indices be prepared?}
%}
%\details{
%  \code{texi2pdf} is a wrapper for the common case of
%  \code{texi2dvi(pdf = TRUE)}.
%
%  Despite the name, this is used in \R to compile LaTeX files,
%  specifically those generated from vignettes and by the
%  \code{\link{Rd2pdf}} script (used for package reference manuals).  It
%  ensures that the \file{\var{\link{R_HOME}}/share/texmf} directory is
%  in the \env{TEXINPUTS} path, so \R style files such as \file{Sweave}
%  and \file{Rd} will be found.  The TeX search path used is first the
%  existing \env{TEXINPUTS} setting (or the current directory if unset),
%  then elements of argument \code{texinputs}, then
%  \file{\var{R_HOME}/share/texmf} and finally the default path.
%  Analogous changes are made to \env{BIBINPUTS} and \env{BSTINPUTS}
%  settings.
%
%#ifdef unix
%  The default option for \code{texi2dvi} is set from environment variable
%  \env{R_TEXI2DVICMD}, and the default for that is set from environment
%  variable \env{TEXI2DVI} or if that is unset, from a value chosen when
%  \R is configured.
%  
%  %% issues included not re-running latex in texinfo 6.1 and bashisms in
%  %% the /bin/sh script in <= 6.0.
%  A shell script \command{texi2dvi} is part of GNU's \pkg{texinfo}.
%  Several issues have been seen with released versions, so if yours does
%  not work correctly try \env{R_TEXI2DVICMD=emulation}.
%#endif
%
%#ifdef windows
%  On Windows the option \code{"texi2dvi"} is normally unset.  The MiKTeX
%  command \command{texify.exe} is a suitable choice for \code{texi2dvi},
%  and is tried as from \R 3.2.3 if the argument is blank or \code{NULL}
%  and a program or script \code{texi2dvi} is not found.
%
%  MiKTeX had a \code{texi2dvi} executable until Sept 2015, but no other
%  Windows TeX installation that we know of does, so emulation is used on
%  e.g.\sspace{}TeXLive installations on Windows.
%#endif
%
%  Occasionally indices contain special characters which cause indexing
%  to fail (particularly when using the \samp{hyperref} LaTeX package)
%  even on valid input.  The argument \code{index = FALSE} is provided to
%  allow package manuals to be made when this happens: it uses emulation.
%}
%
%\note{
%  %% configure just looks for a texi2dvi command and does not check its
%  %% version.  Howvever, it is normally distributed with texinfo, and
%  %% that is checked to be >= 5.1.
%  %% The OS X distribution by default installs /usr/local/bin/texi2dvi,
%  %% but that is optional and OS X has /usr/bin/texi2dvi stuck at 4.8.
%  There are various versions of the \command{texi2dvi} script on
%  Unix-alikes and quite a number of bugs have been seen, some of which
%  this \R wrapper works around.
%
%  One that was present with \command{texi2dvi} version \code{4.8} (as
%  supplied by OS X) is that it will not work correctly for paths which
%  contain spaces, nor if the absolute path to a file would contain
%  spaces.
%
%  The three possible approaches all have their quirks.  For example the
%  Unix-alike \code{texi2dvi} script removes ancillary files that already
%  exist but the other two approaches do not (and may get confused by
%  such files).
%  
%  Where supported (\command{texi2dvi} 5.0 and later;
%  \command{texify.exe} from MiKTeX), option \option{--max-iterations=20}
%  is used to avoid infinite retries.
%  
%  The emulation mode supports \code{quiet = TRUE} from \R 3.2.3 only.
%  Currently \code{clean = TRUE} only cleans up in this mode if the
%  conversion was successful---this gives users a chance to examine log
%  files in the event of error.
%  
%  All the approaches should respect the values of environment variables
%  \env{LATEX}, \env{PDFLATEX}, \env{MAKEINDEX} and \env{BIBTEX} for the
%  full paths to the corresponding commands.
%}
%\value{
%  Invisible \code{NULL}.  Used for the side effect of creating a dvi or
%  PDF file in the current working directory (and maybe other files,
%  especially if \code{clean = FALSE}).
%}
%\author{
%  Originally Achim Zeileis but largely rewritten by R-core.
%}
%\keyword{utilities}
%
%\encoding{UTF8}
%